@@ -41,7 +41,7 @@ from sage.algebras.quantum_groups.q_numbers import q_factorial
 
 class FockSpaceOptions(GlobalOptions):
     r"""
-    Sets and displays the global options for elements of the Fock
+    Set and display the global options for elements of the Fock
     space classes.  If no parameters are set, then the function
     returns a copy of the options dictionary.
 
@@ -444,7 +444,7 @@ class FockSpace(Parent, UniqueRepresentation):
 
         INPUT:
 
-        - ``verbose`` -- boolean (default ``True``) if ``True``, prints
+        - ``verbose`` -- boolean (default: ``True``); if ``True``, prints
           the defined shorthands
 
         EXAMPLES::
@@ -749,7 +749,7 @@ class FockSpace(Parent, UniqueRepresentation):
                     return (sum(1 for y in P._addable(la, i) if P._above(x, y))
                             - sum(1 for y in P._removable(la, i) if P._above(x, y)))
                 q = P.realization_of()._q
-                return P.sum_of_terms(( la.remove_cell(*x), c * q**(-N_left(la, x, i)) )
+                return P.sum_of_terms((la.remove_cell(*x), c * q**(-N_left(la, x, i)))
                                       for la,c in self for x in P._removable(la, i))
 
             def e(self, *data):
@@ -759,7 +759,7 @@ class FockSpace(Parent, UniqueRepresentation):
 
                 INPUT:
 
-                - ``*data`` -- a list of indices or pairs `(i, p)`
+                - ``*data`` -- list of indices or pairs `(i, p)`
 
                 EXAMPLES::
 
@@ -845,8 +845,8 @@ class FockSpace(Parent, UniqueRepresentation):
                     return (sum(1 for y in P._addable(la, i) if P._above(y, x))
                             - sum(1 for y in P._removable(la, i) if P._above(y, x)))
                 q = P.realization_of()._q
-                return P.sum_of_terms( (la.add_cell(*x), c * q**N_right(la, x, i))
-                                       for la,c in self for x in P._addable(la, i) )
+                return P.sum_of_terms((la.add_cell(*x), c * q**N_right(la, x, i))
+                                       for la,c in self for x in P._addable(la, i))
 
             def f(self, *data):
                 r"""
@@ -855,7 +855,7 @@ class FockSpace(Parent, UniqueRepresentation):
 
                 INPUT:
 
-                - ``*data`` -- a list of indices or pairs `(i, p)`
+                - ``*data`` -- list of indices or pairs `(i, p)`
 
                 EXAMPLES::
 
@@ -1384,7 +1384,7 @@ class FockSpace(Parent, UniqueRepresentation):
 
 
 ###############################################################################
-## Bases Category
+# Bases Category
 
 class FockSpaceBases(Category_realization_of_parent):
     r"""
@@ -1605,7 +1605,7 @@ class FockSpaceBases(Category_realization_of_parent):
             return self.monomial(i)
 
 ###############################################################################
-## Truncated Fock space
+# Truncated Fock space
 
 
 class FockSpaceTruncated(FockSpace):
@@ -1751,7 +1751,7 @@ class FockSpaceTruncated(FockSpace):
             self._removable = lambda la,i: [x for x in la.corners()
                                             if la.content(*x, multicharge=F._multicharge) == i]
 
-            indices = Partitions(F._n, max_length=F._k)
+            indices = Partitions(max_length=F._k)
             CombinatorialFreeModule.__init__(self, F.base_ring(), indices,
                                              prefix='', bracket=['|', '>'],
                                              latex_bracket=['\\lvert', '\\rangle'],
@@ -1819,7 +1819,7 @@ class FockSpaceTruncated(FockSpace):
 
         INPUT:
 
-        - ``algorithm`` -- (default ``'GW'``) the algorithm to use when
+        - ``algorithm`` -- (default: ``'GW'``) the algorithm to use when
           computing this basis in the Fock space; the possible values are:
 
           * ``'GW'`` -- use the algorithm given by Goodman and Wenzl
@@ -2020,7 +2020,7 @@ class FockSpaceTruncated(FockSpace):
 
             # For non-interior partitions
             # Construct the d's and the partition ``a``
-            a = list(la) + [0]*(k - 1 - len(la)) # Add 0's to get the correct length
+            a = list(la) + [0]*(k - 1 - len(la)) # Add 0s to get the correct length
             a = [a[i] + (k - 1 - i) for i in range(k-1)] # Shift the diagram
             #shifted = list(a) # Make a copy of the shifted partition in case we need it later
             d = [(a[i] - a[i+1]) % n for i in range(k-2)]
@@ -2178,7 +2178,7 @@ class FockSpaceTruncated(FockSpace):
                     mu = _Partitions([p - x for p in la])
 
                     def add_cols(nu):
-                        return _Partitions([ v + x for v in list(nu) + [0]*(k - len(nu)) ])
+                        return _Partitions([v + x for v in list(nu) + [0]*(k - len(nu))])
                     return fock.sum_of_terms((add_cols(nu), c) for nu,c in self._G_to_fock_basis(mu))
 
                 # For critical partitions
