@@ -1,3 +1,4 @@
+# sage_setup: distribution = sagemath-categories
 r"""
 Examples of semigroups
 """
@@ -15,6 +16,7 @@ from sage.structure.element_wrapper import ElementWrapper
 from sage.categories.semigroups import Semigroups
 from sage.sets.family import Family
 
+
 class LeftZeroSemigroup(UniqueRepresentation, Parent):
     r"""
     An example of a semigroup.
@@ -68,7 +70,7 @@ class LeftZeroSemigroup(UniqueRepresentation, Parent):
     """
     def __init__(self):
         r"""
-        The left zero semigroup
+        The left zero semigroup.
 
         EXAMPLES::
 
@@ -83,18 +85,16 @@ class LeftZeroSemigroup(UniqueRepresentation, Parent):
 
     def _repr_(self):
         r"""
-
         EXAMPLES::
 
             sage: Semigroups().example()._repr_()
             'An example of a semigroup: the left zero semigroup'
-
         """
         return "An example of a semigroup: the left zero semigroup"
 
     def product(self, x, y):
         r"""
-        Returns the product of ``x`` and ``y`` in the semigroup, as per
+        Return the product of ``x`` and ``y`` in the semigroup, as per
         :meth:`Semigroups.ParentMethods.product`.
 
         EXAMPLES::
@@ -104,7 +104,6 @@ class LeftZeroSemigroup(UniqueRepresentation, Parent):
             'hello'
             sage: S(3)*S(1)*S(2)
             3
-
         """
         assert x in self
         assert y in self
@@ -112,25 +111,23 @@ class LeftZeroSemigroup(UniqueRepresentation, Parent):
 
     def an_element(self):
         r"""
-        Returns an element of the semigroup.
+        Return an element of the semigroup.
 
         EXAMPLES::
 
             sage: Semigroups().example().an_element()
             42
-
         """
         return self(42)
 
     def some_elements(self):
         r"""
-        Returns a list of some elements of the semigroup.
+        Return a list of some elements of the semigroup.
 
         EXAMPLES::
 
             sage: Semigroups().example().some_elements()
             [3, 42, 'a', 3.4, 'raton laveur']
-
         """
         return [self(i) for i in [3, 42, "a", 3.4, "raton laveur"]]
 
@@ -147,7 +144,6 @@ class LeftZeroSemigroup(UniqueRepresentation, Parent):
                 True
                 sage: S(17).is_idempotent()
                 True
-
             """
             return True
 
@@ -184,7 +180,7 @@ class FreeSemigroup(UniqueRepresentation, Parent):
 
         INPUT:
 
-        - ``alphabet`` -- a tuple of strings: the generators of the semigroup
+        - ``alphabet`` -- tuple of strings; the generators of the semigroup
 
         EXAMPLES::
 
@@ -207,13 +203,12 @@ class FreeSemigroup(UniqueRepresentation, Parent):
             sage: from sage.categories.examples.semigroups import FreeSemigroup
             sage: FreeSemigroup(('a','b','c'))._repr_()
             "An example of a semigroup: the free semigroup generated by ('a', 'b', 'c')"
-
         """
-        return "An example of a semigroup: the free semigroup generated by %s"%(self.alphabet,)
+        return "An example of a semigroup: the free semigroup generated by %s" % (self.alphabet,)
 
     def product(self, x, y):
         r"""
-        Returns the product of ``x`` and ``y`` in the semigroup, as per
+        Return the product of ``x`` and ``y`` in the semigroup, as per
         :meth:`Semigroups.ParentMethods.product`.
 
         EXAMPLES::
@@ -221,7 +216,6 @@ class FreeSemigroup(UniqueRepresentation, Parent):
             sage: F = Semigroups().example('free')
             sage: F.an_element() * F('a')^5
             'abcdaaaaa'
-
         """
         assert x in self
         assert y in self
@@ -230,27 +224,25 @@ class FreeSemigroup(UniqueRepresentation, Parent):
     @cached_method
     def semigroup_generators(self):
         r"""
-        Returns the generators of the semigroup.
+        Return the generators of the semigroup.
 
         EXAMPLES::
 
             sage: F = Semigroups().example('free')
             sage: F.semigroup_generators()
             Family ('a', 'b', 'c', 'd')
-
         """
         return Family([self(i) for i in self.alphabet])
 
     def an_element(self):
         r"""
-        Returns an element of the semigroup.
+        Return an element of the semigroup.
 
         EXAMPLES::
 
             sage: F = Semigroups().example('free')
             sage: F.an_element()
             'abcd'
-
         """
         return self(''.join(self.alphabet))
 
@@ -260,7 +252,7 @@ class FreeSemigroup(UniqueRepresentation, Parent):
 
         INPUT:
 
-        - ``x`` -- a string
+        - ``x`` -- string
 
         EXAMPLES::
 
@@ -286,7 +278,6 @@ class FreeSemigroup(UniqueRepresentation, Parent):
             sage: S = Semigroups().Subquotients().example()
             sage: type(S._element_constructor_(17))
             <class 'sage.categories.examples.semigroups.QuotientOfLeftZeroSemigroup_with_category.element_class'>
-
         """
         for a in x:
             assert a in self.alphabet
@@ -301,7 +292,7 @@ class FreeSemigroup(UniqueRepresentation, Parent):
 
 class QuotientOfLeftZeroSemigroup(UniqueRepresentation, Parent):
     r"""
-    Example of a quotient semigroup
+    Example of a quotient semigroup.
 
     EXAMPLES::
 
@@ -366,7 +357,6 @@ class QuotientOfLeftZeroSemigroup(UniqueRepresentation, Parent):
             sage: S = Semigroups().Subquotients().example()
             sage: type(S._element_constructor_(17))
             <class 'sage.categories.examples.semigroups.QuotientOfLeftZeroSemigroup_with_category.element_class'>
-
         """
         return self.retract(self.ambient()(x))
 
@@ -403,20 +393,18 @@ class QuotientOfLeftZeroSemigroup(UniqueRepresentation, Parent):
 
             sage: Semigroups().Subquotients().example()._repr_()
             'An example of a (sub)quotient semigroup: a quotient of the left zero semigroup'
-
         """
         return "An example of a (sub)quotient semigroup: a quotient of the left zero semigroup"
 
     def ambient(self):
         r"""
-        Returns the ambient semigroup.
+        Return the ambient semigroup.
 
         EXAMPLES::
 
             sage: S = Semigroups().Subquotients().example()
             sage: S.ambient()
             An example of a semigroup: the left zero semigroup
-
         """
         return Semigroups().example()
 
@@ -426,7 +414,7 @@ class QuotientOfLeftZeroSemigroup(UniqueRepresentation, Parent):
 
         INPUT:
 
-        - ``x`` -- an element of ``self``.
+        - ``x`` -- an element of ``self``
 
         OUTPUT:
 
@@ -445,14 +433,13 @@ class QuotientOfLeftZeroSemigroup(UniqueRepresentation, Parent):
             100
             sage: S.lift(S(y))
             42
-
         """
         assert x in self
         return x.value
 
     def the_answer(self):
         r"""
-        Returns the Answer to Life, the Universe, and Everything as an
+        Return the Answer to Life, the Universe, and Everything as an
         element of this semigroup.
 
         EXAMPLES::
@@ -460,48 +447,43 @@ class QuotientOfLeftZeroSemigroup(UniqueRepresentation, Parent):
             sage: S = Semigroups().Subquotients().example()
             sage: S.the_answer()
             42
-
         """
         return self.retract(self.ambient()(42))
 
     def an_element(self):
         r"""
-        Returns an element of the semigroup.
+        Return an element of the semigroup.
 
         EXAMPLES::
 
             sage: S = Semigroups().Subquotients().example()
             sage: S.an_element()
             42
-
         """
         return self.the_answer()
 
     def some_elements(self):
         r"""
-        Returns a list of some elements of the semigroup.
+        Return a list of some elements of the semigroup.
 
         EXAMPLES::
 
             sage: S = Semigroups().Subquotients().example()
             sage: S.some_elements()
             [1, 2, 3, 8, 42, 42]
-
         """
         return [self.retract(self.ambient()(i))
                 for i in [1, 2, 3, 8, 42, 100]]
 
     def retract(self, x):
         r"""
-        Returns the retract ``x`` onto an element of this semigroup.
+        Return the retract ``x`` onto an element of this semigroup.
 
         INPUT:
 
-        - ``x`` -- an element of the ambient semigroup (``self.ambient()``).
+        - ``x`` -- an element of the ambient semigroup (``self.ambient()``)
 
-        OUTPUT:
-
-        - an element of ``self``.
+        OUTPUT: an element of ``self``
 
         EXAMPLES::
 
@@ -518,7 +500,6 @@ class QuotientOfLeftZeroSemigroup(UniqueRepresentation, Parent):
 
             sage: S.retract(L(171)) in S
             True
-
         """
         from sage.rings.integer_ring import ZZ
         assert x in self.ambient() and x.value in ZZ
@@ -533,7 +514,7 @@ class QuotientOfLeftZeroSemigroup(UniqueRepresentation, Parent):
 class IncompleteSubquotientSemigroup(UniqueRepresentation,Parent):
     def __init__(self, category=None):
         r"""
-        An incompletely implemented subquotient semigroup, for testing purposes
+        An incompletely implemented subquotient semigroup, for testing purposes.
 
         EXAMPLES::
 
@@ -585,14 +566,13 @@ class IncompleteSubquotientSemigroup(UniqueRepresentation,Parent):
 
     def ambient(self):
         r"""
-        Returns the ambient semigroup.
+        Return the ambient semigroup.
 
         EXAMPLES::
 
             sage: S = Semigroups().Subquotients().example()
             sage: S.ambient()
             An example of a semigroup: the left zero semigroup
-
         """
         return Semigroups().example()
 
