@@ -38,6 +38,9 @@ class FiniteDimensionalAlgebrasWithBasis(CategoryWithAxiom_over_base_ring):
     r"""
     The category of finite dimensional algebras with a distinguished basis.
 
+    These algebras are assumed to be associative and
+    unital.
+
     EXAMPLES::
 
         sage: C = FiniteDimensionalAlgebrasWithBasis(QQ); C
@@ -180,14 +183,16 @@ class FiniteDimensionalAlgebrasWithBasis(CategoryWithAxiom_over_base_ring):
                     def product_on_basis(i, j):
                         return B[i] * B[j]
 
+                zero = F.zero()
                 keys = B.keys()
-                cache = [{(i, j): c for i in keys for j, c in product_on_basis(y, i)}
+                cache = [{(i, j): c for i in keys
+                         for j, c in product_on_basis(y, i).monomial_coefficients().items()}
                          for y in keys]
-                mat = [[sum(x.get((j, i), 0) * c for (i,j), c in y.items())
+                mat = [[F.sum(x.get((j, i), zero) * c for (i,j), c in y.items())
                         for x in cache]
                        for y in cache]
 
-                mat = matrix(self.base_ring(), mat)
+                mat = matrix(F, mat)
                 rad_basis = mat.kernel().basis()
 
             else:
@@ -196,10 +201,9 @@ class FiniteDimensionalAlgebrasWithBasis(CategoryWithAxiom_over_base_ring):
                 # some only have a ``nth_root`` element such as ``GF(2)``
                 # I imagine that ``pth_root`` would be fastest, but it is not
                 # always available....
-                if hasattr(self.base_ring().one(), 'nth_root'):
+                if hasattr(F.one(), 'nth_root'):
                     def root_fcn(s, x):
                         return x.nth_root(s)
-
                 else:
                     def root_fcn(s, x):
                         return x ** (1 / s)
@@ -419,6 +423,9 @@ class FiniteDimensionalAlgebrasWithBasis(CategoryWithAxiom_over_base_ring):
             r"""
             Return the subalgebra of ``self`` generated by ``gens``.
 
+            Here, ``gens`` is an iterable containing elements of
+            ``self``.
+
             EXAMPLES::
 
                 sage: # needs sage.modules
@@ -466,6 +473,11 @@ class FiniteDimensionalAlgebrasWithBasis(CategoryWithAxiom_over_base_ring):
             Return the ``side`` ideal of ``self`` generated by ``gens``
             as a submodule.
 
+            Here, ``gens`` is an iterable containing elements of
+            ``self`` or a single element of ``self``,
+            and ``side`` is either ``'left'`` or
+            ``'right'`` or ``'twosided'``.
+
             .. TODO::
 
                 This is not generally compatible with the implementation of
@@ -488,14 +500,16 @@ class FiniteDimensionalAlgebrasWithBasis(CategoryWithAxiom_over_base_ring):
             category = C.Subobjects().or_subcategory(category)
             if gens in self:
                 gens = [self(gens)]
+            else:
+                gens = [self(g) for g in gens]
             if side == 'left':
-                return self.submodule([b * self(g) for b in self.basis() for g in gens],
+                return self.submodule([b * g for b in self.basis() for g in gens],
                                       category=category, *args, **opts)
             if side == 'right':
-                return self.submodule([self(g) * b for b in self.basis() for g in gens],
+                return self.submodule([g * b for b in self.basis() for g in gens],
                                       category=category, *args, **opts)
             if side == 'twosided':
-                return self.submodule([b * self(g) * bp for b in self.basis()
+                return self.submodule([b * g * bp for b in self.basis()
                                        for bp in self.basis() for g in gens],
                                       category=category, *args, **opts)
             raise ValueError("side must be either 'left', 'right', or 'twosided'")
@@ -504,11 +518,17 @@ class FiniteDimensionalAlgebrasWithBasis(CategoryWithAxiom_over_base_ring):
             r"""
             Construct the ``side`` principal ideal generated by ``a``.
 
+            INPUT:
+
+            - ``a`` -- an element
+            - ``side`` -- ``left`` (default) or ``right`` or ``twosided``
+            - ``coerce`` -- ignored, for compatibility with categories
+
             EXAMPLES:
 
             In order to highlight the difference between left and
-            right principal ideals, our first example deals with a non
-            commutative algebra::
+            right principal ideals, our first example deals with a
+            noncommutative algebra::
 
                 sage: # needs sage.graphs sage.modules
                 sage: A = Algebras(QQ).FiniteDimensional().WithBasis().example(); A
@@ -543,12 +563,47 @@ class FiniteDimensionalAlgebrasWithBasis(CategoryWithAxiom_over_base_ring):
                 sage: [B.lift() for B in xA.basis()]                                    # needs sage.graphs sage.modules
                 [x, a, b]
 
+            For another example::
+
+                sage: A = MatrixSpace(QQ, 2)
+                sage: A.basis()
+                Finite family {(0, 0): [1 0]
+                [0 0], (0, 1): [0 1]
+                [0 0], (1, 0): [0 0]
+                [1 0], (1, 1): [0 0]
+                [0 1]}
+                sage: e = list(A.basis())
+                sage: [b.lift() for b in A.principal_ideal(e[0], side="left").basis()]
+                [
+                [1 0]  [0 0]
+                [0 0], [1 0]
+                ]
+                sage: [b.lift() for b in A.principal_ideal(e[0], side="right").basis()]
+                [
+                [1 0]  [0 1]
+                [0 0], [0 0]
+                ]
+                sage: [b.lift() for b in A.principal_ideal(e[0], side="twosided").basis()]
+                [
+                [1 0]  [0 1]  [0 0]  [0 0]
+                [0 0], [0 0], [1 0], [0 1]
+                ]
+
             .. SEEALSO::
 
                 - :meth:`peirce_summand`
             """
-            return self.submodule([(a * b if side == 'right' else b * a)
-                                   for b in self.basis()], *args, **opts)
+            opts.pop("coerce", None)
+            if side == 'right':
+                return self.submodule([a * b
+                                       for b in self.basis()], *args, **opts)
+            if side == 'left':
+                return self.submodule([b * a
+                                       for b in self.basis()], *args, **opts)
+            if side == 'twosided':
+                return self.submodule([b1 * a * b2 for b1 in self.basis()
+                                       for b2 in self.basis()], *args, **opts)
+            raise ValueError("side must be either 'left', 'right', or 'twosided'")
 
         @cached_method
         def orthogonal_idempotents_central_mod_radical(self):
@@ -556,6 +611,11 @@ class FiniteDimensionalAlgebrasWithBasis(CategoryWithAxiom_over_base_ring):
             Return a family of orthogonal idempotents of ``self`` that project
             on the central orthogonal idempotents of the semisimple quotient.
 
+            .. TODO::
+
+                The implementation assumes that the algebra
+                is split over its base field.
+
             OUTPUT:
 
             - a list of orthogonal idempotents obtained by lifting the central
@@ -571,7 +631,7 @@ class FiniteDimensionalAlgebrasWithBasis(CategoryWithAxiom_over_base_ring):
             idempotents of the semisimple quotient of `A`. We
             recursively construct orthogonal idempotents of `A` by the
             following procedure: assuming `(f_i)_{i < n}` is a set of
-            already constructed orthogonal idempotent, we construct
+            already constructed orthogonal idempotents, we construct
             `f_k` by idempotent lifting of `(1-f) g (1-f)`, where `g`
             is any lift of `\overline{e_k}` and `f=\sum_{i<k} f_i`.
 
@@ -680,9 +740,17 @@ class FiniteDimensionalAlgebrasWithBasis(CategoryWithAxiom_over_base_ring):
                 sage: A.idempotent_lift(A.basis()['y'])
                 y
 
-            .. TODO::
+            A less trivial example::
 
-                Add some non trivial example
+                sage: B = DescentAlgebra(QQ, 4).B()
+                sage: a = 1/8*B[[1, 1, 1, 1]] - 1/2*B[[2, 1, 1]] + 1/2*B[[2, 2]]
+                sage: a ** 2 == a  # not idempotent, but idempotent mod radical
+                False
+                sage: al = B.idempotent_lift(a)
+                sage: al ** 2 == al
+                True
+                sage: (a - al) ** 2
+                0
             """
             if not self.is_parent_of(x):
                 x = x.lift()
@@ -690,10 +758,10 @@ class FiniteDimensionalAlgebrasWithBasis(CategoryWithAxiom_over_base_ring):
             if p * p != p:
                 raise ValueError("%s does not retract to an idempotent." % p)
             x_prev = None
-            one = self.one()
             while x != x_prev:
                 tmp = x
-                x = (one - (one - x**2)**2)
+                y = x ** 2
+                x = 2*y - y**2  # == one - (one - x**2)**2
                 x_prev = tmp
             return x
 
@@ -704,7 +772,13 @@ class FiniteDimensionalAlgebrasWithBasis(CategoryWithAxiom_over_base_ring):
 
             OUTPUT: a matrix of nonnegative integers
 
-            Let `A` be this finite dimensional algebra and
+            .. TODO::
+
+                Both the implementation and the documentation
+                assume that the algebra is split over its
+                base field.
+
+            Let `A` be this finite-dimensional algebra and
             `(S_i)_{i\in I}` be representatives of the right simple
             modules of `A`. Note that their adjoints `S_i^*` are
             representatives of the left simple modules.
@@ -816,7 +890,7 @@ class FiniteDimensionalAlgebrasWithBasis(CategoryWithAxiom_over_base_ring):
             idempotents_quo = A_quo.central_orthogonal_idempotents()
             # Dimension of simple modules
             dim_simples = [A_quo.principal_ideal(e).dimension().sqrt()
-                          for e in idempotents_quo]
+                           for e in idempotents_quo]
             # Orthogonal idempotents
             idempotents = self.orthogonal_idempotents_central_mod_radical()
 
@@ -831,6 +905,11 @@ class FiniteDimensionalAlgebrasWithBasis(CategoryWithAxiom_over_base_ring):
             r"""
             Return the isotypic projective ``side`` ``self``-modules.
 
+            .. TODO::
+
+                The current implementation assumes that the
+                algebra is split over its base field.
+
             Let `P_i` be representatives of the indecomposable
             projective ``side``-modules of this finite dimensional
             algebra `A`, and `S_i` be the associated simple modules.
@@ -922,7 +1001,7 @@ class FiniteDimensionalAlgebrasWithBasis(CategoryWithAxiom_over_base_ring):
 
             TESTS:
 
-            We check each idempotent belong to its own Peirce summand
+            We check each idempotent belongs to its own Peirce summand
             (see :issue:`24687`)::
 
                 sage: # needs sage.combinat sage.groups sage.rings.number_field
@@ -1143,7 +1222,7 @@ class FiniteDimensionalAlgebrasWithBasis(CategoryWithAxiom_over_base_ring):
                                                   for f in l[:i]))
 
         @cached_method
-        def is_commutative(self):
+        def is_commutative(self) -> bool:
             """
             Return whether ``self`` is a commutative algebra.
 
@@ -1158,7 +1237,7 @@ class FiniteDimensionalAlgebrasWithBasis(CategoryWithAxiom_over_base_ring):
                 True
             """
             B = list(self.basis())
-            try: # See if 1 is a basis element, if so, remove it
+            try:  # See if 1 is a basis element, if so, remove it
                 B.remove(self.one())
             except ValueError:
                 pass
@@ -1298,6 +1377,8 @@ class FiniteDimensionalAlgebrasWithBasis(CategoryWithAxiom_over_base_ring):
             except (AttributeError, TypeError, ValueError):
                 pass
             if ob is not None:
+                # inverting a scalar multiple of 1
+                # (a trivial but frequent use case)
                 mc = self.monomial_coefficients(copy=False)
                 if len(mc) == 1 and ob in mc:
                     try:
