@@ -78,13 +78,13 @@ class GradedModulesWithBasis(GradedModulesCategory):
 
             INPUT:
 
-            - ``gens`` -- a list or family of elements of ``self``
-            - ``check`` -- (default: ``True``) whether to verify that the
-               elements of ``gens`` are in ``self``
-            - ``already_echelonized`` -- (default: ``False``) whether
+            - ``gens`` -- list or family of elements of ``self``
+            - ``check`` -- boolean (default: ``True``); whether to verify that
+              the elements of ``gens`` are in ``self``
+            - ``already_echelonized`` -- boolean (default: ``False``); whether
                the elements of ``gens`` are already in (not necessarily
                reduced) echelon form
-            - ``unitriangular`` -- (default: ``False``) whether
+            - ``unitriangular`` -- boolean (default: ``False``); whether
               the lift morphism is unitriangular
             - ``support_order`` -- (optional) either something that can
               be converted into a tuple or a key function
