@@ -1,3 +1,4 @@
+# sage_setup: distribution = sagemath-categories
 r"""
 Kac-Moody Algebras
 
@@ -43,12 +44,12 @@ class KacMoodyAlgebras(Category_over_base_ring):
         EXAMPLES::
 
             sage: from sage.categories.kac_moody_algebras import KacMoodyAlgebras
-            sage: KacMoodyAlgebras(QQ).example()                                        # optional - sage.combinat sage.modules
+            sage: KacMoodyAlgebras(QQ).example()                                        # needs sage.combinat sage.modules
             Lie algebra of ['A', 2] in the Chevalley basis
 
         We can specify the rank of the example::
 
-            sage: KacMoodyAlgebras(QQ).example(4)                                       # optional - sage.combinat sage.modules
+            sage: KacMoodyAlgebras(QQ).example(4)                                       # needs sage.combinat sage.modules
             Lie algebra of ['A', 4] in the Chevalley basis
         """
         from sage.algebras.lie_algebras.classical_lie_algebra import LieAlgebraChevalleyBasis
@@ -61,8 +62,8 @@ class KacMoodyAlgebras(Category_over_base_ring):
 
             EXAMPLES::
 
-                sage: L = LieAlgebra(QQ, cartan_type=['A', 2])                          # optional - sage.combinat sage.modules
-                sage: L.cartan_type()                                                   # optional - sage.combinat sage.modules
+                sage: L = LieAlgebra(QQ, cartan_type=['A', 2])                          # needs sage.combinat sage.modules
+                sage: L.cartan_type()                                                   # needs sage.combinat sage.modules
                 ['A', 2]
             """
             return self._cartan_type
@@ -73,8 +74,8 @@ class KacMoodyAlgebras(Category_over_base_ring):
 
             EXAMPLES::
 
-                sage: L = LieAlgebra(QQ, cartan_type=['A', 2])                          # optional - sage.combinat sage.modules
-                sage: L.weyl_group()                                                    # optional - sage.combinat sage.modules
+                sage: L = LieAlgebra(QQ, cartan_type=['A', 2])                          # needs sage.combinat sage.modules
+                sage: L.weyl_group()                                                    # needs sage.combinat sage.modules
                 Weyl Group of type ['A', 2] (as a matrix group acting on the ambient space)
             """
             from sage.combinat.root_system.weyl_group import WeylGroup
