@@ -34,15 +34,14 @@ class LambdaBracketAlgebras(Category_over_base_ring):
 
     This is an abstract base category for Lie conformal algebras and
     super Lie conformal algebras.
-
     """
     @staticmethod
     def __classcall_private__(cls, R, check=True):
         r"""
         INPUT:
 
-        - `R` -- a commutative ring
-        - ``check`` -- a boolean (default: ``True``); whether to check
+        - ``R`` -- a commutative ring
+        - ``check`` -- boolean (default: ``True``); whether to check
           that `R` is a commutative ring
 
         EXAMPLES::
@@ -251,7 +250,7 @@ class LambdaBracketAlgebras(Category_over_base_ring):
 
             INPUT:
 
-            - ``n`` -- integer (default:``1``); how many times
+            - ``n`` -- integer (default: `1`); how many times
               to apply `T` to this element
 
             OUTPUT:
