@@ -375,11 +375,12 @@ class Magmas(Category_singleton):
             return [MagmaticAlgebras(self.base_ring())]
 
         class ParentMethods:
+
             def is_field(self, proof=True):
                 r"""
                 Return ``True`` if ``self`` is a field.
 
-                For a magma algebra `RS` this is always false unless
+                For a magma algebra `R S` this is always false unless
                 `S` is trivial and the base ring `R` is a field.
 
                 EXAMPLES::
@@ -390,15 +391,18 @@ class Magmas(Category_singleton):
                     False
                     sage: SymmetricGroup(2).algebra(QQ).is_field()                      # needs sage.combinat sage.groups
                     False
+                    sage: Magmas().example().algebra(QQ).is_field()
+                    False
+
                 """
                 if not self.base_ring().is_field(proof):
                     return False
-                return (self.basis().keys().cardinality() == 1)
+                return self.basis().keys().cardinality() == 1
 
     class Commutative(CategoryWithAxiom):
 
         class ParentMethods:
-            def is_commutative(self):
+            def is_commutative(self) -> bool:
                 """
                 Return ``True``, since commutative magmas are commutative.
 
