@@ -88,7 +88,6 @@ class Posets(Category):
 
         sage: C = Posets()
         sage: TestSuite(C).run()
-
     """
     @cached_method
     def super_categories(self):
@@ -165,7 +164,7 @@ class Posets(Category):
 
             INPUT:
 
-            - ``x``, ``y`` -- elements of ``self``.
+            - ``x``, ``y`` -- elements of ``self``
 
             EXAMPLES::
 
@@ -184,7 +183,7 @@ class Posets(Category):
 
             INPUT:
 
-            - ``x``, ``y`` -- elements of ``self``.
+            - ``x``, ``y`` -- elements of ``self``
 
             This default implementation delegates the work to :meth:`le`.
 
@@ -206,7 +205,7 @@ class Posets(Category):
 
             INPUT:
 
-            - ``x``, ``y`` -- elements of ``self``.
+            - ``x``, ``y`` -- elements of ``self``
 
             This default implementation delegates the work to :meth:`le`.
 
@@ -228,7 +227,7 @@ class Posets(Category):
 
             INPUT:
 
-            - ``x``, ``y`` -- elements of ``self``.
+            - ``x``, ``y`` -- elements of ``self``
 
             This default implementation delegates the work to :meth:`lt`.
 
@@ -310,17 +309,17 @@ class Posets(Category):
             Return the order filter or the order ideal generated by a
             list of elements.
 
-            If ``direction`` is 'up', the order filter (upper set) is
+            If ``direction`` is ``'up'``, the order filter (upper set) is
             being returned.
 
-            If ``direction`` is 'down', the order ideal (lower set) is
+            If ``direction`` is ``'down'``, the order ideal (lower set) is
             being returned.
 
             INPUT:
 
-            - elements -- a list of elements.
+            - ``elements`` -- list of elements
 
-            - direction -- 'up' or 'down'.
+            - ``direction`` -- ``'up'`` or ``'down'``
 
             EXAMPLES::
 
@@ -456,7 +455,7 @@ class Posets(Category):
 
             INPUT:
 
-            - ``o`` -- a list (or set, or tuple) containing some elements of ``self``
+            - ``o`` -- list (or set, or tuple) containing some elements of ``self``
 
             EXAMPLES::
 
@@ -472,7 +471,6 @@ class Posets(Category):
                 True
                 sage: P.is_order_ideal([1, 3, 4])
                 False
-
             """
             return all((u in self and all(x in o for x in self.lower_covers(u))) for u in o)
 
@@ -483,7 +481,7 @@ class Posets(Category):
 
             INPUT:
 
-            - ``o`` -- a list (or set, or tuple) containing some elements of ``self``
+            - ``o`` -- list (or set, or tuple) containing some elements of ``self``
 
             EXAMPLES::
 
@@ -499,7 +497,6 @@ class Posets(Category):
                 False
                 sage: P.is_order_filter({3, 6, 12})
                 True
-
             """
             return all((u in self and all(x in o for x in self.upper_covers(u))) for u in o)
 
@@ -515,9 +512,8 @@ class Posets(Category):
             - ``o`` -- an iterable (e. g., list, set, or tuple)
               containing some elements of ``self``
 
-            - ``ordered`` -- a Boolean (default: ``False``) which
-              decides whether the notion of a chain includes being
-              ordered
+            - ``ordered`` -- a Boolean (default: ``False``); decides
+              whether the notion of a chain includes being ordered
 
             OUTPUT:
 
