@@ -58,7 +58,7 @@ documentation, and tests, implements:
 - Thousands of different kinds of objects (classes):
 
   Integers, polynomials, matrices, groups, number fields, elliptic
-  curves, permutations, morphisms, languages, ... and a few racoons ...
+  curves, permutations, morphisms, languages, ... and a few raccoons ...
 
 - Tens of thousands methods and functions:
 
@@ -118,7 +118,7 @@ The hierarchy of categories
 What makes binary powering work in the above examples? In both cases,
 we have *a set* endowed with a *multiplicative binary operation* which
 is *associative* and which has a unit element. Such a set is called a
-*monoid*, and binary powering (to a non-negative power) works generally
+*monoid*, and binary powering (to a nonnegative power) works generally
 for any monoid.
 
 Sage knows about monoids::
@@ -193,7 +193,7 @@ Altogether, our group gets algorithms from a bunch of bookshelves::
 Those can be viewed graphically::
 
     sage: g = Groups().category_graph()                                                 # needs sage.graphs
-    sage: g.set_latex_options(format="dot2tex")                                         # needs sage.graphs sage.modules sage.plot
+    sage: g.set_latex_options(format='dot2tex')                                         # needs sage.graphs sage.modules sage.plot
     sage: view(g)                               # not tested                            # needs sage.graphs sage.modules sage.plot
 
 In case ``dot2tex`` is not available, you can use instead::
@@ -203,7 +203,7 @@ In case ``dot2tex`` is not available, you can use instead::
 Here is an overview of all categories in Sage::
 
     sage: g = sage.categories.category.category_graph()                                 # needs sage.graphs sage.groups sage.modules
-    sage: g.set_latex_options(format="dot2tex")                                         # needs sage.graphs sage.modules sage.plot
+    sage: g.set_latex_options(format='dot2tex')                                         # needs sage.graphs sage.modules sage.plot
     sage: view(g)                               # not tested                            # needs sage.graphs sage.modules sage.plot
 
 Wrap-up: generic algorithms in Sage are organized in a hierarchy of
@@ -379,7 +379,7 @@ categories and their super categories::
      Category of objects]
 
     sage: g = EuclideanDomains().category_graph()                                       # needs sage.graphs
-    sage: g.set_latex_options(format="dot2tex")                                         # needs sage.graphs sage.plot
+    sage: g.set_latex_options(format='dot2tex')                                         # needs sage.graphs sage.plot
     sage: view(g)                               # not tested                            # needs sage.graphs sage.plot
 
 A bit of help from computer science
@@ -498,7 +498,7 @@ hierarchy of categories and provide generic algorithms.
 The full hierarchy is best viewed graphically::
 
     sage: g = class_graph(m.__class__)                                                  # needs sage.combinat sage.graphs
-    sage: g.set_latex_options(format="dot2tex")                                         # needs sage.combinat sage.graphs sage.plot
+    sage: g.set_latex_options(format='dot2tex')                                         # needs sage.combinat sage.graphs sage.plot
     sage: view(g)                               # not tested                            # needs sage.combinat sage.graphs sage.plot
 
 Parallel hierarchy of classes for parents
@@ -554,7 +554,7 @@ best viewed graphically::
     sage: # needs sage.combinat sage.graphs sage.modules sage.plot
     sage: g = class_graph(m.__class__)
     sage: g.relabel(lambda x: x.replace("_",r"\_"))
-    sage: g.set_latex_options(format="dot2tex")
+    sage: g.set_latex_options(format='dot2tex')
     sage: view(g)                               # not tested
 
 .. NOTE::
@@ -931,6 +931,7 @@ Where do all the operations on ``S`` and its elements come from?
 to use Sage's introspection tools to recover where it's implemented::
 
     sage: x._repr_.__module__
+    'sage.structure.element_wrapper'
     sage: sage.misc.sageinspect.sage_getfile(x._repr_)
     '.../sage/structure/element_wrapper.pyx'
 
@@ -1114,8 +1115,8 @@ algebraic structure. This includes:
 Let for example `A` and `B` be two parents, and let us construct the
 Cartesian product `A \times B \times B`::
 
-    sage: A = AlgebrasWithBasis(QQ).example();     A.rename("A")                        # needs sage.combinat sage.modules
-    sage: B = HopfAlgebrasWithBasis(QQ).example(); B.rename("B")                        # needs sage.groups sage.modules
+    sage: A = AlgebrasWithBasis(QQ).example();     A.rename('A')                        # needs sage.combinat sage.modules
+    sage: B = HopfAlgebrasWithBasis(QQ).example(); B.rename('B')                        # needs sage.groups sage.modules
     sage: C = cartesian_product([A, B, B]); C                                           # needs sage.combinat sage.groups sage.modules
     A (+) B (+) B
 
@@ -1277,7 +1278,7 @@ this axiom is available in the subcategory of groups::
 
 The meaning of each axiom is described in the documentation of the
 corresponding method, which can be obtained as usual by
-instrospection::
+introspection::
 
     sage: C = Groups()
     sage: C.Finite?              # not tested
@@ -1368,7 +1369,7 @@ prefer right away the more flexible notation::
     How far should this be pushed? :class:`Fields` should definitely
     stay, but should :class:`FiniteGroups` or :class:`DivisionRings`
     be removed from the global namespace? Do we want to further
-    completely deprecate the notation ``FiniteGroups()` in favor of
+    completely deprecate the notation ``FiniteGroups()`` in favor of
     ``Groups().Finite()``?
 
 .. _category-primer-axioms-explosion:
@@ -1405,7 +1406,7 @@ for a category with two operations `+` and `*`::
 or for more advanced categories::
 
     sage: g = HopfAlgebras(QQ).WithBasis().Graded().Connected().category_graph()        # needs sage.graphs
-    sage: g.set_latex_options(format="dot2tex")                                         # needs sage.graphs sage.plot
+    sage: g.set_latex_options(format='dot2tex')                                         # needs sage.graphs sage.plot
     sage: view(g)                               # not tested                            # needs sage.graphs sage.plot
 
 Difference between axioms and regressive covariant functorial constructions
