@@ -444,29 +444,31 @@ class SimplicialSets(Category_singleton):
 
                     sage: # needs sage.graphs sage.groups
                     sage: S1 = simplicial_sets.Sphere(1)
-                    sage: W = S1.wedge(S1)
+                    sage: S1_ = simplicial_sets.Sphere(1)
+                    sage: S1_.n_cells(1)[0].rename("sigma_1'")
+                    sage: W = S1.wedge(S1_)
                     sage: G = CyclicPermutationGroup(3)
                     sage: a, b = W.n_cells(1)
                     sage: C = W.covering_map({a : G.gen(0), b : G.one()}); C
                     Simplicial set morphism:
                       From: Simplicial set with 9 non-degenerate simplices
                       To:   Wedge: (S^1 v S^1)
-                      Defn: [(*, ()), (*, (1,2,3)), (*, (1,3,2)), (sigma_1, ()),
-                             (sigma_1, ()), (sigma_1, (1,2,3)), (sigma_1, (1,2,3)),
-                             (sigma_1, (1,3,2)), (sigma_1, (1,3,2))]
-                            --> [*, *, *, sigma_1, sigma_1, sigma_1, sigma_1, sigma_1, sigma_1]
+                      Defn: [(*, ()), (*, (1,2,3)), (*, (1,3,2)), (sigma_1', ()),
+                             (sigma_1', (1,2,3)), (sigma_1', (1,3,2)), (sigma_1, ()),
+                             (sigma_1, (1,2,3)), (sigma_1, (1,3,2))]
+                            --> [*, *, *, sigma_1', sigma_1', sigma_1', sigma_1, sigma_1, sigma_1]
                     sage: C.domain()
                     Simplicial set with 9 non-degenerate simplices
                     sage: C.domain().face_data()
                     {(*, ()): None,
                      (*, (1,2,3)): None,
                      (*, (1,3,2)): None,
+                     (sigma_1', ()): ((*, ()), (*, ())),
+                     (sigma_1', (1,2,3)): ((*, (1,2,3)), (*, (1,2,3))),
+                     (sigma_1', (1,3,2)): ((*, (1,3,2)), (*, (1,3,2))),
                      (sigma_1, ()): ((*, (1,2,3)), (*, ())),
-                     (sigma_1, ()): ((*, ()), (*, ())),
                      (sigma_1, (1,2,3)): ((*, (1,3,2)), (*, (1,2,3))),
-                     (sigma_1, (1,2,3)): ((*, (1,2,3)), (*, (1,2,3))),
-                     (sigma_1, (1,3,2)): ((*, ()), (*, (1,3,2))),
-                     (sigma_1, (1,3,2)): ((*, (1,3,2)), (*, (1,3,2)))}
+                     (sigma_1, (1,3,2)): ((*, ()), (*, (1,3,2)))}
                 """
                 from sage.topology.simplicial_set import AbstractSimplex, SimplicialSet
                 from sage.topology.simplicial_set_morphism import SimplicialSetMorphism
@@ -530,7 +532,9 @@ class SimplicialSets(Category_singleton):
 
                     sage: # needs sage.graphs sage.groups
                     sage: S1 = simplicial_sets.Sphere(1)
-                    sage: W = S1.wedge(S1)
+                    sage: S1_ = simplicial_sets.Sphere(1)
+                    sage: S1_.n_cells(1)[0].rename("sigma_1'")
+                    sage: W = S1.wedge(S1_)
                     sage: G = CyclicPermutationGroup(3)
                     sage: (a, b) = W.n_cells(1)
                     sage: C = W.cover({a : G.gen(0), b : G.gen(0)^2})
@@ -538,12 +542,12 @@ class SimplicialSets(Category_singleton):
                     {(*, ()): None,
                      (*, (1,2,3)): None,
                      (*, (1,3,2)): None,
+                     (sigma_1', ()): ((*, (1,3,2)), (*, ())),
+                     (sigma_1', (1,2,3)): ((*, ()), (*, (1,2,3))),
+                     (sigma_1', (1,3,2)): ((*, (1,2,3)), (*, (1,3,2))),
                      (sigma_1, ()): ((*, (1,2,3)), (*, ())),
-                     (sigma_1, ()): ((*, (1,3,2)), (*, ())),
                      (sigma_1, (1,2,3)): ((*, (1,3,2)), (*, (1,2,3))),
-                     (sigma_1, (1,2,3)): ((*, ()), (*, (1,2,3))),
-                     (sigma_1, (1,3,2)): ((*, ()), (*, (1,3,2))),
-                     (sigma_1, (1,3,2)): ((*, (1,2,3)), (*, (1,3,2)))}
+                     (sigma_1, (1,3,2)): ((*, ()), (*, (1,3,2)))}
                     sage: C.homology(1)                                                 # needs sage.modules
                     Z x Z x Z x Z
                     sage: C.fundamental_group()
@@ -719,7 +723,7 @@ class SimplicialSets(Category_singleton):
                     if s in twop:
                         return twop[s]
                     if s.dimension() > 1:
-                        return twist(self.face(s,s.dimension()))
+                        return twist(self.face(s, s.dimension()))
                     return 1
                 base_ring = cm.common_parent(*twop.values())
 
@@ -811,9 +815,8 @@ class SimplicialSets(Category_singleton):
                         differentials[d] = matrix(base_ring, old_rank, rank, sparse=False)
 
                 if cochain:
-                    new_diffs = {}
-                    for d in differentials:
-                        new_diffs[d-1] = differentials[d].transpose()
+                    new_diffs = {d - 1: diff_d.transpose()
+                                 for d, diff_d in differentials.items()}
                     return ChainComplex(new_diffs, degree_of_differential=1,
                                         check=check)
                 return ChainComplex(differentials, degree_of_differential=-1,
@@ -957,7 +960,7 @@ class SimplicialSets(Category_singleton):
                     res = M
                     for g in GB:
                         res = res.stack(g*identity_matrix(M.ncols()))
-                    singres = matrix(singlift(res.T, S.T,ring=res.base_ring()))
+                    singres = matrix(singlift(res.T, S.T, ring=res.base_ring()))
                     return singres.submatrix(0, 0, M.nrows(), S.nrows())
 
                 def mgb(M):
@@ -969,7 +972,7 @@ class SimplicialSets(Category_singleton):
                     sres = matrix(singstd(res.T, ring=RP))
                     to_delete = [i for i, r in enumerate(sres.apply_map(reduce_laurent)) if not r]
                     return sres.delete_rows(to_delete)
-                    M2 = border_matrix(n+1)
+
                 if M1.nrows() == 0:
                     opt_verb.reset_default()
                     return (RP**0).quotient_module([])
