@@ -120,7 +120,7 @@ class EvaluationAGCode(AGCode):
 
     INPUT:
 
-    - ``pls`` -- a list of rational places of a function field
+    - ``pls`` -- list of rational places of a function field
 
     - ``G`` -- a divisor whose support is disjoint from ``pls``
 
@@ -331,7 +331,7 @@ class EvaluationAGCode(AGCode):
         """
         Return the designed distance of the AG code.
 
-        If the code is of dimension zero, then a :class:`ValueError` is raised.
+        If the code is of dimension zero, then a :exc:`ValueError` is raised.
 
         EXAMPLES::
 
@@ -355,11 +355,11 @@ class EvaluationAGCode(AGCode):
 
 class DifferentialAGCode(AGCode):
     """
-    Differential AG code defined by rational places ``pls`` and a divisor ``G``
+    Differential AG code defined by rational places ``pls`` and a divisor ``G``.
 
     INPUT:
 
-    - ``pls`` -- a list of rational places of a function field
+    - ``pls`` -- list of rational places of a function field
 
     - ``G`` -- a divisor whose support is disjoint from ``pls``
 
@@ -575,7 +575,7 @@ class DifferentialAGCode(AGCode):
         """
         Return the designed distance of the differential AG code.
 
-        If the code is of dimension zero, then a :class:`ValueError` is raised.
+        If the code is of dimension zero, then a :exc:`ValueError` is raised.
 
         EXAMPLES::
 
@@ -603,7 +603,7 @@ class CartierCode(AGCode):
 
     INPUT:
 
-    - ``pls`` -- a list of rational places
+    - ``pls`` -- list of rational places
 
     - ``G`` -- a divisor whose support is disjoint from ``pls``
 
@@ -611,7 +611,7 @@ class CartierCode(AGCode):
 
     - ``name`` -- string; name of the generator of the subfield `\GF{p^r}`
 
-    OUTPUT: Cartier code over `\GF{p^r}` where `p` is the characteristic of the
+    OUTPUT: cartier code over `\GF{p^r}` where `p` is the characteristic of the
     base constant field of the function field
 
     Note that if ``r`` is 1 the default, then ``name`` can be omitted.
