@@ -11,7 +11,7 @@ finite field `F`, the corresponding Reed-Solomon code (RS code) of dimension
     \{ (f(\alpha_1), \ldots, f(\alpha_n))  \mid  f \in F[x], \deg f < k \}
 
 An RS code is often called "classical" if `\alpha_i = \alpha^{i-1}` and `\alpha`
-is a primitive `n`'th root of unity.
+is a primitive `n`-th root of unity.
 
 More generally, given also `n` "column multipliers" `\beta_1, \dots, \beta_n`,
 the corresponding Generalized Reed-Solomon code (GRS code) of dimension `k` is
@@ -76,18 +76,18 @@ class GeneralizedReedSolomonCode(AbstractLinearCode):
 
     INPUT:
 
-    - ``evaluation_points`` -- a list of distinct elements of some
+    - ``evaluation_points`` -- list of distinct elements of some
       finite field `F`
 
     - ``dimension`` -- the dimension of the resulting code
 
-    - ``column_multipliers`` -- (default: ``None``) list of non-zero
+    - ``column_multipliers`` -- (default: ``None``) list of nonzero
       elements of `F`; all column multipliers are set to 1 if default
       value is kept
 
     EXAMPLES:
 
-    Often, one constructs a Reed-Solomon code by taking all non-zero elements of
+    Often, one constructs a Reed-Solomon code by taking all nonzero elements of
     the field as evaluation points, and specifying no column multipliers (see
     also :func:`ReedSolomonCode` for constructing classical Reed-Solomon codes
     directly)::
@@ -192,7 +192,7 @@ class GeneralizedReedSolomonCode(AbstractLinearCode):
             sage: C = codes.GeneralizedReedSolomonCode(F.list()[:n], k, F.list()[:n])
             Traceback (most recent call last):
             ...
-            ValueError: All column multipliers must be non-zero
+            ValueError: All column multipliers must be nonzero
 
         And all the evaluation points must be different. Note that they should
         be different after converting into the same field::
@@ -240,7 +240,7 @@ class GeneralizedReedSolomonCode(AbstractLinearCode):
         self._dimension = dimension
 
         if F.zero() in self._column_multipliers:
-            raise ValueError("All column multipliers must be non-zero")
+            raise ValueError("All column multipliers must be nonzero")
         if len(self._evaluation_points) != len(set(self._evaluation_points)):
             raise ValueError("All evaluation points must be different")
 
@@ -503,7 +503,7 @@ class GeneralizedReedSolomonCode(AbstractLinearCode):
     @cached_method
     def weight_distribution(self):
         r"""
-        Return the list whose `i`'th entry is the number of words of weight `i`
+        Return the list whose `i`-th entry is the number of words of weight `i`
         in ``self``.
 
         Computing the weight distribution for a GRS code is very fast. Note that
@@ -550,7 +550,7 @@ class GeneralizedReedSolomonCode(AbstractLinearCode):
 
         INPUT:
 
-        - ``points`` -- a set of positions where to puncture ``self``
+        - ``points`` -- set of positions where to puncture ``self``
 
         EXAMPLES::
 
@@ -579,7 +579,7 @@ def ReedSolomonCode(base_field, length, dimension, primitive_root=None):
 
     A classical `[n,k]` Reed-Solomon code over `\GF{q}` with `1 \le k \le n` and
     `n | (q-1)` is a Reed-Solomon code whose evaluation points are the
-    consecutive powers of a primitive `n`'th root of unity `\alpha`, i.e.
+    consecutive powers of a primitive `n`-th root of unity `\alpha`, i.e.
     `\alpha_i = \alpha^{i-1}`, where `\alpha_1, \ldots, \alpha_n` are the
     evaluation points. A classical Reed-Solomon codes has all column multipliers
     equal `1`.
@@ -593,17 +593,17 @@ def ReedSolomonCode(base_field, length, dimension, primitive_root=None):
     INPUT:
 
     - ``base_field`` -- the finite field for which to build the classical
-      Reed-Solomon code.
+      Reed-Solomon code
 
     - ``length`` -- the length of the classical Reed-Solomon code. Must divide
-      `q-1` where `q` is the cardinality of ``base_field``.
+      `q-1` where `q` is the cardinality of ``base_field``
 
-    - ``dimension`` -- the dimension of the resulting code.
+    - ``dimension`` -- the dimension of the resulting code
 
-    - ``primitive_root`` -- (default: ``None``) a primitive `n`'th root of unity
-      to use for constructing the classical Reed-Solomon code. If not supplied,
+    - ``primitive_root`` -- (default: ``None``) a primitive `n`-th root of unity
+      to use for constructing the classical Reed-Solomon code; if not supplied,
       one will be computed and can be recovered as ``C.evaluation_points()[1]``
-      where `C` is the code returned by this method.
+      where `C` is the code returned by this method
 
     EXAMPLES::
 
@@ -623,12 +623,12 @@ def ReedSolomonCode(base_field, length, dimension, primitive_root=None):
         sage: C = codes.ReedSolomonCode(GF(64,'a'), 9, 4); C
         [9, 4, 6] Reed-Solomon Code over GF(64)
 
-    The primitive `n`'th root of unity can be recovered as the 2nd evaluation point of the code::
+    The primitive `n`-th root of unity can be recovered as the 2nd evaluation point of the code::
 
         sage: alpha = C.evaluation_points()[1]; alpha
         a^5 + a^4 + a^2 + a
 
-    We can also supply a different primitive `n`'th root of unity::
+    We can also supply a different primitive `n`-th root of unity::
 
         sage: beta = alpha^2; beta
         a^4 + a
@@ -759,7 +759,7 @@ class GRSEvaluationVectorEncoder(Encoder):
     @cached_method
     def generator_matrix(self):
         r"""
-        Return a generator matrix of ``self``
+        Return a generator matrix of ``self``.
 
         Considering a GRS code of length `n`, dimension `k`, with
         evaluation points `(\alpha_1, \dots, \alpha_n)` and column multipliers
@@ -872,7 +872,6 @@ class GRSEvaluationPolynomialEncoder(Encoder):
             Traceback (most recent call last):
             ...
             ValueError: polynomial_ring's base field has to be the same as code's
-
         """
         from sage.rings.polynomial.polynomial_ring import PolynomialRing_commutative
         super().__init__(code)
@@ -956,9 +955,7 @@ class GRSEvaluationPolynomialEncoder(Encoder):
         - ``p`` -- a polynomial from the message space of ``self`` of degree
           less than ``self.code().dimension()``
 
-        OUTPUT:
-
-        - a codeword in associated code of ``self``
+        OUTPUT: a codeword in associated code of ``self``
 
         EXAMPLES::
 
@@ -1056,7 +1053,6 @@ class GRSEvaluationPolynomialEncoder(Encoder):
             6*x^4 + 6*x^3 + 2*x^2
             sage: E.encode(p) == c
             False
-
         """
         C = self.code()
         alphas = C.evaluation_points()
@@ -1070,7 +1066,7 @@ class GRSEvaluationPolynomialEncoder(Encoder):
 
     def message_space(self):
         r"""
-        Return the message space of ``self``
+        Return the message space of ``self``.
 
         EXAMPLES::
 
@@ -1269,9 +1265,7 @@ class GRSBerlekampWelchDecoder(Decoder):
 
         - ``r`` -- a codeword of ``self``
 
-        OUTPUT:
-
-        - a vector of ``self`` message space
+        OUTPUT: a vector of ``self`` message space
 
         EXAMPLES::
 
@@ -1381,9 +1375,7 @@ class GRSBerlekampWelchDecoder(Decoder):
         r"""
         Return maximal number of errors that ``self`` can decode.
 
-        OUTPUT:
-
-        - the number of errors as an integer
+        OUTPUT: the number of errors as an integer
 
         EXAMPLES::
 
@@ -1464,7 +1456,7 @@ class GRSGaoDecoder(Decoder):
 
     def __hash__(self):
         """
-        Return the hash of self.
+        Return the hash of ``self``.
 
         EXAMPLES::
 
@@ -1519,9 +1511,7 @@ class GRSGaoDecoder(Decoder):
 
         - ``PolRing`` -- polynomial ring of the output
 
-        OUTPUT:
-
-        - a polynomial over ``PolRing``
+        OUTPUT: a polynomial over ``PolRing``
 
         EXAMPLES::
 
@@ -1535,13 +1525,13 @@ class GRSGaoDecoder(Decoder):
         """
         G = PolRing.one()
         x = PolRing.gen()
-        for i in range(0, self.code().length()):
+        for i in range(self.code().length()):
             G = G*(x-self.code().evaluation_points()[i])
         return G
 
     def _partial_xgcd(self, a, b, PolRing):
         r"""
-        Performs an Euclidean algorithm on ``a`` and ``b`` until a remainder
+        Perform a Euclidean algorithm on ``a`` and ``b`` until a remainder
         has degree less than `\frac{n+k}{2}`, `n` being the dimension of the
         code, `k` its dimension, and returns `(r, s)` such that in the step
         just before termination, `r = a s + b t`.
@@ -1622,11 +1612,10 @@ class GRSGaoDecoder(Decoder):
         if n == C.dimension() or r in C:
             return r, self.connected_encoder().unencode_nocheck(r)
 
-        points = [(alphas[i], r[i]/col_mults[i]) for i in
-                range(0, n)]
+        points = [(alphas[i], r[i]/col_mults[i]) for i in range(n)]
         R = PolRing.lagrange_polynomial(points)
 
-        (Q1, Q0) = self._partial_xgcd(G, R, PolRing)
+        Q1, Q0 = self._partial_xgcd(G, R, PolRing)
 
         h, rem = Q1.quo_rem(Q0)
         if not rem.is_zero():
@@ -1652,9 +1641,7 @@ class GRSGaoDecoder(Decoder):
 
         - ``r`` -- a codeword of ``self``
 
-        OUTPUT:
-
-        - a vector of ``self`` message space
+        OUTPUT: a vector of ``self`` message space
 
         EXAMPLES::
 
@@ -1764,11 +1751,9 @@ class GRSGaoDecoder(Decoder):
 
     def decoding_radius(self):
         r"""
-        Return maximal number of errors that ``self`` can decode
+        Return maximal number of errors that ``self`` can decode.
 
-        OUTPUT:
-
-        - the number of errors as an integer
+        OUTPUT: the number of errors as an integer
 
         EXAMPLES::
 
@@ -1898,7 +1883,7 @@ class GRSErrorErasureDecoder(Decoder):
 
         INPUT:
 
-        - ``word_and_erasure_vector`` -- a tuple whose:
+        - ``word_and_erasure_vector`` -- tuple whose:
 
           * first element is an element of the ambient space of the code
           * second element is a vector over `\GF{2}` whose length is the
@@ -1914,9 +1899,7 @@ class GRSErrorErasureDecoder(Decoder):
             In either case, if ``r`` is not a codeword,
             the output is unspecified.
 
-        OUTPUT:
-
-        - a vector of ``self`` message space
+        OUTPUT: a vector of ``self`` message space
 
         EXAMPLES::
 
@@ -1931,6 +1914,12 @@ class GRSErrorErasureDecoder(Decoder):
             sage: y = Chan(c)
             sage: D.connected_encoder().unencode(c) == D.decode_to_message(y)
             True
+            sage: n_era = C.minimum_distance() - 1
+            sage: Chan = channels.ErrorErasureChannel(C.ambient_space(),
+            ....:                                     D.decoding_radius(n_era), n_era)
+            sage: y = Chan(c)
+            sage: D.connected_encoder().unencode(c) == D.decode_to_message(y)
+            True
 
         TESTS:
 
@@ -1974,14 +1963,14 @@ class GRSErrorErasureDecoder(Decoder):
                                 [word[i] for i in range(len(word))
                                  if not erasure_vector[i]])
         C1_length = len(punctured_word)
-        if C1_length == k:
-            return self.connected_encoder().unencode_nocheck(word)
         C1_evaluation_points = [self.code().evaluation_points()[i] for i in
                 range(n) if erasure_vector[i] != 1]
         C1_column_multipliers = [self.code().column_multipliers()[i] for i in
                 range(n) if erasure_vector[i] != 1]
         C1 = GeneralizedReedSolomonCode(C1_evaluation_points, k,
                 C1_column_multipliers)
+        if C1_length == k:
+            return C1.unencode(punctured_word, nocheck=True)
         return C1.decode_to_message(punctured_word)
 
     def decoding_radius(self, number_erasures):
@@ -1993,9 +1982,7 @@ class GRSErrorErasureDecoder(Decoder):
 
         - ``number_erasures`` -- the number of erasures when we try to decode
 
-        OUTPUT:
-
-        - the number of errors as an integer
+        OUTPUT: the number of errors as an integer
 
         EXAMPLES::
 
@@ -2015,7 +2002,7 @@ class GRSErrorErasureDecoder(Decoder):
             ValueError: The number of erasures exceed decoding capability
         """
         diff = self.code().minimum_distance() - 1 - number_erasures
-        if diff <= 0:
+        if diff < 0:
             raise ValueError("The number of erasures exceed decoding capability")
         else:
             return diff // 2
@@ -2032,7 +2019,7 @@ class GRSKeyEquationSyndromeDecoder(Decoder):
 
     INPUT:
 
-    - ``code`` -- The associated code of this decoder.
+    - ``code`` -- the associated code of this decoder
 
     EXAMPLES::
 
@@ -2130,7 +2117,7 @@ class GRSKeyEquationSyndromeDecoder(Decoder):
 
     def _partial_xgcd(self, a, b, PolRing):
         r"""
-        Performs an Euclidean algorithm on ``a`` and ``b`` until a remainder
+        Perform a Euclidean algorithm on ``a`` and ``b`` until a remainder
         has degree less than `\frac{n+k}{2}`, `n` being the dimension of the
         code, `k` its dimension, and returns `(r, t)` such that in the step
         just before termination, `r = a s + b t`.
@@ -2177,9 +2164,7 @@ class GRSKeyEquationSyndromeDecoder(Decoder):
 
         - ``r`` -- a vector of the ambient space of ``self.code()``
 
-        OUTPUT:
-
-        - a list
+        OUTPUT: list
 
         EXAMPLES::
 
@@ -2214,9 +2199,7 @@ class GRSKeyEquationSyndromeDecoder(Decoder):
 
         - ``error_evaluator``, ``error_locator`` -- two polynomials
 
-        OUTPUT:
-
-        - a vector
+        OUTPUT: a vector
 
         EXAMPLES::
 
@@ -2322,7 +2305,7 @@ class GRSKeyEquationSyndromeDecoder(Decoder):
 
     def decode_to_message(self, r):
         r"""
-        Decode ``r`` to an element in message space of ``self``
+        Decode ``r`` to an element in message space of ``self``.
 
         .. NOTE::
 
@@ -2334,9 +2317,7 @@ class GRSKeyEquationSyndromeDecoder(Decoder):
 
         - ``r`` -- a codeword of ``self``
 
-        OUTPUT:
-
-        - a vector of ``self`` message space
+        OUTPUT: a vector of ``self`` message space
 
         EXAMPLES::
 
@@ -2358,11 +2339,9 @@ class GRSKeyEquationSyndromeDecoder(Decoder):
 
     def decoding_radius(self):
         r"""
-        Return maximal number of errors that ``self`` can decode
+        Return maximal number of errors that ``self`` can decode.
 
-        OUTPUT:
-
-        - the number of errors as an integer
+        OUTPUT: the number of errors as an integer
 
         EXAMPLES::
 
