@@ -14,7 +14,7 @@ AUTHORS:
 - David Lucas, ported the original implementation in Sage
 """
 
-#*****************************************************************************
+# ****************************************************************************
 #       Copyright (C) 2015 David Lucas <david.lucas@inria.fr>
 #                     2015 Johan S. R. Nielsen <jsrn@jsrn.dk>
 #
@@ -22,10 +22,9 @@ AUTHORS:
 # it under the terms of the GNU General Public License as published by
 # the Free Software Foundation, either version 2 of the License, or
 # (at your option) any later version.
-#                  http://www.gnu.org/licenses/
-#*****************************************************************************
+#                  https://www.gnu.org/licenses/
+# ****************************************************************************
 
-from sage.arith.misc import integer_floor as floor
 from sage.coding.grs_code import GeneralizedReedSolomonCode
 from sage.rings.integer_ring import ZZ
 from sage.coding.decoder import Decoder
@@ -389,7 +388,7 @@ class GRSGuruswamiSudanDecoder(Decoder):
         # Either s or l is set, but not both. First a shared local function
         def find_integral_max(real_max, f):
             """Given a real (local) maximum of a function `f`, return that of
-            the integers around `real_max` which gives the (local) integral
+            the integers around ``real_max`` which gives the (local) integral
             maximum, and the value of at that point."""
             if real_max in ZZ:
                 int_max = ZZ(real_max)
@@ -849,15 +848,15 @@ class GRSGuruswamiSudanDecoder(Decoder):
         s = self.multiplicity()
         l = self.list_size()
         tau = self.decoding_radius()
-        ## SETUP INTERPOLATION PROBLEM
+        # SETUP INTERPOLATION PROBLEM
         wy = k-1
-        points = [(alphas[i], r[i]/colmults[i]) for i in range(0,len(alphas))]
-        ## SOLVE INTERPOLATION
+        points = [(alphas[i], r[i]/colmults[i]) for i in range(len(alphas))]
+        # SOLVE INTERPOLATION
         try:
             Q = self.interpolation_algorithm()(points, tau, (s,l), wy)
         except TypeError:
             raise ValueError("The provided interpolation algorithm has a wrong signature. See the documentation of `codes.decoders.GRSGuruswamiSudanDecoder.interpolation_algorithm()` for details")
-        ## EXAMINE THE FACTORS AND CONVERT TO CODEWORDS
+        # EXAMINE THE FACTORS AND CONVERT TO CODEWORDS
         try:
             polynomials = self.rootfinding_algorithm()(Q, maxd=wy)
         except TypeError:
