@@ -1,4 +1,4 @@
-# sage.doctest: optional - sage.modules sage.rings.finite_rings
+# sage.doctest: needs sage.modules sage.rings.finite_rings
 r"""
 Punctured code
 
@@ -27,6 +27,7 @@ from sage.modules.free_module_element import vector
 from sage.rings.finite_rings.finite_field_constructor import GF
 from copy import copy
 
+
 def _puncture(v, points):
     r"""
     Return v punctured as the positions listed in ``points``.
@@ -35,7 +36,7 @@ def _puncture(v, points):
 
     - ``v`` -- a vector or a list of vectors
 
-    - ``points`` -- a set of integers, or an integer
+    - ``points`` -- set of integers, or an integer
 
     EXAMPLES::
 
@@ -58,6 +59,7 @@ def _puncture(v, points):
     new_v = [v[i] for i in range(len(v)) if i not in points]
     return S(new_v)
 
+
 def _insert_punctured_positions(l, punctured_points, value=None):
     r"""
     Return ``l`` with ``value`` inserted in the corresponding
@@ -65,9 +67,9 @@ def _insert_punctured_positions(l, punctured_points, value=None):
 
     INPUT:
 
-    - ``l`` -- a list
+    - ``l`` -- list
 
-    - ``punctured_points`` -- a set of integers
+    - ``punctured_points`` -- set of integers
 
     - ``value`` -- (default: ``None``) an element to insert in every position
       given in``punctured_points``.  If it is let to ``None``, a random value
@@ -98,11 +100,12 @@ class PuncturedCode(AbstractLinearCode):
     r"""
     Representation of a punctured code.
 
-    - ``C`` -- A linear code
+    - ``C`` -- a linear code
 
-    - ``positions`` -- the positions where ``C`` will be punctured. It can be either an integer
-      if one need to puncture only one position, a list or a set of positions to puncture.
-      If the same position is passed several times, it will be considered only once.
+    - ``positions`` -- the positions where ``C`` will be punctured. It can be
+      either an integer if one need to puncture only one position, a list or a
+      set of positions to puncture. If the same position is passed several
+      times, it will be considered only once.
 
     EXAMPLES::
 
@@ -151,7 +154,7 @@ class PuncturedCode(AbstractLinearCode):
 
     def __eq__(self, other):
         r"""
-        Tests equality between two Punctured codes.
+        Test equality between two Punctured codes.
 
         EXAMPLES::
 
@@ -245,8 +248,8 @@ class PuncturedCode(AbstractLinearCode):
 
         INPUT:
 
-        - ``agrs``, ``kwds`` - extra positional arguments passed to
-          :meth:`sage.modules.free_module.random_element`.
+        - ``agrs``, ``kwds`` -- extra positional arguments passed to
+          :meth:`sage.modules.free_module.random_element`
 
         EXAMPLES::
 
@@ -262,23 +265,22 @@ class PuncturedCode(AbstractLinearCode):
 
     def encode(self, m, original_encode=False, encoder_name=None, **kwargs):
         r"""
-        Transforms an element of the message space into an element of the code.
+        Transform an element of the message space into an element of the code.
 
         INPUT:
 
-        - ``m`` -- a vector of the message space of the code.
+        - ``m`` -- a vector of the message space of the code
 
-        - ``original_encode`` -- (default: ``False``) if this is set to ``True``,
-          ``m`` will be encoded using an Encoder of ``self``'s :meth:`original_code`.
-          This allow to avoid the computation of a generator matrix for ``self``.
+        - ``original_encode`` -- boolean (default: ``False``); if this is set
+          to ``True``, ``m`` will be encoded using an Encoder of ``self``'s
+          :meth:`original_code`. This allow to avoid the computation of a
+          generator matrix for ``self``.
 
-        - ``encoder_name`` -- (default: ``None``) Name of the encoder which will be used
+        - ``encoder_name`` -- (default: ``None``) name of the encoder which will be used
           to encode ``word``. The default encoder of ``self`` will be used if
-          default value is kept
+          default value is kept.
 
-        OUTPUT:
-
-        - an element of ``self``
+        OUTPUT: an element of ``self``
 
         EXAMPLES::
 
@@ -328,7 +330,7 @@ class PuncturedCode(AbstractLinearCode):
         C = self.original_code()
         pts = copy(self.punctured_positions())
         list_pts = list(pts)
-        while(isinstance(C, PuncturedCode)):
+        while isinstance(C, PuncturedCode):
             cur_pts = list(C.punctured_positions())
             list_len = len(list_pts)
             for p in cur_pts:
@@ -346,7 +348,7 @@ class PuncturedCodePuncturedMatrixEncoder(Encoder):
 
     INPUT:
 
-    - ``code`` -- The associated code of this encoder.
+    - ``code`` -- the associated code of this encoder
 
     EXAMPLES::
 
@@ -437,7 +439,7 @@ class PuncturedCodeOriginalCodeDecoder(Decoder):
 
     INPUT:
 
-    - ``code`` -- The associated code of this encoder
+    - ``code`` -- the associated code of this encoder
 
     - ``strategy`` -- (default: ``None``) the strategy used to decode.
       The available strategies are:
@@ -480,7 +482,7 @@ class PuncturedCodeOriginalCodeDecoder(Decoder):
 
         sage: C = codes.GeneralizedReedSolomonCode(GF(16, 'a').list()[:15], 7)
         sage: Cp = codes.PuncturedCode(C, 3)
-        sage: D = codes.decoders.PuncturedCodeOriginalCodeDecoder(Cp, strategy="try-all")
+        sage: D = codes.decoders.PuncturedCodeOriginalCodeDecoder(Cp, strategy='try-all')
         sage: "error-erasure" in D.decoder_type()
         False
 
@@ -491,7 +493,7 @@ class PuncturedCodeOriginalCodeDecoder(Decoder):
         sage: Cp = codes.PuncturedCode(C, 3)
         sage: Dor = C.decoder("Gao")
         sage: D = codes.decoders.PuncturedCodeOriginalCodeDecoder(Cp, original_decoder=Dor,
-        ....:                                                     strategy="error-erasure")
+        ....:                                                     strategy='error-erasure')
         sage: D.original_decoder() == Dor
         True
     """
@@ -579,7 +581,6 @@ class PuncturedCodeOriginalCodeDecoder(Decoder):
             sage: D = codes.decoders.PuncturedCodeOriginalCodeDecoder(Cp)
             sage: D
             Decoder of Puncturing of [15, 7, 9] Reed-Solomon Code over GF(16) on position(s) [3] through Error-Erasure decoder for [15, 7, 9] Reed-Solomon Code over GF(16)
-
         """
         return "Decoder of %s through %s" % (self.code(), self.original_decoder())
 
@@ -709,6 +710,7 @@ class PuncturedCodeOriginalCodeDecoder(Decoder):
         elif "error-erasure" in D.decoder_type() and number_erasures is None:
             raise ValueError("You must provide the number of erasures")
 
+
 ####################### registration ###############################
 
 PuncturedCode._registered_encoders["PuncturedMatrix"] = PuncturedCodePuncturedMatrixEncoder
