@@ -6,18 +6,18 @@ This module implements functions useful for studying binary self-dual codes.
 The main function is ``self_dual_binary_codes``, which is a case-by-case list
 of entries, each represented by a Python dictionary.
 
-Format of each entry: a Python dictionary with keys ``"order autgp"``, ``"spectrum"``,
-``"code"``, ``"Comment"``, ``"Type"``, where
+Format of each entry: a Python dictionary with keys ``'order autgp'``, ``'spectrum'``,
+``'code'``, ``'Comment'``, ``'Type'``, where
 
-- ``"code"`` -- a sd code `C` of length `n`, dim `n/2`, over `\GF{2}`
+- ``'code'`` -- a sd code `C` of length `n`, dim `n/2`, over `\GF{2}`
 
-- ``"order autgp"`` -- order of the permutation automorphism group of `C`
+- ``'order autgp'`` -- order of the permutation automorphism group of `C`
 
-- ``"Type"`` -- the type of `C` (which can be ``"I"`` or ``"II"``, in the binary case)
+- ``'Type'`` -- the type of `C` (which can be ``'I'`` or ``'II'``, in the binary case)
 
-- ``"spectrum"`` -- the spectrum `[A_0,A_1,...,A_n]`
+- ``'spectrum'`` -- the spectrum `[A_0,A_1,...,A_n]`
 
-- ``"Comment"`` -- possibly an empty string.
+- ``'Comment'`` -- possibly an empty string
 
 Python dictionaries were used since they seemed to be both
 human-readable and allow others to update the database easiest.
@@ -54,10 +54,10 @@ Here's a rather naive construction of self-dual codes in the binary
 case:
 
 For even `m`, let `A_m` denote the `m\times m` matrix over `\GF{2}`
-given by adding the all 1's matrix to the identity matrix (in
+given by adding the all 1s matrix to the identity matrix (in
 ``MatrixSpace(GF(2),m,m)`` of course). If `M_1, ..., M_r` are square
 matrices, let `diag(M_1,M_2,...,M_r)` denote the "block diagonal"
-matrix with the matrices `M_i` on the diagonal and 0's elsewhere. Let
+matrix with the matrices `M_i` on the diagonal and 0s elsewhere. Let
 `C(m_1,...,m_r,s)` denote the linear code with generator matrix
 having block form `G = (I, A)`, where
 `A = diag(A_{m_1},A_{m_2},...,A_{m_r},I_s)`, for some
@@ -141,6 +141,7 @@ def _matA(n):
         A.append(I+O)
     return A
 
+
 def _matId(n):
     r"""
     For internal use; returns a list of identity matrices over GF(2)
@@ -177,9 +178,10 @@ def _MS2(n):
     n2 = n.quo_rem(2)[0]
     return MatrixSpace(_F, n2, n2)
 
+
 def _I2(n):
     r"""
-    Internal function
+    Internal function.
 
     EXAMPLES::
 
@@ -196,6 +198,7 @@ def _I2(n):
     """
     return _MS2(n).identity_matrix()
 
+
 @cached_function
 def _And7():
     """
@@ -253,6 +256,7 @@ def _H8():
 
 ############## main functions ##############
 
+
 def self_dual_binary_codes(n):
     r"""
     Return the dictionary of inequivalent binary self dual codes of length `n`.
@@ -526,7 +530,7 @@ def self_dual_binary_codes(n):
         #      "(1,5)(2,6)(3,7)(4,8)(10,14)(11,15)(12,16)(13,17)" ] )
         spectrum = [1, 0, 1, 0, 28, 0, 28, 0, 198, 0, 198, 0, 28, 0, 28, 0, 1, 0, 1]
         self_dual_codes_18_3 = {"order autgp":7225344,"code":LinearCode(genmat),"spectrum":spectrum,
-                 "Type":"I","Comment": "Large aut gp. Unique codeword of smallest non-zero wt.\
+                 "Type":"I","Comment": "Large aut gp. Unique codeword of smallest nonzero wt.\
                  Same spectrum as '[18,4]' sd code."}
         # [18,4]:
         genmat = _I2(n).augment(block_diagonal_matrix([_matA(n)[8],_matId(n)[8]]))
@@ -534,7 +538,7 @@ def self_dual_binary_codes(n):
         #     "(5,6)(14,15)", "(4,5)(13,14)", "(3,4)(12,13)", "(2,3)(11,12)", "(1,2)(10,11)" ] )
         spectrum = [1, 0, 1, 0, 28, 0, 28, 0, 198, 0, 198, 0, 28, 0, 28, 0, 1, 0, 1]
         self_dual_codes_18_4 = {"order autgp":10321920,"code":LinearCode(genmat),"spectrum":spectrum,
-                 "Type":"I","Comment": "Huge aut gp. Unique codeword of smallest non-zero wt.\
+                 "Type":"I","Comment": "Huge aut gp. Unique codeword of smallest nonzero wt.\
                  Same spectrum as '[18,3]' sd code."}
         # [18,5]:
         C = self_dual_binary_codes(n-2)["%s" % (n-2)]["5"]["code"]
@@ -558,7 +562,7 @@ def self_dual_binary_codes(n):
               "(1,4)(2,6)(3,7)(5,17)(8,14)(10,13)(11,15)(12,16)" ] )
         spectrum = [1, 0, 1, 0, 12, 0, 76, 0, 166, 0, 166, 0, 76, 0, 12, 0, 1, 0, 1]
         self_dual_codes_18_6 = {"order autgp":147456,"code":LinearCode(genmat),"spectrum":spectrum,
-                 "Type":"I","Comment": "'Exceptional'. Unique codeword of smallest non-zero wt."}
+                 "Type":"I","Comment": "'Exceptional'. Unique codeword of smallest nonzero wt."}
         # [18,7] (equiv to H18 in [P])
         genmat = _MS(n)([[1,0,0,0,0,0,0,0,0,1,1,1,1,1,1,1,0,0],
                          [0,1,0,0,0,0,0,0,0,0,0,0,1,1,1,1,0,1],
@@ -608,19 +612,19 @@ def self_dual_binary_codes(n):
         return self_dual_codes
 
     if n == 20:
-    # all of these of these are Type I; 2 of these codes
-    # are formally equivalent but with different automorphism groups;
-    # one of these has a unique codeword of lowest weight
-        A10 = MatrixSpace(_F,10,10)([[1, 1, 1, 1, 1, 1, 1, 1, 1, 0],
-                                     [1, 1, 1, 0, 1, 0, 1, 0, 1, 1],
-                                     [1, 0, 0, 1, 0, 1, 0, 1, 0, 1],
-                                     [0, 0, 0, 1, 1, 1, 0, 1, 0, 1],
-                                     [0, 0, 1, 1, 0, 1, 0, 1, 0, 1],
-                                     [0, 0, 0, 1, 0, 1, 1, 1, 0, 1],
-                                     [0, 1, 0, 1, 0, 1, 0, 1, 0, 1],
-                                     [0, 0, 0, 1, 0, 0, 0, 0, 1, 1],
-                                     [0, 0, 0, 0, 0, 1, 0, 0, 1, 1],
-                                     [0, 0, 0, 0, 0, 0, 0, 1, 1, 1]])
+        # all of these of these are Type I; 2 of these codes
+        # are formally equivalent but with different automorphism groups;
+        # one of these has a unique codeword of lowest weight
+        A10 = MatrixSpace(_F, 10, 10)([[1, 1, 1, 1, 1, 1, 1, 1, 1, 0],
+                                       [1, 1, 1, 0, 1, 0, 1, 0, 1, 1],
+                                       [1, 0, 0, 1, 0, 1, 0, 1, 0, 1],
+                                       [0, 0, 0, 1, 1, 1, 0, 1, 0, 1],
+                                       [0, 0, 1, 1, 0, 1, 0, 1, 0, 1],
+                                       [0, 0, 0, 1, 0, 1, 1, 1, 0, 1],
+                                       [0, 1, 0, 1, 0, 1, 0, 1, 0, 1],
+                                       [0, 0, 0, 1, 0, 0, 0, 0, 1, 1],
+                                       [0, 0, 0, 0, 0, 1, 0, 0, 1, 1],
+                                       [0, 0, 0, 0, 0, 0, 0, 1, 1, 1]])
         # [20,0]:
         genmat = _I2(n).augment(_I2(n))
         # G = PermutationGroup( ["(10,20)", "(9,10)(19,20)", "(8,9)(18,19)", "(7,8)(17,18)", "(6,7)(16,17)",\
