@@ -1,13 +1,12 @@
 """
 Baxter permutations
 """
-
-from sage.structure.unique_representation import UniqueRepresentation
-from sage.structure.parent import Parent
-from sage.sets.disjoint_union_enumerated_sets import DisjointUnionEnumeratedSets
 from sage.combinat.permutation import Permutations
-
+from sage.rings.integer import Integer
 from sage.rings.integer_ring import ZZ
+from sage.sets.disjoint_union_enumerated_sets import DisjointUnionEnumeratedSets
+from sage.structure.parent import Parent
+from sage.structure.unique_representation import UniqueRepresentation
 
 
 class BaxterPermutations(UniqueRepresentation, Parent):
@@ -25,8 +24,8 @@ class BaxterPermutations(UniqueRepresentation, Parent):
 
     INPUT:
 
-    - ``n`` -- (default: ``None``) a nonnegative integer, the size of
-      the permutations.
+    - ``n`` -- nonnegative integer (default: ``None``); the size of
+      the permutations
 
     OUTPUT:
 
@@ -79,13 +78,13 @@ class BaxterPermutations_size(BaxterPermutations):
             Baxter permutations of size 5
         """
         self.element_class = Permutations(n).element_class
-        self._n = ZZ(n)
+        self._n = Integer(n)
         from sage.categories.finite_enumerated_sets import FiniteEnumeratedSets
         super().__init__(category=FiniteEnumeratedSets())
 
-    def _repr_(self):
+    def _repr_(self) -> str:
         """
-        Return a string representation of ``self``
+        Return a string representation of ``self``.
 
         EXAMPLES::
 
@@ -93,16 +92,16 @@ class BaxterPermutations_size(BaxterPermutations):
             sage: BaxterPermutations_size(5)
             Baxter permutations of size 5
         """
-        return "Baxter permutations of size %s" % self._n
+        return f"Baxter permutations of size {self._n}"
 
-    def __contains__(self, x):
+    def __contains__(self, x) -> bool:
         r"""
         Return ``True`` if and only if ``x`` is a Baxter permutation of
         size ``self._n``.
 
         INPUT:
 
-        - ``x`` -- a permutation.
+        - ``x`` -- a permutation
 
         EXAMPLES::
 
@@ -150,9 +149,7 @@ class BaxterPermutations_size(BaxterPermutations):
         r"""
         Efficient generation of Baxter permutations.
 
-        OUTPUT:
-
-        An iterator over the Baxter permutations of size ``self._n``.
+        OUTPUT: an iterator over the Baxter permutations of size ``self._n``
 
         EXAMPLES::
 
@@ -230,12 +227,11 @@ class BaxterPermutations_size(BaxterPermutations):
             Integer Ring
         """
         if self._n == 0:
-            return 1
-        from sage.arith.misc import binomial
-        return sum((binomial(self._n + 1, k) *
-                    binomial(self._n + 1, k + 1) *
-                    binomial(self._n + 1, k + 2)) //
-                   ((self._n + 1) * binomial(self._n + 1, 2))
+            return ZZ.one()
+        n = self._n + 1
+        return sum((n.binomial(k) *
+                    n.binomial(k + 1) *
+                    n.binomial(k + 2)) // (n * n.binomial(2))
                    for k in range(self._n))
 
 
@@ -287,7 +283,7 @@ class BaxterPermutations_all(DisjointUnionEnumeratedSets, BaxterPermutations):
 
         INPUT:
 
-        - ``x`` -- any object.
+        - ``x`` -- any object
 
         EXAMPLES::
 
@@ -312,7 +308,7 @@ class BaxterPermutations_all(DisjointUnionEnumeratedSets, BaxterPermutations):
 
         INPUT:
 
-        - ``p`` -- a Baxter permutation.
+        - ``p`` -- a Baxter permutation
 
         OUTPUT:
 
