@@ -1,6 +1,6 @@
 # sage.doctest: needs sage.combinat sage.modules
 """
-Binary Recurrence Sequences
+Binary recurrence sequences
 
 This class implements several methods relating to general linear binary
 recurrence sequences, including a sieve to find perfect powers in integral
@@ -348,7 +348,7 @@ class BinaryRecurrenceSequence(SageObject):
         """
         return self(1) - self(0) == self(2) - self(1) == self(3) - self(2)
 
-    def period(self, m):
+    def period(self, m, *, eventual=False):
         """
         Return the period of the binary recurrence sequence modulo
         an integer ``m``.
@@ -360,6 +360,11 @@ class BinaryRecurrenceSequence(SageObject):
 
         - ``m`` -- integer; modulo which the period of the recurrence relation is calculated
 
+        - ``eventual`` -- boolean (default: ``False``); if ``True``, allow the
+          sequence to be eventually periodic, rather than requiring it to be
+          purely periodic. So `n_1` might not be congruent to `n_2` modulo
+          ``period(m)`` unless `n_1` and `n_2` are large.
+
         OUTPUT: integer (the period of the sequence modulo m)
 
         EXAMPLES:
@@ -392,7 +397,36 @@ class BinaryRecurrenceSequence(SageObject):
             sage: S.period(17)
             8
 
+        Letting ``eventual`` be ``True`` allows us to find the period of a
+        sequence that is not purely periodic. ::
+
+            sage: T = BinaryRecurrenceSequence(5,12,u0=0,u1=1)
+            sage: [T(n) % 10 for n in range(20)]
+            [0, 1, 5, 7, 5, 9, 5, 3, 5, 1, 5, 7, 5, 9, 5, 3, 5, 1, 5, 7]
+            sage: T.period(10)
+            Traceback (most recent call last):
+            ...
+            ValueError: Binary recurrence sequence modulo 10 is not a purely
+            periodic sequence.
+            sage: T.period(10,eventual=True)
+            8
+
         .. NOTE:: The answer is cached.
+
+        TESTS:
+
+        Verify that :issue:`38112` is fixed::
+
+            sage: T = BinaryRecurrenceSequence(3,2,u0=0,u1=1)
+            sage: [T(n) % 4 for n in range(5)]
+            [0, 1, 3, 3, 3]
+            sage: T.period(4)
+            Traceback (most recent call last):
+            ...
+            ValueError: Binary recurrence sequence modulo 4 is not a purely
+            periodic sequence.
+            sage: T.period(4,eventual=True)
+            1
         """
 
         # If we have already computed the period mod m, then we return the stored value.
@@ -407,6 +441,16 @@ class BinaryRecurrenceSequence(SageObject):
             Fac = list(m.factor())
             Periods = {}
 
+            if eventual is True:
+                # There are only m^2 possible pairs modulo m. Since the numbering
+                # of the sequence starts at 0, this implies that the term numbered
+                # m^2 must be in periodic part of the sequence. Hence, the
+                # sequence starting with the terms numbered m^2 and m^2 + 1 must
+                # be purely periodic.
+                an = (A**(m**2)) * w
+                return BinaryRecurrenceSequence(self.b, self.c,
+                    an[0], an[1]).period(m, eventual=False)
+
             # To compute the period mod m, we compute the least integer n such that A^n*w == w.  This necessarily
             # divides the order of A as a matrix in GL_2(Z/mZ).
 
@@ -489,6 +533,10 @@ class BinaryRecurrenceSequence(SageObject):
                         if FF*v == v:
                             perpe = perp*p**tries
                             break
+                        if tries > e:
+                            raise ValueError("Binary recurrence sequence " +
+                                             f"modulo {m} is not a purely " +
+                                             "periodic sequence.")
                 Periods[p] = perpe
 
             # take the lcm of the periods mod all distinct primes dividing m
@@ -729,8 +777,8 @@ class BinaryRecurrenceSequence(SageObject):
 
                     # Check how long each element has persisted, if it is for at least 7 cycles,
                     # then we check to see if it is actually a perfect power
-                    for i in Possible_count:
-                        if Possible_count[i] == 7:
+                    for i, pci in Possible_count.items():
+                        if pci == 7:
                             n = Integer(i)
                             if n < Bound:
                                 if _is_p_power(self(n), p):
