@@ -1,5 +1,5 @@
 r"""
-Enumerated sets of partitions, tableaux, ...
+Partitions, tableaux, and others
 
 Partitions
 ----------
