@@ -1,6 +1,6 @@
 # sage.doctest: needs sage.combinat sage.modules
 r"""
-Free Quasi-symmetric functions
+Free quasi-symmetric functions
 
 AUTHORS:
 
@@ -165,8 +165,7 @@ class FQSymBasis_abstract(CombinatorialFreeModule, BindableClass):
 
         return super()._coerce_map_from_(R)
 
-    @cached_method
-    def an_element(self):
+    def _an_element_(self):
         """
         Return an element of ``self``.
 
@@ -364,8 +363,14 @@ class FreeQuasisymmetricFunctions(UniqueRepresentation, Parent):
 
             sage: F = algebras.FQSym(QQ)
             sage: TestSuite(F).run() # long time (3s)
+
+            sage: F = algebras.FQSym(ZZ).F()
+            sage: F.is_commutative()
+            False
         """
         category = HopfAlgebras(R).Graded().Connected()
+        if R.is_zero():
+            category = category.Commutative()
         Parent.__init__(self, base=R, category=category.WithRealizations())
 
         # Bases
@@ -401,7 +406,7 @@ class FreeQuasisymmetricFunctions(UniqueRepresentation, Parent):
         """
         return self.F()
 
-    _shorthands = tuple(['F', 'G', 'M'])
+    _shorthands = ('F', 'G', 'M')
 
     class F(FQSymBasis_abstract):
         r"""
@@ -689,7 +694,7 @@ class FreeQuasisymmetricFunctions(UniqueRepresentation, Parent):
                     raise ValueError("n must be at least the maximal degree")
 
                 SGA = SymmetricGroupAlgebra(self.base_ring(), n)
-                return SGA._from_dict({Permutations(n)(key): c for (key, c) in self})
+                return SGA._from_dict({Permutations(n)(key): c for key, c in self})
 
     class G(FQSymBasis_abstract):
         r"""
@@ -1219,7 +1224,7 @@ class FreeQuasisymmetricFunctions(UniqueRepresentation, Parent):
                 # See the FQSymBases.ElementMethods.star_involution doc
                 # for the formula we're using here.
                 M = self.parent()
-                return M._from_dict({w.complement().reverse(): c for (w, c) in self},
+                return M._from_dict({w.complement().reverse(): c for w, c in self},
                                     remove_zeros=False)
 
 
@@ -1351,18 +1356,6 @@ class FQSymBases(Category_realization_of_parent):
             """
             return False
 
-        def is_commutative(self):
-            """
-            Return whether this `FQSym` is commutative.
-
-            EXAMPLES::
-
-                sage: F = algebras.FQSym(ZZ).F()
-                sage: F.is_commutative()
-                False
-            """
-            return self.base_ring().is_zero()
-
         def some_elements(self):
             """
             Return some elements of the free quasi-symmetric functions.
@@ -1523,7 +1516,7 @@ class FQSymBases(Category_realization_of_parent):
                 sage: A.from_symmetric_group_algebra(SGA4.zero())
                 0
             """
-            return self._from_dict({Permutation(key): c for (key, c) in x})
+            return self._from_dict({Permutation(key): c for key, c in x})
 
     class ElementMethods:
         def omega_involution(self):
@@ -1634,7 +1627,7 @@ class FQSymBases(Category_realization_of_parent):
             # componentwise, then convert back.
             parent = self.parent()
             F = parent.realization_of().F()
-            dct = {I.reverse(): coeff for (I, coeff) in F(self)}
+            dct = {I.reverse(): coeff for I, coeff in F(self)}
             return parent(F._from_dict(dct, remove_zeros=False))
 
         def psi_involution(self):
@@ -1736,7 +1729,7 @@ class FQSymBases(Category_realization_of_parent):
             # componentwise, then convert back.
             parent = self.parent()
             F = parent.realization_of().F()
-            dct = {I.complement(): coeff for (I, coeff) in F(self)}
+            dct = {I.complement(): coeff for I, coeff in F(self)}
             return parent(F._from_dict(dct, remove_zeros=False))
 
         def star_involution(self):
@@ -1856,7 +1849,7 @@ class FQSymBases(Category_realization_of_parent):
             # complement componentwise, then convert back.
             parent = self.parent()
             F = parent.realization_of().F()
-            dct = {I.complement().reverse(): coeff for (I, coeff) in F(self)}
+            dct = {I.complement().reverse(): coeff for I, coeff in F(self)}
             return parent(F._from_dict(dct, remove_zeros=False))
 
         def to_symmetric_group_algebra(self, n=None):
