@@ -1,6 +1,6 @@
 # sage.doctest: needs sage.combinat sage.graphs sage.modules
 r"""
-Free Pre-Lie Algebras
+Free pre-Lie algebras
 
 AUTHORS:
 
@@ -375,8 +375,7 @@ class FreePreLieAlgebra(CombinatorialFreeModule):
         """
         return t.node_number()
 
-    @cached_method
-    def an_element(self):
+    def _an_element_(self):
         """
         Return an element of ``self``.
 
