@@ -1,6 +1,6 @@
 # sage.doctest: needs sage.combinat sage.graphs sage.modules
 r"""
-Grossman-Larson Hopf Algebras
+Grossman-Larson Hopf algebras
 
 AUTHORS:
 
@@ -22,7 +22,6 @@ from sage.combinat.words.alphabet import Alphabet
 from sage.combinat.rooted_tree import (RootedTrees, RootedTree,
                                        LabelledRootedTrees,
                                        LabelledRootedTree)
-from sage.misc.cachefunc import cached_method
 from sage.categories.rings import Rings
 from sage.sets.family import Family
 from sage.rings.integer_ring import ZZ
@@ -362,8 +361,7 @@ class GrossmanLarsonAlgebra(CombinatorialFreeModule):
         """
         return t.node_number() - 1
 
-    @cached_method
-    def an_element(self):
+    def _an_element_(self):
         """
         Return an element of ``self``.
 
