@@ -28,21 +28,29 @@ AUTHORS:
 
 from sage.misc.cachefunc import cached_method
 from sage.matrix.constructor import matrix
-from sage.structure.element import is_Matrix
+from sage.misc.lazy_import import lazy_import
+from sage.structure.element import Matrix
 from sage.matrix.matrix_space import MatrixSpace
 from sage.misc.inherit_comparison import InheritComparisonClasscallMetaclass
 from sage.misc.classcall_metaclass import typecall
 from sage.combinat.subset import powerset
-from sage.matrix.matrix_integer_sparse import Matrix_integer_sparse
 from sage.rings.integer_ring import ZZ
 from sage.combinat.root_system.cartan_type import CartanType, CartanType_abstract
 from sage.combinat.root_system.root_system import RootSystem
 from sage.sets.family import Family
-from sage.graphs.digraph import DiGraph
+
+lazy_import('sage.graphs.digraph', 'DiGraph')
+lazy_import('sage.combinat.root_system.dynkin_diagram', 'DynkinDiagram_class')
 
 
-class CartanMatrix(Matrix_integer_sparse, CartanType_abstract,
-        metaclass=InheritComparisonClasscallMetaclass):
+try:
+    from sage.matrix.matrix_integer_sparse import Matrix_integer_sparse as Base
+except ImportError:
+    from sage.matrix.matrix_generic_sparse import Matrix_generic_sparse as Base
+
+
+class CartanMatrix(Base, CartanType_abstract,
+                   metaclass=InheritComparisonClasscallMetaclass):
     r"""
     A (generalized) Cartan matrix.
 
@@ -81,6 +89,7 @@ class CartanMatrix(Matrix_integer_sparse, CartanType_abstract,
 
     EXAMPLES::
 
+        sage: # needs sage.graphs
         sage: CartanMatrix(['A', 4])
         [ 2 -1  0  0]
         [-1  2 -1  0]
@@ -140,6 +149,7 @@ class CartanMatrix(Matrix_integer_sparse, CartanType_abstract,
 
     ::
 
+        sage: # needs sage.graphs
         sage: CartanMatrix(['G', 2])
         [ 2 -3]
         [-1  2]
@@ -207,10 +217,10 @@ class CartanMatrix(Matrix_integer_sparse, CartanType_abstract,
 
     Examples of Borcherds-Cartan matrices::
 
-        sage: CartanMatrix([[2,-1],[-1,-2]], borcherds=True)
+        sage: CartanMatrix([[2,-1],[-1,-2]], borcherds=True)                            # needs sage.graphs
         [ 2 -1]
         [-1 -2]
-        sage: CartanMatrix('B3', borcherds=[-4,-6,2])
+        sage: CartanMatrix('B3', borcherds=[-4,-6,2])                                   # needs sage.graphs
         [-4 -1  0]
         [-1 -6 -1]
         [ 0 -2  2]
@@ -237,6 +247,7 @@ class CartanMatrix(Matrix_integer_sparse, CartanType_abstract,
 
         EXAMPLES::
 
+            sage: # needs sage.graphs
             sage: C = CartanMatrix(['A',1,1])
             sage: C2 = CartanMatrix([[2, -2], [-2, 2]])
             sage: C3 = CartanMatrix(matrix([[2, -2], [-2, 2]]), [0, 1])
@@ -245,8 +256,9 @@ class CartanMatrix(Matrix_integer_sparse, CartanType_abstract,
 
         TESTS:
 
-        Check that :trac:`15740` is fixed::
+        Check that :issue:`15740` is fixed::
 
+            sage: # needs sage.graphs
             sage: d = DynkinDiagram()
             sage: d.add_edge('a', 'b', 2)
             sage: d.index_set()
@@ -274,7 +286,6 @@ class CartanMatrix(Matrix_integer_sparse, CartanType_abstract,
             dynkin_diagram = None
             subdivisions = None
 
-            from sage.combinat.root_system.dynkin_diagram import DynkinDiagram_class
             if isinstance(data, DynkinDiagram_class):
                 dynkin_diagram = data
                 cartan_type = data._cartan_type
@@ -338,14 +349,15 @@ class CartanMatrix(Matrix_integer_sparse, CartanType_abstract,
 
         INPUT:
 
-        - ``nrows`` - number of rows
+        - ``nrows`` -- number of rows
 
-        - ``ncols`` - number of columns
+        - ``ncols`` -- number of columns
 
-        - ``sparse`` - (boolean) sparseness
+        - ``sparse`` -- boolean
 
         EXAMPLES::
 
+            sage: # needs sage.graphs
             sage: cm = CartanMatrix(['A', 3])
             sage: cm.matrix_space()
             Full MatrixSpace of 3 by 3 sparse matrices over Integer Ring
@@ -374,8 +386,16 @@ class CartanMatrix(Matrix_integer_sparse, CartanType_abstract,
 
         TESTS::
 
-            sage: C = CartanMatrix(['A',1,1]) # indirect doctest
-            sage: TestSuite(C).run(skip=["_test_category", "_test_change_ring"])
+            sage: C = CartanMatrix(['A',1,1])  # indirect doctest                       # needs sage.graphs
+            sage: TestSuite(C).run(skip=["_test_category", "_test_change_ring"])        # needs sage.graphs
+
+        Check that :issue:`37979` is fixed::
+
+            sage: C = CartanMatrix([[2]], index_set=(4,))
+            sage: C.index_set()
+            (4,)
+            sage: CartanType("A3").subtype((2,)) is CartanType("A1").relabel({1:2})
+            True
         """
         self._index_set = index_set
         self.set_immutable()
@@ -384,6 +404,8 @@ class CartanMatrix(Matrix_integer_sparse, CartanType_abstract,
             cartan_type = CartanType(cartan_type)
         elif self.nrows() == 1:
             cartan_type = CartanType(['A', 1])
+            if index_set != (1,):
+                cartan_type = cartan_type.relabel({1: index_set[0]})
         elif cartan_type_check:
             # Placeholder so we don't have to reimplement creating a
             #   Dynkin diagram from a Cartan matrix
@@ -398,9 +420,9 @@ class CartanMatrix(Matrix_integer_sparse, CartanType_abstract,
 
         TESTS::
 
-            sage: CM = CartanMatrix(['A',4])
-            sage: x = loads(dumps(CM))
-            sage: x._index_set
+            sage: CM = CartanMatrix(['A',4])                                            # needs sage.graphs
+            sage: x = loads(dumps(CM))                                                  # needs sage.graphs
+            sage: x._index_set                                                          # needs sage.graphs
             (1, 2, 3, 4)
         """
         if self._cartan_type:
@@ -413,8 +435,8 @@ class CartanMatrix(Matrix_integer_sparse, CartanType_abstract,
 
         EXAMPLES::
 
-            sage: C = CartanMatrix(['A',3])
-            sage: C.root_system()
+            sage: C = CartanMatrix(['A',3])                                             # needs sage.graphs
+            sage: C.root_system()                                                       # needs sage.graphs
             Root system of type ['A', 3]
         """
         if self._cartan_type is not None:
@@ -427,20 +449,20 @@ class CartanMatrix(Matrix_integer_sparse, CartanType_abstract,
 
         EXAMPLES::
 
-            sage: C = CartanMatrix(['A',3])
-            sage: C.root_space()
+            sage: C = CartanMatrix(['A',3])                                             # needs sage.graphs
+            sage: C.root_space()                                                        # needs sage.graphs
             Root space over the Rational Field of the Root system of type ['A', 3]
         """
         return self.root_system().root_space()
 
-    def reflection_group(self, type="matrix"):
+    def reflection_group(self, type='matrix'):
         """
         Return the reflection group corresponding to ``self``.
 
         EXAMPLES::
 
-            sage: C = CartanMatrix(['A',3])
-            sage: C.reflection_group()
+            sage: C = CartanMatrix(['A',3])                                             # needs sage.graphs
+            sage: C.reflection_group()                                                  # needs sage.graphs sage.libs.gap
             Weyl Group of type ['A', 3] (as a matrix group acting on the root space)
         """
         RS = self.root_space()
@@ -468,8 +490,8 @@ class CartanMatrix(Matrix_integer_sparse, CartanType_abstract,
 
         EXAMPLES::
 
-            sage: cm = CartanMatrix([[2,-5],[-2,2]])
-            sage: cm.symmetrizer()
+            sage: cm = CartanMatrix([[2,-5],[-2,2]])                                    # needs sage.graphs
+            sage: cm.symmetrizer()                                                      # needs sage.graphs
             Finite family {0: 2, 1: 5}
 
         TESTS:
@@ -478,9 +500,9 @@ class CartanMatrix(Matrix_integer_sparse, CartanType_abstract,
         with the values given by the Cartan type::
 
             sage: ct = CartanType(['B',4,1])
-            sage: ct.symmetrizer()
+            sage: ct.symmetrizer()                                                      # needs sage.graphs
             Finite family {0: 2, 1: 2, 2: 2, 3: 2, 4: 1}
-            sage: ct.cartan_matrix().symmetrizer()
+            sage: ct.cartan_matrix().symmetrizer()                                      # needs sage.graphs
             Finite family {0: 2, 1: 2, 2: 2, 3: 2, 4: 1}
         """
         sym = self.is_symmetrizable(True)
@@ -501,8 +523,8 @@ class CartanMatrix(Matrix_integer_sparse, CartanType_abstract,
 
         EXAMPLES::
 
-            sage: cm = CartanMatrix(['B',4,1])
-            sage: cm.symmetrized_matrix()
+            sage: cm = CartanMatrix(['B',4,1])                                          # needs sage.graphs
+            sage: cm.symmetrized_matrix()                                               # needs sage.graphs
             [ 4  0 -2  0  0]
             [ 0  4 -2  0  0]
             [-2 -2  4 -2  0]
@@ -522,6 +544,7 @@ class CartanMatrix(Matrix_integer_sparse, CartanType_abstract,
 
         EXAMPLES::
 
+            sage: # needs sage.graphs
             sage: C = CartanMatrix(['A',1,1])
             sage: C.index_set()
             (0, 1)
@@ -537,14 +560,14 @@ class CartanMatrix(Matrix_integer_sparse, CartanType_abstract,
 
         EXAMPLES::
 
-            sage: C = CartanMatrix(['A',4,1])
-            sage: C.cartan_type()
+            sage: C = CartanMatrix(['A',4,1])                                           # needs sage.graphs
+            sage: C.cartan_type()                                                       # needs sage.graphs
             ['A', 4, 1]
 
         If the Cartan type is unknown::
 
-            sage: C = CartanMatrix([[2,-1,-2], [-1,2,-1], [-2,-1,2]])
-            sage: C.cartan_type()
+            sage: C = CartanMatrix([[2,-1,-2], [-1,2,-1], [-2,-1,2]])                   # needs sage.graphs
+            sage: C.cartan_type()                                                       # needs sage.graphs
             [ 2 -1 -2]
             [-1  2 -1]
             [-2 -1  2]
@@ -564,6 +587,7 @@ class CartanMatrix(Matrix_integer_sparse, CartanType_abstract,
 
         EXAMPLES::
 
+            sage: # needs sage.graphs
             sage: C = CartanMatrix(['F',4])
             sage: S = C.subtype([1,2,3])
             sage: S
@@ -575,7 +599,7 @@ class CartanMatrix(Matrix_integer_sparse, CartanType_abstract,
         """
         ind = self.index_set()
         I = [ind.index(i) for i in index_set]
-        return CartanMatrix(self.matrix_from_rows_and_columns(I, I), index_set)
+        return CartanMatrix(self.matrix_from_rows_and_columns(I, I), index_set=index_set)
 
     def rank(self):
         r"""
@@ -583,9 +607,9 @@ class CartanMatrix(Matrix_integer_sparse, CartanType_abstract,
 
         EXAMPLES::
 
-            sage: CartanMatrix(['C',3]).rank()
+            sage: CartanMatrix(['C',3]).rank()                                          # needs sage.graphs
             3
-            sage: CartanMatrix(["A2","B2","F4"]).rank()
+            sage: CartanMatrix(["A2","B2","F4"]).rank()                                 # needs sage.graphs
             8
         """
         return self.ncols()
@@ -596,6 +620,7 @@ class CartanMatrix(Matrix_integer_sparse, CartanType_abstract,
 
         EXAMPLES::
 
+            sage: # needs sage.graphs
             sage: CM = CartanMatrix(['C',3])
             sage: R = CM.relabel({1:0, 2:4, 3:1}); R
             [ 2  0 -1]
@@ -617,6 +642,7 @@ class CartanMatrix(Matrix_integer_sparse, CartanType_abstract,
 
         EXAMPLES::
 
+            sage: # needs sage.graphs
             sage: C = CartanMatrix(['A',2])
             sage: C.dynkin_diagram()
             O---O
@@ -642,7 +668,7 @@ class CartanMatrix(Matrix_integer_sparse, CartanType_abstract,
 
         EXAMPLES::
 
-            sage: CartanMatrix(['C',3]).cartan_matrix()
+            sage: CartanMatrix(['C',3]).cartan_matrix()                                 # needs sage.graphs
             [ 2 -1  0]
             [-1  2 -2]
             [ 0 -1  2]
@@ -656,6 +682,7 @@ class CartanMatrix(Matrix_integer_sparse, CartanType_abstract,
 
         EXAMPLES::
 
+            sage: # needs sage.graphs
             sage: ct = CartanType(['C',3])
             sage: M = CartanMatrix(ct); M
             [ 2 -1  0]
@@ -672,6 +699,7 @@ class CartanMatrix(Matrix_integer_sparse, CartanType_abstract,
 
         An example with arbitrary Cartan matrices::
 
+            sage: # needs sage.graphs
             sage: cm = CartanMatrix([[2,-5], [-2, 2]]); cm
             [ 2 -5]
             [-2  2]
@@ -689,15 +717,16 @@ class CartanMatrix(Matrix_integer_sparse, CartanType_abstract,
 
     def is_simply_laced(self):
         """
-        Implements :meth:`CartanType_abstract.is_simply_laced()`.
+        Implement :meth:`CartanType_abstract.is_simply_laced()`.
 
         A Cartan matrix is simply-laced if all non diagonal entries are `0`
         or `-1`.
 
         EXAMPLES::
 
-            sage: cm = CartanMatrix([[2, -1, -1, -1], [-1, 2, -1, -1], [-1, -1, 2, -1], [-1, -1, -1, 2]])
-            sage: cm.is_simply_laced()
+            sage: cm = CartanMatrix([[2, -1, -1, -1], [-1, 2, -1, -1],                  # needs sage.graphs
+            ....:                    [-1, -1, 2, -1], [-1, -1, -1, 2]])
+            sage: cm.is_simply_laced()                                                  # needs sage.graphs
             True
         """
         for i in range(self.nrows()):
@@ -708,39 +737,39 @@ class CartanMatrix(Matrix_integer_sparse, CartanType_abstract,
 
     def is_crystallographic(self):
         """
-        Implements :meth:`CartanType_abstract.is_crystallographic`.
+        Implement :meth:`CartanType_abstract.is_crystallographic`.
 
         A Cartan matrix is crystallographic if it is symmetrizable.
 
         EXAMPLES::
 
-            sage: CartanMatrix(['F',4]).is_crystallographic()
+            sage: CartanMatrix(['F',4]).is_crystallographic()                           # needs sage.graphs
             True
         """
         return self.is_symmetrizable()
 
     def column_with_indices(self, j):
         """
-        Return the `j^{th}` column `(a_{i,j})_i` of ``self`` as a container
+        Return the `j`-th column `(a_{i,j})_i` of ``self`` as a container
         (or iterator) of tuples `(i, a_{i,j})`
 
         EXAMPLES::
 
-            sage: M = CartanMatrix(['B',4])
-            sage: [ (i,a) for (i,a) in M.column_with_indices(3) ]
+            sage: M = CartanMatrix(['B',4])                                             # needs sage.graphs
+            sage: [ (i,a) for (i,a) in M.column_with_indices(3) ]                       # needs sage.graphs
             [(3, 2), (2, -1), (4, -2)]
         """
         return self.dynkin_diagram().column(j)
 
     def row_with_indices(self, i):
         """
-        Return the `i^{th}` row `(a_{i,j})_j` of ``self`` as a container
+        Return the `i`-th row `(a_{i,j})_j` of ``self`` as a container
         (or iterator) of tuples `(j, a_{i,j})`
 
         EXAMPLES::
 
-            sage: M = CartanMatrix(['C',4])
-            sage: [ (i,a) for (i,a) in M.row_with_indices(3) ]
+            sage: M = CartanMatrix(['C',4])                                             # needs sage.graphs
+            sage: [ (i,a) for (i,a) in M.row_with_indices(3) ]                          # needs sage.graphs
             [(3, 2), (2, -1), (4, -2)]
         """
         return self.dynkin_diagram().row(i)
@@ -758,6 +787,7 @@ class CartanMatrix(Matrix_integer_sparse, CartanType_abstract,
 
         EXAMPLES::
 
+            sage: # needs sage.graphs
             sage: M = CartanMatrix(['C',4])
             sage: M.is_finite()
             True
@@ -785,6 +815,7 @@ class CartanMatrix(Matrix_integer_sparse, CartanType_abstract,
 
         EXAMPLES::
 
+            sage: # needs sage.graphs
             sage: M = CartanMatrix(['C',4])
             sage: M.is_affine()
             False
@@ -822,6 +853,7 @@ class CartanMatrix(Matrix_integer_sparse, CartanType_abstract,
 
         EXAMPLES::
 
+            sage: # needs sage.graphs
             sage: M = CartanMatrix([[2,-2,0],[-2,2,-1],[0,-1,2]])
             sage: M.is_hyperbolic()
             True
@@ -858,6 +890,7 @@ class CartanMatrix(Matrix_integer_sparse, CartanType_abstract,
 
         EXAMPLES::
 
+            sage: # needs sage.graphs
             sage: M = CartanMatrix([[2,-3],[-3,2]])
             sage: M.is_lorentzian()
             True
@@ -876,6 +909,7 @@ class CartanMatrix(Matrix_integer_sparse, CartanType_abstract,
 
         EXAMPLES::
 
+           sage: # needs sage.graphs
            sage: M = CartanMatrix([[2,-3],[-3,2]])
            sage: M.is_indefinite()
            True
@@ -892,6 +926,7 @@ class CartanMatrix(Matrix_integer_sparse, CartanType_abstract,
 
         EXAMPLES::
 
+            sage: # needs sage.graphs
             sage: M = CartanMatrix(['A',5])
             sage: M.is_indecomposable()
             True
@@ -912,6 +947,7 @@ class CartanMatrix(Matrix_integer_sparse, CartanType_abstract,
 
         EXAMPLES::
 
+            sage: # needs sage.graphs
             sage: cm = CartanMatrix([[2,-5,0],[-2,2,-1],[0,-1,2]])
             sage: cm.coxeter_matrix()
             [ 1 -1  2]
@@ -927,7 +963,7 @@ class CartanMatrix(Matrix_integer_sparse, CartanType_abstract,
             sage: ct.cartan_matrix().coxeter_matrix() == ct.coxeter_matrix()
             True
         """
-        scalarproducts_to_order = {0: 2,  1: 3,  2: 4,  3: 6}
+        scalarproducts_to_order = {0: 2, 1: 3, 2: 4, 3: 6}
         from sage.combinat.root_system.coxeter_matrix import CoxeterMatrix
         I = self.index_set()
         n = len(I)
@@ -949,6 +985,7 @@ class CartanMatrix(Matrix_integer_sparse, CartanType_abstract,
 
         EXAMPLES::
 
+            sage: # needs sage.graphs
             sage: cm = CartanMatrix([[2,-5,0],[-2,2,-1],[0,-1,2]])
             sage: G = cm.coxeter_diagram(); G
             Graph on 3 vertices
@@ -972,15 +1009,14 @@ class CartanMatrix(Matrix_integer_sparse, CartanType_abstract,
 
         EXAMPLES::
 
-            sage: M = CartanMatrix(['A',2])
-            sage: M.principal_submatrices()
+            sage: M = CartanMatrix(['A',2])                                             # needs sage.graphs
+            sage: M.principal_submatrices()                                             # needs sage.graphs
             [
                           [ 2 -1]
             [], [2], [2], [-1  2]
             ]
-            sage: M.principal_submatrices(proper=True)
+            sage: M.principal_submatrices(proper=True)                                  # needs sage.graphs
             [[], [2], [2]]
-
         """
         iset = list(range(self.ncols()))
         ret = []
@@ -996,6 +1032,7 @@ class CartanMatrix(Matrix_integer_sparse, CartanType_abstract,
 
         EXAMPLES::
 
+            sage: # needs sage.graphs
             sage: M = CartanMatrix(['A',2])
             sage: M.indecomposable_blocks()
             (
@@ -1036,7 +1073,7 @@ def is_borcherds_cartan_matrix(M):
         sage: is_borcherds_cartan_matrix(O)
         False
     """
-    if not is_Matrix(M):
+    if not isinstance(M, Matrix):
         return False
     if not M.is_square():
         return False
@@ -1097,6 +1134,7 @@ def find_cartan_type_from_matrix(CM):
 
     EXAMPLES::
 
+        sage: # needs sage.graphs
         sage: from sage.combinat.root_system.cartan_matrix import find_cartan_type_from_matrix
         sage: CM = CartanMatrix([[2,-1,-1], [-1,2,-1], [-1,-1,2]])
         sage: find_cartan_type_from_matrix(CM)
@@ -1106,13 +1144,39 @@ def find_cartan_type_from_matrix(CM):
         ['C', 3] relabelled by {1: 0, 2: 1, 3: 2}
         sage: CM = CartanMatrix([[2,-1,-2], [-1,2,-1], [-2,-1,2]])
         sage: find_cartan_type_from_matrix(CM)
+
+    TESTS:
+
+    Check that :issue:`35987` is fixed::
+
+        sage: from sage.combinat.root_system.cartan_matrix import find_cartan_type_from_matrix
+        sage: cm = CartanMatrix(['A',7]).subtype([2,3,5])
+        sage: find_cartan_type_from_matrix(cm)
+        A2xA1 relabelled by {1: 2, 2: 3, 3: 5}
+
+        sage: cm = CartanMatrix(['B',10,1]).subtype([0,1,2,3,5,6,8,9,10])
+        sage: ct = find_cartan_type_from_matrix(cm); ct
+        D4xB3xA2 relabelled by {1: 0, 2: 2, 3: 1, 4: 3, 5: 8, 6: 9, 7: 10, 8: 5, 9: 6}
+        sage: ct.dynkin_diagram()
+            O 3
+            |
+            |
+        O---O---O
+        0   2   1
+        O---O=>=O
+        8   9   10
+        O---O
+        5   6
+        D4xB3xA2 relabelled by {1: 0, 2: 2, 3: 1, 4: 3, 5: 8, 6: 9, 7: 10, 8: 5, 9: 6}
     """
     types = []
+    relabel = []
     for S in CM.dynkin_diagram().connected_components_subgraphs():
         S = DiGraph(S) # We need a simple digraph here
         n = S.num_verts()
         # Build the list to test based upon rank
         if n == 1:
+            relabel.append({1: S.vertices()[0]})
             types.append(CartanType(['A', 1]))
             continue
 
@@ -1149,7 +1213,8 @@ def find_cartan_type_from_matrix(CM):
             T = DiGraph(ct.dynkin_diagram()) # We need a simple digraph here
             iso, match = T.is_isomorphic(S, certificate=True, edge_labels=True)
             if iso:
-                types.append(ct.relabel(match))
+                types.append(ct)
+                relabel.append(match)
                 found = True
                 break
 
@@ -1160,10 +1225,20 @@ def find_cartan_type_from_matrix(CM):
             T = DiGraph(ct.dynkin_diagram()) # We need a simple digraph here
             iso, match = T.is_isomorphic(S, certificate=True, edge_labels=True)
             if iso:
-                types.append(ct.relabel(match))
+                types.append(ct)
+                relabel.append(match)
                 found = True
                 break
         if not found:
             return None
 
-    return CartanType(types)
+    if len(types) == 1:
+        # Irreducible, so just relabel
+        return CartanType(types[0]).relabel(relabel[0])
+    ct = CartanType(types)
+    # ct._index_relabelling is a dict ``(ind, j): i``, where i is an index of
+    #   ``ct``, ``ind`` is the position in the list of types, and j is the
+    #   corresponding index of the type number ``ind``.
+    # In other words, the j-th node of ``types[ind]`` is the i-th node of ``ct``.
+    mapping = {i: relabel[d[0]][d[1]] for d, i in ct._index_relabelling.items()}
+    return ct.relabel(mapping)
