@@ -317,7 +317,7 @@ class CartanType(cartan_type.CartanType_decorator):
 
     def dynkin_diagram(self):
         """
-        Returns the Dynkin diagram for this Cartan type.
+        Return the Dynkin diagram for this Cartan type.
 
         EXAMPLES::
 
@@ -358,7 +358,7 @@ class CartanType(cartan_type.CartanType_decorator):
 
     def dual(self):
         """
-        Implements :meth:`sage.combinat.root_system.cartan_type.CartanType_abstract.dual`,
+        Implement :meth:`sage.combinat.root_system.cartan_type.CartanType_abstract.dual`,
         using that taking the dual and relabelling are commuting operations.
 
         EXAMPLES::
@@ -677,7 +677,6 @@ class CartanType_affine(CartanType, cartan_type.CartanType_affine):
             O---O---O---O
             2   3   4   0
             A4 relabelled by {1: 2, 2: 3, 3: 4, 4: 0}
-
         """
         return self._type.classical().relabel(self._relabelling)
 
@@ -700,7 +699,7 @@ class CartanType_affine(CartanType, cartan_type.CartanType_affine):
 
     def special_node(self):
         r"""
-        Returns a special node of the Dynkin diagram
+        Return a special node of the Dynkin diagram.
 
         .. SEEALSO:: :meth:`~sage.combinat.root_system.CartanType_affine.special_node`
 
@@ -718,7 +717,7 @@ class CartanType_affine(CartanType, cartan_type.CartanType_affine):
 
     def is_untwisted_affine(self):
         """
-        Implement :meth:`CartanType_affine.is_untwisted_affine`
+        Implement :meth:`CartanType_affine.is_untwisted_affine`.
 
         A relabelled Cartan type is untwisted affine if the original is.
 
@@ -726,6 +725,5 @@ class CartanType_affine(CartanType, cartan_type.CartanType_affine):
 
             sage: CartanType(['B', 3, 1]).relabel({1:2, 2:3, 3:0, 0:1}).is_untwisted_affine()
             True
-
         """
         return self._type.is_untwisted_affine()
