@@ -1,6 +1,6 @@
 # sage.doctest: needs sage.combinat sage.modules
 r"""
-Hall-Littlewood Polynomials
+Hall-Littlewood polynomials
 
 Notation used in the definitions follows mainly [Mac1995]_.
 """
@@ -19,14 +19,15 @@ Notation used in the definitions follows mainly [Mac1995]_.
 #                  http://www.gnu.org/licenses/
 #*****************************************************************************
 
-from sage.structure.unique_representation import UniqueRepresentation
-from sage.libs.symmetrica.all import hall_littlewood
-from . import sfa
 import sage.combinat.partition
-from sage.matrix.constructor import matrix
-from sage.categories.morphism import SetMorphism
 from sage.categories.homset import Hom
+from sage.categories.morphism import SetMorphism
+from sage.libs.symmetrica.all import hall_littlewood
+from sage.matrix.constructor import matrix
 from sage.rings.rational_field import QQ
+from sage.structure.unique_representation import UniqueRepresentation
+
+from . import sfa
 
 # P basis cache
 p_to_s_cache = {}
@@ -64,11 +65,9 @@ class HallLittlewood(UniqueRepresentation):
 
     def __repr__(self):
         r"""
-        A string representing the family of Hall-Littlewood symmetric function bases
+        A string representing the family of Hall-Littlewood symmetric function bases.
 
-        OUTPUT:
-
-        - a string representing the class
+        OUTPUT: string representing the class
 
         EXAMPLES::
 
@@ -113,17 +112,13 @@ class HallLittlewood(UniqueRepresentation):
 
     def symmetric_function_ring( self ):
         r"""
-        The ring of symmetric functions associated to the class of Hall-Littlewood
-        symmetric functions
+        Return the ring of symmetric functions associated to the class of
+        Hall-Littlewood symmetric functions.
 
         INPUT:
 
         - ``self`` -- a class of Hall-Littlewood symmetric function bases
 
-        OUTPUT:
-
-        - returns the ring of symmetric functions
-
         EXAMPLES::
 
             sage: HL = SymmetricFunctions(FractionField(QQ['t'])).hall_littlewood()
@@ -134,17 +129,13 @@ class HallLittlewood(UniqueRepresentation):
 
     def base_ring( self ):
         r"""
-        Returns the base ring of the symmetric functions where the
-        Hall-Littlewood symmetric functions live
+        Return the base ring of the symmetric functions where the
+        Hall-Littlewood symmetric functions live.
 
         INPUT:
 
         - ``self`` -- a class of Hall-Littlewood symmetric function bases
 
-        OUTPUT:
-
-        The base ring of the symmetric functions.
-
         EXAMPLES::
 
             sage: HL = SymmetricFunctions(QQ['t'].fraction_field()).hall_littlewood(t=1)
@@ -163,9 +154,7 @@ class HallLittlewood(UniqueRepresentation):
 
         - ``self`` -- a class of Hall-Littlewood symmetric function bases
 
-        OUTPUT:
-
-        The class of the Hall-Littlewood `P` basis.
+        OUTPUT: the class of the Hall-Littlewood `P` basis
 
         EXAMPLES::
 
@@ -263,7 +252,7 @@ class HallLittlewood(UniqueRepresentation):
             sage: Pz(Qz[2,1])
             (z^2-2*z+1)*HLP[2, 1]
             sage: Qz(Py[2])
-            ((-y+z)/(z^3-z^2-z+1))*HLQ[1, 1] + (1/(-z+1))*HLQ[2]
+            -((y-z)/(z^3-z^2-z+1))*HLQ[1, 1] + (1/(-z+1))*HLQ[2]
             sage: Qy(Pz[2])
             ((y-z)/(y^3-y^2-y+1))*HLQ[1, 1] + (1/(-y+1))*HLQ[2]
             sage: Qy.hall_littlewood_family() == HLy
@@ -316,7 +305,7 @@ class HallLittlewood(UniqueRepresentation):
 
     def Q(self):
         r"""
-        Returns the algebra of symmetric functions in Hall-Littlewood `Q`
+        Return the algebra of symmetric functions in Hall-Littlewood `Q`
         basis. This is the same as the `Q` basis in John Stembridge's SF
         examples file.
 
@@ -327,9 +316,7 @@ class HallLittlewood(UniqueRepresentation):
 
         - ``self`` -- a class of Hall-Littlewood symmetric function bases
 
-        OUTPUT:
-
-        - returns the class of the Hall-Littlewood `Q` basis
+        OUTPUT: the class of the Hall-Littlewood `Q` basis
 
         EXAMPLES::
 
@@ -343,7 +330,7 @@ class HallLittlewood(UniqueRepresentation):
 
     def Qp(self):
         r"""
-        Returns the algebra of symmetric functions in Hall-Littlewood `Q^\prime` (Qp)
+        Return the algebra of symmetric functions in Hall-Littlewood `Q^\prime` (Qp)
         basis. This is dual to the Hall-Littlewood `P` basis with respect to
         the standard scalar product.
 
@@ -354,9 +341,7 @@ class HallLittlewood(UniqueRepresentation):
 
         - ``self`` -- a class of Hall-Littlewood symmetric function bases
 
-        OUTPUT:
-
-        - returns the class of the Hall-Littlewood `Qp`-basis
+        OUTPUT: the class of the Hall-Littlewood `Qp`-basis
 
         EXAMPLES::
 
@@ -426,16 +411,14 @@ class HallLittlewood_generic(sfa.SymmetricFunctionAlgebra_generic):
 
     def _s_to_self(self, x):
         r"""
-        Isomorphism from the Schur basis into ``self``
+        Isomorphism from the Schur basis into ``self``.
 
         INPUT:
 
         - ``self`` -- a Hall-Littlewood symmetric function basis
         - ``x`` -- an element of the Schur basis
 
-        OUTPUT:
-
-        - an element of ``self`` equivalent to ``x``
+        OUTPUT: an element of ``self`` equivalent to ``x``
 
         EXAMPLES::
 
@@ -454,16 +437,14 @@ class HallLittlewood_generic(sfa.SymmetricFunctionAlgebra_generic):
 
     def _self_to_s(self, x):
         r"""
-        Isomorphism from ``self`` to the Schur basis
+        Isomorphism from ``self`` to the Schur basis.
 
         INPUT:
 
         - ``self`` -- a Hall-Littlewood symmetric function basis
         - ``x`` -- an element of the basis ``self``
 
-        OUTPUT:
-
-        - an element of the Schur basis equivalent to ``x``
+        OUTPUT: an element of the Schur basis equivalent to ``x``
 
         EXAMPLES::
 
@@ -483,14 +464,14 @@ class HallLittlewood_generic(sfa.SymmetricFunctionAlgebra_generic):
 
     def transition_matrix(self, basis, n):
         r"""
-        Returns the transitions matrix between ``self`` and ``basis`` for the
+        Return the transitions matrix between ``self`` and ``basis`` for the
         homogeneous component of degree ``n``.
 
         INPUT:
 
         - ``self`` -- a Hall-Littlewood symmetric function basis
         - ``basis`` -- another symmetric function basis
-        - ``n`` -- a non-negative integer representing the degree
+        - ``n`` -- nonnegative integer representing the degree
 
         OUTPUT:
 
@@ -543,9 +524,7 @@ class HallLittlewood_generic(sfa.SymmetricFunctionAlgebra_generic):
         - ``left`` -- an element of the basis ``self``
         - ``right`` -- another symmetric function
 
-        OUTPUT:
-
-        the product of ``left`` and ``right`` expanded in the basis ``self``
+        OUTPUT: the product of ``left`` and ``right`` expanded in the basis ``self``
 
         EXAMPLES::
 
@@ -566,15 +545,13 @@ class HallLittlewood_generic(sfa.SymmetricFunctionAlgebra_generic):
 
     def hall_littlewood_family(self):
         r"""
-        The family of Hall-Littlewood bases associated to ``self``
+        The family of Hall-Littlewood bases associated to ``self``.
 
         INPUT:
 
         - ``self`` -- a Hall-Littlewood symmetric function basis
 
-        OUTPUT:
-
-        - returns the class of Hall-Littlewood bases
+        OUTPUT: the class of Hall-Littlewood bases
 
         EXAMPLES::
 
@@ -591,17 +568,15 @@ class HallLittlewood_generic(sfa.SymmetricFunctionAlgebra_generic):
 
         def expand(self, n, alphabet='x'):
             r"""
-            Expands the symmetric function as a symmetric polynomial in ``n`` variables.
+            Expand the symmetric function as a symmetric polynomial in ``n`` variables.
 
             INPUT:
 
             - ``self`` -- an element of a Hall-Littlewood basis
-            - ``n`` -- a positive integer
-            - ``alphabet`` -- a string representing a variable name (default: 'x')
+            - ``n`` -- positive integer
+            - ``alphabet`` -- string representing a variable name (default: ``'x'``)
 
-            OUTPUT:
-
-            - returns a symmetric polynomial of ``self`` in ``n`` variables
+            OUTPUT: a symmetric polynomial of ``self`` in ``n`` variables
 
             EXAMPLES::
 
@@ -625,7 +600,7 @@ class HallLittlewood_generic(sfa.SymmetricFunctionAlgebra_generic):
 
         def scalar(self, x, zee=None):
             r"""
-            Returns standard scalar product between ``self`` and ``x``.
+            Return standard scalar product between ``self`` and ``x``.
 
             This is the default implementation that converts both ``self`` and ``x``
             into Schur functions and performs the scalar product that basis.
@@ -638,9 +613,7 @@ class HallLittlewood_generic(sfa.SymmetricFunctionAlgebra_generic):
             - ``self`` -- an element of a Hall-Littlewood basis
             - ``x`` -- another symmetric element of the symmetric functions
 
-            OUTPUT:
-
-            - returns the scalar product between ``self`` and ``x``
+            OUTPUT: the scalar product between ``self`` and ``x``
 
             EXAMPLES::
 
@@ -664,7 +637,7 @@ class HallLittlewood_generic(sfa.SymmetricFunctionAlgebra_generic):
 
         def scalar_hl(self, x, t=None):
             r"""
-            Returns the Hall-Littlewood (with parameter ``t``) scalar product
+            Return the Hall-Littlewood (with parameter ``t``) scalar product
             of ``self`` and ``x``.
 
             The Hall-Littlewood scalar product is defined in Macdonald's
@@ -681,9 +654,7 @@ class HallLittlewood_generic(sfa.SymmetricFunctionAlgebra_generic):
             - ``t`` -- an optional parameter, if this parameter is not specified then
               the value of the ``t`` from the basis is used in the calculation
 
-            OUTPUT:
-
-            - returns the Hall-Littlewood scalar product between ``self`` and ``x``
+            OUTPUT: the Hall-Littlewood scalar product between ``self`` and ``x``
 
             EXAMPLES::
 
@@ -724,7 +695,7 @@ class HallLittlewood_p(HallLittlewood_generic):
 
     def __init__(self, hall_littlewood):
         r"""
-        A class with methods for working with the Hall-Littlewood `P` basis
+        A class with methods for working with the Hall-Littlewood `P` basis.
 
         The `P` basis is calculated from the Schur basis using the functions
         in :meth:`sage.combinat.sf.kfpoly`.  These functions calculate Kostka-Foulkes polynomials
@@ -781,7 +752,7 @@ class HallLittlewood_p(HallLittlewood_generic):
 
     def _s_to_self_base(self, part):
         r"""
-        Returns a function which gives the coefficient of a partition
+        Return a function which gives the coefficient of a partition
         in the expansion of the Schur functions ``s(part)`` in the Hall-Littlewood
         `P` basis.
 
@@ -813,7 +784,7 @@ class HallLittlewood_p(HallLittlewood_generic):
 
     def _s_cache(self, n):
         r"""
-        Computes the change of basis between the `P` polynomials and the
+        Compute the change of basis between the `P` polynomials and the
         Schur functions for partitions of size ``n``.
 
         Uses the fact that the transformation matrix is upper-triangular in
@@ -895,7 +866,7 @@ class HallLittlewood_q(HallLittlewood_generic):
 
     def _p_to_q_normalization(self, m):
         r"""
-        Returns the scalar coefficient on self(m) when converting from the
+        Return the scalar coefficient on self(m) when converting from the
         `Q` basis to the `P` basis. Note that this assumes that ``m`` is a
         Partition object.
 
@@ -984,7 +955,7 @@ class HallLittlewood_qp(HallLittlewood_generic):
 
     def _to_s(self, part):
         r"""
-        Returns a function which gives the coefficient of a partition
+        Return a function which gives the coefficient of a partition
         in the Schur expansion of ``self(part)``.
 
         INPUT:
@@ -1018,7 +989,7 @@ class HallLittlewood_qp(HallLittlewood_generic):
 
     def _s_cache(self, n):
         r"""
-        Computes the change of basis between the `Q^\prime` polynomials and the
+        Compute the change of basis between the `Q^\prime` polynomials and the
         Schur functions for partitions of size ``n``.
 
         Uses the fact that the transformation matrix is lower-triangular in
@@ -1027,7 +998,7 @@ class HallLittlewood_qp(HallLittlewood_generic):
         INPUT:
 
         - ``self`` -- an instance of the Hall-Littlewood `P` basis
-        - ``n`` -- a positive integer
+        - ``n`` -- positive integer
 
         EXAMPLES::
 
