@@ -19,12 +19,13 @@ Monomial symmetric functions
 #                  https://www.gnu.org/licenses/
 # ****************************************************************************
 
-from . import classical
 import sage.libs.symmetrica.all as symmetrica
-from sage.rings.integer import Integer
-from sage.rings.infinity import infinity
+from sage.arith.misc import binomial, factorial, multinomial
 from sage.combinat.partition import _Partitions
-from sage.arith.misc import multinomial, factorial, binomial
+from sage.rings.infinity import infinity
+from sage.rings.integer import Integer
+
+from . import classical
 
 
 class SymmetricFunctionAlgebra_monomial(classical.SymmetricFunctionAlgebra_classical):
@@ -397,6 +398,12 @@ class SymmetricFunctionAlgebra_monomial(classical.SymmetricFunctionAlgebra_class
                 sage: m.zero().principal_specialization(3)
                 0
             """
+            if n == 1:
+                R = self.base_ring()
+                mc = self.monomial_coefficients(copy=False).items()
+                return R.sum(c for partition, c in mc
+                             if len(partition) <= 1)
+
             if q == 1:
                 if n == infinity:
                     raise ValueError("the stable principal specialization at q=1 is not defined")
@@ -486,7 +493,9 @@ class SymmetricFunctionAlgebra_monomial(classical.SymmetricFunctionAlgebra_class
                 try:
                     ring(name)
                 except TypeError:
-                    from sage.rings.polynomial.polynomial_ring_constructor import PolynomialRing
+                    from sage.rings.polynomial.polynomial_ring_constructor import (
+                        PolynomialRing,
+                    )
                     return PolynomialRing(ring, name).gen()
                 else:
                     raise ValueError("the variable %s is in the base ring, pass it explicitly" % name)
@@ -514,5 +523,4 @@ class SymmetricFunctionAlgebra_monomial(classical.SymmetricFunctionAlgebra_class
 # Backward compatibility for unpickling
 from sage.misc.persist import register_unpickle_override
 
-
 register_unpickle_override('sage.combinat.sf.monomial', 'SymmetricFunctionAlgebraElement_monomial', SymmetricFunctionAlgebra_monomial.Element)
