@@ -39,36 +39,44 @@ import platform
 import re
 from collections import defaultdict
 from functools import reduce
+from re import Pattern
 from typing import Literal, Union, overload
 
+from sage.doctest.check_tolerance import (
+    ToleranceExceededError,
+    check_tolerance_complex_domain,
+    check_tolerance_real_domain,
+    float_regex,
+)
+from sage.doctest.external import available_software, external_software
+from sage.doctest.marked_output import MarkedOutput
+from sage.doctest.rif_tol import RIFtol, add_tolerance
 from sage.misc.cachefunc import cached_function
 from sage.repl.preparse import preparse, strip_string_literals
-from sage.doctest.rif_tol import RIFtol, add_tolerance
-from sage.doctest.marked_output import MarkedOutput
-from sage.doctest.check_tolerance import (
-    ToleranceExceededError, check_tolerance_real_domain,
-    check_tolerance_complex_domain, float_regex)
-
-from .external import available_software, external_software
-
 
 # This is the correct pattern to match ISO/IEC 6429 ANSI escape sequences:
-ansi_escape_sequence = re.compile(r"(\x1b[@-Z\\-~]|\x1b\[.*?[@-~]|\x9b.*?[@-~])")
+ansi_escape_sequence: Pattern[str] = re.compile(
+    r"(\x1b[@-Z\\-~]|\x1b\[.*?[@-~]|\x9b.*?[@-~])"
+)
 
-special_optional_regex = (
+special_optional_regex_raw = (
     "py2|long time|not implemented|not tested|optional|needs|known bug"
 )
-tag_with_explanation_regex = r"((?:!?\w|[.])*)\s*(?:\((?P<cmd_explanation>.*?)\))?"
-optional_regex = re.compile(
-    rf"[^ a-z]\s*(?P<cmd>{special_optional_regex})(?:\s|[:-])*(?P<tags>(?:(?:{tag_with_explanation_regex})\s*)*)",
+tag_with_explanation_regex_raw = r"((?:!?\w|[.])*)\s*(?:\((?P<cmd_explanation>.*?)\))?"
+optional_regex: Pattern[str] = re.compile(
+    rf"[^ a-z]\s*(?P<cmd>{special_optional_regex_raw})(?:\s|[:-])*(?P<tags>(?:(?:{tag_with_explanation_regex_raw})\s*)*)",
     re.IGNORECASE,
 )
-special_optional_regex = re.compile(special_optional_regex, re.IGNORECASE)
-tag_with_explanation_regex = re.compile(tag_with_explanation_regex, re.IGNORECASE)
+special_optional_regex: Pattern[str] = re.compile(
+    special_optional_regex_raw, re.IGNORECASE
+)
+tag_with_explanation_regex: Pattern[str] = re.compile(
+    tag_with_explanation_regex_raw, re.IGNORECASE
+)
 
-nodoctest_regex = re.compile(r'\s*(#+|%+|r"+|"+|\.\.)\s*nodoctest')
-optionaltag_regex = re.compile(r"^(\w|[.])+$")
-optionalfiledirective_regex = re.compile(
+no_doctest_regex: Pattern[str] = re.compile(r'\s*(#+|%+|r"+|"+|\.\.)\s*nodoctest')
+optional_tag_regex: Pattern[str] = re.compile(r"^(\w|[.])+$")
+optional_file_directive_regex: Pattern[str] = re.compile(
     r'\s*(#+|%+|r"+|"+|\.\.)\s*sage\.doctest: (.*)'
 )
 
@@ -167,7 +175,7 @@ def parse_optional_tags(
         ....:                     return_string_sans_tags=True)
         ({'scipy': None}, 'sage: #this is not \n....: import scipy', False)
     """
-    safe, literals, state = strip_string_literals(string)
+    safe, literals, _ = strip_string_literals(string)
     split = safe.split('\n', 1)
     if len(split) > 1:
         first_line, rest = split
@@ -231,7 +239,7 @@ def parse_optional_tags(
         return tags
 
 
-def parse_file_optional_tags(lines):
+def parse_file_optional_tags(lines) -> dict[str, str | None]:
     r"""
     Scan the first few lines for file-level doctest directives.
 
@@ -261,11 +269,11 @@ def parse_file_optional_tags(lines):
         ....:     parse_file_optional_tags(enumerate(f))
         {'xyz': None}
     """
-    tags = {}
+    tags: dict[str, str | None] = {}
     for line_count, line in lines:
-        if nodoctest_regex.match(line):
+        if no_doctest_regex.match(line):
             tags['not tested'] = None
-        if m := optionalfiledirective_regex.match(line):
+        if m := optional_file_directive_regex.match(line):
             file_tag_string = m.group(2)
             tags.update(parse_optional_tags('#' + file_tag_string))
         if line_count >= 10:
@@ -274,7 +282,7 @@ def parse_file_optional_tags(lines):
 
 
 @cached_function
-def _standard_tags():
+def _standard_tags() -> frozenset[str]:
     r"""
     Return the set of the names of all standard features.
 
@@ -321,7 +329,7 @@ def _tag_group(tag):
         return 'special'
 
 
-def unparse_optional_tags(tags, prefix='# '):
+def unparse_optional_tags(tags, prefix='# ') -> str:
     r"""
     Return a comment string that sets ``tags``.
 
@@ -596,7 +604,7 @@ def parse_tolerance(source, want):
     return want
 
 
-def pre_hash(s):
+def pre_hash(s) -> str:
     """
     Prepends a string with its length.
 
@@ -821,7 +829,7 @@ class SageDocTestParser(doctest.DocTestParser):
         """
         return not (self == other)
 
-    def parse(self, string, *args):
+    def parse(self, string, *args) -> list[doctest.Example | str]:
         r"""
         A Sage specialization of :class:`doctest.DocTestParser`.
 
@@ -880,26 +888,6 @@ class SageDocTestParser(doctest.DocTestParser):
             sage: ex.source
             'for i in range(Integer(4)):\n    print(i)\n'
 
-        Sage currently accepts backslashes as indicating that the end
-        of the current line should be joined to the next line.  This
-        feature allows for breaking large integers over multiple lines
-        but is not standard for Python doctesting.  It's not
-        guaranteed to persist::
-
-            sage: n = 1234\
-            ....:     5678
-            sage: print(n)
-            12345678
-            sage: type(n)
-            <class 'sage.rings.integer.Integer'>
-
-        It also works without the line continuation::
-
-            sage: m = 8765\
-            4321
-            sage: print(m)
-            87654321
-
         Optional tags at the start of an example block persist to the end of
         the block (delimited by a blank line)::
 
@@ -993,15 +981,15 @@ class SageDocTestParser(doctest.DocTestParser):
 
             sage: parse("::\n\n    sage: # needs sage.combinat\n    sage: from sage.geometry.polyhedron.combinatorial_polyhedron.conversions \\\n    ....:         import incidence_matrix_to_bit_rep_of_Vrep\n    sage: P = polytopes.associahedron(['A',3])\n\n")
             ['::\n\n',
-            '',
-            (None,
-            'from sage.geometry.polyhedron.combinatorial_polyhedron.conversions import incidence_matrix_to_bit_rep_of_Vrep\n',
-            'from sage.geometry.polyhedron.combinatorial_polyhedron.conversions import incidence_matrix_to_bit_rep_of_Vrep\n'),
-            '',
-            (None,
-            "P = polytopes.associahedron(['A',3])\n",
-            "P = polytopes.associahedron(['A',Integer(3)])\n"),
-            '\n']
+             '',
+             (None,
+              'from sage.geometry.polyhedron.combinatorial_polyhedron.conversions \\\n        import incidence_matrix_to_bit_rep_of_Vrep\n',
+              'from sage.geometry.polyhedron.combinatorial_polyhedron.conversions         import incidence_matrix_to_bit_rep_of_Vrep\n'),
+             '',
+             (None,
+              "P = polytopes.associahedron(['A',3])\n",
+              "P = polytopes.associahedron(['A',Integer(3)])\n"),
+             '\n']
 
             sage: example4 = '::\n\n        sage: C.minimum_distance(algorithm="guava")  # optional - guava\n        ...\n        24\n\n'
             sage: parsed4 = DTP.parse(example4)
@@ -1016,20 +1004,10 @@ class SageDocTestParser(doctest.DocTestParser):
         find_sage_continuation = re.compile(r"^(\s*)\.\.\.\.:", re.M)
         find_python_continuation = re.compile(r"^(\s*)\.\.\.([^\.])", re.M)
         python_prompt = re.compile(r"^(\s*)>>>", re.M)
-        backslash_replacer = re.compile(r"""(\s*)sage:(.*)\\\ *
-\ *((\.){4}:)?\ *""")
 
         # The following are used to allow ... at the beginning of output
         ellipsis_tag = "<TEMP_ELLIPSIS_TAG>"
 
-        # Hack for non-standard backslash line escapes accepted by the current
-        # doctest system.
-        m = backslash_replacer.search(string)
-        while m is not None:
-            g = m.groups()
-            string = string[:m.start()] + g[0] + "sage:" + g[1] + string[m.end():]
-            m = backslash_replacer.search(string, m.start())
-
         replace_ellipsis = not python_prompt.search(string)
         if replace_ellipsis:
             # There are no >>> prompts, so we can allow ... to begin the output
@@ -1037,8 +1015,8 @@ class SageDocTestParser(doctest.DocTestParser):
             string = find_python_continuation.sub(r"\1" + ellipsis_tag + r"\2", string)
         string = find_sage_prompt.sub(r"\1>>> sage: ", string)
         string = find_sage_continuation.sub(r"\1...", string)
-        res = doctest.DocTestParser.parse(self, string, *args)
-        filtered = []
+        res: list[doctest.Example | str] = doctest.DocTestParser.parse(self, string, *args)
+        filtered: list[doctest.Example | str] = []
         persistent_optional_tags = self.file_optional_tags
         persistent_optional_tag_setter = None
         persistent_optional_tag_setter_index = None
@@ -1500,7 +1478,7 @@ class SageOutputChecker(doctest.OutputChecker):
             did_fixup = True
 
         if "R[write to console]" in got:
-            # Supress R warnings
+            # suppress R warnings
             r_warning_regex = re.compile(r'R\[write to console\]:.*')
             got = r_warning_regex.sub('', got)
             did_fixup = True
@@ -1531,6 +1509,13 @@ class SageOutputChecker(doctest.OutputChecker):
             got = dup_lib_regex.sub('', got)
             did_fixup = True
 
+        if "duplicate" in got:
+            # Warnings about duplicate rpaths in the linker command line
+            # occurs sometimes when compiling cython code via sage.misc.cython
+            dup_rpath_regex = re.compile("ld: warning: duplicate -rpath .* ignored")
+            got = dup_rpath_regex.sub('', got)
+            did_fixup = True
+
         return did_fixup, want, got
 
     def output_difference(self, example, got, optionflags):
