@@ -28,39 +28,42 @@ from sage.combinat.permutation import Arrangements
 from sage.combinat.subset import Subsets
 from sage.matrix.constructor import matrix
 from sage.misc.functional import sqrt
+from sage.misc.lazy_import import lazy_import
 from sage.misc.misc_c import prod
 from sage.parallel.use_fork import p_iter_fork
 from sage.rings.finite_rings.finite_field_constructor import GF
 from sage.rings.finite_rings.integer_mod_ring import Integers
 from sage.rings.integer_ring import ZZ
-from sage.rings.number_field.number_field import NumberField
 from sage.rings.polynomial.polynomial_ring_constructor import PolynomialRing
 from sage.rings.rational_field import QQ
 from sage.sets.primes import Primes
 from sage.sets.set import Set
-from sage.structure.element import is_Matrix
+from sage.structure.element import Matrix
+
+lazy_import('sage.rings.number_field.number_field', 'NumberField')
 
 
 def automorphism_group_QQ_fixedpoints(rational_function, return_functions=False, iso_type=False):
     r"""
-
-    This function will compute the automorphism group for ``rational_function`` via the method of fixed points
+    Compute the automorphism group for ``rational_function`` via the method of
+    fixed points.
 
     ALGORITHM:
 
-        See Algorithm 3 in Faber-Manes-Viray [FMV]_.
+    See Algorithm 3 in Faber-Manes-Viray [FMV]_.
 
     INPUT:
 
-    - ``rational_function`` - Rational Function defined over `\ZZ` or `\QQ`
+    - ``rational_function`` -- Rational Function defined over `\ZZ` or `\QQ`
 
-    - ``return_functions`` - Boolean Value, True will return elements in the automorphism group
-        as linear fractional transformations. False will return elements as `PGL2` matrices
+    - ``return_functions`` -- boolean value; ``True`` will return elements in
+      the automorphism group as linear fractional transformations. ``False``
+      will return elements as `PGL_2` matrices.
 
-    - ``iso_type`` - Boolean - True will cause the classification of the finite automorphism
-        group to also be returned
+    - ``iso_type`` -- boolean; ``True`` will cause the classification of the
+      finite automorphism group to also be returned
 
-    OUTPUT: a list of automorphisms that make up the Automorphism Group
+    OUTPUT: list of automorphisms that make up the automorphism group
     of ``rational_function``
 
     EXAMPLES::
@@ -69,7 +72,7 @@ def automorphism_group_QQ_fixedpoints(rational_function, return_functions=False,
         sage: rational_function = (z^2 - 2*z - 2)/(-2*z^2 - 2*z + 1)
         sage: from sage.dynamics.arithmetic_dynamics.endPN_automorphism_group import automorphism_group_QQ_fixedpoints
         sage: automorphism_group_QQ_fixedpoints(rational_function, True)
-          [z, 1/z, -z - 1, -z/(z + 1), (-z - 1)/z, -1/(z + 1)]
+        [z, 1/z, -z - 1, -z/(z + 1), (-z - 1)/z, -1/(z + 1)]
 
     ::
 
@@ -77,18 +80,18 @@ def automorphism_group_QQ_fixedpoints(rational_function, return_functions=False,
         sage: rational_function = (z^2 + 2*z)/(-2*z - 1)
         sage: from sage.dynamics.arithmetic_dynamics.endPN_automorphism_group import automorphism_group_QQ_fixedpoints
         sage: automorphism_group_QQ_fixedpoints(rational_function)
-          [
+        [
           [1 0]  [-1 -1]  [-2  0]  [0 2]  [-1 -1]  [ 0 -1]
           [0 1], [ 0  1], [ 2  2], [2 0], [ 1  0], [ 1  1]
-          ]
+        ]
 
     ::
 
         sage: F.<z> = PolynomialRing(QQ)
-        sage: rational_function = (z^2 - 4*z -3)/(-3*z^2 - 2*z + 2)
+        sage: rational_function = (z^2 - 4*z - 3)/(-3*z^2 - 2*z + 2)
         sage: from sage.dynamics.arithmetic_dynamics.endPN_automorphism_group import automorphism_group_QQ_fixedpoints
         sage: automorphism_group_QQ_fixedpoints(rational_function, True, True)
-          ([z, (-z - 1)/z, -1/(z + 1)], 'Cyclic of order 3')
+        ([z, (-z - 1)/z, -1/(z + 1)], 'Cyclic of order 3')
     """
 
     if rational_function.parent().is_field():
@@ -100,7 +103,7 @@ def automorphism_group_QQ_fixedpoints(rational_function, return_functions=False,
 
     F = R.base_ring()
 
-    if F != QQ and F!= ZZ:
+    if F != QQ and F != ZZ:
         raise TypeError("coefficient ring is not the rational numbers or the integers")
 
     z = R.gen(0)
@@ -227,7 +230,7 @@ def automorphism_group_QQ_fixedpoints(rational_function, return_functions=False,
                     elements.append(matrix(F, 2, [zeta, alpha*(1-zeta), 0, 1]))
     factors = (f2 - z*g2).factor()
     L1 = NumberField(z**2 + 1,'i')
-    i=L1.gen(0)
+    i = L1.gen(0)
     L2 = NumberField(z**2 + 3,'isqrt3')
     isqrt3 = L2.gen(0)
     for psi in factors:
@@ -304,13 +307,13 @@ def height_bound(polynomial):
     EXAMPLES::
 
         sage: R.<z> = PolynomialRing(QQ)
-        sage: f = (z^3+2*z+6)
+        sage: f = z^3 + 2*z + 6
         sage: from sage.dynamics.arithmetic_dynamics.endPN_automorphism_group import height_bound
         sage: height_bound(f)
         413526
     """
     # first check that polynomial is over QQ or ZZ
-    K=polynomial.parent()
+    K = polynomial.parent()
 
     if K.is_field():
         R = K.ring()
@@ -318,7 +321,7 @@ def height_bound(polynomial):
         R = K
     F = R.base_ring()
 
-    if F != QQ and F!= ZZ:
+    if F != QQ and F != ZZ:
         raise TypeError("coefficient ring is not the rational numbers or the integers")
 
     # scale polynomial so that it has integer coefficients with gcd 1
@@ -332,6 +335,7 @@ def height_bound(polynomial):
 
     return (6*(L2norm_sq)**3)
 
+
 def PGL_repn(rational_function):
     r"""
     Take a linear fraction transformation and represent it as a 2x2 matrix.
@@ -345,13 +349,13 @@ def PGL_repn(rational_function):
     EXAMPLES::
 
         sage: R.<z> = PolynomialRing(QQ)
-        sage: f = ((2*z-1)/(3-z))
+        sage: f = (2*z-1)/(3-z)
         sage: from sage.dynamics.arithmetic_dynamics.endPN_automorphism_group import PGL_repn
         sage: PGL_repn(f)
         [-2  1]
         [ 1 -3]
     """
-    if is_Matrix(rational_function):
+    if isinstance(rational_function, Matrix):
         return rational_function
     K = rational_function.parent()
     F = K.base_ring()
@@ -362,6 +366,7 @@ def PGL_repn(rational_function):
         g = rational_function.denominator()
         return matrix(F, 2, [f[1], f[0], g[1], g[0]])
 
+
 def PGL_order(A):
     r"""
     Find the multiplicative order of a linear fractional transformation that
@@ -377,7 +382,7 @@ def PGL_order(A):
 
     EXAMPLES::
 
-        sage: M = matrix([[0,2],[2,0]])
+        sage: M = matrix([[0,2], [2,0]])
         sage: from sage.dynamics.arithmetic_dynamics.endPN_automorphism_group import PGL_order
         sage: PGL_order(M)
         2
@@ -399,6 +404,7 @@ def PGL_order(A):
 
     return n
 
+
 def CRT_helper(automorphisms, moduli):
     r"""
     Lift the given list of automorphisms to `Zmod(M)`.
@@ -409,16 +415,16 @@ def CRT_helper(automorphisms, moduli):
 
     INPUT:
 
-    - ``automorphisms`` -- a list of lists of automorphisms over various `Zmod(p^k)`
+    - ``automorphisms`` -- list of lists of automorphisms over various `Zmod(p^k)`
 
     - ``moduli`` -- list of the various `p^k`
 
-    OUTPUT: a list of automorphisms over `Zmod(M)`
+    OUTPUT: list of automorphisms over `Zmod(M)`
 
     EXAMPLES::
 
         sage: from sage.dynamics.arithmetic_dynamics.endPN_automorphism_group import CRT_helper
-        sage: CRT_helper([[matrix([[4,0],[0,1]]), matrix([[0,1],[1,0]])]],[5])
+        sage: CRT_helper([[matrix([[4,0], [0,1]]), matrix([[0,1], [1,0]])]], [5])
         ([
         [4 0]  [0 1]
         [0 1], [1 0]
@@ -446,31 +452,33 @@ def CRT_helper(automorphisms, moduli):
 
     return autos, modulus*moduli[0]
 
+
 def CRT_automorphisms(automorphisms, order_elts, degree, moduli):
     r"""
     Compute a maximal list of automorphisms over `Zmod(M)`.
 
     Given a list of automorphisms over various `Zmod(p^k)`, a list of the
     elements orders, an integer degree, and a list of the `p^k` values compute
-    a maximal list of automorphisms over `Zmod(M)`, such that for every `j` in `len(moduli)`,
+    a maximal list of automorphisms over `Zmod(M)`, such that for every `j` in ``len(moduli)``,
     each element reduces mod ``moduli[j]`` to one of the elements in ``automorphisms[j]`` that
     has order = ``degree``
 
     INPUT:
 
-    - ``automorphisms`` -- a list of lists of automorphisms over various `Zmod(p^k)`
+    - ``automorphisms`` -- list of lists of automorphisms over various `Zmod(p^k)`
 
-    - ``order_elts`` -- a list of lists of the orders of the elements of ``automorphisms``
+    - ``order_elts`` -- list of lists of the orders of the elements of ``automorphisms``
 
-    - ``degree`` - a positive integer
+    - ``degree`` -- positive integer
 
     - ``moduli`` -- list of prime powers, i.e., `p^k`
 
-    OUTPUT: a list containing a list of automorphisms over `Zmod(M)` and the product of the moduli
+    OUTPUT: list containing a list of automorphisms over `Zmod(M)` and the
+    product of the moduli
 
     EXAMPLES::
 
-        sage: aut = [[matrix([[1,0],[0,1]]), matrix([[0,1],[1,0]])]]
+        sage: aut = [[matrix([[1,0], [0,1]]), matrix([[0,1], [1,0]])]]
         sage: ords = [[1,2]]
         sage: degree = 2
         sage: mods = [5]
@@ -491,6 +499,7 @@ def CRT_automorphisms(automorphisms, order_elts, degree, moduli):
     # get list of CRT'ed automorphisms
     return CRT_helper(degree_d_autos, moduli)
 
+
 def valid_automorphisms(automorphisms_CRT, rational_function, ht_bound, M,
                         return_functions=False):
     r"""
@@ -502,24 +511,24 @@ def valid_automorphisms(automorphisms_CRT, rational_function, ht_bound, M,
 
     INPUT:
 
-    - ``automorphisms`` -- a list of lists of automorphisms over various `Zmod(p^k)`
+    - ``automorphisms`` -- list of lists of automorphisms over various `Zmod(p^k)`
 
-    - ``rational_function`` -- A one variable rational function
+    - ``rational_function`` -- a one variable rational function
 
-    - ``ht_bound`` - a positive integer
+    - ``ht_bound`` -- positive integer
 
-    - ``M`` -- a positive integer, a product of prime powers
+    - ``M`` -- positive integer, a product of prime powers
 
-    - ``return_functions`` -- (default: False) boolean
+    - ``return_functions`` -- boolean (default: ``False``)
 
-    OUTPUT: a list of automorphisms over `\ZZ`
+    OUTPUT: list of automorphisms over `\ZZ`
 
     EXAMPLES::
 
         sage: R.<z> = PolynomialRing(QQ)
         sage: F = z^2
         sage: from sage.dynamics.arithmetic_dynamics.endPN_automorphism_group import valid_automorphisms
-        sage: valid_automorphisms([matrix(GF(5),[[0,1],[1,0]])], F, 48, 5, True)
+        sage: valid_automorphisms([matrix(GF(5), [[0,1],[1,0]])], F, 48, 5, True)
         [1/z]
     """
     z = rational_function.parent().gen(0)
@@ -557,21 +566,21 @@ def remove_redundant_automorphisms(automorphisms, order_elts, moduli, integral_a
 
     INPUT:
 
-    - ``automorphisms`` -- a list of lists of automorphisms
+    - ``automorphisms`` -- list of lists of automorphisms
 
-    - ``order_elts`` -- a list of lists of the orders of the elements of ``automorphisms``
+    - ``order_elts`` -- list of lists of the orders of the elements of ``automorphisms``
 
-    - ``moduli`` -- a list of prime powers
+    - ``moduli`` -- list of prime powers
 
     - ``integral_autos`` -- list of known automorphisms
 
-    OUTPUT: a list of automorphisms
+    OUTPUT: list of automorphisms
 
     EXAMPLES::
 
         sage: auts = [[matrix([[1,0],[0,1]]), matrix([[6,0],[0,1]]), matrix([[0,1],[1,0]]),
-        ....: matrix([[6,1],[1,1]]), matrix([[1,1],[1,6]]), matrix([[0,6],[1,0]]),
-        ....: matrix([[1,6],[1,1]]), matrix([[6,6],[1,6]])]]
+        ....:          matrix([[6,1],[1,1]]), matrix([[1,1],[1,6]]), matrix([[0,6],[1,0]]),
+        ....:          matrix([[1,6],[1,1]]), matrix([[6,6],[1,6]])]]
         sage: ord_elts = [[1, 2, 2, 2, 2, 2, 4, 4]]
         sage: mods = [7]
         sage: R.<x> = PolynomialRing(QQ)
@@ -591,7 +600,7 @@ def remove_redundant_automorphisms(automorphisms, order_elts, moduli, integral_a
         for psi in integral_autos:
             #The return_functions boolean determines if the automorphisms
             #are matrices or linear fractional transformations
-            if is_Matrix(psi):
+            if isinstance(psi, Matrix):
                 ppsi = psi.change_ring(GF(p))
                 B = [ppsi[0,0], ppsi[0,1], ppsi[1,0], psi[1,1]]
             else:
@@ -625,15 +634,16 @@ def automorphism_group_QQ_CRT(rational_function, prime_lower_bound=4, return_fun
 
     INPUT:
 
-    - ``rational_function`` - a rational function of a univariate polynomial ring over `\QQ`
+    - ``rational_function`` -- a rational function of a univariate polynomial ring over `\QQ`
 
-    - ``prime_lower_bound`` -- (default: 4) a positive integer - a lower bound for the primes to use for
+    - ``prime_lower_bound`` -- (default: 4) a positive integer; a lower bound for the primes to use for
       the Chinese Remainder Theorem step
 
-    - ``return_functions`` -- (default: True) boolean - True returns linear fractional transformations
-      False returns elements of `PGL(2,\QQ)`
+    - ``return_functions`` -- boolean (default: ``True``); ``True`` returns
+      linear fractional transformations ``False`` returns elements of `PGL(2,\QQ)`
 
-    - ``iso_type`` -- (default: False) boolean - True returns the isomorphism type of the automorphism group
+    - ``iso_type`` -- boolean (default: ``False``); ``True`` returns the
+      isomorphism type of the automorphism group
 
     OUTPUT: a complete list of automorphisms of ``rational_function``
 
@@ -672,7 +682,7 @@ def automorphism_group_QQ_CRT(rational_function, prime_lower_bound=4, return_fun
 
     F = R.base_ring()
 
-    if F != QQ and F!= ZZ:
+    if F != QQ and F != ZZ:
         raise TypeError("coefficient ring is not the rational numbers or the integers")
 
     z = R.gen(0)
@@ -739,7 +749,7 @@ def automorphism_group_QQ_CRT(rational_function, prime_lower_bound=4, return_fun
     # the only possible groups are C_n, D_2n for n|6 or n|4
     # all of these groups have order dividing 24
     while (congruence < (2*MaxH**2)) and len(elements) < gcd(orderaut + [24]):
-        if badprimes%p != 0:  #prime of good reduction
+        if badprimes % p != 0:  #prime of good reduction
             # compute automorphisms mod p
             phi_p = f.change_ring(GF(p))/g.change_ring(GF(p))
             sorted_automorphisms = automorphism_group_FF(phi_p)
@@ -797,7 +807,7 @@ def automorphism_group_QQ_CRT(rational_function, prime_lower_bound=4, return_fun
                             # if an element of Aut_{F_p} has been lifted to QQ
                             # remove that element from Aut_{F_p} so we don't
                             # attempt to lift that element again unnecessarily
-                            automorphisms=remove_redundant_automorphisms(automorphisms,
+                            automorphisms = remove_redundant_automorphisms(automorphisms,
                                 orderelts, primepowers, temp)
                             if order == 4: #have some elements of order 4
                                 # so possible aut group is Z/4 or D_4
@@ -808,7 +818,7 @@ def automorphism_group_QQ_CRT(rational_function, prime_lower_bound=4, return_fun
                                 badorders.append(4)
                     else: #no elements of order d in some F_v
                         for m in divisors(N):
-                            if m%order == 0:
+                            if m % order == 0:
                                 badorders.append(m)
                                 #no elements of that order or any order that
                                 # is a multiple of it
@@ -839,14 +849,16 @@ def automorphism_group_FF(rational_function, absolute=False, iso_type=False, ret
     - ``rational_function`` -- a rational function defined over the fraction field
         of a polynomial ring in one variable with finite field coefficients
 
-    - ``absolute``-- (default: False) boolean - True returns the absolute automorphism group and a field of definition
+    - ``absolute`` -- boolean (default: ``False``); ``True`` returns the
+      absolute automorphism group and a field of definition
 
-    - ``iso_type`` -- (default: False) boolean - True returns the isomorphism type of the automorphism group
+    - ``iso_type`` -- boolean (default: ``False``); ``True`` returns the
+      isomorphism type of the automorphism group
 
-    - ``return_functions`` -- (default: False) boolean, True returns linear fractional transformations
-      False returns elements of `PGL(2)`
+    - ``return_functions`` -- boolean (default: ``False``); ``True`` returns
+      linear fractional transformations ``False`` returns elements of `PGL(2)`
 
-    OUTPUT: a list of automorphisms of ``rational_function``
+    OUTPUT: list of automorphisms of ``rational_function``
 
     EXAMPLES::
 
@@ -880,12 +892,12 @@ def automorphism_group_FF(rational_function, absolute=False, iso_type=False, ret
 
     if not return_functions:
         if absolute:
-            R=G[1][0].parent()
+            R = G[1][0].parent()
             if R.is_field():
                 R = R.ring()
             G[1] = [matrix(R.base_ring(),[[R(g.numerator())[1],R(g.numerator())[0]],[R(g.denominator())[1],R(g.denominator())[0]]]) for g in G[1]]
         else:
-            R=G[0].parent()
+            R = G[0].parent()
             if R.is_field():
                 R = R.ring()
             G = [matrix(R.base_ring(),[[R(g.numerator())[1],R(g.numerator())[0]],[R(g.denominator())[1],R(g.denominator())[0]]]) for g in G]
@@ -897,18 +909,19 @@ def automorphism_group_FF(rational_function, absolute=False, iso_type=False, ret
     else:
         return G, which_group(G[1])
 
+
 def field_descent(sigma, y):
     r"""
-    Function for descending an element in a field E to a subfield F.
+    Function for descending an element in a field `E` to a subfield `F`.
 
-    Here F, E must be finite fields or number fields. This function determines
+    Here `F`, `E` must be finite fields or number fields. This function determines
     the unique image of subfield which is ``y`` by the embedding ``sigma`` if it exists.
     Otherwise returns ``None``.
     This functionality is necessary because Sage does not keep track of subfields.
 
     INPUT:
 
-    - ``sigma``-- an embedding sigma: `F` -> `E` of fields
+    - ``sigma`` -- an embedding sigma: `F` -> `E` of fields
 
     - ``y`` --an element of the field `E`
 
@@ -941,7 +954,7 @@ def field_descent(sigma, y):
     if not remainder.is_constant():
         return
     else:
-        x = x+ F(remainder)
+        x = x + F(remainder)
 
     steps = 1
     while not quotient.is_constant():
@@ -949,11 +962,12 @@ def field_descent(sigma, y):
         if not remainder.is_constant():
             return
         else:
-            x = x+ F(remainder)*a**(steps)
+            x = x + F(remainder)*a**(steps)
             steps += 1
 
     return x + F(quotient)*a**(steps)
 
+
 def rational_function_coefficient_descent(rational_function, sigma, poly_ring):
     r"""
     Function for descending the coefficients of a rational function from field `E`
@@ -961,16 +975,16 @@ def rational_function_coefficient_descent(rational_function, sigma, poly_ring):
 
     Here `F`, `E` must be finite fields or number fields.
     It determines the unique rational function in fraction field of
-    ``poly_ring`` which is the image of ``rational_function`` by ``ssigma``,
+    ``poly_ring`` which is the image of ``rational_function`` by ``sigma``,
     if it exists, and otherwise returns ``None``.
 
     INPUT:
 
     - ``rational_function``--a rational function with coefficients in a field `E`
 
-    - ``sigma``-- a field embedding sigma: `F` -> `E`
+    - ``sigma`` -- a field embedding sigma: `F` -> `E`
 
-    - ``poly_ring``-- a polynomial ring `R` with coefficients in `F`
+    - ``poly_ring`` -- a polynomial ring `R` with coefficients in `F`
 
     OUTPUT: a rational function with coefficients in the fraction field of ``poly_ring``
     if it exists, and otherwise ``None``
@@ -1021,7 +1035,7 @@ def rational_function_coerce(rational_function, sigma, S_polys):
 
     INPUT:
 
-    - ``rational_function``-- rational function with coefficients in `R`
+    - ``rational_function`` -- rational function with coefficients in `R`
 
     - ``sigma`` -- a ring homomorphism sigma: `R` -> ``S_polys``
 
@@ -1052,6 +1066,7 @@ def rational_function_coerce(rational_function, sigma, S_polys):
     else:
         return S_polys([sigma(a) for a in f]) / S_polys([sigma(b) for b in g])
 
+
 def rational_function_reduce(rational_function):
     r"""
     Force Sage to divide out common factors in numerator and denominator
@@ -1061,7 +1076,7 @@ def rational_function_reduce(rational_function):
 
     - ``rational_function`` -- rational function `= F/G` in univariate polynomial ring
 
-    OUTPUT: rational function -- `(F/gcd(F,G) ) / (G/gcd(F,G))`
+    OUTPUT: rational function -- `(F/\gcd(F,G)) / (G/\gcd(F,G))`
 
     EXAMPLES::
 
@@ -1077,6 +1092,7 @@ def rational_function_reduce(rational_function):
     comm_factor = gcd(F,G)
     return (F.quo_rem(comm_factor)[0]) / (G.quo_rem(comm_factor)[0])
 
+
 def three_stable_points(rational_function, invariant_list):
     r"""
     Implementation of Algorithm 1 for automorphism groups from
@@ -1087,7 +1103,7 @@ def three_stable_points(rational_function, invariant_list):
     - ``rational_function`` -- rational function `\phi` defined over finite
       field `E`
 
-    - ``invariant_list`` -- a list of at least `3` points of `\mathbb{P}^1(E)` that
+    - ``invariant_list`` -- list of at least `3` points of `\mathbb{P}^1(E)` that
       is stable under `Aut_{\phi}(E)`
 
     OUTPUT: list of automorphisms
@@ -1125,12 +1141,12 @@ def three_stable_points(rational_function, invariant_list):
 
         b = (T[0][0]*T[1][0]*T[2][1]*T[t[0]][0]*T[t[1]][1]*T[t[2]][0] -
             T[0][0]*T[1][0]*T[2][1]*T[t[0]][1]*T[t[1]][0]*T[t[2]][0] -
-            T[0][0]*T[1][1]*T[2][0]*T[t[0]][0]*T[t[1]][0] *T[t[2]][1] +
+            T[0][0]*T[1][1]*T[2][0]*T[t[0]][0]*T[t[1]][0] * T[t[2]][1] +
             T[0][0]*T[1][1]*T[2][0]*T[t[0]][1]*T[t[1]][0]*T[t[2]][0] +
             T[0][1]*T[1][0]*T[2][0]*T[t[0]][0]*T[t[1]][0]*T[t[2]][1] -
             T[0][1]*T[1][0]*T[2][0]*T[t[0]][0]*T[t[1]][1]*T[t[2]][0])
 
-        c = (T[0][0]*T[1][1]*T[2][1]*T[t[0]][1]*T[t[1]][0] *T[t[2]][1]-
+        c = (T[0][0]*T[1][1]*T[2][1]*T[t[0]][1]*T[t[1]][0] * T[t[2]][1] -
             T[0][0]*T[1][1]*T[2][1]*T[t[0]][1]*T[t[1]][1]*T[t[2]][0] -
             T[0][1]*T[1][0]*T[2][1]*T[t[0]][0]*T[t[1]][1]*T[t[2]][1] +
             T[0][1]*T[1][0]*T[2][1]*T[t[0]][1]*T[t[1]][1]*T[t[2]][0] +
@@ -1138,10 +1154,10 @@ def three_stable_points(rational_function, invariant_list):
             T[0][1]*T[1][1]*T[2][0]*T[t[0]][1]*T[t[1]][0]*T[t[2]][1])
 
         d = (T[0][0]*T[1][0]*T[2][1]*T[t[0]][0]*T[t[1]][1]*T[t[2]][1] -
-            T[0][0]*T[1][0]*T[2][1]*T[t[0]][1]*T[t[1]][0] *T[t[2]][1]-
+            T[0][0]*T[1][0]*T[2][1]*T[t[0]][1]*T[t[1]][0] * T[t[2]][1] -
             T[0][0]*T[1][1]*T[2][0]*T[t[0]][0]*T[t[1]][1]*T[t[2]][1] +
             T[0][0]*T[1][1]*T[2][0]*T[t[0]][1]*T[t[1]][1]*T[t[2]][0] +
-            T[0][1]*T[1][0]*T[2][0]*T[t[0]][1]*T[t[1]][0] *T[t[2]][1]-
+            T[0][1]*T[1][0]*T[2][0]*T[t[0]][1]*T[t[1]][0] * T[t[2]][1] -
             T[0][1]*T[1][0]*T[2][0]*T[t[0]][1]*T[t[1]][1]*T[t[2]][0])
 
         if a*d - b*c != 0:
@@ -1150,6 +1166,7 @@ def three_stable_points(rational_function, invariant_list):
                 automorphisms.append(s)
     return automorphisms
 
+
 def automorphism_group_FF_alg2(rational_function):
     r"""
     Implementation of algorithm for determining the absolute automorphism
@@ -1157,7 +1174,7 @@ def automorphism_group_FF_alg2(rational_function):
 
     INPUT:
 
-    - ``rational_function``--a rational function defined over a finite field
+    - ``rational_function`` -- a rational function defined over a finite field
 
     OUTPUT: absolute automorphism group of ``rational_function`` and a ring of definition
 
@@ -1240,9 +1257,9 @@ def automorphism_group_FF_alg2(rational_function):
             y = fix.roots(multiplicities=False)[0]
             preimage = R(f(z) - y*g(z))
             minimal_preimage = R(prod(x[0] for x in preimage.factor()))
-            if minimal_preimage.degree() + bool(preimage.degree()<D) >= 3:
+            if minimal_preimage.degree() + bool(preimage.degree() < D) >= 3:
                 T_poly = minimal_preimage
-                infinity_check = bool(preimage.degree()<D)
+                infinity_check = bool(preimage.degree() < D)
             else:
                 preimage2 = R(phi(phi(z)).numerator() - y*phi(phi(z)).denominator())
                 T_poly = R(prod(x[0] for x in preimage2.factor() ) )
@@ -1272,9 +1289,9 @@ def order_p_automorphisms(rational_function, pre_image):
 
     INPUT:
 
-    - ``rational_function``--rational function defined over finite field `F`
+    - ``rational_function`` -- rational function defined over finite field `F`
 
-    - ``pre_image``--set of triples `[x, L, f]`, where `x` is an `F`-rational
+    - ``pre_image`` -- set of triples `[x, L, f]`, where `x` is an `F`-rational
         fixed point of ``rational_function``, `L` is the list of `F`-rational
         pre-images of `x` (excluding `x`), and `f` is the polynomial defining
         the full set of pre-images of `x` (again excluding `x` itself)
@@ -1377,10 +1394,10 @@ def order_p_automorphisms(rational_function, pre_image):
 
     elif r2 < r:
 
-        if case=='fix':
+        if case == 'fix':
             T = [x[0] for x in pre_image]
         elif case == 'F-pre_images':
-            T = [x for x in pre_image[0][1]]
+            T = list(pre_image[0][1])
         else:
             T = []
 
@@ -1389,10 +1406,10 @@ def order_p_automorphisms(rational_function, pre_image):
             pt = guy[0]
             # treat case of multiple F-rational fixed points or
             #     1 F-rational fixed point with F-rational pre-images
-            if T != []:
+            if T:
                 M = [t for t in T if t != pt]
                 m = len(M)
-                if pt == [F(1),F(0)]:
+                if pt == [F(1), F(0)]:
                     for i in range(1, m):
                         s = z + M[i][0] - M[0][0]
                         if s(phi(z)) == phi(s(z)):
@@ -1400,8 +1417,8 @@ def order_p_automorphisms(rational_function, pre_image):
                 else:
                     u = F(1) / (z - pt[0])
                     u_inv = pt[0] + F(1)/z
-                    for i in range(1,m):
-                        if M[0] == [F(1),F(0)]:
+                    for i in range(1, m):
+                        if M[0] == [F(1), F(0)]:
                             uy1 = 0
                         else:
                             uy1 = u(M[0][0])
@@ -1448,6 +1465,7 @@ def order_p_automorphisms(rational_function, pre_image):
 
     return automorphisms_p
 
+
 def automorphisms_fixing_pair(rational_function, pair, quad):
     r"""
     Compute the set of automorphisms with order prime to the characteristic
@@ -1455,11 +1473,11 @@ def automorphisms_fixing_pair(rational_function, pair, quad):
 
     INPUT:
 
-    - ``rational_function``-- rational function defined over finite field `E`
+    - ``rational_function`` -- rational function defined over finite field `E`
 
-    - ``pair``-- a pair of points of `\mathbb{P}^1(E)`
+    - ``pair`` -- a pair of points of `\mathbb{P}^1(E)`
 
-    - ``quad``-- Boolean: an indicator if this is a quadratic pair of points
+    - ``quad`` -- boolean; an indicator if this is a quadratic pair of points
 
     OUTPUT: set of automorphisms with order prime to characteristic defined over `E` that fix
     the pair, excluding the identity
@@ -1528,6 +1546,7 @@ def automorphisms_fixing_pair(rational_function, pair, quad):
 
     return list(set(automorphisms_prime_to_p))
 
+
 def automorphism_group_FF_alg3(rational_function):
     r"""
     Implementation of Algorithm 3 in the paper by Faber/Manes/Viray [FMV]_
@@ -1535,14 +1554,14 @@ def automorphism_group_FF_alg3(rational_function):
 
     INPUT:
 
-    - ``rational_function``--a rational function defined over a finite field `F`
+    - ``rational_function`` -- a rational function defined over a finite field `F`
 
     OUTPUT: list of `F`-rational automorphisms of ``rational_function``
 
     EXAMPLES::
 
         sage: R.<z> = PolynomialRing(GF(5^3,'t'))
-        sage: f = (3456*z^4)
+        sage: f = 3456*z^4
         sage: from sage.dynamics.arithmetic_dynamics.endPN_automorphism_group import automorphism_group_FF_alg3
         sage: automorphism_group_FF_alg3(f)
         [z, 1/z]
@@ -1623,11 +1642,11 @@ def automorphism_group_FF_alg3(rational_function):
     # An F-rational fixed point has orbit length 1 or p under the action of an element of
     # order p. An F-quadratic fixed point has orbit length p. The set of F-rational
     # pre-images of fixed points decomposes as a union of orbits of length p.
-    if n1%p == 1 and n2%p == 0 and sum(len(x[1]) for x in pre_images)%p == 0:
+    if n1 % p == 1 and n2 % p == 0 and sum(len(x[1]) for x in pre_images) % p == 0:
         # Compute total number of distinct fixed points as a final check for order p auts
         factor_list = fix.factor()
         n = sum(x[0].degree() for x in factor_list) + bool(fix.degree() < D+1)
-        if n%p == 1:
+        if n % p == 1:
             automorphisms = automorphisms + order_p_automorphisms(phi, pre_images)
 
     # nontrivial elements with order prime to p #
@@ -1694,16 +1713,16 @@ def automorphism_group_FF_alg3(rational_function):
 
 def which_group(list_of_elements):
     r"""
-    Given a finite subgroup of `PGL2` determine its isomorphism class.
+    Given a finite subgroup of `PGL_2` determine its isomorphism class.
 
     This function makes heavy use of the classification of finite subgroups of `PGL(2,K)`.
 
     INPUT:
 
-    - ``list_of_elements``-- a finite list of elements of `PGL(2,K)`
-        that we know a priori form a group
+    - ``list_of_elements`` -- a finite list of elements of `PGL(2,K)`
+      that we know a priori form a group
 
-    OUTPUT: a string -- the isomorphism type of the group
+    OUTPUT: string; the isomorphism type of the group
 
     EXAMPLES::
 
@@ -1713,10 +1732,10 @@ def which_group(list_of_elements):
         sage: which_group(G)
         'Dihedral of order 6'
     """
-    if is_Matrix(list_of_elements[-1]):
+    if isinstance(list_of_elements[-1], Matrix):
         R = PolynomialRing(list_of_elements[-1].base_ring(),'z')
         z = R.gen(0)
-        G=[(t[0,0]*z+t[0,1])/(t[1,0]*z+t[1,1]) for t in list_of_elements]
+        G = [(t[0,0]*z+t[0,1])/(t[1,0]*z+t[1,1]) for t in list_of_elements]
     else:
         G = list_of_elements
 
@@ -1765,7 +1784,7 @@ def which_group(list_of_elements):
                 return 'Cyclic of order {0}'.format(n)
             if len(H) > max_reg_cyclic[0] and gcd(len(H), p) != p:
                 max_reg_cyclic = [len(H), g, H]
-            discard = list(set(discard +H)) # adjoin all new elements to discard
+            discard = list(set(discard + H)) # adjoin all new elements to discard
 
     n_reg = max_reg_cyclic[0]
     # Test for dihedral subgroup. A subgroup of index 2 is always normal, so the
@@ -1834,7 +1853,7 @@ def conjugating_set_initializer(f, g):
       of which no `n+1` are linearly dependent. Used to specify a possible conjugation
       from `f` to `g`.
 
-    - ``possible_targets`` -- a list of tuples of the form (``points``, ``repeated``). ``points``
+    - ``possible_targets`` -- list of tuples of the form (``points``, ``repeated``). ``points``
       is a list of ``points`` which are possible targets for point(s) in ``source``. ``repeated``
       specifies how many points in ``source`` have points in ``points`` as their possible target.
 
@@ -1844,9 +1863,10 @@ def conjugating_set_initializer(f, g):
     ``possible_targets`` tracks multiplier information::
 
         sage: P.<x,y,z> = ProjectiveSpace(QQ, 2)
-        sage: f = DynamicalSystem([(8*x^7 - 35*x^4*y^3 - 35*x^4*z^3 - 7*x*y^6 - 140*x*y^3*z^3 \
-                  - 7*x*z^6), (-7*x^6*y - 35*x^3*y^4 - 140*x^3*y*z^3 + 8*y^7 - 35*y^4*z^3 \
-                  - 7*y*z^6), -7*x^6*z - 140*x^3*y^3*z - 35*x^3*z^4 - 7*y^6*z - 35*y^3*z^4 + 8*z^7])
+        sage: f = DynamicalSystem([
+        ....:         8*x^7 - 35*x^4*y^3 - 35*x^4*z^3 - 7*x*y^6 - 140*x*y^3*z^3 - 7*x*z^6,
+        ....:         -7*x^6*y - 35*x^3*y^4 - 140*x^3*y*z^3 + 8*y^7 - 35*y^4*z^3 - 7*y*z^6,
+        ....:         -7*x^6*z - 140*x^3*y^3*z - 35*x^3*z^4 - 7*y^6*z - 35*y^3*z^4 + 8*z^7])
         sage: from sage.dynamics.arithmetic_dynamics.endPN_automorphism_group import conjugating_set_initializer
         sage: source, possible_targets = conjugating_set_initializer(f, f)
         sage: P.is_linearly_independent(source, 3)
@@ -2058,12 +2078,12 @@ def greedy_independence_check(P, repeated_mult, point_to_mult):
 
     - ``P`` -- a projective space
 
-    - ``repeated_mult`` -- a dictionary of integers to lists of points of
+    - ``repeated_mult`` -- dictionary of integers to lists of points of
       the projective space ``P``. The list of points should be conjugation
       invariant. The keys are considered as weights, and this function attempts
       to minimize the total weight
 
-    - ``point_to_mult`` -- a dictionary of points of ``P`` to tuples of the form
+    - ``point_to_mult`` -- dictionary of points of ``P`` to tuples of the form
       (multiplier, level), where multiplier is the characteristic polynomial
       of the multiplier of the point, and level is the number of preimages
       taken to find the point
@@ -2076,9 +2096,9 @@ def greedy_independence_check(P, repeated_mult, point_to_mult):
     Otherwise, a tuple of the form (``source``, ``corresponding``) is returned.
 
     - ``source`` -- the set `U` of the conjugation invariant pair. A set of `n+2` points
-      of the domain of `f`, of which no `n+1` are linearly dependent.
+      of the domain of `f`, of which no `n+1` are linearly dependent
 
-    - ``corresponding`` -- a list of tuples of the form ((multiplier, level), repeat) where the
+    - ``corresponding`` -- list of tuples of the form ((multiplier, level), repeat) where the
       (multiplier, level) pair is the multiplier of a point in ``source`` and repeat
       specifies how many points in source have that (multiplier, level) pair. This
       information specifies the set `V` of the invariant pair.
@@ -2117,6 +2137,7 @@ def greedy_independence_check(P, repeated_mult, point_to_mult):
                 if len(source) == n+2:
                     return source, corresponding
 
+
 def conjugating_set_helper(f, g, num_cpus, source, possible_targets):
     r"""
     Return the set of elements in PGL over the base ring
@@ -2136,14 +2157,14 @@ def conjugating_set_helper(f, g, num_cpus, source, possible_targets):
 
     - ``num_cpus`` -- the number of threads to run in parallel
 
-    - ``source`` -- a list of `n+2` conjugation invariant points, of which
-      no `n+1` are linearly dependent.
+    - ``source`` -- list of `n+2` conjugation invariant points, of which
+      no `n+1` are linearly dependent
 
-    - ``possible_targets`` -- a list of tuples of the form (``points``, ``repeated``). ``points``
+    - ``possible_targets`` -- list of tuples of the form (``points``, ``repeated``). ``points``
       is a list of ``points`` which are possible targets for point(s) in ``source``. ``repeated``
       specifies how many points in ``source`` have points in ``points`` as their possible target.
 
-    OUTPUT: a list of elements of PGL which conjugate ``f`` to ``g``.
+    OUTPUT: list of elements of PGL which conjugate ``f`` to ``g``
 
     EXAMPLES::
 
@@ -2262,6 +2283,7 @@ def conjugating_set_helper(f, g, num_cpus, source, possible_targets):
         Conj = find_conjugations_subset(product(*subset_iterators))
     return Conj
 
+
 def is_conjugate_helper(f, g, num_cpus, source, possible_targets):
     r"""
     Return if ``f`` is conjugate to ``g``.
@@ -2280,14 +2302,14 @@ def is_conjugate_helper(f, g, num_cpus, source, possible_targets):
 
     - ``num_cpus`` -- the number of threads to run in parallel
 
-    - ``source`` -- a list of `n+2` conjugation invariant points, of which
-      no `n+1` are linearly dependent.
+    - ``source`` -- list of `n+2` conjugation invariant points, of which
+      no `n+1` are linearly dependent
 
-    - ``possible_targets`` -- a list of tuples of the form (``points``, ``repeated``). ``points``
+    - ``possible_targets`` -- list of tuples of the form (``points``, ``repeated``). ``points``
       is a list of ``points`` which are possible targets for point(s) in ``source``. ``repeated``
       specifies how many points in ``source`` have points in ``points`` as their possible target.
 
-    OUTPUT: ``True`` if ``f`` is conjugate to ``g``, ``False`` otherwise.
+    OUTPUT: ``True`` if ``f`` is conjugate to ``g``, ``False`` otherwise
 
     EXAMPLES::
 
