@@ -89,7 +89,7 @@ from sage.misc.misc_c import prod
 from sage.modules.free_module_morphism import FreeModuleMorphism
 from sage.rings.infinity import Infinity
 from sage.rings.integer_ring import ZZ
-from sage.rings.infinity import is_Infinite
+from sage.rings.infinity import InfinityElement
 from functools import reduce
 
 
@@ -122,29 +122,27 @@ class FanMorphism(FreeModuleMorphism):
       integral matrix defining such a morphism;
 
     - ``domain_fan`` -- a :class:`fan
-      <sage.geometry.fan.RationalPolyhedralFan>` in the domain;
+      <sage.geometry.fan.RationalPolyhedralFan>` in the domain
 
     - ``codomain`` -- (default: ``None``) either a codomain lattice or a fan in
       the codomain. If the codomain fan is not given, the image fan (fan
       generated by images of generating cones) of ``domain_fan`` will be used,
-      if possible;
+      if possible.
 
-    - ``subdivide`` -- (default: ``False``) if ``True`` and ``domain_fan`` is
+    - ``subdivide`` -- boolean (default: ``False``); if ``True`` and ``domain_fan`` is
       not compatible with the codomain fan because it is too coarse, it will be
       automatically refined to become compatible (the minimal refinement is
-      canonical, so there are no choices involved);
+      canonical, so there are no choices involved)
 
-    - ``check`` -- (default: ``True``) if ``False``, given fans and morphism
+    - ``check`` -- boolean (default: ``True``); if ``False``, given fans and morphism
       will be assumed to be compatible. Be careful when using this option,
       since wrong assumptions can lead to wrong and hard-to-detect errors. On
-      the other hand, this option may save you some time;
+      the other hand, this option may save you some time.
 
-    - ``verbose`` -- (default: ``False``) if ``True``, some information may be
-      printed during construction of the fan morphism.
+    - ``verbose`` -- boolean (default: ``False``); if ``True``, some information may be
+      printed during construction of the fan morphism
 
-    OUTPUT:
-
-    - a fan morphism.
+    OUTPUT: a fan morphism
 
     EXAMPLES:
 
@@ -266,7 +264,7 @@ class FanMorphism(FreeModuleMorphism):
             [0 1]
             Domain fan: Rational polyhedral fan in 2-d lattice N
             Codomain fan: Rational polyhedral fan in 2-d lattice N
-            sage: TestSuite(fm).run(skip="_test_category")
+            sage: TestSuite(fm).run(skip='_test_category')
         """
         assert isinstance(domain_fan, RationalPolyhedralFan)
         if isinstance(codomain, RationalPolyhedralFan):
@@ -307,11 +305,9 @@ class FanMorphism(FreeModuleMorphism):
         INPUT:
 
         - ``right`` -- a :class:`FanMorphism` whose :meth:`codomain_fan` can be
-          mapped to :meth:`domain_fan` of ``self`` via identity map of lattices.
+          mapped to :meth:`domain_fan` of ``self`` via identity map of lattices
 
-        OUTPUT:
-
-        - a :class:`FanMorphism`.
+        OUTPUT: a :class:`FanMorphism`
 
         EXAMPLES::
 
@@ -392,7 +388,7 @@ class FanMorphism(FreeModuleMorphism):
 
         - ``chambers`` is a :class:`list` of :class:`cones
           <sage.geometry.cone.ConvexRationalPolyhedralCone>` in the domain of
-          ``self``;
+          ``self``
 
         - ``cone_to_chamber`` is a :class:`list` of integers, if its `i`-th
           element is `j`, then the `j`-th element of ``chambers`` is the
@@ -444,11 +440,9 @@ class FanMorphism(FreeModuleMorphism):
 
         INPUT:
 
-        - ``check`` -- passed on to the fan constructor.
+        - ``check`` -- passed on to the fan constructor
 
-        OUTPUT:
-
-        - none, but the codomain fan of ``self`` is set to the constructed fan.
+        OUTPUT: none, but the codomain fan of ``self`` is set to the constructed fan
 
         TESTS::
 
@@ -481,9 +475,7 @@ class FanMorphism(FreeModuleMorphism):
         r"""
         Return the `\LaTeX` representation of ``self``.
 
-        OUTPUT:
-
-        - a :class:`string`.
+        OUTPUT: a :class:`string`
 
         EXAMPLES::
 
@@ -518,7 +510,7 @@ class FanMorphism(FreeModuleMorphism):
           domain fan is mapped to the origin. If it is `j`, then the `i`-th ray
           of the domain fan is mapped onto the `j`-th ray of the codomain fan.
           If there is a ray in the domain fan which is mapped into the relative
-          interior of a higher dimensional cone, a :class:`ValueError`
+          interior of a higher dimensional cone, a :exc:`ValueError`
           exception is raised.
 
         .. NOTE::
@@ -554,9 +546,7 @@ class FanMorphism(FreeModuleMorphism):
         r"""
         Return the string representation of ``self``.
 
-        OUTPUT:
-
-        - a :class:`string`.
+        OUTPUT: a :class:`string`
 
         EXAMPLES::
 
@@ -587,19 +577,19 @@ class FanMorphism(FreeModuleMorphism):
 
         INPUT:
 
-        - ``check`` -- (default: ``True``) if ``False``, some of the
+        - ``check`` -- boolean (default: ``True``); if ``False``, some of the
           consistency checks will be omitted, which saves time but can
           potentially lead to wrong results. Currently, with
           ``check=False`` option there will be no check that ``domain_fan``
-          maps to ``codomain_fan``;
+          maps to ``codomain_fan``
 
-        - ``verbose`` -- (default: ``False``) if ``True``, some timing
-          information will be printed in the process.
+        - ``verbose`` -- boolean (default: ``False``); if ``True``, some timing
+          information will be printed in the process
 
         OUTPUT:
 
-        - none, but the domain fan of self is replaced with its minimal
-          refinement, if possible. Otherwise a :class:`ValueError`
+        - none, but the domain fan of ``self`` is replaced with its minimal
+          refinement, if possible. Otherwise a :exc:`ValueError`
           exception is raised.
 
         TESTS::
@@ -761,11 +751,9 @@ class FanMorphism(FreeModuleMorphism):
 
     def _support_error(self):
         r"""
-        Raise a :class:`ValueError` exception due to support incompatibility.
+        Raise a :exc:`ValueError` exception due to support incompatibility.
 
-        OUTPUT:
-
-        - none, a :class:`ValueError` exception is raised.
+        OUTPUT: none, a :exc:`ValueError` exception is raised
 
         TESTS:
 
@@ -804,7 +792,7 @@ class FanMorphism(FreeModuleMorphism):
 
         OUTPUT:
 
-        - none, but a :class:`ValueError` exception is raised if there is
+        - none, but a :exc:`ValueError` exception is raised if there is
           a cone of the domain fan of ``self`` which is not completely
           contained in a single cone of the codomain fan of ``self``,
           or if one of these fans does not sit in the appropriate lattice.
@@ -894,9 +882,9 @@ class FanMorphism(FreeModuleMorphism):
 
         INPUT:
 
-        - ``dim`` -- dimension of the requested cones;
+        - ``dim`` -- dimension of the requested cones
 
-        - ``codim`` -- codimension of the requested cones.
+        - ``codim`` -- codimension of the requested cones
 
         OUTPUT:
 
@@ -924,9 +912,9 @@ class FanMorphism(FreeModuleMorphism):
 
         INPUT:
 
-        - ``dim`` -- dimension of the requested cones;
+        - ``dim`` -- dimension of the requested cones
 
-        - ``codim`` -- codimension of the requested cones.
+        - ``codim`` -- codimension of the requested cones
 
         OUTPUT:
 
@@ -1020,9 +1008,7 @@ class FanMorphism(FreeModuleMorphism):
           <sage.geometry.cone.ConvexRationalPolyhedralCone>` of the
           :meth:`codomain_fan` of ``self``.
 
-        OUTPUT:
-
-        - an integer, infinity, or ``None``.
+        OUTPUT: integer, infinity, or ``None``
 
         If no cone was specified, this function computes the index of the
         image of ``self`` in the codomain. If a cone `\sigma` was given, the
@@ -1122,9 +1108,7 @@ class FanMorphism(FreeModuleMorphism):
         r"""
         Check if ``self`` is birational.
 
-        OUTPUT:
-
-        - ``True`` if ``self`` is birational, ``False`` otherwise.
+        OUTPUT: ``True`` if ``self`` is birational, ``False`` otherwise
 
         For fan morphisms this check is equivalent to ``self.index() == 1`` and
         means that the corresponding map between toric varieties is birational.
@@ -1149,9 +1133,7 @@ class FanMorphism(FreeModuleMorphism):
         r"""
         Check if ``self`` is a bundle.
 
-        OUTPUT:
-
-        - ``True`` if ``self`` is a bundle, ``False`` otherwise.
+        OUTPUT: ``True`` if ``self`` is a bundle, ``False`` otherwise
 
         Let `\phi: \Sigma \to \Sigma'` be a fan morphism such that the
         underlying lattice morphism `\phi: N \to N'` is surjective. Let
@@ -1246,9 +1228,7 @@ class FanMorphism(FreeModuleMorphism):
         r"""
         Check if ``self`` is a fibration.
 
-        OUTPUT:
-
-        - ``True`` if ``self`` is a fibration, ``False`` otherwise.
+        OUTPUT: ``True`` if ``self`` is a fibration, ``False`` otherwise
 
         A fan morphism `\phi: \Sigma \to \Sigma'` is a **fibration**
         if for any cone `\sigma' \in \Sigma'` and any primitive
@@ -1334,9 +1314,7 @@ class FanMorphism(FreeModuleMorphism):
         r"""
         Check if ``self`` is injective.
 
-        OUTPUT:
-
-        - ``True`` if ``self`` is injective, ``False`` otherwise.
+        OUTPUT: ``True`` if ``self`` is injective, ``False`` otherwise
 
         Let `\phi: \Sigma \to \Sigma'` be a fan morphism such that the
         underlying lattice morphism `\phi: N \to N'` bijectively maps `N` to a
@@ -1407,9 +1385,7 @@ class FanMorphism(FreeModuleMorphism):
         r"""
         Check if ``self`` is surjective.
 
-        OUTPUT:
-
-        - ``True`` if ``self`` is surjective, ``False`` otherwise.
+        OUTPUT: ``True`` if ``self`` is surjective, ``False`` otherwise
 
         A fan morphism `\phi: \Sigma \to \Sigma'` is **surjective** if the
         corresponding map between cones is surjective, i.e. for each cone
@@ -1458,7 +1434,7 @@ class FanMorphism(FreeModuleMorphism):
             sage: phi.is_surjective()
             False
         """
-        if is_Infinite(self.index()):
+        if isinstance(self.index(), InfinityElement):
             return False    # Not surjective between vector spaces.
         for dcones in self.codomain_fan().cones():
             for sigma_p in dcones:
@@ -1484,9 +1460,7 @@ class FanMorphism(FreeModuleMorphism):
         of toric varieties is dominant in the algebraic-geometric
         sense (that is, surjective onto a dense subset).
 
-        OUTPUT:
-
-        Boolean.
+        OUTPUT: boolean
 
         EXAMPLES::
 
@@ -1505,9 +1479,7 @@ class FanMorphism(FreeModuleMorphism):
         r"""
         Return the subfan of the domain fan mapped into the origin.
 
-        OUTPUT:
-
-        - a :class:`fan <sage.geometry.fan.RationalPolyhedralFan>`.
+        OUTPUT: a :class:`fan <sage.geometry.fan.RationalPolyhedralFan>`
 
         .. NOTE::
 
@@ -1607,11 +1579,9 @@ class FanMorphism(FreeModuleMorphism):
 
         - ``cone`` -- a :class:`cone
           <sage.geometry.cone.ConvexRationalPolyhedralCone>` equivalent to a
-          cone of the :meth:`codomain_fan` of ``self``.
+          cone of the :meth:`codomain_fan` of ``self``
 
-        OUTPUT:
-
-        - a :class:`fan <sage.geometry.fan.RationalPolyhedralFan>`.
+        OUTPUT: a :class:`fan <sage.geometry.fan.RationalPolyhedralFan>`
 
         .. NOTE::
 
@@ -1663,11 +1633,9 @@ class FanMorphism(FreeModuleMorphism):
 
         - ``cone`` -- a :class:`cone
           <sage.geometry.cone.ConvexRationalPolyhedralCone>` equivalent to a
-          cone of the :meth:`codomain_fan` of ``self``.
+          cone of the :meth:`codomain_fan` of ``self``
 
-        OUTPUT:
-
-        - a :class:`cone <sage.geometry.cone.ConvexRationalPolyhedralCone>`.
+        OUTPUT: a :class:`cone <sage.geometry.cone.ConvexRationalPolyhedralCone>`
 
         Let `\phi: \Sigma \to \Sigma'` be a fan morphism, let `\sigma \in
         \Sigma`, and let `\sigma' = \phi(\sigma)`. Then `\sigma` is a
@@ -1759,7 +1727,7 @@ class FanMorphism(FreeModuleMorphism):
             \hookrightarrow
             \Sigma.
 
-        .. note::
+        .. NOTE::
 
             * `\Sigma_s` is the finest fan with the smallest support that is
               compatible with ``self``: any fan morphism from `\Sigma` given by
@@ -1890,7 +1858,7 @@ class FanMorphism(FreeModuleMorphism):
 
         INPUT:
 
-        - ``domain_cone`` -- a cone of the :meth:`domain_fan` of ``self``.
+        - ``domain_cone`` -- a cone of the :meth:`domain_fan` of ``self``
 
         OUTPUT:
 
