@@ -21,7 +21,7 @@ Base class for polyhedra: Methods related to lattice points
 #       Copyright (C) 2019      Julian Ritter
 #       Copyright (C) 2019-2020 Laith Rastanawi
 #       Copyright (C) 2019-2020 Sophia Elia
-#       Copyright (C) 2019-2021 Jonathan Kliem <jonathan.kliem@fu-berlin.de>
+#       Copyright (C) 2019-2021 Jonathan Kliem <jonathan.kliem@gmail.com>
 #
 # This program is free software: you can redistribute it and/or modify
 # it under the terms of the GNU General Public License as published by
@@ -37,6 +37,7 @@ from sage.rings.integer_ring import ZZ
 from sage.modules.free_module_element import vector
 from .base1 import Polyhedron_base1
 
+
 class Polyhedron_base2(Polyhedron_base1):
     """
     Methods related to lattice points.
@@ -95,7 +96,7 @@ class Polyhedron_base2(Polyhedron_base1):
 
             sage: polytopes.cross_polytope(3).is_lattice_polytope()
             True
-            sage: polytopes.regular_polygon(5).is_lattice_polytope()            # optional - sage.rings.number_field
+            sage: polytopes.regular_polygon(5).is_lattice_polytope()                    # needs sage.rings.number_field
             False
         """
         if not self.is_compact():
@@ -111,10 +112,10 @@ class Polyhedron_base2(Polyhedron_base1):
 
         INPUT:
 
-        - ``envelope`` -- boolean (default: ``False``). If the
+        - ``envelope`` -- boolean (default: ``False``); if the
           polyhedron has non-integral vertices, this option decides
           whether to return a strictly larger lattice polytope or
-          raise a ``ValueError``. This option has no effect if the
+          raise a :exc:`ValueError`. This option has no effect if the
           polyhedron has already integral vertices.
 
         OUTPUT:
@@ -126,11 +127,11 @@ class Polyhedron_base2(Polyhedron_base1):
         but has at least one non-integral vertex, a strictly larger
         lattice polytope is returned.
 
-        If the polyhedron is not compact, a ``NotImplementedError`` is
+        If the polyhedron is not compact, a :exc:`NotImplementedError` is
         raised.
 
         If the polyhedron is not integral and ``envelope=False``, a
-        ``ValueError`` is raised.
+        :exc:`ValueError` is raised.
 
         ALGORITHM:
 
@@ -143,8 +144,9 @@ class Polyhedron_base2(Polyhedron_base1):
         First, a polyhedron with integral vertices::
 
             sage: P = Polyhedron(vertices=[(1, 0), (0, 1), (-1, 0), (0, -1)])
-            sage: lp = P.lattice_polytope()
-            sage: lp                                                            # optional - palp
+            sage: lp = P.lattice_polytope(); lp
+            2-d reflexive polytope... in 2-d lattice M
+            sage: lp                                                            # optional - polytopes_db, needs palp
             2-d reflexive polytope #3 in 2-d lattice M
             sage: lp.vertices()
             M(-1,  0),
@@ -163,7 +165,7 @@ class Polyhedron_base2(Polyhedron_base1):
             to add the argument "envelope=True" to compute an enveloping
             lattice polytope.
             sage: lp = P.lattice_polytope(True)
-            sage: lp                                                            # optional - palp
+            sage: lp                                                            # optional - polytopes_db, needs palp
             2-d reflexive polytope #5 in 2-d lattice M
             sage: lp.vertices()
             M(-1,  0),
@@ -203,13 +205,13 @@ class Polyhedron_base2(Polyhedron_base1):
         OUTPUT:
 
         The list of integral points in the polyhedron. If the
-        polyhedron is not compact, a ``ValueError`` is raised.
+        polyhedron is not compact, a :exc:`ValueError` is raised.
 
         EXAMPLES::
 
-            sage: Polyhedron(vertices=[(-1,-1),(1,0),(1,1),(0,1)])._integral_points_PALP()              # optional - palp
+            sage: Polyhedron(vertices=[(-1,-1),(1,0),(1,1),(0,1)])._integral_points_PALP()                              # needs palp
             [M(-1, -1), M(0, 1), M(1, 0), M(1, 1), M(0, 0)]
-            sage: Polyhedron(vertices=[(-1/2,-1/2),(1,0),(1,1),(0,1)]).lattice_polytope(True).points()  # optional - palp
+            sage: Polyhedron(vertices=[(-1/2,-1/2),(1,0),(1,1),(0,1)]).lattice_polytope(True).points()                  # needs palp
             M(-1, -1),
             M(-1,  0),
             M( 0, -1),
@@ -218,7 +220,7 @@ class Polyhedron_base2(Polyhedron_base1):
             M( 1,  0),
             M( 0,  0)
             in 2-d lattice M
-            sage: Polyhedron(vertices=[(-1/2,-1/2),(1,0),(1,1),(0,1)])._integral_points_PALP()          # optional - palp
+            sage: Polyhedron(vertices=[(-1/2,-1/2),(1,0),(1,1),(0,1)])._integral_points_PALP()                          # needs palp
             [M(1, 1), M(0, 1), M(1, 0), M(0, 0)]
         """
         if not self.is_compact():
@@ -244,13 +246,13 @@ class Polyhedron_base2(Polyhedron_base1):
 
         INPUT:
 
-        - ``self`` -- A lattice polytope.
+        - ``self`` -- a lattice polytope
 
         OUTPUT:
 
         A list whose entries give the `h^*`-vector.
 
-        .. NOTE:
+        .. NOTE::
 
             The backend of ``self`` should be ``'normaliz'``.
             This function depends on Normaliz (i.e. the ``'pynormaliz'`` optional
@@ -262,18 +264,19 @@ class Polyhedron_base2(Polyhedron_base1):
         volume = `\frac{1}{dim(S)!}`) is always 1. Here we test this on
         simplices up to dimension 3::
 
-            sage: s1 = polytopes.simplex(1,backend='normaliz')              # optional - pynormaliz
-            sage: s2 = polytopes.simplex(2,backend='normaliz')              # optional - pynormaliz
-            sage: s3 = polytopes.simplex(3,backend='normaliz')              # optional - pynormaliz
-            sage: [s1.h_star_vector(),s2.h_star_vector(),s3.h_star_vector()]  # optional - pynormaliz
+            sage: # optional - pynormaliz
+            sage: s1 = polytopes.simplex(1,backend='normaliz')
+            sage: s2 = polytopes.simplex(2,backend='normaliz')
+            sage: s3 = polytopes.simplex(3,backend='normaliz')
+            sage: [s1.h_star_vector(), s2.h_star_vector(), s3.h_star_vector()]
             [[1], [1], [1]]
 
         For a less trivial example, we compute the `h^*`-vector of the
         `0/1`-cube, which has the Eulerian numbers `(3,i)` for `i \in [0,2]`
         as an `h^*`-vector::
 
-            sage: cube = polytopes.cube(intervals='zero_one', backend='normaliz') # optional - pynormaliz
-            sage: cube.h_star_vector()   # optional - pynormaliz
+            sage: cube = polytopes.cube(intervals='zero_one', backend='normaliz')   # optional - pynormaliz
+            sage: cube.h_star_vector()                                              # optional - pynormaliz
             [1, 4, 1]
             sage: from sage.combinat.combinat import eulerian_number
             sage: [eulerian_number(3,i) for i in range(3)]
@@ -293,8 +296,8 @@ class Polyhedron_base2(Polyhedron_base1):
             ...
             TypeError: The h_star vector is only defined for lattice polytopes
 
-            sage: t2 = Polyhedron(vertices=[[AA(sqrt(2))],[1/2]])
-            sage: t2.h_star_vector()
+            sage: t2 = Polyhedron(vertices=[[AA(sqrt(2))], [1/2]])                      # needs sage.rings.number_field sage.symbolic
+            sage: t2.h_star_vector()                                                    # needs sage.rings.number_field sage.symbolic
             Traceback (most recent call last):
             ...
             TypeError: The h_star vector is only defined for lattice polytopes
@@ -319,15 +322,15 @@ class Polyhedron_base2(Polyhedron_base1):
 
         INPUT:
 
-        - ``self`` -- A lattice polytope.
+        - ``self`` -- a lattice polytope
 
         OUTPUT:
 
         The `h^*`-vector as a list.
 
-        .. NOTE:
+        .. NOTE::
 
-        The backend of ``self`` should be ``'normaliz'``.
+            The backend of ``self`` should be ``'normaliz'``.
 
         TESTS::
 
@@ -377,7 +380,6 @@ class Polyhedron_base2(Polyhedron_base1):
             Traceback (most recent call last):
             ...
             NotImplementedError: ...
-
         """
         return len(self.integral_points())
 
@@ -390,13 +392,13 @@ class Polyhedron_base2(Polyhedron_base1):
 
         INPUT:
 
-        - ``threshold`` -- integer (default: 100000). Use the naive
-          algorithm as long as the bounding box is smaller than this.
+        - ``threshold`` -- integer (default: 100000); use the naive
+          algorithm as long as the bounding box is smaller than this
 
         OUTPUT:
 
         The list of integral points in the polyhedron. If the
-        polyhedron is not compact, a ``ValueError`` is raised.
+        polyhedron is not compact, a :exc:`ValueError` is raised.
 
         EXAMPLES::
 
@@ -445,9 +447,9 @@ class Polyhedron_base2(Polyhedron_base1):
             sage: pts1 = P.integral_points()                     # Sage's own code
             sage: all(P.contains(p) for p in pts1)
             True
-            sage: pts2 = LatticePolytope(v).points()                            # optional - palp
+            sage: pts2 = LatticePolytope(v).points()                                    # needs palp
             sage: for p in pts1: p.set_immutable()
-            sage: set(pts1) == set(pts2)                                        # optional - palp
+            sage: set(pts1) == set(pts2)                                                # needs palp
             True
 
             sage: timeit('Polyhedron(v).integral_points()')   # not tested - random
@@ -457,7 +459,7 @@ class Polyhedron_base2(Polyhedron_base1):
 
         TESTS:
 
-        Test some trivial cases (see :trac:`17937`)::
+        Test some trivial cases (see :issue:`17937`)::
 
             sage: P = Polyhedron(ambient_dim=1)  # empty polyhedron in 1 dimension
             sage: P.integral_points()
@@ -530,21 +532,21 @@ class Polyhedron_base2(Polyhedron_base1):
         However, so long as :meth:`integral_points_count` does not need to
         enumerate all integral points, neither does this method. Hence it can
         be significantly faster. If the polyhedron is not compact, a
-        ``ValueError`` is raised.
+        :exc:`ValueError` is raised.
 
         INPUT:
 
-        - ``index`` -- integer. The index of the integral point to be found. If
-          this is not in [0, ``self.integral_point_count()``), an ``IndexError``
+        - ``index`` -- integer; the index of the integral point to be found. If
+          this is not in [0, ``self.integral_point_count()``), an :exc:`IndexError`
           is raised.
 
         - ``**kwds`` -- optional keyword parameters that are passed to
-          :meth:`integral_points_count`.
+          :meth:`integral_points_count`
 
         ALGORITHM:
 
         The function computes each of the components of the requested point in
-        turn. To compute x_i, the ith component, it bisects the upper and lower
+        turn. To compute x_i, the `i`-th component, it bisects the upper and lower
         bounds on x_i given by the bounding box. At each bisection, it uses
         :meth:`integral_points_count` to determine on which side of the
         bisecting hyperplane the requested point lies.
@@ -625,12 +627,12 @@ class Polyhedron_base2(Polyhedron_base1):
         INPUT:
 
         - ``**kwds`` -- optional keyword parameters that are passed to
-          :meth:`get_integral_point`.
+          :meth:`get_integral_point`
 
         OUTPUT:
 
         The integral point in the polyhedron chosen uniformly at random. If the
-        polyhedron is not compact, a ``ValueError`` is raised. If the
+        polyhedron is not compact, a :exc:`ValueError` is raised. If the
         polyhedron does not contain any integral points, an
         :class:`~sage.categories.sets_cat.EmptySetError` is raised.
 
@@ -641,13 +643,15 @@ class Polyhedron_base2(Polyhedron_base1):
         EXAMPLES::
 
             sage: P = Polyhedron(vertices=[(-1,-1),(1,0),(1,1),(0,1)])
-            sage: P.random_integral_point()  # random
+            sage: P.random_integral_point()                                     # random
             (0, 0)
             sage: P.random_integral_point() in P.integral_points()
             True
-            sage: P.random_integral_point(explicit_enumeration_threshold=0, triangulation='cddlib')  # random, optional - latte_int
+            sage: P.random_integral_point(explicit_enumeration_threshold=0,     # random, optional - latte_int
+            ....:                         triangulation='cddlib')
             (1, 1)
-            sage: P.random_integral_point(explicit_enumeration_threshold=0, triangulation='cddlib', foo=7)  # optional - latte_int
+            sage: P.random_integral_point(explicit_enumeration_threshold=0,     # optional - latte_int
+            ....:                         triangulation='cddlib', foo=7)
             Traceback (most recent call last):
             ...
             RuntimeError: ...
@@ -675,3 +679,133 @@ class Polyhedron_base2(Polyhedron_base1):
             raise EmptySetError('polyhedron does not contain any integral points')
 
         return self.get_integral_point(current_randstate().python_random().randint(0, count-1), **kwds)
+
+    def generating_function_of_integral_points(self, **kwds):
+        r"""
+        Return the multivariate generating function of the
+        integral points of this polyhedron.
+
+        To be precise, this returns
+
+        .. MATH::
+
+            \sum_{(r_0,\dots,r_{d-1}) \in \mathit{polyhedron}\cap \ZZ^d}
+            y_0^{r_0} \dots y_{d-1}^{r_{d-1}}.
+
+        This calls
+        :func:`~sage.geometry.polyhedron.generating_function.generating_function_of_integral_points`,
+        so have a look at the documentation and examples there.
+
+        INPUT:
+
+        The following keyword arguments are passed to
+        :func:`~sage.geometry.polyhedron.generating_function.generating_function_of_integral_points`:
+
+        - ``split`` -- boolean (default: ``False``) or list
+
+          - ``split=False`` computes the generating function directly,
+            without any splitting.
+
+          - When ``split`` is a list of disjoint polyhedra, then
+            for each of these polyhedra, this polyhedron is intersected with it,
+            its generating function computed and all these generating functions
+            are summed up.
+
+          - ``split=True`` splits into `d!` disjoint polyhedra.
+
+        - ``result_as_tuple`` -- (default: ``None``) a boolean or ``None``
+
+          This specifies whether the output is a (partial) factorization
+          (``result_as_tuple=False``) or a sum of such (partial)
+          factorizations (``result_as_tuple=True``). By default
+          (``result_as_tuple=None``), this is automatically determined.
+          If the output is a sum, it is represented as a tuple whose
+          entries are the summands.
+
+        - ``indices`` -- (default: ``None``) a list or tuple
+
+          If this
+          is ``None``, this is automatically determined.
+
+        - ``name`` -- (default: ``'y'``) a string
+
+          The variable names of the Laurent polynomial ring of the output
+          are this string followed by an integer.
+
+        - ``names`` -- list or tuple of names (strings), or a comma separated string
+
+          ``name`` is extracted from ``names``, therefore ``names`` has to contain
+          exactly one variable name, and ``name`` and``names`` cannot be specified
+          both at the same time.
+
+        - ``Factorization_sort`` (default: ``False``) and
+          ``Factorization_simplify`` (default: ``True``) -- booleans
+
+          These are passed on to
+          :class:`sage.structure.factorization.Factorization` when creating
+          the result.
+
+        - ``sort_factors`` -- boolean (default: ``False``)
+
+          If set, then the factors of the output are sorted such that the
+          numerator is first and only then all factors of the denominator. It
+          is ensured that the sorting is always the same; use this for
+          doctesting.
+
+        OUTPUT:
+
+        The generating function as a (partial)
+        :class:`~sage.structure.factorization.Factorization`
+        of the result whose factors are Laurent polynomials
+
+        The result might be a tuple of such factorizations
+        (depending on the parameter ``result_as_tuple``) as well.
+
+        .. NOTE::
+
+            At the moment, only polyhedra with nonnegative coordinates
+            (i.e. a polyhedron in the nonnegative orthant) are handled.
+
+        EXAMPLES::
+
+            sage: # needs sage.combinat
+            sage: P2 = (Polyhedron(ieqs=[(0, 0, 0, 1), (0, 0, 1, 0), (0, 1, 0, -1)]),
+            ....:       Polyhedron(ieqs=[(0, -1, 0, 1), (0, 1, 0, 0), (0, 0, 1, 0)]))
+            sage: P2[0].generating_function_of_integral_points(sort_factors=True)
+            1 * (-y0 + 1)^-1 * (-y1 + 1)^-1 * (-y0*y2 + 1)^-1
+            sage: P2[1].generating_function_of_integral_points(sort_factors=True)
+            1 * (-y1 + 1)^-1 * (-y2 + 1)^-1 * (-y0*y2 + 1)^-1
+            sage: (P2[0] & P2[1]).Hrepresentation()
+            (An equation (1, 0, -1) x + 0 == 0,
+             An inequality (1, 0, 0) x + 0 >= 0,
+             An inequality (0, 1, 0) x + 0 >= 0)
+            sage: (P2[0] & P2[1]).generating_function_of_integral_points(sort_factors=True)
+            1 * (-y1 + 1)^-1 * (-y0*y2 + 1)^-1
+
+        The number of integer partitions
+        `1 \leq r_0 \leq r_1 \leq r_2 \leq r_3 \leq r_4`::
+
+            sage: # needs sage.combinat
+            sage: P = Polyhedron(ieqs=[(-1, 1, 0, 0, 0, 0), (0, -1, 1, 0, 0, 0),
+            ....:                      (0, 0, -1, 1, 0, 0), (0, 0, 0, -1, 1, 0),
+            ....:                      (0, 0, 0, 0, -1, 1)])
+            sage: f = P.generating_function_of_integral_points(sort_factors=True); f
+            y0*y1*y2*y3*y4 * (-y4 + 1)^-1 * (-y3*y4 + 1)^-1 * (-y2*y3*y4 + 1)^-1 *
+            (-y1*y2*y3*y4 + 1)^-1 * (-y0*y1*y2*y3*y4 + 1)^-1
+            sage: f = f.value()
+            sage: P.<z> = PowerSeriesRing(ZZ)
+            sage: c = f.subs({y: z for y in f.parent().gens()}); c
+            z^5 + z^6 + 2*z^7 + 3*z^8 + 5*z^9 + 7*z^10 + 10*z^11 + 13*z^12 + 18*z^13 +
+            23*z^14 + 30*z^15 + 37*z^16 + 47*z^17 + 57*z^18 + 70*z^19 + 84*z^20 +
+            101*z^21 + 119*z^22 + 141*z^23 + 164*z^24 + O(z^25)
+            sage: ([Partitions(k, length=5).cardinality() for k in range(5,20)] ==
+            ....:     c.truncate().coefficients(sparse=False)[5:20])
+            True
+
+        .. SEEALSO::
+
+            More examples can be found at
+            :func:`~sage.geometry.polyhedron.generating_function.generating_function_of_integral_points`.
+        """
+        from .generating_function import generating_function_of_integral_points
+        return generating_function_of_integral_points(self, **kwds)
