@@ -17,7 +17,7 @@ from sage.geometry.convex_set import ConvexSet_relatively_open
 
 class RelativeInterior(ConvexSet_relatively_open):
     r"""
-    The relative interior of a polyhedron or cone
+    The relative interior of a polyhedron or cone.
 
     This class should not be used directly. Use methods
     :meth:`~sage.geometry.polyhedron.Polyhedron_base.relative_interior`,
@@ -43,7 +43,7 @@ class RelativeInterior(ConvexSet_relatively_open):
         INPUT:
 
         - ``polyhedron`` -- an instance of :class:`Polyhedron_base` or
-          :class:`ConvexRationalPolyhedralCone`.
+          :class:`ConvexRationalPolyhedralCone`
 
         TESTS::
 
@@ -216,11 +216,9 @@ class RelativeInterior(ConvexSet_relatively_open):
 
     def is_universe(self):
         r"""
-        Return whether ``self`` is the whole ambient space
+        Return whether ``self`` is the whole ambient space.
 
-        OUTPUT:
-
-        Boolean.
+        OUTPUT: boolean
 
         EXAMPLES::
 
@@ -240,9 +238,7 @@ class RelativeInterior(ConvexSet_relatively_open):
         r"""
         Return whether ``self`` is closed.
 
-        OUTPUT:
-
-        Boolean.
+        OUTPUT: boolean
 
         EXAMPLES::
 
@@ -370,7 +366,7 @@ class RelativeInterior(ConvexSet_relatively_open):
 
         INPUT:
 
-        - ``scalar`` -- A scalar
+        - ``scalar`` -- a scalar
 
         EXAMPLES::
 
@@ -406,7 +402,7 @@ class RelativeInterior(ConvexSet_relatively_open):
 
         - ``linear_transf`` -- a matrix
         - ``**kwds`` -- passed to the :meth:`linear_transformation` method of
-          the closure of ``self``.
+          the closure of ``self``
 
         EXAMPLES::
 
