@@ -320,8 +320,9 @@ class GenericGraphQuery(SQLQuery):
 
 class GraphQuery(GenericGraphQuery):
 
-    def __init__(self, graph_db=None, query_dict=None, display_cols=None, **kwds):
-        """
+    def __init__(self, graph_db=None, query_dict=None, display_cols=None,
+                 immutable=False, **kwds):
+        r"""
         A query for an instance of :class:`~GraphDatabase`.
 
         This class nicely wraps the :class:`sage.databases.sql_db.SQLQuery`
@@ -352,6 +353,9 @@ class GraphQuery(GenericGraphQuery):
           column names (strings) to display in the result when running or
           showing a query
 
+        - ``immutable`` -- boolean (default: ``False``); whether to return
+          immutable or mutable graphs
+
         - ``kwds`` -- the columns of the database are all keywords. For a
           database table/column structure dictionary, call
           :func:`~graph_db_info`. Keywords accept both single values and lists
@@ -413,7 +417,17 @@ class GraphQuery(GenericGraphQuery):
             F_?@w                7                    [1, 1, 1, 1, 1, 1, 4]
             F_?Hg                7                    [1, 1, 1, 1, 1, 2, 3]
             F_?XO                7                    [1, 1, 1, 1, 2, 2, 2]
+
+        Check the behavior of parameter ``immutable``::
+
+            sage: Q = GraphQuery(display_cols=['graph6'], num_vertices=3)
+            sage: any(g.is_immutable() for g in Q)
+            False
+            sage: Q = GraphQuery(display_cols=['graph6'], num_vertices=3, immutable=True)
+            sage: all(g.is_immutable() for g in Q)
+            True
         """
+        self._immutable = immutable
         if graph_db is None:
             graph_db = GraphDatabase()
         if query_dict is not None:
@@ -534,10 +548,16 @@ class GraphQuery(GenericGraphQuery):
                                                self.__query_string__)
                 self.__query_string__ += ' ORDER BY graph_data.graph6'
 
-    def query_iterator(self):
+    def query_iterator(self, immutable=None):
         """
         Return an iterator over the results list of the :class:`~GraphQuery`.
 
+        INPUT:
+
+        - ``immutable`` -- boolean (default: ``None``); whether to create
+          mutable/immutable graphs. By default (``immutable=None``), follow the
+          behavior of ``self``.
+
         EXAMPLES::
 
             sage: Q = GraphQuery(display_cols=['graph6'], num_vertices=7, diameter=5)
@@ -566,8 +586,27 @@ class GraphQuery(GenericGraphQuery):
             FEOhW
             FGC{o
             FIAHo
+
+        Check the behavior of parameter ``immutable``::
+
+            sage: Q = GraphQuery(display_cols=['graph6'], num_vertices=3)
+            sage: any(g.is_immutable() for g in Q.query_iterator())
+            False
+            sage: all(g.is_immutable() for g in Q.query_iterator(immutable=True))
+            True
+            sage: Q = GraphQuery(display_cols=['graph6'], num_vertices=3, immutable=True)
+            sage: all(g.is_immutable() for g in Q.query_iterator())
+            True
+            sage: any(g.is_immutable() for g in Q.query_iterator(immutable=False))
+            False
         """
-        return iter(self.get_graphs_list())
+        if immutable is None:
+            immutable = self._immutable
+        s = self.__query_string__
+        re.sub('SELECT.*FROM ', 'SELECT graph6 FROM ', s)
+        q = GenericGraphQuery(s, self.__database__, self.__param_tuple__)
+        for g in q.query_results():
+            yield Graph(str(g[0]), immutable=immutable)
 
     __iter__ = query_iterator
 
@@ -687,10 +726,16 @@ class GraphQuery(GenericGraphQuery):
                           format_cols=format_cols, relabel_cols=relabel,
                           id_col='graph6')
 
-    def get_graphs_list(self):
+    def get_graphs_list(self, immutable=None):
         """
         Return a list of Sage Graph objects that satisfy the query.
 
+        INPUT:
+
+        - ``immutable`` -- boolean (default: ``None``); whether to create
+          mutable/immutable graphs. By default (``immutable=None``), follow the
+          behavior of ``self``.
+
         EXAMPLES::
 
             sage: Q = GraphQuery(display_cols=['graph6', 'num_vertices', 'degree_sequence'], num_edges=['<=', 5], min_degree=1)
@@ -699,12 +744,23 @@ class GraphQuery(GenericGraphQuery):
             Graph on 2 vertices
             sage: len(L)
             35
+
+        Check the behavior of parameter ``immutable``::
+
+            sage: Q = GraphQuery(display_cols=['graph6'], num_vertices=3)
+            sage: any(g.is_immutable() for g in Q.get_graphs_list())
+            False
+            sage: all(g.is_immutable() for g in Q.get_graphs_list(immutable=True))
+            True
+            sage: Q = GraphQuery(display_cols=['graph6'], num_vertices=3, immutable=True)
+            sage: all(g.is_immutable() for g in Q.get_graphs_list())
+            True
+            sage: any(g.is_immutable() for g in Q.get_graphs_list(immutable=False))
+            False
         """
-        s = self.__query_string__
-        re.sub('SELECT.*FROM ', 'SELECT graph6 FROM ', s)
-        q = GenericGraphQuery(s, self.__database__, self.__param_tuple__)
-        graph6_list = q.query_results()
-        return [Graph(str(g[0])) for g in graph6_list]
+        if immutable is None:
+            immutable = self._immutable
+        return list(self.query_iterator(immutable=immutable))
 
     def number_of(self):
         """
