@@ -371,7 +371,7 @@ class CubicBraidElement(FinitelyPresentedGroupElement):
         - ``root_bur`` -- six (resp. twelfth) root of unity in some field
           (default: root of unity over `\QQ`)
         - ``domain`` -- (default: cyclotomic field of order 3 and degree 2, resp.
-          the domain of `root_bur` if given) base ring for the Burau matrix
+          the domain of ``root_bur`` if given) base ring for the Burau matrix
         - ``characteristic`` -- integer giving the characteristic of the
           domain (default: 0 or the characteristic of ``domain`` if given)
         - ``var`` -- string used for the indeterminate name in case ``root_bur``
@@ -640,7 +640,6 @@ class CubicBraidGroup(UniqueRepresentation, FinitelyPresentedGroup):
         sage: C3.gens()
         (t0, t1)
         sage: U3.is_isomorphic(C3)
-        #I  Forcing finiteness test
         True
         sage: U3.as_classical_group()
         Subgroup generated by [(1,7,6)(3,19,14)(4,15,10)(5,11,18)(12,16,20),
@@ -802,7 +801,6 @@ class CubicBraidGroup(UniqueRepresentation, FinitelyPresentedGroup):
         self._classical_embedding = None   # if self._classical_group different from self._classical_base_group
         self._centralizing_matrix = None   # for Assion groups: element in classical base group commuting with self
         self._centralizing_element = None   # image under nat. map of the former one in the proj. classical group
-        return
 
     def _repr_(self):
         r"""
@@ -914,7 +912,6 @@ class CubicBraidGroup(UniqueRepresentation, FinitelyPresentedGroup):
         if self.is_finite() and self.strands() <= 7: # not realistic for larger number of strands
             att_grp_elem_back = self(att_grp_elem)
             tester.assertEqual(att_grp_elem_back, elem)
-        return
 
     def _test_classical_group(self, **options):
         r"""
@@ -935,7 +932,6 @@ class CubicBraidGroup(UniqueRepresentation, FinitelyPresentedGroup):
         classic_grp = self.as_classical_group()
         if self.is_finite():
             self._internal_test_attached_group(classic_grp, tester)
-        return
 
     def _test_permutation_group(self, **options):
         r"""
@@ -956,7 +952,6 @@ class CubicBraidGroup(UniqueRepresentation, FinitelyPresentedGroup):
             tester = self._tester(**options)
             permgrp = self.as_permutation_group()
             self._internal_test_attached_group(permgrp, tester)
-        return
 
     def _test_matrix_group(self, **options):
         r"""
@@ -1025,7 +1020,6 @@ class CubicBraidGroup(UniqueRepresentation, FinitelyPresentedGroup):
                 tester = self._tester(**options)
                 reflgrp = self.as_reflection_group()
                 self._internal_test_attached_group(reflgrp, tester)
-        return
 
     # -------------------------------------------------------------------------------
     # -------------------------------------------------------------------------------
@@ -1136,7 +1130,6 @@ class CubicBraidGroup(UniqueRepresentation, FinitelyPresentedGroup):
             self._centralizing_matrix = centralizing_matrix
             self._centralizing_element = centralizing_element
             self._classical_embedding = embedding
-            return
 
         # -------------------------------------------------------------------------------
         # local methods to set up the classical group (specific part)
@@ -1211,7 +1204,6 @@ class CubicBraidGroup(UniqueRepresentation, FinitelyPresentedGroup):
             transvec_matrices = [transvec2mat(v) for v in transvections]
 
             set_classical_realization(self, base_group, proj_group, centralizing_matrix, transvec_matrices)
-            return
 
         # -------------------------------------------------------------------------------
         # Case for unitary groups
@@ -1296,7 +1288,6 @@ class CubicBraidGroup(UniqueRepresentation, FinitelyPresentedGroup):
             transvec_matrices = [transvec2mat(v) for v in transvections]
 
             set_classical_realization(self, base_group, proj_group, centralizing_matrix, transvec_matrices)
-            return
 
         # ----------------------------------------------------------------
         # local functions declaration section finishes here
@@ -1347,7 +1338,6 @@ class CubicBraidGroup(UniqueRepresentation, FinitelyPresentedGroup):
             self._classical_embedding = classical_group
             if self._classical_invariant_form is None:
                 self._classical_invariant_form = classical_group.ambient().invariant_form()
-        return
 
     def _element_constructor_(self, x, **kwds):
         r"""
@@ -1604,7 +1594,6 @@ class CubicBraidGroup(UniqueRepresentation, FinitelyPresentedGroup):
             sage: C3 = CubicBraidGroup(3)
             sage: PC3 = C3.as_permutation_group()
             sage: assert C3.is_isomorphic(PC3)  # random (with respect to the occurrence of the info message)
-            #I  Forcing finiteness test
             sage: PC3.degree()
             8
             sage: c = C3([2,1-2])
