@@ -946,4 +946,16 @@ class GroupMixinLibGAP:
             sage: F == G, G == H, F == H
             (False, False, False)
         """
-        return self.gap().IsomorphismGroups(H.gap()) != libgap.fail
+        # If GAP doesn't know that the groups are finite, it will
+        # check. This emits an informational warning, and then
+        # annotates the groups as being finite (assuming they were) so
+        # that future isomorphism checks are silent. This can lead to
+        # apparent non-determinism in the output as statements are
+        # rearranged. There's nothing the user can do about this
+        # anyway, and it happens in trivial cases like the alternating
+        # group on one element, so we prefer to hide the warning.
+        old_warnlevel = libgap.InfoLevel(libgap.InfoWarning)
+        libgap.SetInfoLevel(libgap.InfoWarning, 0)
+        result = self.gap().IsomorphismGroups(H.gap()) != libgap.fail
+        libgap.SetInfoLevel(libgap.InfoWarning, old_warnlevel)
+        return result
