@@ -72,7 +72,6 @@ class PSage(Sage):
             sage: from sage.interfaces.psage import PSage
             sage: PSage()                                   # indirect doctest
             A running non-blocking (parallel) instance of Sage (number ...)
-
         """
         return 'A running non-blocking (parallel) instance of Sage (number %s)' % (self._number)
 
@@ -123,7 +122,7 @@ class PSage(Sage):
         except OSError:
             pass
 
-        if not (self._expect is None):
+        if self._expect is not None:
             cmd = 'kill -9 %s' % self._expect.pid
             os.system(cmd)
 
