@@ -1,13 +1,11 @@
-# -*- coding: utf-8 -*-
 """
-L-functions from PARI
+`L`-functions from PARI
 
-This is a wrapper around the general PARI L-functions functionality.
+This is a wrapper around the general PARI `L`-functions functionality.
 
 AUTHORS:
 
 - Frédéric Chapoton (2018) interface
-
 """
 # ****************************************************************************
 #       Copyright (C) 2018 Frédéric Chapoton <chapoton@unistra.fr>
@@ -22,10 +20,13 @@ from operator import index as PyNumber_Index
 from cypari2.gen import Gen
 from sage.libs.pari import pari
 from sage.structure.sage_object import SageObject
-from sage.rings.all import (ZZ, RealField, ComplexField, PowerSeriesRing)
+from sage.rings.integer_ring import ZZ
+from sage.rings.real_mpfr import RealField
+from sage.rings.complex_mpfr import ComplexField
+from sage.rings.power_series_ring import PowerSeriesRing
 
 
-class lfun_generic():
+class lfun_generic:
     r"""
     Create a PARI `L`-function (:pari:`lfun` instance).
 
@@ -35,22 +36,22 @@ class lfun_generic():
 
     where
 
-    - ``conductor`` -- integer, the conductor
+    - ``conductor`` -- integer; the conductor
 
     - ``gammaV`` -- list of Gamma-factor parameters, e.g. [0] for
-      Riemann zeta, [0,1] for ell.curves, (see examples).
+      Riemann zeta, [0,1] for ell.curves, (see examples)
 
     - ``weight`` -- positive real number, usually an integer e.g. 1 for
       Riemann zeta, 2 for `H^1` of curves/`\QQ`
 
     - ``eps`` -- complex number; sign in functional equation
 
-    - ``poles`` -- (default: []) list of points where `L^*(s)` has
+    - ``poles`` -- (default: ``[]``) list of points where `L^*(s)` has
       (simple) poles; only poles with `Re(s)>weight/2` should be
       included
 
     - ``residues`` -- vector of residues of `L^*(s)` in those poles or
-      set residues='automatic' (default value)
+      set ``residues='automatic'`` (default)
 
     - ``init`` -- list of coefficients
 
@@ -62,7 +63,7 @@ class lfun_generic():
         sage: lf = lfun_generic(conductor=1, gammaV=[0], weight=1, eps=1, poles=[1], residues=[1])
         sage: lf.init_coeffs([1]*2000)
 
-    Now we can wrap this PARI L-function into one Sage L-function::
+    Now we can wrap this PARI `L`-function into one Sage `L`-function::
 
         sage: L = LFunction(lf); L
         L-series of conductor 1 and weight 1
@@ -108,7 +109,7 @@ class lfun_generic():
         if args or kwds:
             self.init_coeffs(*args, **kwds)
 
-    def init_coeffs(self, v, cutoff=None, w=1, *args, **kwds):
+    def init_coeffs(self, v, cutoff=None, w=1):
         """
         Set the coefficients `a_n` of the `L`-series.
 
@@ -117,34 +118,34 @@ class lfun_generic():
 
         INPUT:
 
-        -  ``v`` -- list of complex numbers or unary function
+        - ``v`` -- list of complex numbers or unary function
 
-        -  ``cutoff`` -- unused
+        - ``cutoff`` -- unused
 
-        -  ``w`` --  list of complex numbers or unary function
+        - ``w`` -- list of complex numbers or unary function
 
         EXAMPLES::
 
             sage: from sage.lfunctions.pari import lfun_generic, LFunction
-            sage: lf = lfun_generic(conductor=1, gammaV=[0,1], weight=12, eps=1)
+            sage: lf = lfun_generic(conductor=1, gammaV=[0, 1], weight=12, eps=1)
             sage: pari_coeffs = pari('k->vector(k,n,(5*sigma(n,3)+7*sigma(n,5))*n/12 - 35*sum(k=1,n-1,(6*k-4*(n-k))*sigma(k,3)*sigma(n-k,5)))')
             sage: lf.init_coeffs(pari_coeffs)
 
-        Evaluate the resulting L-function at a point, and compare with
-        the answer that one gets "by definition" (of L-function
+        Evaluate the resulting `L`-function at a point, and compare with
+        the answer that one gets "by definition" (of `L`-function
         attached to a modular form)::
 
             sage: L = LFunction(lf)
             sage: L(14)
             0.998583063162746
             sage: a = delta_qexp(1000)
-            sage: sum(a[n]/float(n)^14 for n in range(1,1000))
-            0.9985830631627459
+            sage: sum(a[n]/float(n)^14 for n in reversed(range(1,1000)))
+            0.9985830631627461
 
         Illustrate that one can give a list of complex numbers for v
-        (see :trac:`10937`)::
+        (see :issue:`10937`)::
 
-            sage: l2 = lfun_generic(conductor=1, gammaV=[0,1], weight=12, eps=1)
+            sage: l2 = lfun_generic(conductor=1, gammaV=[0, 1], weight=12, eps=1)
             sage: l2.init_coeffs(list(delta_qexp(1000))[1:])
             sage: L2 = LFunction(l2)
             sage: L2(14)
@@ -153,22 +154,11 @@ class lfun_generic():
         TESTS:
 
         Verify that setting the `w` parameter does not raise an error
-        (see :trac:`10937`)::
+        (see :issue:`10937`)::
 
-            sage: L2 = lfun_generic(conductor=1, gammaV=[0,1], weight=12, eps=1)
+            sage: L2 = lfun_generic(conductor=1, gammaV=[0, 1], weight=12, eps=1)
             sage: L2.init_coeffs(list(delta_qexp(1000))[1:], w=[1..1000])
-
-        Additional arguments are ignored for compatibility with the old
-        Dokchitser script::
-
-            sage: L2.init_coeffs(list(delta_qexp(1000))[1:], foo="bar")
-            doctest:...: DeprecationWarning: additional arguments for initializing an lfun_generic are ignored
-            See https://trac.sagemath.org/26098 for details.
         """
-        if args or kwds:
-            from sage.misc.superseded import deprecation
-            deprecation(26098, "additional arguments for initializing an lfun_generic are ignored")
-
         v = pari(v)
         if v.type() not in ('t_CLOSURE', 't_VEC'):
             raise TypeError("v (coefficients) must be a list or a function")
@@ -192,7 +182,7 @@ class lfun_generic():
 
     def __pari__(self):
         """
-        Return the PARI L-function object.
+        Return the PARI `L`-function object.
 
         EXAMPLES::
 
@@ -215,14 +205,12 @@ class lfun_generic():
 
 def lfun_character(chi):
     """
-    Create the L-function of a primitive Dirichlet character.
+    Create the `L`-function of a primitive Dirichlet character.
 
     If the given character is not primitive, it is replaced by its
     associated primitive character.
 
-    OUTPUT:
-
-    one :pari:`lfun` object
+    OUTPUT: one :pari:`lfun` object
 
     EXAMPLES::
 
@@ -250,12 +238,12 @@ def lfun_character(chi):
 
     Check the values::
 
-        sage: chi = DirichletGroup(24)([1,-1,-1]); chi
+        sage: chi = DirichletGroup(24)([1, -1, -1]); chi
         Dirichlet character modulo 24 of conductor 24
         mapping 7 |--> 1, 13 |--> -1, 17 |--> -1
         sage: Lchi = lfun_character(chi)
         sage: v = [0] + Lchi.lfunan(30).sage()
-        sage: all(v[i] == chi(i) for i in (7,13,17))
+        sage: all(v[i] == chi(i) for i in (7, 13, 17))
         True
     """
     if not chi.is_primitive():
@@ -264,13 +252,31 @@ def lfun_character(chi):
     return pari.lfuncreate([G, v])
 
 
+def lfun_hgm(motif, t):
+    """
+    Create the `L`-function of an hypergeometric motive.
+
+    OUTPUT: one :pari:`lfun` object
+
+    EXAMPLES::
+
+        sage: from sage.lfunctions.pari import lfun_hgm, LFunction
+        sage: from sage.modular.hypergeometric_motive import HypergeometricData as Hyp
+        sage: H = Hyp(gamma_list=([3,-1,-1,-1]))
+        sage: L = LFunction(lfun_hgm(H, 1/5))
+        sage: L(3)
+        0.901925346034773
+    """
+    H = pari.hgminit(*motif.alpha_beta())
+    lf = pari.lfunhgm(H, t)
+    return pari.lfuncreate(lf)
+
+
 def lfun_elliptic_curve(E):
     """
-    Create the L-function of an elliptic curve.
+    Create the `L`-function of an elliptic curve.
 
-    OUTPUT:
-
-    one :pari:`lfun` object
+    OUTPUT: one :pari:`lfun` object
 
     EXAMPLES::
 
@@ -285,7 +291,7 @@ def lfun_elliptic_curve(E):
     Over number fields::
 
         sage: K.<a> = QuadraticField(2)
-        sage: E = EllipticCurve([1,a])
+        sage: E = EllipticCurve([1, a])
         sage: L = LFunction(lfun_elliptic_curve(E))
         sage: L(3)
         1.00412346717019
@@ -297,9 +303,7 @@ def lfun_number_field(K):
     """
     Create the Dedekind zeta function of a number field.
 
-    OUTPUT:
-
-    one :pari:`lfun` object
+    OUTPUT: one :pari:`lfun` object
 
     EXAMPLES::
 
@@ -309,7 +313,7 @@ def lfun_number_field(K):
         sage: L(3)
         1.20205690315959
 
-        sage: K = NumberField(x**2-2, 'a')
+        sage: K = NumberField(x**2 - 2, 'a')
         sage: L = LFunction(lfun_number_field(K))
         sage: L(3)
         1.15202784126080
@@ -321,15 +325,15 @@ def lfun_number_field(K):
 
 def lfun_eta_quotient(scalings, exponents):
     """
-    Return the L-function of an eta-quotient.
+    Return the `L`-function of an eta-quotient.
 
     This uses :pari:`lfunetaquo`.
 
     INPUT:
 
-    - scalings -- a list of integers, the scaling factors
+    - ``scalings`` -- list of integers; the scaling factors
 
-    - exponents -- a list of integers, the exponents
+    - ``exponents`` -- list of integers; the exponents
 
     EXAMPLES::
 
@@ -338,10 +342,10 @@ def lfun_eta_quotient(scalings, exponents):
         sage: L(1)
         0.0374412812685155
 
-        sage: lfun_eta_quotient([6],[4])
+        sage: lfun_eta_quotient([6], [4])
         [[Vecsmall([7]), [Vecsmall([6]), Vecsmall([4]), 0]], 0, [0, 1], 2, 36, 1]
 
-        sage: lfun_eta_quotient([2,1,4], [5,-2,-2])
+        sage: lfun_eta_quotient([2, 1, 4], [5, -2, -2])
         Traceback (most recent call last):
         ...
         PariError: sorry, noncuspidal eta quotient is not yet implemented
@@ -356,7 +360,7 @@ def lfun_eta_quotient(scalings, exponents):
 
 def lfun_delta():
     """
-    Return the L-function of Ramanujan's Delta modular form.
+    Return the `L`-function of Ramanujan's Delta modular form.
 
     EXAMPLES::
 
@@ -370,14 +374,14 @@ def lfun_delta():
 
 def lfun_quadratic_form(qf):
     """
-    Return the L-function of a positive definite quadratic form.
+    Return the `L`-function of a positive definite quadratic form.
 
     This uses :pari:`lfunqf`.
 
     EXAMPLES::
 
         sage: from sage.lfunctions.pari import lfun_quadratic_form, LFunction
-        sage: Q = QuadraticForm(ZZ,2,[2,3,4])
+        sage: Q = QuadraticForm(ZZ, 2, [2, 3, 4])
         sage: L = LFunction(lfun_quadratic_form(Q))
         sage: L(3)
         0.377597233183583
@@ -389,7 +393,7 @@ def lfun_quadratic_form(qf):
 
 def lfun_genus2(C):
     """
-    Return the L-function of a curve of genus 2.
+    Return the `L`-function of a curve of genus 2.
 
     INPUT:
 
@@ -409,7 +413,7 @@ def lfun_genus2(C):
         sage: L(3)
         0.965946926261520
 
-        sage: C = HyperellipticCurve(x^2+x, x^3+x^2+1)
+        sage: C = HyperellipticCurve(x^2 + x, x^3 + x^2 + 1)
         sage: L = LFunction(lfun_genus2(C))
         sage: L(2)
         0.364286342944359
@@ -432,24 +436,24 @@ def lfun_genus2(C):
 
 class LFunction(SageObject):
     r"""
-    Build the L-function from a PARI L-function.
+    Build the `L`-function from a PARI `L`-function.
 
     .. RUBRIC:: Rank 1 elliptic curve
 
     We compute with the `L`-series of a rank `1` curve. ::
 
         sage: E = EllipticCurve('37a')
-        sage: L = E.lseries().dokchitser(algorithm="pari"); L
+        sage: L = E.lseries().dokchitser(algorithm='pari'); L
         PARI L-function associated to Elliptic Curve defined by y^2 + y = x^3 - x over Rational Field
         sage: L(1)
         0.000000000000000
         sage: L.derivative(1)
         0.305999773834052
-        sage: L.derivative(1,2)
+        sage: L.derivative(1, 2)
         0.373095594536324
         sage: L.num_coeffs()
         50
-        sage: L.taylor_series(1,4)
+        sage: L.taylor_series(1, 4)
         0.000000000000000 + 0.305999773834052*z + 0.186547797268162*z^2 - 0.136791463097188*z^3 + O(z^4)
         sage: L.check_functional_equation()  # abs tol 4e-19
         1.08420217248550e-19
@@ -460,12 +464,12 @@ class LFunction(SageObject):
     `L`-series of a rank `2` elliptic curve::
 
         sage: E = EllipticCurve('389a')
-        sage: L = E.lseries().dokchitser(algorithm="pari")
+        sage: L = E.lseries().dokchitser(algorithm='pari')
         sage: L.num_coeffs()
         163
-        sage: L.derivative(1,E.rank())
+        sage: L.derivative(1, E.rank())
         1.51863300057685
-        sage: L.taylor_series(1,4)
+        sage: L.taylor_series(1, 4)
         ...e-19 + (...e-19)*z + 0.759316500288427*z^2 - 0.430302337583362*z^3 + O(z^4)
 
     .. RUBRIC:: Number field
@@ -474,14 +478,14 @@ class LFunction(SageObject):
 
         sage: x = var('x')
         sage: K = NumberField(x**4 - x**2 - 1,'a')
-        sage: L = K.zeta_function(algorithm="pari")
+        sage: L = K.zeta_function(algorithm='pari')
         sage: L.conductor
         400
         sage: L.num_coeffs()
         348
         sage: L(2)
         1.10398438736918
-        sage: L.taylor_series(2,3)
+        sage: L.taylor_series(2, 3)
         1.10398438736918 - 0.215822638498759*z + 0.279836437522536*z^2 + O(z^3)
 
     .. RUBRIC:: Ramanujan `\Delta` L-function
@@ -489,7 +493,7 @@ class LFunction(SageObject):
     The coefficients are given by Ramanujan's tau function::
 
         sage: from sage.lfunctions.pari import lfun_generic, LFunction
-        sage: lf = lfun_generic(conductor=1, gammaV=[0,1], weight=12, eps=1)
+        sage: lf = lfun_generic(conductor=1, gammaV=[0, 1], weight=12, eps=1)
         sage: tau = pari('k->vector(k,n,(5*sigma(n,3)+7*sigma(n,5))*n/12 - 35*sum(k=1,n-1,(6*k-4*(n-k))*sigma(k,3)*sigma(n-k,5)))')
         sage: lf.init_coeffs(tau)
         sage: L = LFunction(lf)
@@ -498,17 +502,17 @@ class LFunction(SageObject):
 
         sage: L(1)
         0.0374412812685155
-        sage: L.taylor_series(1,3)
+        sage: L.taylor_series(1, 3)
         0.0374412812685155 + 0.0709221123619322*z + 0.0380744761270520*z^2 + O(z^3)
     """
     def __init__(self, lfun, prec=None):
         """
-        Initialization of the L-function from a PARI L-function.
+        Initialization of the `L`-function from a PARI `L`-function.
 
         INPUT:
 
-        - lfun -- a PARI :pari:`lfun` object or an instance of :class:`lfun_generic`
-        - prec -- integer (default: 53) number of *bits* of precision
+        - ``lfun`` -- a PARI :pari:`lfun` object or an instance of :class:`lfun_generic`
+        - ``prec`` -- integer (default: 53); number of *bits* of precision
 
         EXAMPLES::
 
@@ -580,11 +584,11 @@ class LFunction(SageObject):
         EXAMPLES::
 
             sage: E = EllipticCurve('11a')
-            sage: L = E.lseries().dokchitser(algorithm="pari")
+            sage: L = E.lseries().dokchitser(algorithm='pari')
             sage: L.num_coeffs()
             27
             sage: E = EllipticCurve('5077a')
-            sage: L = E.lseries().dokchitser(algorithm="pari")
+            sage: L = E.lseries().dokchitser(algorithm='pari')
             sage: L.num_coeffs()
             591
 
@@ -600,7 +604,7 @@ class LFunction(SageObject):
 
     def Lambda(self, s):
         """
-        Evaluate the completed L-function at s.
+        Evaluate the completed `L`-function at s.
 
         EXAMPLES::
 
@@ -608,7 +612,7 @@ class LFunction(SageObject):
             sage: L = LFunction(lfun_number_field(QQ))
             sage: L.Lambda(2)
             0.523598775598299
-            sage: L.Lambda(1-2)
+            sage: L.Lambda(1 - 2)
             0.523598775598299
         """
         s = self._CCin(s)
@@ -630,7 +634,7 @@ class LFunction(SageObject):
 
         TESTS::
 
-            sage: L.hardy(.4+.3*I)
+            sage: L.hardy(.4 + .3*I)
             Traceback (most recent call last):
             ...
             PariError: incorrect type in lfunhardy (t_COMPLEX)
@@ -641,13 +645,13 @@ class LFunction(SageObject):
 
     def derivative(self, s, D=1):
         """
-        Return the derivative of the L-function at point s and order D.
+        Return the derivative of the `L`-function at point s and order D.
 
         INPUT:
 
-        -  ``s`` -- complex number
+        - ``s`` -- complex number
 
-        - ``D`` -- optional integer (default 1)
+        - ``D`` -- integer (default: 1)
 
         EXAMPLES::
 
@@ -669,13 +673,11 @@ class LFunction(SageObject):
 
         INPUT:
 
-        -  ``s`` -- complex number; point about which to expand
+        - ``s`` -- complex number; point about which to expand
 
-        -  ``k`` -- optional integer (default: 6), series is
-           `O(``var``^k)`
+        - ``k`` -- integer (default: 6); series is `O(``var``^k)`
 
-        -  ``var`` -- optional string (default: 'z'), variable of power
-           series
+        - ``var`` -- string (default: ``'z'``); variable of power series
 
         EXAMPLES::
 
@@ -685,7 +687,7 @@ class LFunction(SageObject):
             sage: L.taylor_series(2, 3)
             1.64493406684823 - 0.937548254315844*z + 0.994640117149451*z^2 + O(z^3)
             sage: E = EllipticCurve('37a')
-            sage: L = E.lseries().dokchitser(algorithm="pari")
+            sage: L = E.lseries().dokchitser(algorithm='pari')
             sage: L.taylor_series(1)
             0.000000000000000 + 0.305999773834052*z + 0.186547797268162*z^2 - 0.136791463097188*z^3 + 0.0161066468496401*z^4 + 0.0185955175398802*z^5 + O(z^6)
 
@@ -693,11 +695,11 @@ class LFunction(SageObject):
         precision::
 
             sage: E = EllipticCurve('389a')
-            sage: L = E.lseries().dokchitser(200,algorithm="pari")
-            sage: L.taylor_series(1,3)
+            sage: L = E.lseries().dokchitser(200,algorithm='pari')
+            sage: L.taylor_series(1, 3)
             2...e-63 + (...e-63)*z + 0.75931650028842677023019260789472201907809751649492435158581*z^2 + O(z^3)
 
-        Check that :trac:`25402` is fixed::
+        Check that :issue:`25402` is fixed::
 
             sage: L = EllipticCurve("24a1").modular_form().lseries()
             sage: L.taylor_series(-1, 3)
@@ -739,11 +741,11 @@ class LFunction(SageObject):
 
     def __call__(self, s):
         r"""
-        Return the value of the L-function at point ``s``.
+        Return the value of the `L`-function at point ``s``.
 
         INPUT:
 
-        -  ``s`` -- complex number
+        - ``s`` -- complex number
 
         .. NOTE::
 
@@ -754,10 +756,10 @@ class LFunction(SageObject):
         EXAMPLES::
 
             sage: E = EllipticCurve('5077a')
-            sage: L = E.lseries().dokchitser(100, algorithm="pari")
+            sage: L = E.lseries().dokchitser(100, algorithm='pari')
             sage: L(1)
             0.00000000000000000000000000000
-            sage: L(1+I)
+            sage: L(1 + I)
             -1.3085436607849493358323930438 + 0.81298000036784359634835412129*I
         """
         s = self._CC(s)
