@@ -19,7 +19,7 @@ Submodules of Hecke modules
 #                  https://www.gnu.org/licenses/
 # ****************************************************************************
 
-import sage.arith.all as arith
+import sage.arith.misc as arith
 from sage.misc.verbose import verbose
 from sage.misc.cachefunc import cached_method
 from sage.modules.free_module import FreeModule_generic
@@ -383,8 +383,7 @@ class HeckeSubmodule(module.HeckeModule_free_module):
                 break
 
         if V.rank() + self.rank() == A.rank():
-            C = A.submodule(V, check=False)
-            return C
+            return A.submodule(V, check=False)
 
         # first attempt to compute the complement failed, we now try
         # the following naive approach: decompose the ambient space,
@@ -425,10 +424,8 @@ class HeckeSubmodule(module.HeckeModule_free_module):
         EXAMPLES::
 
             sage: D = ModularSymbols(10,4).cuspidal_submodule().decomposition(); D
-            [
-            Modular Symbols subspace of dimension 2 of Modular Symbols space of dimension 10 for Gamma_0(10) of weight 4 with sign 0 over Rational Field,
-            Modular Symbols subspace of dimension 4 of Modular Symbols space of dimension 10 for Gamma_0(10) of weight 4 with sign 0 over Rational Field
-            ]
+            [Modular Symbols subspace of dimension 2 of Modular Symbols space of dimension 10 for Gamma_0(10) of weight 4 with sign 0 over Rational Field,
+             Modular Symbols subspace of dimension 4 of Modular Symbols space of dimension 10 for Gamma_0(10) of weight 4 with sign 0 over Rational Field]
             sage: d = D[1].degeneracy_map(5); d
             Hecke module morphism defined by the matrix
             [   0    0   -1    1]
@@ -521,8 +518,7 @@ class HeckeSubmodule(module.HeckeModule_free_module):
         if self.complement.is_in_cache():
             verbose('This module knows its complement already -- cheating in dual_free_module')
             C = self.complement()
-            V = C.basis_matrix().right_kernel()
-            return V
+            return C.basis_matrix().right_kernel()
 
         verbose("computing dual")
 
@@ -674,7 +670,7 @@ class HeckeSubmodule(module.HeckeModule_free_module):
 
         return M
 
-    def is_ambient(self):
+    def is_ambient(self) -> bool:
         r"""
         Return ``True`` if ``self`` is an ambient space of modular symbols.
 
@@ -690,7 +686,7 @@ class HeckeSubmodule(module.HeckeModule_free_module):
         """
         return self.free_module() == self.ambient_hecke_module().free_module()
 
-    def is_new(self, p=None):
+    def is_new(self, p=None) -> bool:
         """
         Return ``True`` if this Hecke module is `p`-new. If `p` is None,
         returns ``True`` if it is new.
@@ -712,7 +708,7 @@ class HeckeSubmodule(module.HeckeModule_free_module):
         self.__is_new[p] = self.is_submodule(N)
         return self.__is_new[p]
 
-    def is_old(self, p=None):
+    def is_old(self, p=None) -> bool:
         """
         Return ``True`` if this Hecke module is `p`-old. If `p` is ``None``,
         returns ``True`` if it is old.
@@ -737,7 +733,7 @@ class HeckeSubmodule(module.HeckeModule_free_module):
         self.__is_old[p] = self.is_submodule(O)
         return self.__is_old[p]
 
-    def is_submodule(self, V):
+    def is_submodule(self, V) -> bool:
         """
         Return ``True`` if and only if ``self`` is a submodule of V.
 
@@ -776,10 +772,7 @@ class HeckeSubmodule(module.HeckeModule_free_module):
 
             sage: S = M.cuspidal_submodule()
             sage: S.basis()
-            [
-            q + 252*q^3 - 2048*q^4 + 4830*q^5 + O(q^6),
-            q^2 - 24*q^4 + O(q^6)
-            ]
+            [q + 252*q^3 - 2048*q^4 + 4830*q^5 + O(q^6), q^2 - 24*q^4 + O(q^6)]
             sage: S.linear_combination_of_basis([3, 10])
             3*q + 10*q^2 + 756*q^3 - 6384*q^4 + 14490*q^5 + O(q^6)
         """
