@@ -20,22 +20,28 @@ AUTHORS:
 - Jared Weinstein
 """
 
-from sage.structure.sage_object import SageObject
+from typing import Self
+
+from sage.misc.abstract_method import abstract_method
+from sage.misc.cachefunc import cached_method
+from sage.misc.flatten import flatten
+from sage.misc.lazy_import import lazy_import
+from sage.misc.verbose import verbose
+from sage.modular.modform.element import Newform
 from sage.rings.integer_ring import ZZ
 from sage.rings.polynomial.polynomial_ring import polygen
 from sage.rings.polynomial.polynomial_ring_constructor import PolynomialRing
-from sage.misc.abstract_method import abstract_method
-from sage.misc.cachefunc import cached_method
-from sage.misc.lazy_import import lazy_import
-from sage.misc.verbose import verbose
-from sage.misc.flatten import flatten
-from sage.modular.modform.element import Newform
+from sage.structure.sage_object import SageObject
 from sage.structure.sequence import Sequence
 
 lazy_import('sage.rings.qqbar', 'QQbar')
 
+from .smoothchar import (
+    SmoothCharacterGroupQp,
+    SmoothCharacterGroupRamifiedQuadratic,
+    SmoothCharacterGroupUnramifiedQuadratic,
+)
 from .type_space import TypeSpace
-from .smoothchar import SmoothCharacterGroupQp, SmoothCharacterGroupUnramifiedQuadratic, SmoothCharacterGroupRamifiedQuadratic
 
 
 def LocalComponent(f, p, twist_factor=None):
@@ -320,7 +326,7 @@ class PrimitiveLocalComponent(LocalComponentBase):
     Base class for primitive (twist-minimal) local components.
     """
 
-    def is_primitive(self):
+    def is_primitive(self) -> bool:
         r"""
         Return ``True`` if this local component is primitive (has minimal level
         among its character twists).
@@ -332,7 +338,7 @@ class PrimitiveLocalComponent(LocalComponentBase):
         """
         return True
 
-    def minimal_twist(self):
+    def minimal_twist(self) -> Self:
         r"""
         Return a twist of this local component which has the minimal possible
         conductor.
@@ -800,8 +806,7 @@ class PrimitiveSupercuspidal(PrimitiveLocalComponent):
                             verbose("  chisB FAILED", level=1)
                             B_fail = 1
                             break
-                        else:
-                            verbose("  Trace identity check works for both", level=1)
+                        verbose("  Trace identity check works for both", level=1)
 
                 if B_fail and not A_fail:
                     chi1, chi2 = chisA
@@ -964,7 +969,7 @@ class ImprimitiveLocalComponent(LocalComponentBase):
         self._min_twist = min_twist
         self._chi = chi
 
-    def is_primitive(self):
+    def is_primitive(self) -> bool:
         r"""
         Return ``True`` if this local component is primitive (has minimal level
         among its character twists).
