@@ -1,3 +1,4 @@
+# sage.doctest: needs sage.libs.pari
 """
 Modular forms over a non-minimal base ring
 """
@@ -15,6 +16,7 @@ from .cuspidal_submodule import CuspidalSubmodule_R
 from sage.rings.integer_ring import ZZ
 from sage.misc.cachefunc import cached_method
 
+
 class ModularFormsAmbient_R(ambient.ModularFormsAmbient):
     def __init__(self, M, base_ring):
         """
@@ -22,9 +24,10 @@ class ModularFormsAmbient_R(ambient.ModularFormsAmbient):
 
         EXAMPLES::
 
-            sage: M = ModularForms(23,2,base_ring=GF(7)) # indirect doctest
+            sage: M = ModularForms(23, 2, base_ring=GF(7)) # indirect doctest
             sage: M
-            Modular Forms space of dimension 3 for Congruence Subgroup Gamma0(23) of weight 2 over Finite Field of size 7
+            Modular Forms space of dimension 3 for Congruence Subgroup Gamma0(23)
+             of weight 2 over Finite Field of size 7
             sage: M == loads(dumps(M))
             True
         """
@@ -36,16 +39,18 @@ class ModularFormsAmbient_R(ambient.ModularFormsAmbient):
         ambient.ModularFormsAmbient.__init__(self, M.group(), M.weight(), base_ring, M.character(), M._eis_only)
 
     @cached_method(key=lambda self,sign: ZZ(sign)) # convert sign to an Integer before looking this up in the cache
-    def modular_symbols(self,sign=0):
+    def modular_symbols(self, sign=0):
         r"""
         Return the space of modular symbols attached to this space, with the given sign (default 0).
 
         TESTS::
 
+            sage: # needs sage.rings.number_field
             sage: K.<i> = QuadraticField(-1)
-            sage: chi = DirichletGroup(5, base_ring = K).0
+            sage: chi = DirichletGroup(5, base_ring=K).0
+            sage: x = polygen(ZZ, 'x')
             sage: L.<c> = K.extension(x^2 - 402*i)
-            sage: M = ModularForms(chi, 7, base_ring = L)
+            sage: M = ModularForms(chi, 7, base_ring=L)
             sage: symbs = M.modular_symbols()
             sage: symbs.character() == chi
             True
@@ -65,6 +70,7 @@ class ModularFormsAmbient_R(ambient.ModularFormsAmbient):
             sage: M._repr_()
             'Modular Forms space of dimension 3 for Congruence Subgroup Gamma0(23) of weight 2 over Finite Field of size 7'
 
+            sage: # needs sage.rings.number_field
             sage: chi = DirichletGroup(109).0 ** 36
             sage: ModularForms(chi, 2, base_ring = chi.base_ring())
             Modular Forms space of dimension 9, character [zeta3] and weight 2 over Cyclotomic Field of order 108 and degree 36
@@ -77,19 +83,19 @@ class ModularFormsAmbient_R(ambient.ModularFormsAmbient):
 
     def _compute_q_expansion_basis(self, prec=None):
         """
-        Compute q-expansions for a basis of self to precision prec.
+        Compute `q`-expansions for a basis of ``self`` to precision ``prec``.
 
         EXAMPLES::
 
             sage: M = ModularForms(23,2,base_ring=GF(7))
             sage: M._compute_q_expansion_basis(10)
             [q + 6*q^3 + 6*q^4 + 5*q^6 + 2*q^7 + 6*q^8 + 2*q^9 + O(q^10),
-            q^2 + 5*q^3 + 6*q^4 + 2*q^5 + q^6 + 2*q^7 + 5*q^8 + O(q^10),
-            1 + 5*q^3 + 5*q^4 + 5*q^6 + 3*q^8 + 5*q^9 + O(q^10)]
+             q^2 + 5*q^3 + 6*q^4 + 2*q^5 + q^6 + 2*q^7 + 5*q^8 + O(q^10),
+             1 + 5*q^3 + 5*q^4 + 5*q^6 + 3*q^8 + 5*q^9 + O(q^10)]
 
         TESTS:
 
-        This checks that :trac:`13445` is fixed::
+        This checks that :issue:`13445` is fixed::
 
             sage: M = ModularForms(Gamma0(11), base_ring=GF(11))
             sage: S = M.cuspidal_subspace()
@@ -123,7 +129,7 @@ class ModularFormsAmbient_R(ambient.ModularFormsAmbient):
                     newB.append(f)
                     V = A.span(gens)
             if len(newB) != self.dimension():
-                raise RuntimeError("The dimension of the space is %s but the basis we computed has %s elements"%(self.dimension(), len(newB)))
+                raise RuntimeError("The dimension of the space is %s but the basis we computed has %s elements" % (self.dimension(), len(newB)))
             lst = [R(f) for f in newB]
             return [f/f[f.valuation()] for f in lst]
         else:
@@ -141,7 +147,8 @@ class ModularFormsAmbient_R(ambient.ModularFormsAmbient):
 
         EXAMPLES::
 
-            sage: C = CuspForms(7, 4, base_ring=CyclotomicField(5)) # indirect doctest
+            sage: # needs sage.rings.number_field
+            sage: C = CuspForms(7, 4, base_ring=CyclotomicField(5))  # indirect doctest
             sage: type(C)
             <class 'sage.modular.modform.cuspidal_submodule.CuspidalSubmodule_R_with_category'>
         """
@@ -153,10 +160,12 @@ class ModularFormsAmbient_R(ambient.ModularFormsAmbient):
 
         EXAMPLES::
 
+            sage: # needs sage.rings.number_field
             sage: chi = DirichletGroup(109, CyclotomicField(3)).0
             sage: M9 = ModularForms(chi, 2, base_ring = CyclotomicField(9))
             sage: M9.change_ring(CyclotomicField(15))
-            Modular Forms space of dimension 10, character [zeta3 + 1] and weight 2 over Cyclotomic Field of order 15 and degree 8
+            Modular Forms space of dimension 10, character [zeta3 + 1] and weight 2
+             over Cyclotomic Field of order 15 and degree 8
             sage: M9.change_ring(QQ)
             Traceback (most recent call last):
             ...
