@@ -71,11 +71,9 @@ class FreeAbelianMonoidFactory(UniqueFactory):
 
     INPUT:
 
+    - ``n`` -- integer
 
-    -  ``n`` -- integer
-
-    -  ``names`` -- names of generators
-
+    - ``names`` -- names of generators
 
     OUTPUT: free abelian monoid
 
@@ -116,7 +114,7 @@ def FreeAbelianMonoid(index_set=None, names=None, **kwds):
     Return a free abelian monoid on `n` generators or with the generators
     indexed by a set `I`.
 
-    We construct free abelian monoids by specifing either:
+    We construct free abelian monoids by specifying either:
 
     - the number of generators and/or the names of the generators
     - the indexing set for the generators (this ignores the other two inputs)
@@ -126,11 +124,9 @@ def FreeAbelianMonoid(index_set=None, names=None, **kwds):
     - ``index_set`` -- an indexing set for the generators; if an integer,
       then this becomes `\{0, 1, \ldots, n-1\}`
 
-    -  ``names`` -- names of generators
+    - ``names`` -- names of generators
 
-    OUTPUT:
-
-    A free abelian monoid.
+    OUTPUT: a free abelian monoid
 
     EXAMPLES::
 
@@ -163,7 +159,7 @@ def FreeAbelianMonoid(index_set=None, names=None, **kwds):
 
 def is_FreeAbelianMonoid(x):
     """
-    Return True if `x` is a free abelian monoid.
+    Return ``True`` if `x` is a free abelian monoid.
 
     EXAMPLES::
 
@@ -231,7 +227,7 @@ class FreeAbelianMonoid_class(Parent):
 
     def __contains__(self, x):
         """
-        Return True if `x` is an element of this abelian monoid.
+        Return ``True`` if `x` is an element of this abelian monoid.
 
         EXAMPLES::
 
