@@ -32,18 +32,18 @@ def setup_for_eval_on_grid(funcs,
 
     - ``funcs`` -- a function, or a list, tuple, or vector of functions
 
-    - ``ranges`` -- a list of ranges.  A range can be a 2-tuple of
+    - ``ranges`` -- list of ranges.  A range can be a 2-tuple of
       numbers specifying the minimum and maximum, or a 3-tuple giving
       the variable explicitly.
 
-    - ``plot_points`` -- a tuple of integers specifying the number of
+    - ``plot_points`` -- tuple of integers specifying the number of
       plot points for each range.  If a single number is specified, it
       will be the value for all ranges.  This defaults to 2.
 
-    - ``return_vars`` -- (default ``False``) If ``True``, return the variables,
-      in order.
+    - ``return_vars`` -- (default: ``False``) if ``True``, return the variables,
+      in order
 
-    - ``imaginary_tolerance`` -- (default: ``1e-8``); if an imaginary
+    - ``imaginary_tolerance`` -- (default: ``1e-8``) if an imaginary
       number arises (due, for example, to numerical issues), this
       tolerance specifies how large it has to be in magnitude before
       we raise an error. In other words, imaginary parts smaller than
@@ -51,12 +51,11 @@ def setup_for_eval_on_grid(funcs,
 
     OUTPUT:
 
-
     - ``fast_funcs`` -- if only one function passed, then a fast
       callable function.  If funcs is a list or tuple, then a tuple
       of fast callable functions is returned.
 
-    - ``range_specs`` -- a list of range_specs: for each range, a
+    - ``range_specs`` -- list of range_specs: for each range, a
       tuple is returned of the form (range_min, range_max,
       range_step) such that ``srange(range_min, range_max,
       range_step, include_endpoint=True)`` gives the correct points
@@ -64,10 +63,10 @@ def setup_for_eval_on_grid(funcs,
 
     EXAMPLES::
 
-        sage: x,y,z=var('x,y,z')
-        sage: f(x,y)=x+y-z
-        sage: g(x,y)=x+y
-        sage: h(y)=-y
+        sage: x,y,z = var('x,y,z')
+        sage: f(x,y) = x+y-z
+        sage: g(x,y) = x+y
+        sage: h(y) = -y
         sage: sage.plot.misc.setup_for_eval_on_grid(f, [(0, 2),(1,3),(-4,1)], plot_points=5)
         (<sage...>, [(0.0, 2.0, 0.5), (1.0, 3.0, 0.5), (-4.0, 1.0, 1.25)])
         sage: sage.plot.misc.setup_for_eval_on_grid([g,h], [(0, 2),(-1,1)], plot_points=5)
@@ -125,7 +124,6 @@ def setup_for_eval_on_grid(funcs,
         Graphics3d Object
         sage: streamline_plot(abs(x+i*y), (x,-1,1),(y,-1,1))
         Graphics object consisting of 1 graphics primitive
-
     """
     if max(map(len, ranges)) > 3:
         raise ValueError("At least one variable range has more than 3 entries: each should either have 2 or 3 entries, with one of the forms (xmin, xmax) or (x, xmin, xmax)")
@@ -151,7 +149,7 @@ def setup_for_eval_on_grid(funcs,
     # pad the variables if we don't have enough
     nargs = len(ranges)
     if len(vars) < nargs:
-        vars += ('_',)*(nargs-len(vars))
+        vars += ('_',) * (nargs - len(vars))
 
     ranges = [[float(z) for z in r] for r in ranges]
 
@@ -159,12 +157,13 @@ def setup_for_eval_on_grid(funcs,
         plot_points = 2
 
     if not isinstance(plot_points, (list, tuple)):
-        plot_points = [plot_points]*len(ranges)
+        plot_points = [plot_points] * len(ranges)
     elif len(plot_points) != nargs:
         raise ValueError("plot_points must be either an integer or a list of integers, one for each range")
 
     plot_points = [int(p) if p >= 2 else 2 for p in plot_points]
-    range_steps = [abs(range[1] - range[0])/(p-1) for range, p in zip(ranges, plot_points)]
+    range_steps = [abs(range[1] - range[0]) / (p - 1)
+                   for range, p in zip(ranges, plot_points)]
     if min(range_steps) == float(0):
         raise ValueError("plot start point and end point must be different")
 
@@ -208,11 +207,12 @@ def setup_for_eval_on_grid(funcs,
 
     # Handle vectors, lists, tuples, etc.
     if isinstance(funcs, Iterable):
-        funcs = tuple( try_make_fast(f) for f in funcs )
+        funcs = tuple(try_make_fast(f) for f in funcs)
     else:
         funcs = try_make_fast(funcs)
 
-    #TODO: raise an error if there is a function/method in funcs that takes more values than we have ranges
+    # TODO: raise an error if there is a function/method in funcs that
+    # takes more values than we have ranges
 
     if return_vars:
         return (funcs,
@@ -233,8 +233,8 @@ def unify_arguments(funcs):
 
     INPUT:
 
-    - ``funcs`` -- a list of functions; these can be symbolic
-      expressions, polynomials, etc
+    - ``funcs`` -- list of functions; these can be symbolic
+      expressions, polynomials, etc.
 
     OUTPUT: functions, expected arguments
 
@@ -244,10 +244,10 @@ def unify_arguments(funcs):
 
     EXAMPLES::
 
-        sage: x,y,z=var('x,y,z')
-        sage: f(x,y)=x+y-z
-        sage: g(x,y)=x+y
-        sage: h(y)=-y
+        sage: x,y,z = var('x,y,z')
+        sage: f(x,y) = x+y-z
+        sage: g(x,y) = x+y
+        sage: h(y) = -y
         sage: sage.plot.misc.unify_arguments((f,g,h))
         ((x, y, z), (z,))
         sage: sage.plot.misc.unify_arguments((g,h))
@@ -286,8 +286,10 @@ def _multiple_of_constant(n, pos, const):
     r"""
     Function for internal use in formatting ticks on axes with
     nice-looking multiples of various symbolic constants, such
-    as `\pi` or `e`.  Should only be used via keyword argument
-    `tick_formatter` in :meth:`plot.show`.  See documentation
+    as `\pi` or `e`.
+
+    This should only be used via keyword argument
+    ``tick_formatter`` in :meth:`plot.show`.  See documentation
     for the matplotlib.ticker module for more details.
 
     EXAMPLES:
@@ -313,11 +315,11 @@ def _multiple_of_constant(n, pos, const):
     from sage.misc.latex import latex
     from sage.rings.continued_fraction import continued_fraction
     from sage.rings.infinity import Infinity
-    cf = continued_fraction(n/const)
+    cf = continued_fraction(n / const)
     k = 1
     while cf.quotient(k) != Infinity and cf.denominator(k) < 12:
         k += 1
-    return '$%s$' % latex(cf.convergent(k-1)*const)
+    return '$%s$' % latex(cf.convergent(k - 1) * const)
 
 
 def get_matplotlib_linestyle(linestyle, return_type):
@@ -327,32 +329,32 @@ def get_matplotlib_linestyle(linestyle, return_type):
     'dotted', 'dashdot' ).
 
     If linestyle is none of these allowed options, the function raises
-    a ValueError.
+    a :exc:`ValueError`.
 
     INPUT:
 
-    - ``linestyle`` -- The style of the line, which is one of
-       - ``"-"`` or ``"solid"``
-       - ``"--"`` or ``"dashed"``
-       - ``"-."`` or ``"dash dot"``
-       - ``":"`` or ``"dotted"``
+    - ``linestyle`` -- the style of the line, which is one of
+       - ``'-'`` or ``'solid'``
+       - ``'--'`` or ``'dashed'``
+       - ``'-.'`` or ``'dash dot'``
+       - ``':'`` or ``'dotted'``
        - ``"None"`` or ``" "`` or ``""`` (nothing)
 
-       The linestyle can also be prefixed with a drawing style (e.g., ``"steps--"``)
+       The linestyle can also be prefixed with a drawing style (e.g., ``'steps--'``)
 
-       - ``"default"`` (connect the points with straight lines)
-       - ``"steps"`` or ``"steps-pre"`` (step function; horizontal
+       - ``'default'`` (connect the points with straight lines)
+       - ``'steps'`` or ``'steps-pre'`` (step function; horizontal
          line is to the left of point)
-       - ``"steps-mid"`` (step function; points are in the middle of
+       - ``'steps-mid'`` (step function; points are in the middle of
          horizontal lines)
-       - ``"steps-post"`` (step function; horizontal line is to the
+       - ``'steps-post'`` (step function; horizontal line is to the
          right of point)
 
        If ``linestyle`` is ``None`` (of type NoneType), then we return it
        back unmodified.
 
-    - ``return_type`` -- The type of linestyle that should be output. This
-      argument takes only two values - ``"long"`` or ``"short"``.
+    - ``return_type`` -- the type of linestyle that should be output. This
+      argument takes only two values - ``'long'`` or ``'short'``
 
     EXAMPLES:
 
@@ -382,9 +384,9 @@ def get_matplotlib_linestyle(linestyle, return_type):
         sage: get_matplotlib_linestyle(None, 'short') is None
         True
 
-    Linestyles with ``"default"`` or ``"steps"`` in them should also be
+    Linestyles with ``'default'`` or ``'steps'`` in them should also be
     properly handled.  For instance, matplotlib understands only the short
-    version when ``"steps"`` is used::
+    version when ``'steps'`` is used::
 
         sage: get_matplotlib_linestyle("default", "short")
         ''
@@ -402,12 +404,15 @@ def get_matplotlib_linestyle(linestyle, return_type):
         linestyle options are:
         {'solid', 'dashed', 'dotted', dashdot', 'None'}, respectively {'-',
         '--', ':', '-.', ''}
-
     """
-    long_to_short_dict = {'solid' : '-','dashed' : '--', 'dotted' : ':',
-                        'dashdot':'-.'}
-    short_to_long_dict = {'-' : 'solid','--' : 'dashed', ':' : 'dotted',
-                        '-.':'dashdot'}
+    long_to_short_dict = {'solid': '-',
+                          'dashed': '--',
+                          'dotted': ':',
+                          'dashdot': '-.'}
+    short_to_long_dict = {'-': 'solid',
+                          '--': 'dashed',
+                          ':': 'dotted',
+                          '-.': 'dashdot'}
 
     # We need this to take care of region plot. Essentially, if None is
     # passed, then we just return back the same thing.
@@ -415,20 +420,20 @@ def get_matplotlib_linestyle(linestyle, return_type):
         return None
 
     if linestyle.startswith("default"):
-        return get_matplotlib_linestyle(linestyle.strip("default"), "short")
+        return get_matplotlib_linestyle(linestyle.removeprefix("default"), "short")
     elif linestyle.startswith("steps"):
         if linestyle.startswith("steps-mid"):
             return "steps-mid" + get_matplotlib_linestyle(
-                                    linestyle.strip("steps-mid"), "short")
+                linestyle.removeprefix("steps-mid"), "short")
         elif linestyle.startswith("steps-post"):
             return "steps-post" + get_matplotlib_linestyle(
-                                    linestyle.strip("steps-post"), "short")
+                linestyle.removeprefix("steps-post"), "short")
         elif linestyle.startswith("steps-pre"):
             return "steps-pre" + get_matplotlib_linestyle(
-                                    linestyle.strip("steps-pre"), "short")
+                linestyle.removeprefix("steps-pre"), "short")
         else:
             return "steps" + get_matplotlib_linestyle(
-                                    linestyle.strip("steps"), "short")
+                linestyle.removeprefix("steps"), "short")
 
     if return_type == 'short':
         if linestyle in short_to_long_dict.keys():
@@ -496,7 +501,6 @@ class FastCallablePlotWrapper(FastCallableFloatWrapper):
             sage: fff = FastCallablePlotWrapper(ff, imag_tol=0.1)
             sage: type(fff(CDF.random_element())) is float
             True
-
         """
         try:
             return super().__call__(*args)
