@@ -91,9 +91,7 @@ def parse_color(info, base=None):
     - ``info`` -- color, valid color str or number
     - ``base`` -- tuple of length 3 (default: ``None``)
 
-    OUTPUT:
-
-    A tuple or color.
+    OUTPUT: a tuple or color
 
     EXAMPLES:
 
@@ -183,22 +181,20 @@ class Texture(WithEqualityById, SageObject, metaclass=ClasscallMetaclass):
 
         INPUT:
 
-        - ``id`` -- a texture (default: None), a dict, a color, a
-          str, a tuple, None or any other type acting as an ID. If ``id`` is
-          None and keyword ``texture`` is empty, then it returns a unique texture object.
+        - ``id`` -- a texture (default: ``None``), a dictionary, a color, a
+          string, a tuple, ``None`` or any other type acting as an ID. If ``id`` is
+          ``None`` and keyword ``texture`` is empty, then it returns a unique texture object.
         - ``texture`` -- a texture
-        - ``color`` -- tuple or str, (default: (.4, .4, 1))
+        - ``color`` -- tuple or string (default: (.4, .4, 1))
         - ``opacity`` -- number between 0 and 1 (default: 1)
         - ``ambient`` -- number (default: 0.5)
         - ``diffuse`` -- number (default: 1)
         - ``specular`` -- number (default: 0)
         - ``shininess`` -- number (default: 1)
-        - ``name`` -- str (default: None)
+        - ``name`` -- string (default: ``None``)
         - ``**kwds`` -- other valid keywords
 
-        OUTPUT:
-
-        A texture object.
+        OUTPUT: a texture object
 
         EXAMPLES:
 
@@ -425,10 +421,10 @@ class Texture(WithEqualityById, SageObject, metaclass=ClasscallMetaclass):
             illum {illumination}
             Ns {shininess!r}
             d {opacity!r}"""
-        ).format(id=self.id, ambient=self.ambient, diffuse=self.diffuse,
-                 specular=self.specular,
-                 illumination=(2 if sum(self.specular) > 0 else 1),
-                 shininess=self.shininess, opacity=self.opacity)
+                      ).format(id=self.id, ambient=self.ambient, diffuse=self.diffuse,
+                               specular=self.specular,
+                               illumination=(2 if sum(self.specular) > 0 else 1),
+                               shininess=self.shininess, opacity=self.opacity)
 
     def jmol_str(self, obj):
         r"""
@@ -451,6 +447,6 @@ class Texture(WithEqualityById, SageObject, metaclass=ClasscallMetaclass):
         """
         translucent = "translucent %s" % float(1 - self.opacity) if self.opacity < 1 else ""
         return "color {} {} [{},{},{}]".format(obj, translucent,
-                                           int(255 * self.color[0]),
-                                           int(255 * self.color[1]),
-                                           int(255 * self.color[2]))
+                                               int(255 * self.color[0]),
+                                               int(255 * self.color[1]),
+                                               int(255 * self.color[2]))
