@@ -129,7 +129,7 @@ def solve(self, c=0):
 
     - ``c`` -- (default: 0) a rational number
 
-    OUTPUT: A non-zero vector `x` satisfying ``self(x) == c``.
+    OUTPUT: a nonzero vector `x` satisfying ``self(x) == c``
 
     ALGORITHM:
 
