@@ -13,7 +13,7 @@ from sage.rings.rational_field import QQ
 from sage.arith.misc import valuation
 from sage.misc.verbose import verbose
 
-from sage.quadratic_forms.count_local_2 import count_modp__by_gauss_sum
+from sage.quadratic_forms.count_local_2 import count_modp__by_gauss_sum, count_all_local_good_types_normal_form
 
 
 def count_modp_solutions__by_Gauss_sum(self, p, m):
@@ -34,9 +34,9 @@ def count_modp_solutions__by_Gauss_sum(self, p, m):
 
     - ``p`` -- a prime number > 2
 
-    - ``m`` -- an integer
+    - ``m`` -- integer
 
-    OUTPUT: an integer `\geq 0`
+    OUTPUT: integer `\geq 0`
 
     EXAMPLES::
 
@@ -75,7 +75,7 @@ def local_good_density_congruence_odd(self, p, m, Zvec, NZvec):
 
     - ``p`` -- a prime number
 
-    - ``m`` -- an integer
+    - ``m`` -- integer
 
     - ``Zvec``, ``NZvec`` -- non-repeating lists of integers in ``range(self.dim())`` or ``None``
 
@@ -111,7 +111,7 @@ def local_good_density_congruence_odd(self, p, m, Zvec, NZvec):
     UnitVec = Set(i for i in range(n) if self[i, i] % p)
     NonUnitVec = Set(range(n)) - UnitVec
 
-    #  Take cases on the existence of additional non-zero congruence conditions (mod p)
+    #  Take cases on the existence of additional nonzero congruence conditions (mod p)
     UnitVec_minus_Zvec = list(UnitVec - Set(Zvec))
     NonUnitVec_minus_Zvec = list(NonUnitVec - Set(Zvec))
     Q_Unit_minus_Zvec = self.extract_variables(UnitVec_minus_Zvec)
@@ -171,7 +171,7 @@ def local_good_density_congruence_even(self, m, Zvec, NZvec):
 
     - ``p`` -- a prime number
 
-    - ``m`` -- an integer
+    - ``m`` -- integer
 
     - ``Zvec``, ``NZvec`` -- non-repeating lists of integers in ``range(self.dim())`` or ``None``
 
@@ -208,19 +208,14 @@ def local_good_density_congruence_even(self, m, Zvec, NZvec):
         [ * 10 5 6 ]
         [ * * 15 8 ]
         [ * * * 20 ]
-        sage: Q.theta_series(20)                                                    # optional - sage.libs.pari
+        sage: Q.theta_series(20)                                                        # needs sage.libs.pari
         1 + 2*q^5 + 2*q^10 + 2*q^14 + 2*q^15 + 2*q^16 + 2*q^18 + O(q^20)
-        sage: Q.local_normal_form(2)                                                # optional - sage.libs.pari sage.rings.padics
-        Quadratic form in 4 variables over Integer Ring with coefficients:
-        [ 0 1 0 0 ]
-        [ * 0 0 0 ]
-        [ * * 0 1 ]
-        [ * * * 0 ]
-        sage: Q.local_good_density_congruence_even(1, None, None)
+        sage: Q_local = Q.local_normal_form(2)                                          # needs sage.libs.pari sage.rings.padics
+        sage: Q_local.local_good_density_congruence_even(1, None, None)                 # needs sage.libs.pari sage.rings.padics
         3/4
-        sage: Q.local_good_density_congruence_even(2, None, None)
-        1
-        sage: Q.local_good_density_congruence_even(5, None, None)
+        sage: Q_local.local_good_density_congruence_even(2, None, None)                 # needs sage.libs.pari sage.rings.padics
+        9/8
+        sage: Q_local.local_good_density_congruence_even(5, None, None)                 # needs sage.libs.pari sage.rings.padics
         3/4
     """
     n = self.dim()
@@ -237,7 +232,7 @@ def local_good_density_congruence_even(self, m, Zvec, NZvec):
     if (NZvec is not None) and (len(Set(NZvec) + Sn) > n):
         raise RuntimeError("NZvec must be a subset of {0, ..., n-1}.")
 
-    #  Find the indices of x for which the associated Jordan blocks are non-zero mod 8    TODO: Move this to special Jordan block code separately!
+    #  Find the indices of x for which the associated Jordan blocks are nonzero mod 8    TODO: Move this to special Jordan block code separately!
     #  -------------------------------------------------------------------------------
     Not8vec = []
     for i in range(n):
@@ -293,10 +288,10 @@ def local_good_density_congruence_even(self, m, Zvec, NZvec):
     verbose("Z_Is8 = " + str(Z_Is8))
     verbose("Is8_minus_Z = " + str(Is8_minus_Z))
 
-    # Take cases on the existence of additional non-zero congruence conditions (mod 2)
+    # Take cases on the existence of additional nonzero congruence conditions (mod 2)
     if NZvec is None:
         total = (4 ** len(Z_Is8)) * (8 ** len(Is8_minus_Z)) \
-            * Q_Not8.count_congruence_solutions__good_type(2, 3, m, list(Z_Not8), None)
+            * count_all_local_good_types_normal_form(Q_Not8, 2, 3, m, list(Z_Not8), None)
     else:
         ZNZ = Z + Set(NZvec)
         ZNZ_Not8 = Not8.intersection(ZNZ)
@@ -310,9 +305,9 @@ def local_good_density_congruence_even(self, m, Zvec, NZvec):
         verbose("Is8_minus_ZNZ = " + str(Is8_minus_ZNZ))
 
         total = (4 ** len(Z_Is8)) * (8 ** len(Is8_minus_Z)) \
-            * Q_Not8.count_congruence_solutions__good_type(2, 3, m, list(Z_Not8), None) \
+            * count_all_local_good_types_normal_form(Q_Not8, 2, 3, m, list(Z_Not8), None) \
             - (4 ** len(ZNZ_Is8)) * (8 ** len(Is8_minus_ZNZ)) \
-            * Q_Not8.count_congruence_solutions__good_type(2, 3, m, list(ZNZ_Not8), None)
+            * count_all_local_good_types_normal_form(Q_Not8, 2, 3, m, list(ZNZ_Not8), None)
 
     # DIAGNOSTIC
     verbose("total = " + str(total))
@@ -337,7 +332,7 @@ def local_good_density_congruence(self, p, m, Zvec=None, NZvec=None):
 
     - ``p`` -- a prime number
 
-    - ``m`` -- an integer
+    - ``m`` -- integer
 
     - ``Zvec``, ``NZvec`` -- non-repeating lists of integers in ``range(self.dim())`` or ``None``
 
@@ -358,7 +353,6 @@ def local_good_density_congruence(self, p, m, Zvec=None, NZvec=None):
         1
         sage: Q.local_good_density_congruence(3, 1, None, None)
         8/9
-
     """
     #  DIAGNOSTIC
     verbose(" In local_good_density_congruence with ")
@@ -408,7 +402,7 @@ def local_zero_density_congruence(self, p, m, Zvec=None, NZvec=None):
 
     - ``p`` -- a prime number
 
-    - ``m`` -- an integer
+    - ``m`` -- integer
 
     - ``Zvec``, ``NZvec`` -- non-repeating lists of integers in ``range(self.dim())`` or ``None``
 
@@ -481,7 +475,7 @@ def local_badI_density_congruence(self, p, m, Zvec=None, NZvec=None):
 
     - ``p`` -- a prime number
 
-    - ``m`` -- an integer
+    - ``m`` -- integer
 
     - ``Zvec``, ``NZvec`` -- non-repeating lists of integers in ``range(self.dim())`` or ``None``
 
@@ -560,7 +554,7 @@ def local_badI_density_congruence(self, p, m, Zvec=None, NZvec=None):
     S0 = []
     S1_empty_flag = True
     # This is used to check if we should be computing BI solutions at all!
-    # (We should really to this earlier, but S1 must be non-zero to proceed.)
+    # (We should really to this earlier, but S1 must be nonzero to proceed.)
 
     #  Find the valuation of each variable (which will be the same over 2x2 blocks),
     #  remembering those of valuation 0 and if an entry of valuation 1 exists.
@@ -644,7 +638,7 @@ def local_badII_density_congruence(self, p, m, Zvec=None, NZvec=None):
 
     - ``p`` -- a prime number
 
-    - ``m`` -- an integer
+    - ``m`` -- integer
 
     - ``Zvec``, ``NZvec`` -- non-repeating lists of integers in ``range(self.dim())`` or ``None``
 
@@ -790,7 +784,7 @@ def local_bad_density_congruence(self, p, m, Zvec=None, NZvec=None):
 
     - ``p`` -- a prime number
 
-    - ``m`` -- an integer
+    - ``m`` -- integer
 
     - ``Zvec``, ``NZvec`` -- non-repeating lists of integers in ``range(self.dim())`` or ``None``
 
@@ -848,7 +842,7 @@ def local_density_congruence(self, p, m, Zvec=None, NZvec=None):
 
     - ``p`` -- a prime number
 
-    - ``m`` -- an integer
+    - ``m`` -- integer
 
     - ``Zvec``, ``NZvec`` -- non-repeating lists of integers in ``range(self.dim())`` or ``None``
 
@@ -920,7 +914,7 @@ def local_primitive_density_congruence(self, p, m, Zvec=None, NZvec=None):
 
     - ``p`` -- a prime number
 
-    - ``m`` -- an integer
+    - ``m`` -- integer
 
     - ``Zvec``, ``NZvec`` -- non-repeating lists of integers in ``range(self.dim())`` or ``None``
 
