@@ -19,8 +19,9 @@ Path Algebras
 #                  https://www.gnu.org/licenses/
 # ****************************************************************************
 
-from sage.misc.cachefunc import cached_method
 from sage.combinat.free_module import CombinatorialFreeModule
+from sage.misc.cachefunc import cached_method
+
 from .algebra_elements import PathAlgebraElement
 
 
@@ -41,13 +42,11 @@ class PathAlgebra(CombinatorialFreeModule):
 
     - ``P`` -- the path semigroup of a quiver `Q`
 
-    - ``order`` -- optional string, one of "negdegrevlex" (default),
-      "degrevlex", "negdeglex" or "deglex", defining the monomial order to be
-      used.
+    - ``order`` -- string; one of ``'negdegrevlex'`` (default),
+      ``'degrevlex'``, ``'negdeglex'`` or ``'deglex'``, defining the monomial
+      order to be used
 
-    OUTPUT:
-
-    - the path algebra `kP` with the given monomial order
+    OUTPUT: the path algebra `kP` with the given monomial order
 
     .. NOTE::
 
@@ -67,7 +66,7 @@ class PathAlgebra(CombinatorialFreeModule):
 
         sage: A is P.algebra(GF(7))
         True
-        sage: A is P.algebra(GF(7), order="degrevlex")
+        sage: A is P.algebra(GF(7), order='degrevlex')
         False
         sage: A is P.algebra(RR)
         False
@@ -132,7 +131,7 @@ class PathAlgebra(CombinatorialFreeModule):
     #                                                                         #
     ###########################################################################
 
-    def __init__(self, k, P, order="negdegrevlex"):
+    def __init__(self, k, P, order='negdegrevlex'):
         """
         Create a :class:`PathAlgebra` object.
 
@@ -179,9 +178,9 @@ class PathAlgebra(CombinatorialFreeModule):
         EXAMPLES::
 
             sage: P1 = DiGraph({1:{1:['x','y','z']}}).path_semigroup().algebra(GF(25,'t'))
-            sage: P2 = DiGraph({1:{1:['x','y','z']}}).path_semigroup().algebra(GF(25,'t'), order="degrevlex")
-            sage: P3 = DiGraph({1:{1:['x','y','z']}}).path_semigroup().algebra(GF(25,'t'), order="negdeglex")
-            sage: P4 = DiGraph({1:{1:['x','y','z']}}).path_semigroup().algebra(GF(25,'t'), order="deglex")
+            sage: P2 = DiGraph({1:{1:['x','y','z']}}).path_semigroup().algebra(GF(25,'t'), order='degrevlex')
+            sage: P3 = DiGraph({1:{1:['x','y','z']}}).path_semigroup().algebra(GF(25,'t'), order='negdeglex')
+            sage: P4 = DiGraph({1:{1:['x','y','z']}}).path_semigroup().algebra(GF(25,'t'), order='deglex')
             sage: P1.order_string()
             'negdegrevlex'
             sage: P2.order_string()
@@ -190,7 +189,6 @@ class PathAlgebra(CombinatorialFreeModule):
             'negdeglex'
             sage: P4.order_string()
             'deglex'
-
         """
         return self._ordstr
 
@@ -277,7 +275,6 @@ class PathAlgebra(CombinatorialFreeModule):
             sage: A = P.algebra(GF(5))
             sage: A.ngens()
             7
-
         """
         return self._semigroup.ngens()
 
@@ -300,7 +297,6 @@ class PathAlgebra(CombinatorialFreeModule):
             2*e_0 + 2*e_1 + 2*e_2 + 2*e_3
             sage: B([(0,1,'a'),(1,2,'c')])  # indirect doctest
             a*c
-
         """
         from sage.quivers.paths import QuiverPath
         # If it's an element of another path algebra, do a linear combination
@@ -399,7 +395,6 @@ class PathAlgebra(CombinatorialFreeModule):
             2*e_0 + 2*e_1 + 2*e_2 + 2*e_3
             sage: B(2)*x*B(3)  # indirect doctest
             e_2 + b + e_3
-
         """
         if isinstance(other, PathAlgebra) and self._base.has_coerce_map_from(other._base):
             OQ = other._quiver
@@ -430,8 +425,8 @@ class PathAlgebra(CombinatorialFreeModule):
 
         INPUT:
 
-        A list providing the indices of the path algebra generators occurring
-        in the monomial.
+        - ``data`` -- list providing the indices of the path algebra
+          generators occurring in the monomial
 
         EXAMPLES::
 
@@ -439,7 +434,6 @@ class PathAlgebra(CombinatorialFreeModule):
             sage: X = sage_eval('a+2*b+3*c+5*e_0+3*e_2', A.gens_dict())
             sage: X         # indirect doctest
             5*e_0 + a + 2*b + 3*c + 3*e_2
-
         """
         # m is [list, pos, mid], where the list gives the nb of arrows, pos
         # gives the component in the module, and mid gives the length of the
@@ -453,8 +447,8 @@ class PathAlgebra(CombinatorialFreeModule):
 
         INPUT:
 
-        A list providing the indices of the path algebra generators occurring
-        in the monomial.
+        - ``data`` -- list providing the indices of the path algebra
+          generators occurring in the monomial
 
         EXAMPLES::
 
@@ -462,7 +456,6 @@ class PathAlgebra(CombinatorialFreeModule):
             sage: X = sage_eval('a+2*b+3*c+5*e_0+3*e_2', A.gens_dict())
             sage: latex(X)  # indirect doctest
             5 e_0 + a + 2 b + 3 c + 3 e_2
-
         """
         arrows = self.variable_names()
         return '\\cdot '.join(arrows[n] for n in data)
@@ -496,9 +489,7 @@ class PathAlgebra(CombinatorialFreeModule):
         """
         Return the quiver from which the algebra ``self`` was formed.
 
-        OUTPUT:
-
-        - :class:`DiGraph`, the quiver of the algebra
+        OUTPUT: :class:`DiGraph`; the quiver of the algebra
 
         EXAMPLES::
 
@@ -563,11 +554,11 @@ class PathAlgebra(CombinatorialFreeModule):
 
     def sum(self, iter_of_elements):
         """
-        Return the sum of all elements in ``iter_of_elements``
+        Return the sum of all elements in ``iter_of_elements``.
 
         INPUT:
 
-        - ``iter_of_elements``: iterator of elements of ``self``
+        - ``iter_of_elements`` -- iterator of elements of ``self``
 
         .. NOTE::
 
@@ -654,7 +645,6 @@ class PathAlgebra(CombinatorialFreeModule):
             sage: A = P.algebra(ZZ)
             sage: A.homogeneous_component(3)
             Free module spanned by [a*b*c, b*c*a, c*a*b] over Integer Ring
-
         """
         basis = []
         for v in self._semigroup._quiver:
@@ -667,7 +657,7 @@ class PathAlgebra(CombinatorialFreeModule):
 
     def homogeneous_components(self):
         r"""
-        Return the non-zero homogeneous components of ``self``.
+        Return the nonzero homogeneous components of ``self``.
 
         EXAMPLES::
 
