@@ -1,5 +1,5 @@
-# sage.doctest: optional - sage.rings.finite_rings               (because all doctests use finite fields)
-# sage.doctest: optional - sage.rings.function_field    (because almost all doctests use function field extensions)
+# sage.doctest: needs sage.rings.finite_rings               (because all doctests use finite fields)
+# sage.doctest: needs sage.rings.function_field    (because almost all doctests use function field extensions)
 """
 Divisors of function fields
 
@@ -37,7 +37,6 @@ We verify the Riemann-Roch theorem::
 AUTHORS:
 
 - Kwankyu Lee (2017-04-30): initial version
-
 """
 
 # ****************************************************************************
@@ -75,6 +74,7 @@ from sage.rings.integer import Integer
 
 from .place import PlaceSet
 
+
 def divisor(field, data):
     """
     Construct a divisor from the data.
@@ -99,6 +99,7 @@ def divisor(field, data):
     divisor_group = field.divisor_group()
     return divisor_group.element_class(divisor_group, data)
 
+
 def prime_divisor(field, place, m=1):
     """
     Construct a prime divisor from the place.
@@ -133,7 +134,7 @@ class FunctionFieldDivisor(ModuleElement):
 
     - ``parent`` -- divisor group
 
-    - ``data`` -- dict of place and multiplicity pairs
+    - ``data`` -- dictionary of place and multiplicity pairs
 
     EXAMPLES::
 
@@ -468,7 +469,7 @@ class FunctionFieldDivisor(ModuleElement):
 
     def is_effective(self):
         """
-        Return ``True`` if this divisor has non-negative multiplicity at all
+        Return ``True`` if this divisor has nonnegative multiplicity at all
         places.
 
         EXAMPLES::
@@ -871,9 +872,10 @@ class FunctionFieldDivisor(ModuleElement):
         # invariants of M.
         basis = []
         for j in range(n):
-            i,ideg = pivot_row[j][0]
-            for k in range( den.degree() - ideg + 1 ):
-                basis.append(one.shift(k) * gens[i])
+            i, ideg = pivot_row[j][0]
+            gi = gens[i]
+            basis.extend(one.shift(k) * gi
+                         for k in range(den.degree() - ideg + 1))
         # Done!
         return basis
 
@@ -920,7 +922,7 @@ class FunctionFieldDivisor(ModuleElement):
                 if e != 0:
                     return (i,e.numerator().degree() - e.denominator().degree())
 
-        def greater(v,w): # v and w are not equal
+        def greater(v, w): # v and w are not equal
             return v[0] < w[0] or v[0] == w[0] and v[1] > w[1]
 
         # collate rows by their pivot position
@@ -1023,7 +1025,7 @@ class DivisorGroup(UniqueRepresentation, Parent):
             sage: F.divisor_group()
             Divisor group of Function field in y defined by y^2 + 4*x^3 + 4
         """
-        return "Divisor group of %s"%(self._field,)
+        return "Divisor group of %s" % (self._field,)
 
     def _element_constructor_(self, x):
         """
