@@ -1,4 +1,4 @@
-# sage.doctest: optional - sage.rings.function_field
+# sage.doctest: needs sage.rings.function_field
 """
 Places of function fields: extension
 """
@@ -387,7 +387,7 @@ class FunctionFieldPlace_polymod(FunctionFieldPlace):
 
         INPUT:
 
-        - ``name`` -- string (default: `None`); name of the generator
+        - ``name`` -- string (default: ``None``); name of the generator
           of the residue field
 
         EXAMPLES::
@@ -463,7 +463,7 @@ class FunctionFieldPlace_polymod(FunctionFieldPlace):
         prime = self.prime_ideal()  # Let P be this prime ideal
 
         if self.is_infinite_place():
-            _F, from_F, to_F  = F._inversion_isomorphism()
+            _F, from_F, to_F = F._inversion_isomorphism()
             _prime = prime._ideal
             _place = _prime.place()
 
@@ -602,7 +602,7 @@ class FunctionFieldPlace_polymod(FunctionFieldPlace):
         if deg > 1:
             if isinstance(k, NumberField):
                 if name is None:
-                    name='s'
+                    name = 's'
                 K = k.extension(min_poly, names=name)
 
                 def from_W(e):
