@@ -59,11 +59,11 @@ Construct multivariate power series rings over various base rings.
     sage: z = H.base_ring().gens()
     sage: f = H.gens()
     sage: h = 4*z[1]^2 + 2*z[0]*z[2] + z[1]*z[2] + z[2]^2 \
-    + (-z[2]^2 - 2*z[0] + z[2])*f[0]*f[2] \
-    + (-22*z[0]^2 + 2*z[1]^2 - z[0]*z[2] + z[2]^2 - 1955*z[2])*f[1]*f[2] \
-    + (-z[0]*z[1] - 2*z[1]^2)*f[2]*f[3] \
-    + (2*z[0]*z[1] + z[1]*z[2] - z[2]^2 - z[1] + 3*z[2])*f[3]^2 \
-    + H.O(3)
+    ....: + (-z[2]^2 - 2*z[0] + z[2])*f[0]*f[2] \
+    ....: + (-22*z[0]^2 + 2*z[1]^2 - z[0]*z[2] + z[2]^2 - 1955*z[2])*f[1]*f[2] \
+    ....: + (-z[0]*z[1] - 2*z[1]^2)*f[2]*f[3] \
+    ....: + (2*z[0]*z[1] + z[1]*z[2] - z[2]^2 - z[1] + 3*z[2])*f[3]^2 \
+    ....: + H.O(3)
     sage: h in H
     True
     sage: h
@@ -205,15 +205,16 @@ AUTHORS:
 
 import sage.misc.latex as latex
 
+from sage.misc.lazy_import import lazy_import
 from sage.rings.infinity import infinity
 from sage.rings.multi_power_series_ring_element import MPowerSeries
-from sage.rings.polynomial.polynomial_ring import is_PolynomialRing
+from sage.rings.polynomial.polynomial_ring import PolynomialRing_generic
 from sage.rings.polynomial.polynomial_ring_constructor import PolynomialRing
-from sage.rings.polynomial.multi_polynomial_ring import is_MPolynomialRing
+from sage.rings.polynomial.multi_polynomial_ring import MPolynomialRing_base
 from sage.rings.polynomial.term_order import TermOrder
-from sage.rings.power_series_ring import PowerSeriesRing, PowerSeriesRing_generic, is_PowerSeriesRing
-from sage.rings.ring import CommutativeRing
+from sage.rings.power_series_ring import PowerSeriesRing, PowerSeriesRing_generic
 from sage.structure.nonexact import Nonexact
+from sage.structure.parent import Parent
 
 from sage.categories.commutative_rings import CommutativeRings
 _CommutativeRings = CommutativeRings()
@@ -226,6 +227,8 @@ try:
 except ImportError:
     LaurentSeriesRing = ()
 
+lazy_import('sage.rings.lazy_series_ring', ('LazyPowerSeriesRing', 'LazyLaurentSeriesRing'))
+
 
 def is_MPowerSeriesRing(x):
     """
@@ -237,8 +240,16 @@ def is_MPowerSeriesRing(x):
         sage: from sage.rings.multi_power_series_ring import is_MPowerSeriesRing
         sage: M = PowerSeriesRing(ZZ, 4, 'v')
         sage: is_PowerSeriesRing(M)
+        doctest:warning...
+        DeprecationWarning: The function is_PowerSeriesRing is deprecated;
+        use 'isinstance(..., (PowerSeriesRing_generic, LazyPowerSeriesRing) and ....ngens() == 1)' instead.
+        See https://github.com/sagemath/sage/issues/38290 for details.
         False
         sage: is_MPowerSeriesRing(M)
+        doctest:warning...
+        DeprecationWarning: The function is_MPowerSeriesRing is deprecated;
+        use 'isinstance(..., (MPowerSeriesRing_generic, LazyPowerSeriesRing))' instead.
+        See https://github.com/sagemath/sage/issues/38290 for details.
         True
         sage: T = PowerSeriesRing(RR, 'v')
         sage: is_PowerSeriesRing(T)
@@ -252,7 +263,10 @@ def is_MPowerSeriesRing(x):
         sage: is_MPowerSeriesRing(L)
         True
     """
-    from sage.rings.lazy_series_ring import LazyPowerSeriesRing
+    from sage.misc.superseded import deprecation
+    deprecation(38290,
+                "The function is_MPowerSeriesRing is deprecated; "
+                "use 'isinstance(..., (MPowerSeriesRing_generic, LazyPowerSeriesRing))' instead.")
     return isinstance(x, (MPowerSeriesRing_generic, LazyPowerSeriesRing))
 
 
@@ -306,7 +320,6 @@ class MPowerSeriesRing_generic(PowerSeriesRing_generic, Nonexact):
             sage: P2 = PowerSeriesRing(QQ,4,'f', order='degrevlex')
             sage: P1 is P2   # indirect doctest
             True
-
         """
         order = TermOrder(order, num_gens)
         return super().__classcall__(cls, base_ring, num_gens, name_list,
@@ -315,7 +328,7 @@ class MPowerSeriesRing_generic(PowerSeriesRing_generic, Nonexact):
     def __init__(self, base_ring, num_gens, name_list,
                  order='negdeglex', default_prec=10, sparse=False):
         """
-        Initializes a multivariate power series ring.  See PowerSeriesRing
+        Initialize a multivariate power series ring.  See PowerSeriesRing
         for complete documentation.
 
         INPUT:
@@ -324,7 +337,7 @@ class MPowerSeriesRing_generic(PowerSeriesRing_generic, Nonexact):
 
         - ``num_gens`` -- number of generators
 
-        - ``name_list`` -- List of indeterminate names or a single name.
+        - ``name_list`` -- list of indeterminate names or a single name
             If a single name is given, indeterminates will be this name
             followed by a number from 0 to num_gens - 1.  If a list is
             given, these will be the indeterminate names and the length
@@ -333,11 +346,11 @@ class MPowerSeriesRing_generic(PowerSeriesRing_generic, Nonexact):
         - ``order`` -- ordering of variables; default is
           negative degree lexicographic
 
-        - ``default_prec`` -- The default total-degree precision for
-          elements.  The default value of default_prec is 10.
+        - ``default_prec`` -- (default: 10) the default total-degree precision
+          for elements
 
-        - ``sparse`` -- whether or not the power series are sparse.
-          The underlying polynomial ring is always sparse.
+        - ``sparse`` -- whether or not the power series are sparse; the
+          underlying polynomial ring is always sparse
 
         EXAMPLES::
 
@@ -364,7 +377,6 @@ class MPowerSeriesRing_generic(PowerSeriesRing_generic, Nonexact):
             sage: P.category()
             Category of commutative rings
             sage: TestSuite(P).run()
-
         """
         self._term_order = order
         if not base_ring.is_commutative():
@@ -377,8 +389,9 @@ class MPowerSeriesRing_generic(PowerSeriesRing_generic, Nonexact):
         # Multivariate power series rings inherit from power series rings. But
         # apparently we can not call their initialisation. Instead, initialise
         # CommutativeRing and Nonexact:
-        CommutativeRing.__init__(self, base_ring, name_list, category=_IntegralDomains if base_ring in
-                                 _IntegralDomains else _CommutativeRings)
+        Parent.__init__(self, base=base_ring, names=name_list,
+                        category=_IntegralDomains if base_ring in
+                        _IntegralDomains else _CommutativeRings)
         Nonexact.__init__(self, default_prec)
 
         # underlying polynomial ring in which to represent elements
@@ -397,7 +410,7 @@ class MPowerSeriesRing_generic(PowerSeriesRing_generic, Nonexact):
 
     def _repr_(self):
         """
-        Prints out a multivariate power series ring.
+        Print out a multivariate power series ring.
 
         EXAMPLES::
 
@@ -420,7 +433,7 @@ class MPowerSeriesRing_generic(PowerSeriesRing_generic, Nonexact):
 
     def _latex_(self):
         """
-        Returns latex representation of power series ring
+        Return latex representation of power series ring.
 
         EXAMPLES::
 
@@ -465,7 +478,7 @@ class MPowerSeriesRing_generic(PowerSeriesRing_generic, Nonexact):
 
     def term_order(self):
         """
-        Print term ordering of self.  Term orderings are implemented by the
+        Print term ordering of ``self``.  Term orderings are implemented by the
         TermOrder class.
 
         EXAMPLES::
@@ -476,7 +489,7 @@ class MPowerSeriesRing_generic(PowerSeriesRing_generic, Nonexact):
             sage: m = y*z^12 - y^6*z^8 - x^7*y^5*z^2 + x*y^2*z + M.O(15); m
             x*y^2*z + y*z^12 - x^7*y^5*z^2 - y^6*z^8 + O(x, y, z)^15
 
-            sage: N = PowerSeriesRing(ZZ,3,'x,y,z', order="deglex")
+            sage: N = PowerSeriesRing(ZZ,3,'x,y,z', order='deglex')
             sage: N.term_order()
             Degree lexicographic term order
             sage: N(m)
@@ -486,7 +499,7 @@ class MPowerSeriesRing_generic(PowerSeriesRing_generic, Nonexact):
 
     def characteristic(self):
         """
-        Return characteristic of base ring, which is characteristic of self.
+        Return characteristic of base ring, which is characteristic of ``self``.
 
         EXAMPLES::
 
@@ -499,8 +512,8 @@ class MPowerSeriesRing_generic(PowerSeriesRing_generic, Nonexact):
         return self.base_ring().characteristic()
 
     def construction(self):
-        """
-        Returns a functor F and base ring R such that F(R) == self.
+        r"""
+        Return a functor `F` and base ring `R` such that ``F(R) == self``.
 
         EXAMPLES::
 
@@ -533,7 +546,6 @@ class MPowerSeriesRing_generic(PowerSeriesRing_generic, Nonexact):
             sage: c,R = M3.construction()
             sage: c(R)==M3
             True
-
         """
         from sage.categories.pushout import CompletionFunctor
         extras = {'order':self.term_order(), 'num_gens':self.ngens()}
@@ -545,10 +557,10 @@ class MPowerSeriesRing_generic(PowerSeriesRing_generic, Nonexact):
 
     def change_ring(self, R):
         """
-        Returns the power series ring over R in the same variable as self.
+        Return the power series ring over `R` in the same variable as ``self``.
         This function ignores the question of whether the base ring of self
-        is or can extend to the base ring of R; for the latter, use
-        base_extend.
+        is or can extend to the base ring of `R`; for the latter, use
+        ``base_extend``.
 
         EXAMPLES::
 
@@ -576,7 +588,7 @@ class MPowerSeriesRing_generic(PowerSeriesRing_generic, Nonexact):
 
     def remove_var(self, *var):
         """
-        Remove given variable or sequence of variables from self.
+        Remove given variable or sequence of variables from ``self``.
 
         EXAMPLES::
 
@@ -598,7 +610,6 @@ class MPowerSeriesRing_generic(PowerSeriesRing_generic, Nonexact):
 
             sage: M.remove_var(*M.gens())
             Finite Field of size 5
-
         """
         vars = list(self.variable_names())
         for v in var:
@@ -617,7 +628,7 @@ class MPowerSeriesRing_generic(PowerSeriesRing_generic, Nonexact):
     def _coerce_impl(self, f):
         """
         Return the canonical coercion of ``f`` into this multivariate power
-        series ring, if one is defined, or raise a TypeError.
+        series ring, if one is defined, or raise a :exc:`TypeError`.
 
         The rings that canonically coerce to this multivariate power series
         ring are:
@@ -663,8 +674,9 @@ class MPowerSeriesRing_generic(PowerSeriesRing_generic, Nonexact):
             True
         """
         P = f.parent()
-        if is_MPolynomialRing(P) or is_MPowerSeriesRing(P) \
-               or is_PolynomialRing(P) or is_PowerSeriesRing(P):
+        if isinstance(P, (PolynomialRing_generic, MPolynomialRing_base,
+                          PowerSeriesRing_generic, MPowerSeriesRing_generic,
+                          LazyPowerSeriesRing)):
             if set(P.variable_names()).issubset(set(self.variable_names())):
                 if self.has_coerce_map_from(P.base_ring()):
                     return self(f)
@@ -742,7 +754,8 @@ class MPowerSeriesRing_generic(PowerSeriesRing_generic, Nonexact):
         if all(v == 0 for v in im_gens):
             return True
 
-        if is_MPowerSeriesRing(codomain) or is_PowerSeriesRing(codomain) or isinstance(codomain, LaurentSeriesRing):
+        if isinstance(codomain, (PowerSeriesRing_generic, MPowerSeriesRing_generic, LazyPowerSeriesRing,
+                                 LaurentSeriesRing, LazyLaurentSeriesRing)):
             try:
                 B = all(v.valuation() > 0 or v.is_nilpotent() for v in im_gens)
             except NotImplementedError:
@@ -827,8 +840,8 @@ class MPowerSeriesRing_generic(PowerSeriesRing_generic, Nonexact):
             sage: R.has_coerce_map_from(L)
             True
         """
-        if is_MPolynomialRing(P) or is_MPowerSeriesRing(P) \
-                   or is_PolynomialRing(P) or is_PowerSeriesRing(P):
+        if isinstance(P, (MPolynomialRing_base, MPowerSeriesRing_generic, LazyPowerSeriesRing,
+                          PolynomialRing_generic, PowerSeriesRing_generic)):
             if set(P.variable_names()).issubset(set(self.variable_names())):
                 if self.has_coerce_map_from(P.base_ring()):
                     return True
@@ -881,7 +894,7 @@ class MPowerSeriesRing_generic(PowerSeriesRing_generic, Nonexact):
 
     def laurent_series_ring(self):
         """
-        Laurent series not yet implemented for multivariate power series rings
+        Laurent series not yet implemented for multivariate power series rings.
 
         TESTS::
 
@@ -915,7 +928,7 @@ class MPowerSeriesRing_generic(PowerSeriesRing_generic, Nonexact):
 
     def _mpoly_ring(self, x=None):
         """
-        Same as _poly_ring
+        Same as ``_poly_ring``.
 
         TESTS::
 
@@ -940,7 +953,6 @@ class MPowerSeriesRing_generic(PowerSeriesRing_generic, Nonexact):
             t, u over Rational Field
             sage: R._bg_ps_ring(4).parent() == R
             False
-
         """
         if x is None:
             return self._bg_power_series_ring
@@ -949,7 +961,7 @@ class MPowerSeriesRing_generic(PowerSeriesRing_generic, Nonexact):
 
     def is_sparse(self):
         """
-        Is self sparse?
+        Check whether ``self`` is sparse.
 
         EXAMPLES::
 
@@ -966,7 +978,7 @@ class MPowerSeriesRing_generic(PowerSeriesRing_generic, Nonexact):
 
     def is_dense(self):
         """
-        Is self dense? (opposite of sparse)
+        Is ``self`` dense? (opposite of sparse)
 
         EXAMPLES::
 
@@ -983,7 +995,7 @@ class MPowerSeriesRing_generic(PowerSeriesRing_generic, Nonexact):
 
     def gen(self, n=0):
         """
-        Return the nth generator of self.
+        Return the `n`-th generator of ``self``.
 
         EXAMPLES::
 
@@ -994,11 +1006,11 @@ class MPowerSeriesRing_generic(PowerSeriesRing_generic, Nonexact):
         if n < 0 or n >= self._ngens:
             raise ValueError("Generator not defined.")
         #return self(self._poly_ring().gens()[int(n)])
-        return self.element_class(parent=self,x=self._poly_ring().gens()[int(n)], is_gen=True)
+        return self.element_class(parent=self, x=self._poly_ring().gens()[int(n)], is_gen=True)
 
     def ngens(self):
         """
-        Return number of generators of self.
+        Return number of generators of ``self``.
 
         EXAMPLES::
 
@@ -1008,6 +1020,18 @@ class MPowerSeriesRing_generic(PowerSeriesRing_generic, Nonexact):
         """
         return self._ngens
 
+    def gens(self) -> tuple:
+        """
+        Return the generators of this ring.
+
+        EXAMPLES::
+
+            sage: M = PowerSeriesRing(ZZ, 3, 'v')
+            sage: M.gens()
+            (v0, v1, v2)
+        """
+        return tuple(self.gen(i) for i in range(self._ngens))
+
     def prec_ideal(self):
         """
         Return the ideal which determines precision; this is the ideal
@@ -1023,7 +1047,7 @@ class MPowerSeriesRing_generic(PowerSeriesRing_generic, Nonexact):
         """
         return self._poly_ring().ideal(self._poly_ring().gens())
 
-    def bigoh(self,prec):
+    def bigoh(self, prec):
         """
         Return big oh with precision ``prec``.  The function ``O`` does the same thing.
 
@@ -1038,7 +1062,7 @@ class MPowerSeriesRing_generic(PowerSeriesRing_generic, Nonexact):
         """
         return self.zero().O(prec)
 
-    def O(self,prec):
+    def O(self, prec):
         """
         Return big oh with precision ``prec``.  This function is an alias for ``bigoh``.
 
@@ -1053,7 +1077,7 @@ class MPowerSeriesRing_generic(PowerSeriesRing_generic, Nonexact):
         """
         return self.bigoh(prec)
 
-    def _send_to_bg(self,f):
+    def _send_to_bg(self, f):
         """
         Send an element of the foreground polynomial ring to the background
         power series ring.
@@ -1076,7 +1100,7 @@ class MPowerSeriesRing_generic(PowerSeriesRing_generic, Nonexact):
             raise TypeError("Cannot coerce input to polynomial ring.")
         return self._bg_ps_ring(f.homogeneous_components())
 
-    def _send_to_fg(self,f):
+    def _send_to_fg(self, f):
         """
         Send an element of the background univariate power series ring to
         the foreground multivariate polynomial ring.
