@@ -673,7 +673,11 @@ class MPowerSeries(PowerSeries):
 
     def __getitem__(self, n):
         """
-        Return summand of total degree ``n``.
+        Return the coefficient of the monomial ``x1^e1 * x2^e2 * ... * xk^ek``
+        if ``n = (e_1, e2, ..., ek)`` is a tuple whose length is the number of
+        variables ``x1,x2,...,xk`` in the power series ring.
+
+        Return the sum of the monomials of degree ``n`` if ``n`` is an integer.
 
         TESTS::
 
@@ -690,9 +694,30 @@ class MPowerSeries(PowerSeries):
             ...
             IndexError: Cannot return terms of total degree greater than or
             equal to precision of self.
+
+        Ensure that the enhancement detailed in :issue:`39314` works as intended::
+
+            sage: R.<x,y> = QQ[[]]
+            sage: ((x+y)^3)[2,1]
+            3
+            sage: f = 1/(1 + x + y)
+            sage: f[2,5]
+            -21
+            sage: f[0,30]
+            Traceback (most recent call last):
+            ...
+            IndexError: Cannot return the coefficients of terms of total degree
+            greater than or equal to precision of self.
         """
+        if type(n) is tuple:
+            if sum(n) >= self.prec():
+                raise IndexError("Cannot return the coefficients of terms of " +
+                                 "total degree greater than or equal to " +
+                                 "precision of self.")
+            return self._bg_value[sum(n)][n]
         if n >= self.prec():
-            raise IndexError("Cannot return terms of total degree greater than or equal to precision of self.")
+            raise IndexError("Cannot return terms of total degree greater " +
+                             "than or equal to precision of self.")
         return self.parent(self._bg_value[n])
 
     def __invert__(self):
@@ -1487,11 +1512,8 @@ class MPowerSeries(PowerSeries):
         """
         if self.prec() < infinity and self.valuation() > 0:
             return True
-        elif self == self.constant_coefficient() and \
-           self.base_ring()(self.constant_coefficient()).is_nilpotent():
-            return True
-        else:
-            return False
+        return (self == self.constant_coefficient() and
+                self.base_ring()(self.constant_coefficient()).is_nilpotent())
 
     def degree(self):
         """
