@@ -100,7 +100,7 @@ from sage.rings.number_field.totallyreal_data import ZZx, lagrange_degree_3, int
 from sage.rings.number_field.number_field import NumberField
 from sage.rings.polynomial.polynomial_ring_constructor import PolynomialRing
 from sage.rings.number_field.totallyreal import weed_fields, odlyzko_bound_totallyreal, enumerate_totallyreal_fields_prim
-from sage.libs.pari.all import pari
+from sage.libs.pari import pari
 from sage.rings.integer_ring import ZZ
 from sage.rings.rational_field import QQ
 
@@ -118,7 +118,7 @@ def integral_elements_in_box(K, C):
     INPUT:
 
     - ``K`` -- a totally real number field
-    - ``C`` -- a list ``[[lower, upper], ...]`` of lower and upper bounds,
+    - ``C`` -- list ``[[lower, upper], ...]`` of lower and upper bounds,
       for each embedding
 
     EXAMPLES::
@@ -227,6 +227,7 @@ def integral_elements_in_box(K, C):
 
 eps_global = 10**(-6)
 
+
 class tr_data_rel:
     r"""
     This class encodes the data used in the enumeration of totally real
@@ -244,11 +245,11 @@ class tr_data_rel:
 
         INPUT:
 
-        - ``F`` -- number field, the base field
-        - ``m`` -- integer, the relative degree
-        - ``B`` -- integer, the discriminant bound
-        - ``a`` -- list (default: ``[]``), the coefficient list to begin with,
-          corresponding to ``a[len(a)]*x^n + ... + a[0]x^(n-len(a))``.
+        - ``F`` -- number field; the base field
+        - ``m`` -- integer; the relative degree
+        - ``B`` -- integer; the discriminant bound
+        - ``a`` -- list (default: ``[]``); the coefficient list to begin with,
+          corresponding to ``a[len(a)]*x^n + ... + a[0]x^(n-len(a))``
 
         OUTPUT:
 
@@ -291,7 +292,7 @@ class tr_data_rel:
             # No starting input, all polynomials will be found; initialize to zero.
             self.a = [0]*m + [1]
             self.amaxvals = [[]]*m
-            anm1s = [[i] for i in range(0,m//2+1)]
+            anm1s = [[i] for i in range(m//2+1)]
             for i in range(1,self.d):
                 for j in range(len(anm1s)):
                     anm1s[j] = [anm1s[j] + [i] for i in range(m)]
@@ -371,17 +372,15 @@ class tr_data_rel:
 
         INPUT:
 
-        - ``f_out`` -- an integer sequence, to be written with the
-          coefficients of the next polynomial
-        - ``verbose`` -- boolean or nonnegative integer (default: ``False``)
-          print verbosely computational details. It prints extra
-          information if ``verbose`` is set to ``2`` or more
-        - ``haltk`` -- integer, the level at which to halt the inductive
+        - ``f_out`` -- integer sequence; to be written with the coefficients of
+          the next polynomial
+        - ``verbose`` -- boolean or nonnegative integer (default: ``False``);
+          print verbosely computational details. It prints extra information if
+          ``verbose`` is set to ``2`` or more.
+        - ``haltk`` -- integer; the level at which to halt the inductive
           coefficient bounds
 
-        OUTPUT:
-
-        the successor polynomial as a coefficient list.
+        OUTPUT: the successor polynomial as a coefficient list
         """
         import numpy
 
@@ -393,7 +392,7 @@ class tr_data_rel:
         if k == -1:
             if len(self.amaxvals[0]) > 0 and self.amaxvals[0]:
                 self.a[0] = self.amaxvals[0].pop()
-                for i in range(0,m):
+                for i in range(m):
                     f_out[i] = self.a[i]
                 return
             else:
@@ -431,7 +430,7 @@ class tr_data_rel:
                     print(k, ":", end="")
                     for i in range(self.m + 1):
                         print(self.a[i], end="")
-                    print("")
+                    print()
 
                 if k == m - 2:
                     # We only know the value of a[n-1], the trace.
@@ -651,34 +650,33 @@ def enumerate_totallyreal_fields_rel(F, m, B, a=[], verbose=0,
 
     ::
 
-        a[d]*x^n + ... + a[0]*x^(n-d)
+        a[k]*x^m + ... + a[0]*x^(m-k)
 
-    if ``length(a) = d+1``, so in particular always ``a[d] = 1``.
+    if ``length(a) = k+1``, so in particular always ``a[k] = 1``.
 
-    .. note::
+    .. NOTE::
 
         This is guaranteed to give all primitive such fields, and
         seems in practice to give many imprimitive ones.
 
     INPUT:
 
-    - ``F`` -- number field, the base field
-    - ``m`` -- integer, the degree
-    - ``B`` -- integer, the discriminant bound
-    - ``a`` -- list (default: ``[]``), the coefficient list to begin with
-    - ``verbose`` -- boolean or nonnegative integer or string (default: 0)
+    - ``F`` -- number field; the base field
+    - ``m`` -- integer; the degree
+    - ``B`` -- integer; the discriminant bound
+    - ``a`` -- list (default: ``[]``); the coefficient list to begin with
+    - ``verbose`` -- boolean or nonnegative integer or string (default: 0);
       give a verbose description of the computations being performed. If
       ``verbose`` is set to ``2`` or more then it outputs some extra
       information. If ``verbose`` is a string then it outputs to a file
-      specified by ``verbose``
-    - ``return_seqs`` -- (boolean, default ``False``) If ``True``, then return
+      specified by ``verbose``.
+    - ``return_seqs`` -- boolean (default: ``False``); if ``True``, then return
       the polynomials as sequences (for easier exporting to a file). This
       also returns a list of four numbers, as explained in the OUTPUT
       section below.
-    - ``return_pari_objects`` -- (boolean, default: ``True``) if
-      both ``return_seqs`` and ``return_pari_objects`` are ``False`` then
-      it returns the elements as Sage objects; otherwise it returns PARI
-      objects.
+    - ``return_pari_objects`` -- boolean (default: ``True``); if both
+      ``return_seqs`` and ``return_pari_objects`` are ``False`` then it returns
+      the elements as Sage objects; otherwise it returns PARI objects.
 
     OUTPUT:
 
@@ -798,7 +796,7 @@ def enumerate_totallyreal_fields_rel(F, m, B, a=[], verbose=0,
                 counts[1] += 1
                 if nf.polisirreducible():
                     counts[2] += 1
-                    [zk,d] = nf.nfbasis_d()
+                    zk, d = nf.nfbasis_d()
 
                     if d <= B:
                         if verbose:
@@ -910,21 +908,19 @@ def enumerate_totallyreal_fields_all(n, B, verbose=0, return_seqs=False,
 
     INPUT:
 
-    - ``n`` -- integer, the degree
-    - ``B`` -- integer, the discriminant bound
-    - ``verbose`` -- boolean or nonnegative integer or string (default: 0)
+    - ``n`` -- integer; the degree
+    - ``B`` -- integer; the discriminant bound
+    - ``verbose`` -- boolean or nonnegative integer or string (default: 0);
       give a verbose description of the computations being performed. If
-      ``verbose`` is set to ``2`` or more, it outputs some extra
-      information. If ``verbose`` is a string, it outputs to a file
-      specified by ``verbose``
-    - ``return_seqs`` -- (boolean, default ``False``) If ``True``, then return
+      ``verbose`` is set to ``2`` or more, it outputs some extra information.
+      If ``verbose`` is a string, it outputs to a file specified by ``verbose``.
+    - ``return_seqs`` -- boolean (default: ``False``); if ``True``, then return
       the polynomials as sequences (for easier exporting to a file). This
       also returns a list of four numbers, as explained in the OUTPUT
       section below.
-    - ``return_pari_objects`` -- (boolean, default: ``True``) if both
+    - ``return_pari_objects`` -- boolean (default: ``True``); if both
       ``return_seqs`` and ``return_pari_objects`` are ``False`` then it
-      returns the elements as Sage objects; otherwise it returns PARI
-      objects.
+      returns the elements as Sage objects; otherwise it returns PARI objects.
 
     EXAMPLES::
 
