@@ -167,7 +167,7 @@ AUTHOR:
 
 from sage.groups.abelian_gps.values import AbelianGroupWithValues_class
 from sage.structure.proof.proof import get_flag
-from sage.libs.pari.all import pari
+from sage.libs.pari import pari
 from sage.misc.misc_c import prod
 from sage.rings.integer_ring import ZZ
 
