@@ -211,7 +211,7 @@ class LaurentPolynomialIdeal( Ideal_generic ):
             g = f.__reduce__()[1][0]
         return (g in self.polynomial_ideal())
 
-    def gens_reduced(self):
+    def gens_reduced(self) -> tuple:
         """
         Return a reduced system of generators.
 
