@@ -161,6 +161,7 @@ Classes
 -------
 """
 
+from sage.misc.persist import register_unpickle_override
 from sage.misc.cachefunc import cached_method
 from sage.misc.converting_dict import KeyConvertingDict
 from sage.misc.method_decorator import MethodDecorator
@@ -313,11 +314,12 @@ def PolynomialSequence(arg1, arg2=None, immutable=False, cr=False, cr_str=None):
     except ImportError:
         BooleanMonomialMonoid = ()
 
-    is_ring = lambda r: (isinstance(r, (MPolynomialRing_base,
-                                        BooleanMonomialMonoid,
-                                        InfinitePolynomialRing_sparse))
-                         or (isinstance(r, QuotientRing_nc)
-                             and isinstance(r.cover_ring(), MPolynomialRing_base)))
+    def is_ring(r):
+        return (isinstance(r, (MPolynomialRing_base,
+                               BooleanMonomialMonoid,
+                               InfinitePolynomialRing_sparse))
+                or (isinstance(r, QuotientRing_nc)
+                    and isinstance(r.cover_ring(), MPolynomialRing_base)))
 
     if is_ring(arg1):
         ring, gens = arg1, arg2
@@ -704,14 +706,14 @@ class PolynomialSequence_generic(Sequence_generic):
         # Expand R by r new variables.
         T = 'T'
         while T in [str(x) for x in Xs]:
-            T = T+'T'
+            T = T + 'T'
         Ts = [T + str(j) for j in range(r)]
-        RR = PolynomialRing(K,d+r,tuple(Xs+Ts))
+        RR = PolynomialRing(K, d + r, tuple(Xs + Ts))
         Vs = list(RR.gens())
-        Xs = Vs[0 :d]
+        Xs = Vs[0:d]
         Ts = Vs[d:]
 
-        J = RR.ideal([ Ts[j] - RR(self[j]) for j in range(r)])
+        J = RR.ideal([Ts[j] - RR(self[j]) for j in range(r)])
         JJ = J.elimination_ideal(Xs)
         # By the elimination theorem, JJ is the kernel of the ring morphism
         # `phi:K[\bar T] \to K[\bar X]` that fixes `K` and sends each
@@ -722,7 +724,7 @@ class PolynomialSequence_generic(Sequence_generic):
 
         # Coerce JJ into `K[T_1,\ldots,T_r]`.
         # Choosing the negdeglex order simply because i find it useful in my work.
-        RRR = PolynomialRing(K,r,tuple(Ts),order='negdeglex')
+        RRR = PolynomialRing(K, r, tuple(Ts), order='negdeglex')
         return RRR.ideal(JJ.gens())
 
     def coefficients_monomials(self, order=None, sparse=True):
@@ -849,7 +851,306 @@ class PolynomialSequence_generic(Sequence_generic):
 
         R = self.ring()
         A, v = self.coefficients_monomials(sparse=sparse)
-        return A, matrix(R,len(v),1,v)
+        return A, matrix(R, len(v), 1, v)
+
+    def macaulay_matrix(self, degree,
+                        homogeneous=False,
+                        variables=None,
+                        return_indices=False,
+                        remove_zero=False,
+                        reverse_column_order=False,
+                        row_order=None):
+        r"""
+        Return the Macaulay matrix of degree ``degree`` for this sequence
+        of polynomials.
+
+        INPUT:
+
+        - ``homogeneous`` -- boolean (default: ``False``);
+          when ``False``, the polynomials in the sequence do not need to be homogeneous
+          the rows of the Macaulay matrix correspond to all possible products
+          between a polynomial from the sequence and monomials of the polynomial
+          ring up to degree ``degree``;
+          when ``True``, all polynomials in the sequence must be homogeneous, and
+          the rows of the Macaulay matrix then represent all possible products
+          between a polynomial in the sequence and a monomial of the polynomial
+          ring such that the resulting product is homogeneous of degree
+          ``degree + d_max``, where ``d_max`` is the maximum degree among the
+          input polynomials
+
+        - ``variables`` -- list (default: ``None``);
+          when ``None``, ``variables`` is interpreted as being the list of
+          all variables of the ring of the polynomials in the sequence;
+          otherwise ``variables`` is a list describing a subset of these
+          variables, and only these variables are used (instead of all ring
+          variables) when forming monomials to multiply the polynomials of the
+          sequence
+
+        - ``return_indices`` -- boolean (default: ``False``);
+          when ``False``, only return the Macaulay matrix;
+          when ``True``, return the Macaulay matrix and two lists: the first
+          one is a list of pairs, each of them containing a monomial and the
+          index in the sequence of the input polynomial, whose product
+          describes the corresponding row of the matrix; the second one is the
+          list of monomials corresponding to the columns of the matrix
+
+        - ``remove_zero`` -- boolean (default: ``False``);
+          when ``False``, all monomials of the polynomial ring up to
+          degree ``degree``are included as columns in the Macaulay matrix;
+          when ``True``, only the monomials that actually appear in the polynomial
+          sequence are included
+
+        - ``reverse_column_order`` -- boolean (default: ``False``);
+          when ``False``, by default, the order of the columns is the same
+          as the order of the polynomial ring;
+          when ``True``, the order of the columns is the reverse of the order
+          of the polynomial ring
+
+        - ``row_order`` -- str (default: ``None``);
+          determines the ordering of the rows in the matrix;
+          when ``None`` (or ``"POT"``), a **position over term** (POT) order is used:
+          rows are first ordered by the index of the corresponding polynomial
+          in the sequence, and then by the (multiplicative) monomials;
+          when set to ``"TOP"``, the rows follow a **term over position**
+          (TOP) order: rows are first ordered by the (multiplicative) monomials
+          and then by the index of the corresponding polynomial
+          in the sequence
+
+        EXAMPLES::
+
+            sage: R.<x,y,z> = PolynomialRing(GF(7), order='deglex')
+            sage: L = Sequence([2*x*z - y*z + 2*z^2 + 3*x - 1,
+            ....:               2*x^2 - 3*y*z + z^2 - 3*y + 3,
+            ....:               -x^2 - 2*x*z - 3*y*z + 3*x])
+            sage: L.macaulay_matrix(0)
+            [0 0 2 0 6 2 3 0 0 6]
+            [2 0 0 0 4 1 0 4 0 3]
+            [6 0 5 0 4 0 3 0 0 0]
+
+        Example with a sequence of homogeneous polynomials::
+
+            sage: R.<x,y,z> = PolynomialRing(QQ)
+            sage: L = Sequence([x*y^2 + y^3 + x*y*z + y*z^2,
+            ....:               x^2*y + x*y^2 + x*y*z + 3*x*z^2 + z^3,
+            ....:               x^3 + 2*y^3 + x^2*z + 2*x*y*z + 2*z^3])
+            sage: L.macaulay_matrix(1, homogeneous=True)
+            [0 0 0 0 0 0 0 1 1 0 1 0 0 1 0]
+            [0 0 0 1 1 0 0 1 0 0 0 1 0 0 0]
+            [0 0 1 1 0 0 1 0 0 0 1 0 0 0 0]
+            [0 0 0 0 0 0 1 1 0 0 1 0 3 0 1]
+            [0 0 1 1 0 0 0 1 0 0 3 0 0 1 0]
+            [0 1 1 0 0 0 1 0 0 3 0 0 1 0 0]
+            [0 0 0 0 0 1 0 0 2 1 2 0 0 0 2]
+            [0 1 0 0 2 0 1 2 0 0 0 0 0 2 0]
+            [1 0 0 2 0 1 2 0 0 0 0 0 2 0 0]
+
+        Same example for which we now ask to remove monomials that do not
+        appear in the sequence (``remove_zero=True``), and to return the row
+        and column indices::
+
+            sage: R.<x,y,z> = PolynomialRing(QQ)
+            sage: L = Sequence([x*y + 2*z^2, y^2 + y*z, x*z])
+            sage: L.macaulay_matrix(1, homogeneous=True, remove_zero=True, return_indices=True)
+            (
+            [0 0 0 0 1 0 0 0 2]
+            [0 1 0 0 0 0 0 2 0]
+            [1 0 0 0 0 0 2 0 0]
+            [0 0 0 0 0 1 0 1 0]
+            [0 0 1 0 0 1 0 0 0]
+            [0 1 0 0 1 0 0 0 0]
+            [0 0 0 0 0 0 1 0 0]
+            [0 0 0 0 1 0 0 0 0]
+            [0 0 0 1 0 0 0 0 0],
+            [(z, 0), (y, 0), (x, 0), (z, 1), (y, 1), (x, 1), (z, 2), (y, 2), (x, 2)],
+            [x^2*y, x*y^2, y^3, x^2*z, x*y*z, y^2*z, x*z^2, y*z^2, z^3]
+            )
+
+        Example in which we build rows using monomials that involve only a
+        subset of the ring variables (``variables=['x']``)::
+
+            sage: R.<x,y,z> = PolynomialRing(QQ)
+            sage: L = Sequence([2*y*z - 2*z^2 - 3*x + z - 3,
+            ....:               -3*y^2 + 3*y*z + 2*z^2 - 2*x - 2*y,
+            ....:               -2*y - z - 3])
+            sage: L.macaulay_matrix(1, variables=['x'], remove_zero=True, return_indices=True)
+            (
+            [ 0  0  0  0  0  0  0  0  0  2 -2 -3  0  1 -3]
+            [ 0  0  0  2 -2 -3  0  0  1  0  0 -3  0  0  0]
+            [ 0  0  0  0  0  0  0 -3  0  3  2 -2 -2  0  0]
+            [ 0 -3  0  3  2 -2 -2  0  0  0  0  0  0  0  0]
+            [ 0  0  0  0  0  0  0  0  0  0  0  0 -2 -1 -3]
+            [ 0  0  0  0  0  0 -2  0 -1  0  0 -3  0  0  0]
+            [-2  0 -1  0  0 -3  0  0  0  0  0  0  0  0  0],
+            [(1, 0), (x, 0), (1, 1), (x, 1), (1, 2), (x, 2), (x^2, 2)],
+            [x^2*y, x*y^2, x^2*z, x*y*z, x*z^2, x^2, x*y, y^2, x*z, y*z, z^2, x, y, z, 1]
+            )
+
+        TESTS::
+
+            sage: R.<x,y,z> = PolynomialRing(GF(7),order='deglex')
+            sage: from sage.rings.polynomial.multi_polynomial_sequence import PolynomialSequence_generic
+            sage: PolynomialSequence_generic([], R).macaulay_matrix(1)
+            Traceback (most recent call last):
+            ...
+            ValueError: the sequence of polynomials must be nonempty
+
+            sage: Sequence([x*y, x**2]).macaulay_matrix(-1)
+            Traceback (most recent call last):
+            ...
+            ValueError: the degree must be nonnegative
+
+            sage: Sequence([y*z + z^2 - 1,x*y - z^2 - x ]).macaulay_matrix(0, homogeneous=True)
+            Traceback (most recent call last):
+            ...
+            ValueError: all the polynomials of the sequence must be homogeneous
+
+            sage:Sequence([y*z + z^2 - 1,x*y - z^2 - x ]).macaulay_matrix(0, row_order="POP")
+            Traceback (most recent call last):
+            ...
+            ValueError: the argument of ``row_order`` must be ``None``, "TOP" or "POT"
+
+            sage: R1.<t>=PolynomialRing(GF(3))
+            sage: Sequence([y*z + z^2 - 1,x*y - z^2 - x ]).macaulay_matrix(1, variables=[t])
+            Traceback (most recent call last):
+            ...
+            ValueError: the variables must be in the polynomial ring
+
+        sage: Sequence([y*z + z^2 - 1,x*y - z^2 - x ]).macaulay_matrix(1, row_order="increasing")
+        Traceback (most recent call last):
+        ...
+        ValueError: the argument of ``row_order`` must be ``None``, "TOP" or "POT"
+
+        sage: R.<x,y,z> = PolynomialRing(GF(7),order='degrevlex(2),neglex(1)')
+        sage: Sequence([y*z + z^2 - 1,x*y - z^2 - x ]).macaulay_matrix(1, variables=[x,z])
+        Traceback (most recent call last):
+        ...
+        ValueError: impossible to use the original term order (most likely because it was a block order). Please specify the term order for the subring
+
+        REFERENCES:
+
+        [Mac1902]_, Chapter 1 of [Mac1916]_
+        """
+        from sage.matrix.constructor import matrix
+
+        m = len(self)
+
+        # handle unsuitable input
+        if m == 0:
+            raise ValueError('the sequence of polynomials must be nonempty')
+        if degree < 0:
+            raise ValueError('the degree must be nonnegative')
+        if homogeneous:
+            for i in range(m):
+                if not (self[i].is_homogeneous()):
+                    raise ValueError('all the polynomials of the sequence must be homogeneous')
+        if not (row_order is None or row_order == "TOP" or row_order == "POT"):
+            raise ValueError('the argument of ``row_order`` must be ``None``, "TOP" or "POT"')
+
+        # handle subset of variables
+        S = self.ring()
+        F = S.base_ring()
+        if variables is None:
+            R = S
+        else:
+            vars_names_base_ring = list(S.variable_names())
+            for x in variables:
+                if str(x) not in vars_names_base_ring:
+                    raise ValueError("the variables must be in the polynomial ring")
+            try:
+                R = PolynomialRing(F, variables,
+                                   order=S.term_order())
+            except ValueError:
+                raise ValueError("impossible to use the original term order (most likely because it was a block order). Please specify the term order for the subring")
+
+        # maximum degree for monomials appearing in considered polynomial multiples
+        target_degree = self.maximal_degree() + degree
+
+        # precompute `monomials_of_degree(deg)` for the relevant values of `deg`
+        # homogeneous:
+        #     row_indices: we need them for deg = target_degree - self[i].degree(),
+        #                  for all i = 0 ... len(self)-1
+        #     column_indices: we need them for deg = target_degree
+        # non homogeneous:
+        #     row_indices: we need them for deg = 0 ... target_degree - self[i].degree(),
+        #                  for all i = 0 ... len(self)-1,
+        #                  -> i.e. for deg = 0 ... target_degree - min(self[i].degree() for all i)
+        #     column_indices: we need them for deg = 0 ... target_degree
+        R_monomials_of_degree = {}
+        S_monomials_of_degree = {}
+        if homogeneous:
+            for poly_deg in {poly.degree() for poly in self}:
+                deg = target_degree - poly_deg
+                R_monomials_of_degree[deg] = R.monomials_of_degree(deg)
+            S_monomials_of_degree[target_degree] = S.monomials_of_degree(target_degree)
+        else:
+            max_deg = target_degree - min(poly.degree() for poly in self)
+            for deg in range(max_deg + 1):
+                R_monomials_of_degree[deg] = R.monomials_of_degree(deg)
+            for deg in range(target_degree + 1):
+                S_monomials_of_degree[deg] = S.monomials_of_degree(deg)
+
+        # compute list of extended monomials (ring monomials + polynomial position)
+        # that will be used to construct the rows
+        row_indices = []
+        if homogeneous:
+            # order the rows with POT (or None)
+            if row_order is None or row_order == "POT":
+                for i in range(m):
+                    deg = target_degree - self[i].degree()
+                    R_monomials_of_degree[deg].sort()
+                    row_indices += [(mon, i) for mon in R_monomials_of_degree[deg]]
+            # order the rows with TOP
+            else:
+                R_monomials_useful = []
+                for i in range(degree, target_degree-self.minimal_degree()+1):
+                    R_monomials_useful += R_monomials_of_degree[i]
+                R_monomials_useful.sort()
+                for mon in R_monomials_useful:
+                    row_indices += [(mon, i) for i in range(m) if self[i].degree() + mon.degree() == target_degree]
+        else:
+            # order the row with POT (or None)
+            if row_order is None or row_order == "POT":
+                for i in range(m):
+                    R_monomials_useful = []
+                    for deg in range(target_degree - self[i].degree() + 1):
+                        R_monomials_useful += R_monomials_of_degree[deg]
+                    R_monomials_useful.sort()
+                    row_indices += [(mon, i) for mon in R_monomials_useful]
+            # order the row with TOP
+            else:
+                R_monomials_useful = []
+                for deg in range(max_deg + 1):
+                    R_monomials_useful += R_monomials_of_degree[deg]
+                R_monomials_useful.sort()
+                for mon in R_monomials_useful:
+                    row_indices += [(mon, i) for i in range(m)
+                                    if mon.degree() + self[i].degree() <= target_degree]
+
+        # compute sorted list of monomials that index the columns
+        if remove_zero:
+            # FIXME clean (and refactor multiplications?)
+            column_indices = list(set(sum(((mon * self[i]).monomials() for mon, i in row_indices), [])))
+        else:
+            if homogeneous:
+                column_indices = S_monomials_of_degree[target_degree]
+            else:
+                column_indices = [mon for deg in range(target_degree + 1)
+                                  for mon in S_monomials_of_degree[deg]]
+        column_indices.sort(reverse=not reverse_column_order)
+        dict_columns = {mon.exponents()[0]: j for (j, mon) in enumerate(column_indices)}
+
+        # actually build the Macaulay matrix
+        macaulay_mat = matrix(F, len(row_indices), len(column_indices))
+        for (ii, (mrow, i)) in enumerate(row_indices):
+            # in row ii, we put coefficients of the multiple mrow * self[i]
+            poly = mrow * self[i]
+            for mon, coeff in poly.iterator_exp_coeff():
+                macaulay_mat[ii, dict_columns[mon]] = coeff
+
+        if not return_indices:
+            return macaulay_mat
+        else:
+            return macaulay_mat, row_indices, column_indices
 
     def subs(self, *args, **kwargs):
         """
@@ -950,7 +1251,7 @@ class PolynomialSequence_generic(Sequence_generic):
         if self._is_short_for_repr():
             return super()._repr_()
         else:
-            return "Polynomial Sequence with %d Polynomials in %d Variables" % (len(self),self.nvariables())
+            return "Polynomial Sequence with %d Polynomials in %d Variables" % (len(self), self.nvariables())
 
     def _repr_pretty_(self, p, cycle):
         """
@@ -1012,10 +1313,10 @@ class PolynomialSequence_generic(Sequence_generic):
         if isinstance(right, PolynomialSequence_generic) and right.ring() == self.ring():
             return PolynomialSequence(self.ring(), self.parts() + right.parts())
 
-        elif isinstance(right,(tuple,list)) and all((x.parent() == self.ring() for x in right)):
+        elif isinstance(right, (tuple, list)) and all((x.parent() == self.ring() for x in right)):
             return PolynomialSequence(self.ring(), self.parts() + (right,))
 
-        elif isinstance(right,MPolynomialIdeal) and (right.ring() is self.ring() or right.ring() == self.ring()):
+        elif isinstance(right, MPolynomialIdeal) and (right.ring() is self.ring() or right.ring() == self.ring()):
             return PolynomialSequence(self.ring(), self.parts() + (right.gens(),))
 
         else:
@@ -1160,7 +1461,27 @@ class PolynomialSequence_generic(Sequence_generic):
         try:
             return max(f.degree() for f in self)
         except ValueError:
-            return -1 # empty sequence
+            return -1  # empty sequence
+
+    def minimal_degree(self):
+        """
+        Return the minimal degree of any polynomial in this sequence.
+
+        EXAMPLES::
+
+            sage: P.<x,y,z> = PolynomialRing(GF(7))
+            sage: F = Sequence([x*y + x, x])
+            sage: F.minimal_degree()
+            1
+            sage: P.<x,y,z> = PolynomialRing(GF(7))
+            sage: F = Sequence([], universe=P)
+            sage: F.minimal_degree()
+            -1
+        """
+        try:
+            return min(f.degree() for f in self)
+        except ValueError:
+            return -1  # empty sequence
 
     def __reduce__(self):
         """
@@ -1257,7 +1578,7 @@ class PolynomialSequence_generic(Sequence_generic):
 
         R = self.ring()
 
-        if isinstance(R,MPolynomialRing_libsingular):
+        if isinstance(R, MPolynomialRing_libsingular):
             return PolynomialSequence(R, interred_libsingular(self), immutable=True)
         else:
             try:
@@ -1267,8 +1588,8 @@ class PolynomialSequence_generic(Sequence_generic):
                 ret = []
                 for f in self._singular_().interred():
                     f = R(f)
-                    ret.append(f.lc()**(-1)*f) # lead coeffs are not reduced by interred
-                s.option("set",o)
+                    ret.append(f.lc()**(-1) * f)  # lead coeffs are not reduced by interred
+                s.option("set", o)
             except TypeError:
                 from sage.rings.polynomial.toy_buchberger import \
                     inter_reduction
@@ -1312,6 +1633,7 @@ class PolynomialSequence_gf2(PolynomialSequence_generic):
     r"""
     Polynomial Sequences over `\GF{2}`.
     """
+
     def eliminate_linear_variables(self, maxlength=Infinity, skip=None, return_reductors=False, use_polybori=False):
         """
         Return a new system where linear leading variables are
@@ -1457,7 +1779,8 @@ class PolynomialSequence_gf2(PolynomialSequence_generic):
         else:
             # slower, more flexible solution
             if skip is None:
-                skip = lambda lm, tail: False
+                def skip(lm, tail):
+                    return False
 
             while True:
                 linear = []
@@ -1466,7 +1789,7 @@ class PolynomialSequence_gf2(PolynomialSequence_generic):
                 for f in F:
                     if f.degree() == 1 and len(f) <= maxlength + 1:
                         flm = f.lex_lead()
-                        if skip(flm, f-flm):
+                        if skip(flm, f - flm):
                             higher.append(f)
                             continue
                         linear.append(f)
@@ -1645,8 +1968,8 @@ class PolynomialSequence_gf2(PolynomialSequence_generic):
                 from sage.rings.polynomial.pbori.pbori import \
                     BooleanPolynomialRing
 
-                R_solving = BooleanPolynomialRing( T.nvariables(), [str(_) for _ in list(T.variables())] )
-            S = PolynomialSequence( R_solving, [ R_solving(f) for f in T] )
+                R_solving = BooleanPolynomialRing(T.nvariables(), [str(_) for _ in list(T.variables())])
+            S = PolynomialSequence(R_solving, [R_solving(f) for f in T])
 
         if S != []:
             if algorithm == "polybori":
@@ -1673,27 +1996,29 @@ class PolynomialSequence_gf2(PolynomialSequence_generic):
         if S.variables() == ():
             solved_variables = set()
         else:
-            solved_variables = { R_origin(x).lm() for x in R_solving.gens() }
-        eliminated_variables = { f.lex_lead() for f in reductors }
-        leftover_variables = { x.lm() for x in R_origin.gens() } - solved_variables - eliminated_variables
+            solved_variables = {R_origin(x).lm() for x in R_solving.gens()}
+        eliminated_variables = {f.lex_lead() for f in reductors}
+        leftover_variables = {x.lm() for x in R_origin.gens()} - solved_variables - eliminated_variables
+
+        def key_convert(x):
+            return R_origin(x).lm()
 
-        key_convert = lambda x: R_origin(x).lm()
         if leftover_variables != set():
             partial_solutions = solutions
             solutions = []
             for sol in partial_solutions:
-                for v in VectorSpace( GF(2), len(leftover_variables) ):
+                for v in VectorSpace(GF(2), len(leftover_variables)):
                     new_solution = KeyConvertingDict(key_convert, sol)
-                    for var,val in zip(leftover_variables, v):
-                        new_solution[ var ] = val
-                    solutions.append( new_solution )
+                    for var, val in zip(leftover_variables, v):
+                        new_solution[var] = val
+                    solutions.append(new_solution)
         else:
-            solutions = [ KeyConvertingDict(key_convert, sol)
-                          for sol in solutions ]
+            solutions = [KeyConvertingDict(key_convert, sol)
+                         for sol in solutions]
 
         for r in reductors:
             for sol in solutions:
-                sol[ r.lm() ] = r.subs(sol).constant_coefficient()
+                sol[r.lm()] = r.subs(sol).constant_coefficient()
 
         return solutions
 
@@ -1870,7 +2195,5 @@ class PolynomialSequence_gf2e(PolynomialSequence_generic):
         return PolynomialSequence(J)
 
 
-from sage.misc.persist import register_unpickle_override
-
-register_unpickle_override("sage.crypto.mq.mpolynomialsystem","MPolynomialSystem_generic", PolynomialSequence_generic)
-register_unpickle_override("sage.crypto.mq.mpolynomialsystem","MPolynomialRoundSystem_generic", PolynomialSequence_generic)
+register_unpickle_override("sage.crypto.mq.mpolynomialsystem", "MPolynomialSystem_generic", PolynomialSequence_generic)
+register_unpickle_override("sage.crypto.mq.mpolynomialsystem", "MPolynomialRoundSystem_generic", PolynomialSequence_generic)
