@@ -128,6 +128,23 @@ Of course, multiplication remains noncommutative::
     sage: g^(-1) * f
     (d - 1/t)^(-1) * (d + (t^2 - 1)/t)
 
+TESTS:
+
+The Ore function field is commutative if the twisting morphism is the
+identity and the twisting derivation vanishes. ::
+
+    sage: # needs sage.rings.finite_rings
+    sage: k.<a> = GF(5^3)
+    sage: Frob = k.frobenius_endomorphism()
+    sage: S.<x> = k['x', Frob]
+    sage: K = S.fraction_field()
+    sage: K.is_commutative()
+    False
+    sage: T.<y> = k['y', Frob^3]
+    sage: L = T.fraction_field()
+    sage: L.is_commutative()
+    True
+
 AUTHOR:
 
 - Xavier Caruso (2020-05)
@@ -144,21 +161,21 @@ AUTHOR:
 #                  https://www.gnu.org/licenses/
 # ***************************************************************************
 
-import sage
-
-from sage.structure.richcmp import op_EQ
-from sage.structure.category_object import normalize_names
-from sage.structure.unique_representation import UniqueRepresentation
-from sage.structure.parent import Parent
 from sage.categories.algebras import Algebras
+from sage.categories.commutative_rings import CommutativeRings
 from sage.categories.fields import Fields
-
-from sage.rings.morphism import RingHomomorphism
 from sage.categories.homset import Hom
 from sage.categories.map import Section
-
+from sage.rings.morphism import RingHomomorphism
+from sage.rings.polynomial.ore_function_element import (
+    OreFunction_with_large_center,
+    OreFunctionBaseringInjection,
+)
 from sage.rings.polynomial.ore_polynomial_ring import OrePolynomialRing
-from sage.rings.polynomial.ore_function_element import OreFunctionBaseringInjection
+from sage.structure.category_object import normalize_names
+from sage.structure.parent import Parent
+from sage.structure.richcmp import op_EQ
+from sage.structure.unique_representation import UniqueRepresentation
 
 WORKING_CENTER_MAX_TRIES = 1000
 
@@ -200,7 +217,10 @@ class OreFunctionField(Parent, UniqueRepresentation):
             self._simplification = False
         self._ring = ring
         base = ring.base_ring()
-        category = Algebras(base).or_subcategory(category)
+        if ring in CommutativeRings():
+            category = Algebras(base).Commutative().or_subcategory(category)
+        else:
+            category = Algebras(base).or_subcategory(category)
         Parent.__init__(self, base=base, names=ring.variable_name(),
                         normalize=True, category=category)
 
@@ -614,27 +634,6 @@ class OreFunctionField(Parent, UniqueRepresentation):
         denominator = self._ring.random_element(degdenom, True, *args, **kwds)
         return self(numerator, denominator)
 
-    def is_commutative(self) -> bool:
-        r"""
-        Return ``True`` if this Ore function field is commutative, i.e. if the
-        twisting morphism is the identity and the twisting derivation vanishes.
-
-        EXAMPLES::
-
-            sage: # needs sage.rings.finite_rings
-            sage: k.<a> = GF(5^3)
-            sage: Frob = k.frobenius_endomorphism()
-            sage: S.<x> = k['x', Frob]
-            sage: K = S.fraction_field()
-            sage: K.is_commutative()
-            False
-            sage: T.<y> = k['y', Frob^3]
-            sage: L = T.fraction_field()
-            sage: L.is_commutative()
-            True
-        """
-        return self._ring.is_commutative()
-
     def is_field(self, proof=False) -> bool:
         r"""
         Return always ``True`` since Ore function field are (skew) fields.
@@ -892,7 +891,7 @@ class OreFunctionField_with_large_center(OreFunctionField):
             sage: TestSuite(K).run()
         """
         if self.Element is None:
-            self.Element = sage.rings.polynomial.ore_function_element.OreFunction_with_large_center
+            self.Element = OreFunction_with_large_center
         OreFunctionField.__init__(self, ring, category)
         self._center = {}
         self._center_variable_name = 'z'
