@@ -1,4 +1,4 @@
-from .PyPolyBoRi import Polynomial, gauss_on_polys
+from sage.rings.polynomial.pbori.PyPolyBoRi import Polynomial, gauss_on_polys
 
 
 def dense_system(I):
