@@ -106,11 +106,9 @@ def _minimal_vanishing_polynomial(R, eval_pts):
 
     - ``R`` -- a skew polynomial ring over a field
 
-    - ``eval_pts`` -- a list of evaluation points
+    - ``eval_pts`` -- list of evaluation points
 
-    OUTPUT:
-
-    The minimal vanishing polynomial.
+    OUTPUT: the minimal vanishing polynomial
 
     EXAMPLES::
 
@@ -164,9 +162,7 @@ def _lagrange_polynomial(R, eval_pts, values):
     - ``values`` -- list of values that the Lagrange polynomial takes
         at the respective ``eval_pts``
 
-    OUTPUT:
-
-    - the Lagrange polynomial
+    OUTPUT: the Lagrange polynomial
 
     EXAMPLES::
 
@@ -269,9 +265,7 @@ class SkewPolynomialRing(OrePolynomialRing):
           independent over the fixed field of the twisting morphism of
           the associated skew polynomial ring
 
-        OUTPUT:
-
-        The minimal vanishing polynomial.
+        OUTPUT: the minimal vanishing polynomial
 
         EXAMPLES::
 
@@ -319,13 +313,11 @@ class SkewPolynomialRing(OrePolynomialRing):
 
         INPUT:
 
-        - ``points`` -- a list of pairs `(x_1, y_1), \ldots, (x_n, y_n)` of
+        - ``points`` -- list of pairs `(x_1, y_1), \ldots, (x_n, y_n)` of
           elements of the base ring of ``self``; the `x_i` should be linearly
           independent over the fixed field of ``self.twisting_morphism()``
 
-        OUTPUT:
-
-        The Lagrange polynomial.
+        OUTPUT: the Lagrange polynomial
 
         EXAMPLES::
 
@@ -366,7 +358,7 @@ class SkewPolynomialRing(OrePolynomialRing):
             raise TypeError("the evaluation points must be distinct")
         zero_i = [i for i in range(l) if eval_pts[i].is_zero()]
         if zero_i and not values[zero_i[0]].is_zero():
-            raise TypeError("a skew polynomial always evaluates to 0 at 0, but a non-zero value was requested")
+            raise TypeError("a skew polynomial always evaluates to 0 at 0, but a nonzero value was requested")
 
         return _lagrange_polynomial(_base_ring_to_fraction_field(self), eval_pts, values)
 
@@ -640,10 +632,10 @@ class SkewPolynomialRing_finite_order(SkewPolynomialRing):
 
         INPUT:
 
-        - ``name`` -- a string or ``None`` (default: ``None``);
+        - ``name`` -- string or ``None`` (default: ``None``);
           the name for the central variable (namely `x^r`)
 
-        - ``default`` -- a boolean (default: ``False``); if ``True``,
+        - ``default`` -- boolean (default: ``False``); if ``True``,
           set the default variable name for the center to ``name``
 
         EXAMPLES::
@@ -877,7 +869,7 @@ class SkewPolynomialRing_finite_field(SkewPolynomialRing_finite_order):
 
         INPUT:
 
-        - ``newmap`` -- a boolean (default: ``False``); whether we
+        - ``newmap`` -- boolean (default: ``False``); whether we
           first create and use a new retraction map
 
         - ``seed`` -- an element of the base ring or ``None`` (default:
