@@ -1,4 +1,3 @@
-# -*- coding: utf-8 -*-
 """
 Gauss valuations on polynomial rings
 
@@ -34,7 +33,6 @@ polynomial rings::
     Gauss valuation induced by [ Gauss valuation induced by 2-adic valuation, v(x) = 1/4, v(x^4 + 2*x^3 + 2*x^2 + 2*x + 2) = 4/3 ]
     sage: w(2*T + 1)
     0
-
 """
 # ****************************************************************************
 #       Copyright (C) 2013-2017 Julian Rüth <julian.rueth@fsfe.org>
@@ -89,10 +87,9 @@ class GaussValuationFactory(UniqueFactory):
             Traceback (most recent call last):
             ...
             ValueError: the domain of v must be the base ring of domain but 2-adic valuation is not defined over Integer Ring but over Rational Field
-
         """
-        from sage.rings.polynomial.polynomial_ring import is_PolynomialRing
-        if not is_PolynomialRing(domain):
+        from sage.rings.polynomial.polynomial_ring import PolynomialRing_generic
+        if not isinstance(domain, PolynomialRing_generic):
             raise TypeError("GaussValuations can only be created over polynomial rings but %r is not a polynomial ring" % (domain,))
         if not domain.ngens() == 1:
             raise NotImplementedError("domain must be univariate but %r is not univariate" % (domain,))
@@ -100,7 +97,7 @@ class GaussValuationFactory(UniqueFactory):
         if v is None:
             v = domain.base_ring().valuation()
 
-        if not v.domain() is domain.base_ring():
+        if v.domain() is not domain.base_ring():
             raise ValueError("the domain of v must be the base ring of domain but %r is not defined over %r but over %r" % (v, domain.base_ring(), v.domain()))
         if not v.is_discrete_valuation():
             raise ValueError("v must be a discrete valuation but %r is not" % (v,))
@@ -117,7 +114,6 @@ class GaussValuationFactory(UniqueFactory):
             sage: R.<x> = QQ[]
             sage: GaussValuation.create_object(0, (R, v))
             Gauss valuation induced by 2-adic valuation
-
         """
         domain, v = key
         from sage.rings.valuation.valuation_space import DiscretePseudoValuationSpace
@@ -141,9 +137,9 @@ class GaussValuation_generic(NonFinalInductiveValuation):
     EXAMPLES::
 
         sage: R = Zp(3,5)
-        sage: S.<x> = R[]
+        sage: S.<x> = R[]                                                               # needs sage.libs.ntl
         sage: v0 = R.valuation()
-        sage: v = GaussValuation(S, v0); v
+        sage: v = GaussValuation(S, v0); v                                              # needs sage.libs.ntl
         Gauss valuation induced by 3-adic valuation
 
         sage: S.<x> = QQ[]
@@ -152,8 +148,7 @@ class GaussValuation_generic(NonFinalInductiveValuation):
 
     TESTS::
 
-        sage: TestSuite(v).run() # long time
-
+        sage: TestSuite(v).run()                # long time                             # needs sage.geometry.polyhedron
     """
     def __init__(self, parent, v):
         """
@@ -164,7 +159,6 @@ class GaussValuation_generic(NonFinalInductiveValuation):
             sage: v = GaussValuation(S, QQ.valuation(5))
             sage: isinstance(v, GaussValuation_generic)
             True
-
         """
         NonFinalInductiveValuation.__init__(self, parent, parent.domain().gen())
 
@@ -180,7 +174,6 @@ class GaussValuation_generic(NonFinalInductiveValuation):
             sage: v = GaussValuation(S, QQ.valuation(5))
             sage: v.value_group()
             Additive Abelian Group generated by 1
-
         """
         return self._base_valuation.value_group()
 
@@ -194,7 +187,6 @@ class GaussValuation_generic(NonFinalInductiveValuation):
             sage: v = GaussValuation(S, QQ.valuation(5))
             sage: v.value_semigroup()
             Additive Abelian Semigroup generated by -1, 1
-
         """
         return self._base_valuation.value_semigroup()
 
@@ -225,7 +217,6 @@ class GaussValuation_generic(NonFinalInductiveValuation):
             5
             sage: v.uniformizer().parent() is S
             True
-
         """
         return self.domain()(self._base_valuation.uniformizer())
 
@@ -246,9 +237,8 @@ class GaussValuation_generic(NonFinalInductiveValuation):
           assuming that the result is only used to compute the valuation of
           ``f`` (default: ``False``)
 
-        OUTPUT:
-
-        A list, each entry a rational numbers or infinity, the valuations of `f_0, f_1\phi, \dots`
+        OUTPUT: list, each entry a rational numbers or infinity, the valuations
+        of `f_0, f_1\phi, \dots`
 
         EXAMPLES::
 
@@ -295,11 +285,10 @@ class GaussValuation_generic(NonFinalInductiveValuation):
 
         EXAMPLES::
 
-            sage: S.<x> = Qp(2,5)[]
-            sage: v = GaussValuation(S)
-            sage: v.residue_ring()
+            sage: S.<x> = Qp(2,5)[]                                                     # needs sage.libs.ntl
+            sage: v = GaussValuation(S)                                                 # needs sage.libs.ntl
+            sage: v.residue_ring()                                                      # needs sage.libs.ntl
             Univariate Polynomial Ring in x over Finite Field of size 2 (using ...)
-
         """
         return self.domain().change_ring(self._base_valuation.residue_ring())
 
@@ -311,7 +300,7 @@ class GaussValuation_generic(NonFinalInductiveValuation):
 
         - ``f`` -- an integral element of the domain of this valuation
 
-        - ``check`` -- whether or not to check whether ``f`` has non-negative
+        - ``check`` -- whether or not to check whether ``f`` has nonnegative
           valuation (default: ``True``)
 
         - ``degree_bound`` -- an a-priori known bound on the degree of the
@@ -323,12 +312,11 @@ class GaussValuation_generic(NonFinalInductiveValuation):
         - ``valuations`` -- the valuations of ``coefficients`` or ``None``
           (default: ``None``); ignored
 
-        OUTPUT:
-
-        A polynomial in the :meth:`residue_ring` of this valuation.
+        OUTPUT: a polynomial in the :meth:`residue_ring` of this valuation
 
         EXAMPLES::
 
+            sage: # needs sage.libs.ntl
             sage: S.<x> = Qp(2,5)[]
             sage: v = GaussValuation(S)
             sage: f = x^2 + 2*x + 16
@@ -339,8 +327,8 @@ class GaussValuation_generic(NonFinalInductiveValuation):
 
         The reduction is only defined for integral elements::
 
-            sage: f = x^2/2
-            sage: v.reduce(f)
+            sage: f = x^2/2                                                             # needs sage.libs.ntl
+            sage: v.reduce(f)                                                           # needs sage.libs.ntl
             Traceback (most recent call last):
             ...
             ValueError: reduction not defined for non-integral elements and (2^-1 + O(2^4))*x^2 is not integral over Gauss valuation induced by 2-adic valuation
@@ -348,7 +336,6 @@ class GaussValuation_generic(NonFinalInductiveValuation):
         .. SEEALSO::
 
             :meth:`lift`
-
         """
         f = self.domain().coerce(f)
 
@@ -377,6 +364,7 @@ class GaussValuation_generic(NonFinalInductiveValuation):
 
         EXAMPLES::
 
+            sage: # needs sage.libs.ntl
             sage: S.<x> = Qp(3,5)[]
             sage: v = GaussValuation(S)
             sage: f = x^2 + 2*x + 16
@@ -421,7 +409,6 @@ class GaussValuation_generic(NonFinalInductiveValuation):
             sage: y = v.residue_ring().gen()
             sage: f = v.lift_to_key(y^2 + y + 1); f
             x^2 + x + 1
-
         """
         F = self.residue_ring().coerce(F)
 
@@ -443,19 +430,19 @@ class GaussValuation_generic(NonFinalInductiveValuation):
 
         - ``s`` -- an element of the :meth:`value_group`
 
-        - ``reciprocal`` -- a boolean (default: ``False``); whether or not to
+        - ``reciprocal`` -- boolean (default: ``False``); whether or not to
           return the equivalence unit as the :meth:`~sage.rings.valuation.inductive_valuation.InductiveValuation.equivalence_reciprocal` of
           the equivalence unit of valuation ``-s``
 
         EXAMPLES::
 
+            sage: # needs sage.libs.ntl
             sage: S.<x> = Qp(3,5)[]
             sage: v = GaussValuation(S)
             sage: v.equivalence_unit(2)
             3^2 + O(3^7)
             sage: v.equivalence_unit(-2)
             3^-2 + O(3^3)
-
         """
         if reciprocal:
             return self.equivalence_reciprocal(self.equivalence_unit(-s))
@@ -473,7 +460,6 @@ class GaussValuation_generic(NonFinalInductiveValuation):
             sage: v = GaussValuation(R, QQ.valuation(2))
             sage: v.element_with_valuation(-2)
             1/4
-
         """
         return self.equivalence_unit(s)
 
@@ -484,12 +470,12 @@ class GaussValuation_generic(NonFinalInductiveValuation):
 
         EXAMPLES::
 
+            sage: # needs sage.libs.ntl
             sage: R.<u> = Qq(4,5)
             sage: S.<x> = R[]
             sage: v = GaussValuation(S)
             sage: v.E()
             1
-
         """
         from sage.rings.integer_ring import ZZ
         return ZZ.one()
@@ -501,12 +487,12 @@ class GaussValuation_generic(NonFinalInductiveValuation):
 
         EXAMPLES::
 
+            sage: # needs sage.libs.ntl
             sage: R.<u> = Qq(4,5)
             sage: S.<x> = R[]
             sage: v = GaussValuation(S)
             sage: v.F()
             1
-
         """
         from sage.rings.integer_ring import ZZ
         return ZZ.one()
@@ -522,10 +508,9 @@ class GaussValuation_generic(NonFinalInductiveValuation):
             sage: w = GaussValuation(R, v)
             sage: w.change_domain(QQ['x'])
             Gauss valuation induced by 2-adic valuation
-
         """
-        from sage.rings.polynomial.polynomial_ring import is_PolynomialRing
-        if is_PolynomialRing(ring) and ring.ngens() == 1:
+        from sage.rings.polynomial.polynomial_ring import PolynomialRing_generic
+        if isinstance(ring, PolynomialRing_generic) and ring.ngens() == 1:
             base_valuation = self._base_valuation.change_domain(ring.base_ring())
             return GaussValuation(self.domain().change_ring(ring.base_ring()), base_valuation)
         return super().change_domain(ring)
@@ -539,12 +524,11 @@ class GaussValuation_generic(NonFinalInductiveValuation):
             sage: v = ZZ.valuation(2)
             sage: R.<x> = ZZ[]
             sage: w = GaussValuation(R, v)
-            sage: w.extensions(GaussianIntegers()['x'])
+            sage: w.extensions(GaussianIntegers()['x'])                                 # needs sage.rings.number_field
             [Gauss valuation induced by 2-adic valuation]
-
         """
-        from sage.rings.polynomial.polynomial_ring import is_PolynomialRing
-        if is_PolynomialRing(ring) and ring.ngens() == 1:
+        from sage.rings.polynomial.polynomial_ring import PolynomialRing_generic
+        if isinstance(ring, PolynomialRing_generic) and ring.ngens() == 1:
             if self.domain().is_subring(ring):
                 return [GaussValuation(ring, w) for w in self._base_valuation.extensions(ring.base_ring())]
         return super().extensions(ring)
@@ -560,12 +544,11 @@ class GaussValuation_generic(NonFinalInductiveValuation):
             sage: w = GaussValuation(R, v)
             sage: w.restriction(ZZ)
             2-adic valuation
-
         """
         if ring.is_subring(self.domain().base_ring()):
             return self._base_valuation.restriction(ring)
-        from sage.rings.polynomial.polynomial_ring import is_PolynomialRing
-        if is_PolynomialRing(ring) and ring.ngens() == 1:
+        from sage.rings.polynomial.polynomial_ring import PolynomialRing_generic
+        if isinstance(ring, PolynomialRing_generic) and ring.ngens() == 1:
             if ring.base().is_subring(self.domain().base()):
                 return GaussValuation(ring, self._base_valuation.restriction(ring.base()))
         return super().restriction(ring)
@@ -576,12 +559,12 @@ class GaussValuation_generic(NonFinalInductiveValuation):
 
         EXAMPLES::
 
+            sage: # needs sage.libs.ntl
             sage: R.<u> = Qq(4,5)
             sage: S.<x> = R[]
             sage: v = GaussValuation(S)
             sage: v.is_gauss_valuation()
             True
-
         """
         return True
 
@@ -592,12 +575,12 @@ class GaussValuation_generic(NonFinalInductiveValuation):
 
         EXAMPLES::
 
+            sage: # needs sage.libs.ntl
             sage: R.<u> = Qq(4,5)
             sage: S.<x> = R[]
             sage: v = GaussValuation(S)
             sage: v.augmentation_chain()
             [Gauss valuation induced by 2-adic valuation]
-
         """
         return [self]
 
@@ -612,7 +595,6 @@ class GaussValuation_generic(NonFinalInductiveValuation):
             sage: v = GaussValuation(R, valuations.TrivialValuation(QQ))
             sage: v.is_trivial()
             True
-
         """
         return self._base_valuation.is_trivial()
 
@@ -624,15 +606,14 @@ class GaussValuation_generic(NonFinalInductiveValuation):
 
         EXAMPLES::
 
-            sage: R.<x> = Qp(2, 5)[]
-            sage: v = GaussValuation(R)
-            sage: v.monic_integral_model(5*x^2 + 1/2*x + 1/4)
+            sage: R.<x> = Qp(2, 5)[]                                                    # needs sage.libs.ntl
+            sage: v = GaussValuation(R)                                                 # needs sage.libs.ntl
+            sage: v.monic_integral_model(5*x^2 + 1/2*x + 1/4)                           # needs sage.libs.ntl
             (Ring endomorphism of Univariate Polynomial Ring in x over 2-adic Field with capped relative precision 5
                Defn: (1 + O(2^5))*x |--> (2^-1 + O(2^4))*x,
              Ring endomorphism of Univariate Polynomial Ring in x over 2-adic Field with capped relative precision 5
                Defn: (1 + O(2^5))*x |--> (2 + O(2^6))*x,
              (1 + O(2^5))*x^2 + (1 + 2^2 + 2^3 + O(2^5))*x + 1 + 2^2 + 2^3 + O(2^5))
-
         """
         if not G.is_monic():
             # this might fail if the base ring is not a field
@@ -667,7 +648,6 @@ class GaussValuation_generic(NonFinalInductiveValuation):
             False
             sage: w >= v
             False
-
         """
         if isinstance(other, GaussValuation_generic):
             return self._base_valuation >= other._base_valuation
@@ -688,7 +668,6 @@ class GaussValuation_generic(NonFinalInductiveValuation):
             sage: v = GaussValuation(R, QQ.valuation(2))
             sage: 3*v # indirect doctest
             Gauss valuation induced by 3 * 2-adic valuation
-
         """
         from sage.rings.rational_field import QQ
         if scalar in QQ and scalar > 0 and scalar != 1:
@@ -720,7 +699,6 @@ class GaussValuation_generic(NonFinalInductiveValuation):
 
             sage: v._relative_size(1024*x + 1)
             1
-
         """
         return self._base_valuation._relative_size(f[0])
 
@@ -755,13 +733,13 @@ class GaussValuation_generic(NonFinalInductiveValuation):
 
         EXAMPLES::
 
+            sage: # needs sage.libs.ntl
             sage: R.<u> = Qq(4, 5)
             sage: S.<x> = R[]
             sage: v = GaussValuation(S)
             sage: f = x^10/2 + 1
             sage: v.simplify(f)
             (2^-1 + O(2^4))*x^10 + 1 + O(2^5)
-
         """
         f = self.domain().coerce(f)
 
@@ -780,13 +758,14 @@ class GaussValuation_generic(NonFinalInductiveValuation):
 
     def lower_bound(self, f):
         r"""
-        Return an lower bound of this valuation at ``f``.
+        Return a lower bound of this valuation at ``f``.
 
         Use this method to get an approximation of the valuation of ``f``
         when speed is more important than accuracy.
 
         EXAMPLES::
 
+            sage: # needs sage.libs.ntl
             sage: R.<u> = Qq(4, 5)
             sage: S.<x> = R[]
             sage: v = GaussValuation(S)
@@ -794,7 +773,6 @@ class GaussValuation_generic(NonFinalInductiveValuation):
             1
             sage: v(1024*x + 2)
             1
-
         """
         from sage.rings.infinity import infinity
         coefficients = f.coefficients(sparse=True)
@@ -815,6 +793,7 @@ class GaussValuation_generic(NonFinalInductiveValuation):
 
         EXAMPLES::
 
+            sage: # needs sage.libs.ntl
             sage: R.<u> = Qq(4, 5)
             sage: S.<x> = R[]
             sage: v = GaussValuation(S)
