@@ -39,7 +39,7 @@ from sage.categories.fields import Fields
 from sage.categories.number_fields import NumberFields
 
 from sage.rings.polynomial.multi_polynomial import MPolynomial
-from sage.rings.polynomial.multi_polynomial_ring import is_MPolynomialRing
+from sage.rings.polynomial.multi_polynomial_ring import MPolynomialRing_base
 from sage.rings.finite_rings.finite_field_base import FiniteField
 from sage.rings.rational_field import QQ
 
@@ -107,7 +107,7 @@ def Curve(F, A=None):
 
     - ``F`` -- a multivariate polynomial, or a list or tuple of polynomials, or an algebraic scheme
 
-    - ``A`` -- (default: None) an ambient space in which to create the curve
+    - ``A`` -- (default: ``None``) an ambient space in which to create the curve
 
     EXAMPLES:
 
@@ -240,7 +240,7 @@ def Curve(F, A=None):
 
         if isinstance(F, (list, tuple)):
             P = Sequence(F).universe()
-            if not is_MPolynomialRing(P):
+            if not isinstance(P, MPolynomialRing_base):
                 raise TypeError("universe of F must be a multivariate polynomial ring")
             for f in F:
                 if not f.is_homogeneous():
