@@ -47,16 +47,18 @@ REFERENCES:
 
 from sage.arith.misc import legendre_symbol, primes
 from sage.misc.functional import cyclotomic_polynomial
+from sage.misc.lazy_import import lazy_import
 from sage.modules.free_module import VectorSpace
 from sage.rings.finite_rings.finite_field_constructor import GF
 from sage.rings.infinity import Infinity
 from sage.rings.integer import Integer
 from sage.rings.integer_ring import ZZ
-from sage.rings.number_field.number_field import NumberField
 from sage.rings.rational_field import QQ
 from sage.sets.set import Set
 from sage.structure.sage_object import SageObject
 
+lazy_import('sage.rings.number_field.number_field', 'NumberField')
+
 
 class GaloisRepresentation(SageObject):
     r"""
@@ -130,9 +132,9 @@ class GaloisRepresentation(SageObject):
         else:
             return "Compatible family of Galois representations associated to the " + repr(self.E)
 
-    def __eq__(self,other):
+    def __eq__(self, other):
         r"""
-        Compares two Galois representations.
+        Compare two Galois representations.
 
         We define two compatible families of representations attached
         to elliptic curves to be equal if the curves are isomorphic.
@@ -176,15 +178,14 @@ class GaloisRepresentation(SageObject):
 
         INPUT:
 
-        - ``A`` -- int (a bound on the number of traces of Frobenius to use
-          while trying to prove surjectivity).
+        - ``A`` -- integer; a bound on the number of traces of Frobenius to use
+          while trying to prove surjectivity
 
         OUTPUT:
 
-        - ``list`` -- A list of primes where mod-`p` representation is
-          very likely not surjective. At any prime not in this list,
-          the representation is definitely surjective. If `E` has CM,
-          the list [0] is returned.
+        A list of primes where mod-`p` representation is very likely not
+        surjective. At any prime not in this list, the representation is
+        definitely surjective. If `E` has CM, the list ``[0]`` is returned.
 
         EXAMPLES::
 
@@ -232,10 +233,10 @@ class GaloisRepresentation(SageObject):
 
         INPUT:
 
-        * ``p`` -- a prime number.
+        - ``p`` -- prime number
 
-        * ``A`` -- (integer) a bound on the number of traces of Frobenius to use
-          while trying to prove surjectivity.
+        - ``A`` -- integer; a bound on the number of traces of Frobenius to use
+          while trying to prove surjectivity
 
         EXAMPLES::
 
@@ -290,18 +291,17 @@ class GaloisRepresentation(SageObject):
 
         INPUT:
 
-        - ``A`` -- int (a bound on the number of traces of Frobenius to
-          use while trying to prove the mod-`p`
-          representation is not contained in a Borel).
+        - ``A`` -- integer; a bound on the number of traces of Frobenius to
+          use while trying to prove the mod-`p` representation is not contained
+          in a Borel
 
         OUTPUT:
 
-        - ``list`` -- A list of primes which contains (but may not be
-          equal to) all `p` for which the image of the mod-`p`
-          representation is contained in a Borel subgroup.  At any
-          prime not in this list, the image is definitely not
-          contained in a Borel. If E has `CM` defined over `K`, the list
-          [0] is returned.
+        A list of primes which contains (but may not be equal to) all `p` for
+        which the image of the mod-`p` representation is contained in a Borel
+        subgroup.  At any prime not in this list, the image is definitely not
+        contained in a Borel. If E has `CM` defined over `K`, the list ``[0]``
+        is returned.
 
         EXAMPLES::
 
@@ -377,11 +377,10 @@ class GaloisRepresentation(SageObject):
 
         OUTPUT:
 
-        - ``list`` -- A list of those primes `p` for which the mod-`p`
-          representation is contained in a Borel subgroup, i.e. is
-          reducible.  If E has CM *defined over K*, the list [0] is
-          returned (in this case the representation is reducible for
-          infinitely many primes).
+        A list of those primes `p` for which the mod-`p` representation is
+        contained in a Borel subgroup, i.e. is reducible.  If E has CM
+        *defined over K*, the list ``[0]`` is returned (in this case the
+        representation is reducible for infinitely many primes).
 
         EXAMPLES::
 
@@ -423,6 +422,7 @@ class GaloisRepresentation(SageObject):
 
         return [l for l in self.isogeny_bound() if self.E.isogenies_prime_degree(l)]
 
+
 def _non_surjective(E, patience=100):
     r"""
     Return a list of primes `p` including all primes for which the mod-`p`
@@ -430,16 +430,16 @@ def _non_surjective(E, patience=100):
 
     INPUT:
 
-    - ``E`` -- EllipticCurve (over a number field).
+    - ``E`` -- :class:`EllipticCurve` (over a number field)
 
-    - ``A`` -- int (a bound on the number of traces of Frobenius to use
-      while trying to prove surjectivity).
+    - ``A`` -- integer; a bound on the number of traces of Frobenius to use
+      while trying to prove surjectivity
 
     OUTPUT:
 
-    - ``list`` -- A list of primes where mod-`p` representation is very likely
-      not surjective. At any prime not in this list, the representation is
-      definitely surjective. If E has CM, a :class:`ValueError` is raised.
+    A list of primes where mod-`p` representation is very likely not
+    surjective. At any prime not in this list, the representation is
+    definitely surjective. If E has CM, a :exc:`ValueError` is raised.
 
     EXAMPLES::
 
@@ -503,19 +503,17 @@ def Frobenius_filter(E, L, patience=100):
 
     INPUT:
 
-    - ``E`` -- EllipticCurve over a number field.
+    - ``E`` -- :class:`EllipticCurve` over a number field
 
-    - ``L`` -- a list of prime numbers.
+    - ``L`` -- list of prime numbers
 
-    - ``patience`` (int), default 100 -- a positive integer bounding
-      the number of traces of Frobenius to use while trying to prove
-      irreducibility.
+    - ``patience`` -- positive integer (default: 100) bounding the number of
+      traces of Frobenius to use while trying to prove irreducibility
 
     OUTPUT:
 
-    - list -- The list of all primes `\ell` in L for which the mod
-      `\ell` image might be contained in a Borel subgroup of
-      `GL_2(\mathbf{F}_{\ell})`.
+    The list of all primes `\ell` in L for which the mod `\ell` image might be
+    contained in a Borel subgroup of `GL_2(\mathbf{F}_{\ell})`.
 
     EXAMPLES::
 
@@ -604,17 +602,17 @@ def _exceptionals(E, L, patience=1000):
 
     INPUT:
 
-    - ``E`` -- EllipticCurve over a number field.
+    - ``E`` -- :class:`EllipticCurve` over a number field
 
-    - ``L`` -- a list of prime numbers.
+    - ``L`` -- list of prime numbers
 
-    - ``patience`` (int) -- a bound on the number of traces of Frobenius to
-      use while trying to prove surjectivity.
+    - ``patience`` -- integer; a bound on the number of traces of Frobenius to
+      use while trying to prove surjectivity
 
     OUTPUT:
 
-    - list -- The list of all primes l in L for which the mod l image
-      might fail to be surjective.
+    The list of all primes l in L for which the mod l image might fail to be
+    surjective.
 
     EXAMPLES::
 
@@ -753,7 +751,7 @@ def _over_numberfield(E):
 
     INPUT:
 
-    - ``E`` -- EllipticCurve over a number field.
+    - ``E`` -- :class:`EllipticCurve` over a number field
 
     OUTPUT:
 
@@ -768,7 +766,6 @@ def _over_numberfield(E):
         sage: E = EllipticCurve([1, 2])
         sage: sage.schemes.elliptic_curves.gal_reps_number_field._over_numberfield(E)
         Elliptic Curve defined by y^2 = x^3 + x + 2 over Number Field in a with defining polynomial x
-
     """
     K = E.base_field()
 
@@ -779,6 +776,7 @@ def _over_numberfield(E):
         K = K.absolute_field('a')
     return E.change_ring(K)
 
+
 def deg_one_primes_iter(K, principal_only=False):
     r"""
     Return an iterator over degree 1 primes of ``K``.
@@ -786,7 +784,7 @@ def deg_one_primes_iter(K, principal_only=False):
     INPUT:
 
     - ``K`` -- a number field
-    - ``principal_only`` -- bool; if ``True``, only yield principal primes
+    - ``principal_only`` -- boolean; if ``True``, only yield principal primes
 
     OUTPUT:
 
@@ -802,17 +800,17 @@ def deg_one_primes_iter(K, principal_only=False):
         [Fractional ideal (2, a + 1),
          Fractional ideal (3, a + 1),
          Fractional ideal (3, a + 2),
-         Fractional ideal (a),
+         Fractional ideal (-a),
          Fractional ideal (7, a + 3),
          Fractional ideal (7, a + 4)]
         sage: it = deg_one_primes_iter(K, True)
         sage: [next(it) for _ in range(6)]
-        [Fractional ideal (a),
-         Fractional ideal (-2*a + 3),
-         Fractional ideal (2*a + 3),
+        [Fractional ideal (-a),
+         Fractional ideal (2*a - 3),
+         Fractional ideal (-2*a - 3),
          Fractional ideal (a + 6),
          Fractional ideal (a - 6),
-         Fractional ideal (-3*a + 4)]
+         Fractional ideal (3*a - 4)]
     """
     # imaginary quadratic fields have no principal primes of norm < disc / 4
     start = K.discriminant().abs() // 4 if principal_only and K.signature() == (0,1) else 2
@@ -827,20 +825,21 @@ def deg_one_primes_iter(K, principal_only=False):
                 if not principal_only or P.is_principal():
                     yield P
 
+
 def _semistable_reducible_primes(E, verbose=False):
     r"""Find a list containing all semistable primes l unramified in K/QQ
     for which the Galois image for E could be reducible.
 
     INPUT:
 
-    - ``E`` -- EllipticCurve over a number field.
+    - ``E`` -- :class:`EllipticCurve` over a number field
 
     OUTPUT:
 
     A list of primes, which contains all primes `l` unramified in
     `K/\mathbb{QQ}`, such that `E` is semistable at all primes lying
     over `l`, and the Galois image at `l` is reducible. If `E` has CM
-    defined over its ground field, a ``ValueError`` is raised.
+    defined over its ground field, a :exc:`ValueError` is raised.
 
     EXAMPLES::
 
@@ -1009,19 +1008,18 @@ def _possible_normalizers(E, SA):
 
     INPUT:
 
-    - ``E`` -- EllipticCurve over a number field K.
+    - ``E`` -- :class:`EllipticCurve` over a number field K
 
-    - ``SA`` -- a list of primes of K.
+    - ``SA`` -- list of primes of K
 
     OUTPUT:
 
-    - list -- A list of primes, which contains all primes `l` such that the
-             Galois image at `l` is contained in the normalizer of a Cartan
-             subgroup, such that the corresponding quadratic character is
-             ramified only at primes in SA.
+    - a list of primes, which contains all primes `l` such that the Galois
+      image at `l` is contained in the normalizer of a Cartan subgroup, such
+      that the corresponding quadratic character is ramified only at primes in SA.
 
-    - If `E` has geometric CM that is not defined over its ground field, a
-      ValueError is raised.
+    - if `E` has geometric CM that is not defined over its ground field, a
+      :exc:`ValueError` is raised.
 
     EXAMPLES::
 
@@ -1156,6 +1154,7 @@ def _possible_normalizers(E, SA):
 # elliptiques", Nicolas Billerey, https://arxiv.org/abs/0908.1084
 #
 
+
 def Billerey_P_l(E, l):
     r"""
     Return Billerey's `P_l^*` as defined in [Bil2011]_, equation (9).
@@ -1163,7 +1162,7 @@ def Billerey_P_l(E, l):
     INPUT:
 
     - ``E`` -- an elliptic curve over a number field `K`, given by a
-      global integral model.
+      global integral model
 
     - ``l`` -- a rational prime
 
@@ -1191,18 +1190,20 @@ def Billerey_P_l(E, l):
         P = P.composed_op(E.reduction(q).frobenius_polynomial().adams_operator_on_roots(12*e), mul, monic=True)
     return P
 
-def Billerey_B_l(E,l,B=0):
+
+def Billerey_B_l(E, l, B=0):
     r"""
     Return Billerey's `B_l`, adapted from the definition in [Bil2011]_, after (9).
 
     INPUT:
 
     - ``E`` -- an elliptic curve over a number field `K`, given by a
-      global integral model.
+      global integral model
 
-    - ``l`` (int) -- a rational prime
+    - ``l`` -- integer; a rational prime
 
-    - ``B`` (int) -- 0 or LCM of previous `B_l`: the prime-to-B part of this `B_l` is ignored.
+    - ``B`` -- integer; 0 or LCM of previous `B_l` the prime-to-B part of this
+      `B_l` is ignored
 
     EXAMPLES::
 
@@ -1240,11 +1241,12 @@ def Billerey_R_q(E, q, B=0):
     INPUT:
 
     - ``E`` -- an elliptic curve over a number field `K`, given by a
-      global integral model.
+      global integral model
 
     - ``q`` -- a prime ideal of `K`
 
-    - ``B`` (int) -- 0 or LCM of previous `R_q`: the prime-to-B part of this `R_q` is ignored.
+    - ``B`` -- integer; 0 or LCM of previous `R_q` the prime-to-B part of this
+      `R_q` is ignored
 
     EXAMPLES::
 
@@ -1284,21 +1286,21 @@ def Billerey_B_bound(E, max_l=200, num_l=8, small_prime_bound=0, debug=False):
     nonzero values are found (at most).  Return the list of primes
     dividing all `B_l` computed, excluding those dividing 6 or
     ramified or of bad reduction or less than small_prime_bound.  If
-    no non-zero values are found return [0].
+    no nonzero values are found return ``[0]``.
 
     INPUT:
 
     - ``E`` -- an elliptic curve over a number field `K`, given by a
-      global integral model.
+      global integral model
 
-    - ``max_l`` (int, default 200) -- maximum size of primes l to check.
+    - ``max_l`` -- integer (default: 200); maximum size of primes l to check
 
-    - ``num_l`` (int, default 8)  -- maximum number of primes l to check.
+    - ``num_l`` integer (default: 8); maximum number of primes l to check
 
-    - ``small_prime_bound`` (int, default 0) -- remove primes less
-      than this from the output.
+    - ``small_prime_bound`` -- integer (default: 0); remove primes less
+      than this from the output
 
-    - ``debug`` (bool, default ``False``)  -- if ``True`` prints details.
+    - ``debug`` -- boolean (default: ``False``); if ``True`` prints details
 
     .. NOTE::
 
@@ -1392,23 +1394,23 @@ def Billerey_R_bound(E, max_l=200, num_l=8, small_prime_bound=None, debug=False)
     (at most) until ``num_l`` nonzero values are found (at most).
     Return the list of primes dividing all ``R_q`` computed, excluding
     those dividing 6 or ramified or of bad reduction or less than
-    small_prime_bound.  If no non-zero values are found return [0].
+    small_prime_bound.  If no nonzero values are found return ``[0]``.
 
     INPUT:
 
     - ``E`` -- an elliptic curve over a number field `K`, given by a
-      global integral model.
+      global integral model
 
-    - ``max_l`` (int, default 200) -- maximum size of rational primes
-      l for which the primes q above l are checked.
+    - ``max_l`` -- integer (default: 200); maximum size of rational primes
+      l for which the primes q above l are checked
 
-    - ``num_l`` (int, default 8) -- maximum number of rational primes
-      l for which the primes q above l are checked.
+    - ``num_l`` -- integer (default: 8); maximum number of rational primes
+      l for which the primes q above l are checked
 
-    - ``small_prime_bound`` (int, default 0) -- remove primes less
-      than this from the output.
+    - ``small_prime_bound`` -- integer (default: 0); remove primes less
+      than this from the output
 
-    - ``debug`` (bool, default ``False``)  -- if ``True`` prints details.
+    - ``debug`` -- boolean (default: ``False``); if ``True`` prints details
 
     .. NOTE::
 
@@ -1501,13 +1503,13 @@ def reducible_primes_Billerey(E, num_l=None, max_l=None, verbose=False):
 
     INPUT:
 
-    - ``E`` -- an elliptic curve defined over a number field `K`.
+    - ``E`` -- an elliptic curve defined over a number field `K`
 
-    - ``max_l`` (int or ``None`` (default)) -- the maximum prime
+    - ``max_l`` -- integer or ``None`` (default); the maximum prime
       `\ell` to use for the B-bound and R-bound.  If ``None``, a
       default value will be used.
 
-    - ``num_l`` (int or ``None`` (default)) -- the number of primes
+    - ``num_l`` -- integer or ``None`` (default); the number of primes
       `\ell` to use for the B-bound and R-bound.  If ``None``, a
       default value will be used.
 
@@ -1524,7 +1526,7 @@ def reducible_primes_Billerey(E, num_l=None, max_l=None, verbose=False):
     Provided that one of these methods succeeds in producing a finite
     list of primes we check these using a local condition, and finally
     test that the primes returned actually are reducible.  Otherwise
-    we return [0].
+    we return ``[0]``.
 
     EXAMPLES::
 
@@ -1630,11 +1632,11 @@ def reducible_primes_naive(E, max_l=None, num_P=None, verbose=False):
 
     - ``E`` -- an elliptic curve defined over a number field `K`
 
-    - ``max_l`` (int or ``None`` (default)) -- the maximum prime
-      `\ell` to test.
+    - ``max_l`` -- integer or ``None`` (default); the maximum prime
+      `\ell` to test
 
-    - ``num_P`` (int or ``None`` (default)) -- the number of primes
-      `P` of `K` to use in testing each `\ell`.
+    - ``num_P`` -- integer or ``None`` (default); the number of primes
+      `P` of `K` to use in testing each `\ell`
 
     EXAMPLES::
 
