@@ -52,12 +52,12 @@ class ProductProjectiveSpaces_point_ring(SchemeMorphism_point):
 
         INPUT:
 
-        - ``parent`` -- Hom-set.
+        - ``parent`` -- Hom-set
 
-        - ``polys`` -- anything that defines a point in the class.
+        - ``polys`` -- anything that defines a point in the class
 
-        - ``check`` -- Boolean. Whether or not to perform input checks.
-          (Default: ``True``)
+        - ``check`` -- boolean (default: ``True``); whether or not to perform
+          input checks
 
         EXAMPLES::
 
@@ -110,11 +110,9 @@ class ProductProjectiveSpaces_point_ring(SchemeMorphism_point):
 
         INPUT:
 
-        - ``i`` -- integer.
+        - ``i`` -- integer
 
-        OUTPUT:
-
-        The projective space point that is the ``i``-th coordinate.
+        OUTPUT: the projective space point that is the ``i``-th coordinate
 
         EXAMPLES::
 
@@ -133,7 +131,7 @@ class ProductProjectiveSpaces_point_ring(SchemeMorphism_point):
         r"""
         Return a string representation of this point.
 
-        OUTPUT: String.
+        OUTPUT: string
 
         EXAMPLES::
 
@@ -153,9 +151,7 @@ class ProductProjectiveSpaces_point_ring(SchemeMorphism_point):
 
         - ``other`` -- another point
 
-        OUTPUT:
-
-        boolean
+        OUTPUT: boolean
 
         EXAMPLES::
 
@@ -207,9 +203,7 @@ class ProductProjectiveSpaces_point_ring(SchemeMorphism_point):
         r"""
         Return a copy of this point.
 
-        OUTPUT:
-
-        - a point in the same space as third point.
+        OUTPUT: a point in the same space as third point
 
         EXAMPLES::
 
@@ -228,7 +222,7 @@ class ProductProjectiveSpaces_point_ring(SchemeMorphism_point):
         r"""
         Iterate over the coordinates of the point.
 
-        OUTPUT: An iterator.
+        OUTPUT: an iterator
 
         EXAMPLES::
 
@@ -262,7 +256,7 @@ class ProductProjectiveSpaces_point_ring(SchemeMorphism_point):
         """
         Compute the hash value of this point.
 
-        OUTPUT: Integer.
+        OUTPUT: integer
 
         EXAMPLES::
 
@@ -304,7 +298,7 @@ class ProductProjectiveSpaces_point_ring(SchemeMorphism_point):
         r"""
         Remove common factors (componentwise) from the coordinates of this point (including `-1`).
 
-        OUTPUT: None.
+        OUTPUT: none
 
         EXAMPLES::
 
@@ -319,18 +313,16 @@ class ProductProjectiveSpaces_point_ring(SchemeMorphism_point):
 
     def dehomogenize(self, L):
         r"""
-        Dehomogenize `k^{th}` point at `L[k]^{th}` coordinate.
+        Dehomogenize `k`-th point at `L[k]`-th coordinate.
 
         This function computes the appropriate affine patch using ``L``
         and then returns the dehomogenized point on of this affine space.
 
         INPUT:
 
-        - ``L`` -- a list of non-negative integers
+        - ``L`` -- list of nonnegative integers
 
-        OUTPUT:
-
-        - :class:`SchemeMorphism_point_affine`.
+        OUTPUT: :class:`SchemeMorphism_point_affine`
 
         EXAMPLES::
 
@@ -368,7 +360,7 @@ class ProductProjectiveSpaces_point_ring(SchemeMorphism_point):
         r"""
         Scale the coordinates of the point by ``t``, done componentwise.
 
-        A :class:`TypeError` occurs if the point is not in the base ring
+        A :exc:`TypeError` occurs if the point is not in the base ring
         of the codomain after scaling.
 
         INPUT:
@@ -399,15 +391,15 @@ class ProductProjectiveSpaces_point_ring(SchemeMorphism_point):
 
         INPUT:
 
-        - ``R`` -- ring.
+        - ``R`` -- ring
 
         kwds:
 
-        - ``check`` -- Boolean.
+        - ``check`` -- boolean
 
-        - ``embedding`` -- field embedding from the base ring of this point to ``R``.
+        - ``embedding`` -- field embedding from the base ring of this point to ``R``
 
-        OUTPUT: :class:`ProductProjectiveSpaces_point`.
+        OUTPUT: :class:`ProductProjectiveSpaces_point`
 
         EXAMPLES::
 
@@ -432,9 +424,9 @@ class ProductProjectiveSpaces_point_ring(SchemeMorphism_point):
         INPUT:
 
         - ``prec`` -- desired floating point precision (default:
-          default RealField precision).
+          default RealField precision)
 
-        OUTPUT: A real number.
+        OUTPUT: a real number
 
         EXAMPLES::
 
@@ -484,12 +476,12 @@ class ProductProjectiveSpaces_point_ring(SchemeMorphism_point):
 
         INPUT:
 
-        - ``v`` -- a prime or prime ideal of the base ring.
+        - ``v`` -- a prime or prime ideal of the base ring
 
         - ``prec`` -- desired floating point precision (default:
-          default RealField precision).
+          default RealField precision)
 
-        OUTPUT: A real number.
+        OUTPUT: a real number
 
         EXAMPLES::
 
@@ -524,9 +516,9 @@ class ProductProjectiveSpaces_point_field(ProductProjectiveSpaces_point_ring):
 
         INPUT:
 
-        - ``X`` -- a subscheme in the same ambient space as the codomain of this point.
+        - ``X`` -- a subscheme in the same ambient space as the codomain of this point
 
-        OUTPUT: An integer.
+        OUTPUT: integer
 
         EXAMPLES::
 
@@ -549,7 +541,7 @@ class ProductProjectiveSpaces_point_field(ProductProjectiveSpaces_point_ring):
         This uses the subscheme implementation of multiplicity. This point must be a point
         on a subscheme of a product of projective spaces.
 
-        OUTPUT: an integer.
+        OUTPUT: integer
 
         EXAMPLES::
 
