@@ -16,7 +16,7 @@ Product Projective, over `\QQ`::
 
     sage: PP.<x,y,z> = ProductProjectiveSpaces([1,0], QQ)
     sage: from sage.schemes.product_projective.rational_point import \
-            enum_product_projective_rational_field
+    ....:   enum_product_projective_rational_field
     sage: enum_product_projective_rational_field(PP, 3)
     [(-3 : 1 , 1), (-2 : 1 , 1), (-3/2 : 1 , 1),
      (-1 : 1 , 1), (-2/3 : 1 , 1), (-1/2 : 1 , 1),
@@ -30,7 +30,7 @@ Product projective over finite field::
     sage: P1.<x,y,a,b> = ProductProjectiveSpaces([1, 1], GF(7))
     sage: X = P1.subscheme([2*x + 3*y])
     sage: from sage.schemes.product_projective.rational_point import \
-            enum_product_projective_finite_field
+    ....:   enum_product_projective_finite_field
     sage: enum_product_projective_finite_field(X)
     [(2 : 1 , 0 : 1), (2 : 1 , 1 : 0), (2 : 1 , 1 : 1),
      (2 : 1 , 2 : 1), (2 : 1 , 3 : 1), (2 : 1 , 4 : 1),
@@ -78,18 +78,18 @@ def enum_product_projective_rational_field(X, B):
 
     - ``X`` -- a scheme or set of abstract rational points of a scheme
 
-    - ``B`` -- a positive integer bound
+    - ``B`` -- positive integer bound
 
     OUTPUT:
 
-    - a list containing the product projective points of ``X`` of height up
-      to ``B``, sorted.
+    A list containing the product projective points of ``X`` of height up
+    to ``B``, sorted.
 
     EXAMPLES::
 
         sage: PP.<x0,x1,x2,x3,x4> = ProductProjectiveSpaces([1, 2], QQ)
         sage: from sage.schemes.product_projective.rational_point import \
-                enum_product_projective_rational_field
+        ....:   enum_product_projective_rational_field
         sage: enum_product_projective_rational_field(PP, 1)
         [(-1 : 1 , -1 : -1 : 1), (-1 : 1 , -1 : 0 : 1), (-1 : 1 , -1 : 1 : 0),
          (-1 : 1 , -1 : 1 : 1), (-1 : 1 , 0 : -1 : 1), (-1 : 1 , 0 : 0 : 1),
@@ -115,7 +115,7 @@ def enum_product_projective_rational_field(X, B):
         sage: PP.<x,y,z,u,v> = ProductProjectiveSpaces([2, 1], QQ)
         sage: X = PP.subscheme([x^2 + x*y + y*z, u*u - v*u])
         sage: from sage.schemes.product_projective.rational_point import \
-                enum_product_projective_rational_field
+        ....:   enum_product_projective_rational_field
         sage: enum_product_projective_rational_field(X, 4)
         [(-2 : 4 : 1 , 0 : 1), (-2 : 4 : 1 , 1 : 1), (-1 : 1 : 0 , 0 : 1),
          (-1 : 1 : 0 , 1 : 1), (-2/3 : -4/3 : 1 , 0 : 1), (-2/3 : -4/3 : 1 , 1 : 1),
@@ -173,6 +173,7 @@ def enum_product_projective_rational_field(X, B):
 
     return pts
 
+
 def enum_product_projective_number_field(X, **kwds):
     r"""
     Enumerates product projective points on scheme ``X`` defined over a number field.
@@ -191,20 +192,20 @@ def enum_product_projective_number_field(X, **kwds):
     This is an implementation of the revised algorithm (Algorithm 4) in
     [DK2013]_. Algorithm 5 is used for imaginary quadratic fields.
 
-    INPUT:
-
-    kwds:
+    INPUT: keyword arguments:
 
     - ``bound`` -- a real number
 
-    - ``tolerance`` -- a rational number in (0,1] used in doyle-krumm algorithm-4
+    - ``tolerance`` -- a rational number in (0,1] used in Doyle-Krumm
+      algorithm-4
 
-    - ``precision`` -- the precision to use for computing the elements of bounded height of number fields.
+    - ``precision`` -- the precision to use for computing the elements of
+      bounded height of number fields
 
     OUTPUT:
 
-    - a list containing the product projective points of ``X`` of
-      absolute height up to ``B``, sorted.
+    A list containing the product projective points of ``X`` of
+    absolute height up to ``B``, sorted.
 
     EXAMPLES::
 
@@ -214,7 +215,7 @@ def enum_product_projective_number_field(X, **kwds):
         sage: PP.<x,y,z,w> = ProductProjectiveSpaces([1, 1], K)
         sage: X = PP.subscheme([x^2 + 2*y^2])
         sage: from sage.schemes.product_projective.rational_point import \
-                enum_product_projective_number_field
+        ....:   enum_product_projective_number_field
         sage: enum_product_projective_number_field(X, bound=1.5)
         [(-v : 1 , -1 : 1), (-v : 1 , -v : 1), (-v : 1 , -1/2*v : 1),
          (-v : 1 , 0 : 1), (-v : 1 , 1/2*v : 1), (-v : 1 , v : 1),
@@ -247,25 +248,26 @@ def enum_product_projective_number_field(X, **kwds):
     pts.sort()
     return pts
 
+
 def enum_product_projective_finite_field(X):
     r"""
     Enumerates projective points on scheme ``X`` defined over a finite field.
 
     INPUT:
 
-    - ``X`` --  a scheme defined over a finite field or a set of abstract
-      rational points of such a scheme.
+    - ``X`` -- a scheme defined over a finite field or a set of abstract
+      rational points of such a scheme
 
     OUTPUT:
 
-    - a list containing the projective points of ``X`` over the finite field,
-      sorted.
+    A list containing the projective points of ``X`` over the finite field,
+    sorted.
 
     EXAMPLES::
 
         sage: PP.<x,y,z,w> = ProductProjectiveSpaces([1, 1], GF(3))
         sage: from sage.schemes.product_projective.rational_point import \
-                enum_product_projective_finite_field
+        ....:   enum_product_projective_finite_field
         sage: enum_product_projective_finite_field(PP)
         [(0 : 1 , 0 : 1), (0 : 1 , 1 : 0), (0 : 1 , 1 : 1),
          (0 : 1 , 2 : 1), (1 : 0 , 0 : 1), (1 : 0 , 1 : 0),
@@ -279,7 +281,7 @@ def enum_product_projective_finite_field(X):
         sage: PP.<x0,x1,x2,x3> = ProductProjectiveSpaces([1, 1], GF(17))
         sage: X = PP.subscheme([x0^2 + 2*x1^2])
         sage: from sage.schemes.product_projective.rational_point import \
-                enum_product_projective_finite_field
+        ....:   enum_product_projective_finite_field
         sage: len(enum_product_projective_finite_field(X))
         36
     """
@@ -306,7 +308,7 @@ def enum_product_projective_finite_field(X):
 
 def sieve(X, bound):
     r"""
-    Returns the list of all rational points on scheme
+    Return the list of all rational points on scheme
     ``X`` of height up to ``bound``.
 
     ALGORITHM:
@@ -326,12 +328,12 @@ def sieve(X, bound):
 
     - ``X`` -- a scheme with ambient space defined over a product of projective spaces
 
-    - ``bound`` -- a positive integer bound
+    - ``bound`` -- positive integer bound
 
     OUTPUT:
 
-    - a list containing the rational points of ``X`` of height
-      up to ``bound``, sorted
+    A list containing the rational points of ``X`` of height
+    up to ``bound``, sorted
 
     EXAMPLES::
 
@@ -368,7 +370,7 @@ def sieve(X, bound):
 
     def sufficient_primes(x):
         r"""
-        Returns a list of primes whose product is > `x`
+        Return a list of primes whose product is > `x`.
         """
         small_primes = [2,3]
         prod_primes = 6
