@@ -63,12 +63,12 @@ from sage.schemes.product_projective.subscheme import AlgebraicScheme_subscheme_
 
 def is_ProductProjectiveSpaces(x):
     r"""
-    Return True if ``x`` is a product of projective spaces.
+    Return ``True`` if ``x`` is a product of projective spaces.
 
     This is an ambient space defined by `\mathbb{P}^n_R \times \cdots \times \mathbb{P}^m_R`,
     where `R` is a ring and `n,\ldots, m\geq 0` are integers.
 
-    OUTPUT: Boolean.
+    OUTPUT: boolean
 
     EXAMPLES::
 
@@ -95,11 +95,11 @@ def ProductProjectiveSpaces(n, R=None, names='x'):
 
     INPUT:
 
-    - ``n`` -- a list of integers or a list of projective spaces
+    - ``n`` -- list of integers or a list of projective spaces
 
     - ``R`` -- a ring
 
-    - ``names`` -- a string or list of strings
+    - ``names`` -- string or list of strings
 
     EXAMPLES::
 
@@ -205,11 +205,11 @@ class ProductProjectiveSpaces_ring(AmbientSpace):
 
         INPUT:
 
-        - ``N`` -- a list or tuple of positive integers
+        - ``N`` -- list or tuple of positive integers
 
         - ``R`` -- a ring
 
-        - ``names`` -- a tuple or list of strings; this must either be a single
+        - ``names`` -- tuple or list of strings; this must either be a single
           variable name or the complete list of variables
 
         EXAMPLES::
@@ -293,8 +293,8 @@ class ProductProjectiveSpaces_ring(AmbientSpace):
         EXAMPLES::
 
             sage: latex(ProductProjectiveSpaces([1, 2, 3], ZZ, 'x'))
-            {\mathbf P}_{\Bold{Z}}^1 \times {\mathbf P}_{\Bold{Z}}^2 \times {\mathbf
-            P}_{\Bold{Z}}^3
+            {\mathbf P}_{\Bold{Z}}^{1} \times {\mathbf P}_{\Bold{Z}}^{2} \times
+             {\mathbf P}_{\Bold{Z}}^{3}
         """
         return " \\times ".join(PS._latex_() for PS in self)
 
@@ -322,7 +322,7 @@ class ProductProjectiveSpaces_ring(AmbientSpace):
 
         INPUT:
 
-        - ``i`` -- a positive integer
+        - ``i`` -- positive integer
 
         OUTPUT: a projective space
 
@@ -342,7 +342,7 @@ class ProductProjectiveSpaces_ring(AmbientSpace):
 
         - ``right`` -- a product of projective spaces
 
-        OUTPUT: Boolean
+        OUTPUT: boolean
 
         EXAMPLES::
 
@@ -364,7 +364,7 @@ class ProductProjectiveSpaces_ring(AmbientSpace):
 
         - ``other`` -- a product of projective spaces
 
-        OUTPUT: Boolean
+        OUTPUT: boolean
 
         EXAMPLES::
 
@@ -395,9 +395,11 @@ class ProductProjectiveSpaces_ring(AmbientSpace):
         """
         Return the Cartesian power of this space.
 
-        INPUT: ``m`` -- integer.
+        INPUT:
 
-        OUTPUT: product of projective spaces.
+        - ``m`` -- integer
+
+        OUTPUT: product of projective spaces
 
         EXAMPLES::
 
@@ -480,7 +482,7 @@ class ProductProjectiveSpaces_ring(AmbientSpace):
         r"""
         Return the components of this product of projective spaces.
 
-        OUTPUT: a list of projective spaces
+        OUTPUT: list of projective spaces
 
         EXAMPLES::
 
@@ -530,7 +532,7 @@ class ProductProjectiveSpaces_ring(AmbientSpace):
         r"""
         Return the relative dimension of the product of projective spaces.
 
-        OUTPUT: a list of positive integers
+        OUTPUT: list of positive integers
 
         EXAMPLES::
 
@@ -544,7 +546,7 @@ class ProductProjectiveSpaces_ring(AmbientSpace):
         r"""
         Return the absolute dimension of the product of projective spaces.
 
-        OUTPUT: a list of positive integers
+        OUTPUT: list of positive integers
 
         EXAMPLES::
 
@@ -563,9 +565,9 @@ class ProductProjectiveSpaces_ring(AmbientSpace):
 
     def num_components(self):
         r"""
-        Returns the number of components of this space.
+        Return the number of components of this space.
 
-        OUTPUT: an integer
+        OUTPUT: integer
 
         EXAMPLES::
 
@@ -582,7 +584,7 @@ class ProductProjectiveSpaces_ring(AmbientSpace):
         This is the number of variables in the coordinate ring of the
         projective space.
 
-        OUTPUT: an integer
+        OUTPUT: integer
 
         EXAMPLES::
 
@@ -598,9 +600,9 @@ class ProductProjectiveSpaces_ring(AmbientSpace):
 
         INPUT:
 
-        - ``v`` -- a list or tuple
+        - ``v`` -- list or tuple
 
-        OUTPUT: a list of lists
+        OUTPUT: list of lists
 
         EXAMPLES::
 
@@ -628,8 +630,8 @@ class ProductProjectiveSpaces_ring(AmbientSpace):
 
         - ``polynomial`` -- a polynomial in the coordinate_ring
 
-        OUTPUT: A tuple of integers, one for each projective space component. A
-        :class:`ValueError` is raised if the polynomial is not multihomogeneous.
+        OUTPUT: a tuple of integers, one for each projective space component. A
+        :exc:`ValueError` is raised if the polynomial is not multihomogeneous.
 
         EXAMPLES::
 
@@ -699,17 +701,16 @@ class ProductProjectiveSpaces_ring(AmbientSpace):
     def _validate(self, polynomials):
         r"""
         If ``polynomials`` is a tuple of valid polynomial functions on this space,
-        return ``polynomials``, otherwise raise a :class:`TypeError`.
+        return ``polynomials``, otherwise raise a :exc:`TypeError`.
 
         Since this is a product of projective spaces, the polynomials must be multi-homogeneous.
 
         INPUT:
 
-        - ``polynomials`` -- tuple of polynomials in the coordinate ring of this projective space.
+        - ``polynomials`` -- tuple of polynomials in the coordinate ring of
+          this projective space
 
-        OUTPUT:
-
-        - tuple of polynomials in the coordinate ring of this space.
+        OUTPUT: tuple of polynomials in the coordinate ring of this space
 
         EXAMPLES::
 
@@ -750,7 +751,7 @@ class ProductProjectiveSpaces_ring(AmbientSpace):
     def _check_satisfies_equations(self, v):
         """
         Return ``True`` if ``v`` defines a point on the scheme this space;
-        raise a :class:`TypeError` otherwise.
+        raise a :exc:`TypeError` otherwise.
 
         EXAMPLES::
 
@@ -810,13 +811,11 @@ class ProductProjectiveSpaces_ring(AmbientSpace):
 
     def _an_element_(self):
         r"""
-        Returns a (preferably typical) element of this space.
+        Return a (preferably typical) element of this space.
 
         This is used both for illustration and testing purposes.
 
-        OUTPUT:
-
-        A point in the this projective space.
+        OUTPUT: a point in the this projective space
 
         EXAMPLES::
 
@@ -834,11 +833,9 @@ class ProductProjectiveSpaces_ring(AmbientSpace):
 
         INPUT:
 
-        - ``X`` -- a list or tuple of equations
+        - ``X`` -- list or tuple of equations
 
-        OUTPUT:
-
-        :class:`AlgebraicScheme_subscheme_projective_cartesian_product`.
+        OUTPUT: :class:`AlgebraicScheme_subscheme_projective_cartesian_product`
 
         EXAMPLES::
 
@@ -870,15 +867,14 @@ class ProductProjectiveSpaces_ring(AmbientSpace):
 
     def change_ring(self, R):
         r"""
-        Return a product of projective spaces over a ring ``R`` and otherwise the same as this projective space.
+        Return a product of projective spaces over a ring ``R`` and otherwise
+        the same as this projective space.
 
         INPUT:
 
         - ``R`` -- commutative ring or morphism
 
-        OUTPUT:
-
-        - Product of projective spaces over ``R``.
+        OUTPUT: product of projective spaces over ``R``
 
         .. NOTE::
 
@@ -897,14 +893,15 @@ class ProductProjectiveSpaces_ring(AmbientSpace):
 
     def affine_patch(self, I, return_embedding=False):
         r"""
-        Return the `I^{th}` affine patch of this projective space product
+        Return the `I`-th affine patch of this projective space product
         where ``I`` is a multi-index.
 
         INPUT:
 
-        - ``I`` -- a list or tuple of positive integers.
+        - ``I`` -- list or tuple of positive integers
 
-        - ``return_embedding`` -- Boolean, if true the projective embedding is also returned.
+        - ``return_embedding`` -- boolean; if ``True`` the projective embedding
+          is also returned
 
         OUTPUT:
 
@@ -966,14 +963,14 @@ class ProductProjectiveSpaces_ring(AmbientSpace):
 
         INPUT:
 
-        -  ``PP`` -- (default: ``None``) ambient image projective space;
-            this is constructed if it is not given.
+        - ``PP`` -- (default: ``None``) ambient image projective space;
+            this is constructed if it is not given
 
-        - ``var`` -- string, variable name of the image projective space, default `u` (optional).
+        - ``var`` -- string (default: ``'u'``); variable name of the image
+          projective space
 
-        OUTPUT:
-
-        Hom -- from this space to the appropriate subscheme of projective space.
+        OUTPUT: Hom; from this space to the appropriate subscheme of projective
+        space
 
         .. TODO::
 
@@ -1083,6 +1080,7 @@ class ProductProjectiveSpaces_ring(AmbientSpace):
 
         return phi
 
+
 class ProductProjectiveSpaces_field(ProductProjectiveSpaces_ring):
     def _point(self, *args, **kwds):
         """
@@ -1117,13 +1115,13 @@ class ProductProjectiveSpaces_field(ProductProjectiveSpaces_ring):
 
     def points_of_bounded_height(self, **kwds):
         r"""
-        Returns an iterator of the points in this product of projective spaces with the absolute heights of the
-        components of at most the given bound.
+        Return an iterator of the points in this product of projective spaces
+        with the absolute heights of the components of at most the given bound.
 
-        Bound check is strict for the rational field. Requires the base field of this space to be a number field.
-        Uses the
-        Doyle-Krumm algorithm 4 (algorithm 5 for imaginary quadratic) for
-        computing algebraic numbers up to a given height [DK2013]_.
+        Bound check is strict for the rational field. Requires the base field
+        of this space to be a number field. Uses the Doyle-Krumm algorithm 4
+        (algorithm 5 for imaginary quadratic) for computing algebraic numbers
+        up to a given height [DK2013]_.
 
         The algorithm requires floating point arithmetic, so the user is
         allowed to specify the precision for such calculations.
@@ -1136,9 +1134,11 @@ class ProductProjectiveSpaces_field(ProductProjectiveSpaces_ring):
 
         - ``bound`` -- a real number
 
-        - ``tolerance`` -- a rational number in (0,1] used in doyle-krumm algorithm-4
+        - ``tolerance`` -- a rational number in (0,1] used in Doyle-Krumm
+          algorithm-4
 
-        - ``precision`` -- the precision to use for computing the elements of bounded height of number fields.
+        - ``precision`` -- the precision to use for computing the elements of
+          bounded height of number fields
 
         OUTPUT: an iterator of points in this space
 
@@ -1221,6 +1221,7 @@ class ProductProjectiveSpaces_field(ProductProjectiveSpaces_ring):
                     P[dim_prefix[i] + j] = pt[j]
                 i += 1
 
+
 class ProductProjectiveSpaces_finite_field(ProductProjectiveSpaces_field):
     def _point(self, *args, **kwds):
         r"""
@@ -1238,7 +1239,7 @@ class ProductProjectiveSpaces_finite_field(ProductProjectiveSpaces_field):
 
     def __iter__(self):
         r"""
-        Returns iterator over the elements of this product of projective spaces.
+        Return an iterator over the elements of this product of projective spaces.
 
         EXAMPLES::
 
