@@ -100,7 +100,7 @@ from sage.rings.fraction_field import FractionField
 from sage.rings.integer import Integer
 from sage.rings.integer_ring import ZZ
 from sage.rings.polynomial.multi_polynomial_ring import MPolynomialRing_base
-from sage.rings.polynomial.polynomial_ring import PolynomialRing_general
+from sage.rings.polynomial.polynomial_ring import PolynomialRing_generic
 from sage.rings.polynomial.polynomial_ring_constructor import PolynomialRing
 from sage.rings.rational_field import QQ, RationalField
 from sage.schemes.generic.ambient_space import AmbientSpace
@@ -248,7 +248,7 @@ def ProjectiveSpace(n, R=None, names=None):
         sage: P.gens() == R.gens()
         True
     """
-    if isinstance(n, (MPolynomialRing_base, PolynomialRing_general)) and R is None:
+    if isinstance(n, (MPolynomialRing_base, PolynomialRing_generic)) and R is None:
         if names is not None:
             # Check for the case that the user provided a variable name
             # That does not match what we wanted to use from R
@@ -982,9 +982,9 @@ class ProjectiveSpace_ring(UniqueRepresentation, AmbientSpace):
         TESTS::
 
             sage: TestSuite(X).run(skip=["_test_an_element", "_test_elements",\
-            "_test_elements_eq", "_test_some_elements", "_test_elements_eq_reflexive",\
-            "_test_elements_eq_symmetric", "_test_elements_eq_transitive",\
-            "_test_elements_neq"])
+            ....: "_test_elements_eq", "_test_some_elements", "_test_elements_eq_reflexive",\
+            ....: "_test_elements_eq_symmetric", "_test_elements_eq_transitive",\
+            ....: "_test_elements_neq"])
         """
         R = self.base_ring()
         if R.is_field() and R.is_exact():
