@@ -12,7 +12,7 @@ AUTHORS:
 #  Distributed under the terms of the GNU General Public License (GPL)
 #  as published by the Free Software Foundation; either version 2 of
 #  the License, or (at your option) any later version.
-#                  http://www.gnu.org/licenses/
+#                  https://www.gnu.org/licenses/
 # ******************************************************************************
 
 import itertools
@@ -95,7 +95,6 @@ class TensorFreeSubmodule_sym(TensorFreeModule):
         'T^{2,3}(M)⊗T^{6,7}(M*)⊗Sym^{0,1}(M)⊗ASym^{4,5}(M*)'
         sage: latex(T)
         T^{\{2,3\}}(M) \otimes T^{\{6,7\}}(M^*) \otimes \mathrm{Sym}^{\{0,1\}}(M) \otimes \mathrm{ASym}^{\{4,5\}}(M^*)
-
     """
     def __init__(self, fmodule, tensor_type, name=None, latex_name=None,
                  sym=None, antisym=None, *, category=None, ambient=None):
@@ -211,7 +210,6 @@ class TensorFreeSubmodule_sym(TensorFreeModule):
             Free module of fully symmetric type-(2,0) tensors on the Rank-3 free module M over the Integer Ring
             sage: c = Sym2M._basis_sym(); c
             Fully symmetric 2-indices components w.r.t. (0, 1, 2)
-
         """
         frame = tuple(self.base_module().irange())
         # Need to call _element_constructor_ explicitly, or the passed arguments are dropped
@@ -228,7 +226,6 @@ class TensorFreeSubmodule_sym(TensorFreeModule):
             sage: Sym2M = M.tensor_module(2, 0, sym=range(2)); Sym2M
             Free module of fully symmetric type-(2,0) tensors
              on the Rank-3 free module M over the Integer Ring
-
         """
         prefix, suffix = self._basis_sym()._repr_symmetry()
         return "Free module of {}type-({},{}) tensors on the {}{}".format(
@@ -240,7 +237,7 @@ class TensorFreeSubmodule_sym(TensorFreeModule):
 
         INPUT:
 
-        - ``coarser_comp``, ``finer_comp``: :class:`~sage.tensor.modules.comp.Components`
+        - ``coarser_comp``, ``finer_comp`` -- :class:`~sage.tensor.modules.comp.Components`
 
         EXAMPLES::
 
@@ -310,9 +307,7 @@ class TensorFreeSubmodule_sym(TensorFreeModule):
         coarser_sym, coarser_antisym = sym_antisym(coarser_comp)
         if not is_coarsening_of(coarser_sym, finer_sym):
             return False
-        if not is_coarsening_of(coarser_antisym, finer_antisym):
-            return False
-        return True
+        return is_coarsening_of(coarser_antisym, finer_antisym)
 
     def _element_constructor_(self, comp=[], basis=None, name=None,
                               latex_name=None, sym=None, antisym=None):
@@ -386,7 +381,6 @@ class TensorFreeSubmodule_sym(TensorFreeModule):
             False
             sage: all(S.is_submodule(T60M) for S in (Sym0123x45M, Sym012x345M, Sym012345M))
             True
-
         """
         if super().is_submodule(other):
             return True
